-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: Common/src/tedw_app/amx/fixpack2/etl/sql/amx_c05_s020_parsing.db2, tmnt_etl, tmnt_5.1.1_FP06, 512ITMFP01_0616
-- #   Revision: 1.11
-- #   Date: 4/7/04 12:17:09
-- ############################################################################

----------------------------------------------------------
-- Update ETL1_STATUS
------------------------------------------------------------
--#EXECUTE_AT_TARGET
update TWG.Extract_Control set Extctl_from_Dttm= current timestamp  - current timezone where EXTCTL_TARGET='AMX_STATUS_S020_PARSING_STEP';

-- //////////////////
-- //////// RmProfiles
-- //////////////////
--
-- We update the Category field of Stage_RmProfiles table in order
-- to support the different categories used by the ITM's Resource Models
--
update AMX.Stage_RmProfiles s
set s.category = (select
   distinct c1.category_convert
 from
  AMX.Categories_convert c1
 where
  c1.category=s.category)
where upper(s.category) in (select distinct upper(c2.category) from AMX.Categories_Convert c2)
;

-----------------------------------
-- Reconstitute the staging tables
-- from the permanent ITM tables
-----------------------------------

-- //////////////////
-- //////// Instances
-- //////////////////

--#IGNORE_ERROR
drop table AMX.stage_instances
;
create table AMX.stage_instances (
  instance_key  varchar(2096),
  iid           bigint not null,
  rcid          bigint not null,
  eid           integer not null,
    primary key (iid,eid)
);
--
-- insert the instances from the extract stage1_instances;
-- change the end delimiter with @@
--
insert into AMX.stage_instances
select
 case when length(rtrim(instance_key)) = 0
 then
 '@@'
 else
 substr(rtrim(instance_key),1,length(rtrim(instance_key))-1) concat '@@'
 end as instance_key,
 iid,
 rcid,
 eid
from
 AMX.stage1_instances
;


-- ///////////////////
-- //////// Categories
-- ///////////////////

--#IGNORE_ERROR
drop table AMX.stage_categories
;
create table AMX.stage_categories (
  name  varchar(128),
  rcid  bigint not null,
  cid   bigint not null,
  eid   integer not null,
    primary key (cid,eid)
);
--
-- insert the categories from the extract stage1_categories
--
insert into AMX.Stage_categories
select
 rtrim(ltrim(r.resource)) concat '.' concat c.name as name,
 c.rcid as rcid,
 c.cid as cid,
 c.eid as eid
from
 AMX.Stage1_categories c,
 AMX.Stage1_Resources r
where
 locate('.',c.name) = 0 and
 c.rcid = r.rcid and
 c.eid = r.eid
group by
 r.resource, c.eid, c.cid, c.name, c.rcid
;

insert into AMX.Stage_Categories
select
 c.name as name,
 c.rcid as rcid,
 c.cid as cid,
 c.eid as eid
from
 AMX.Stage1_categories c
where
 locate('.',c.name) > 0
group by
 c.eid, c.cid, c.name, c.rcid
;


-- ////////////////
-- ////// Resources
-- ////////////////

--#IGNORE_ERROR
DROP TABLE AMX.stage2_resources
;
create table AMX.stage2_resources (
  resource  varchar(128),
  context   varchar(64),
  rcid      bigint not null,
  id        bigint not null,
  eid       integer not null,
    primary key (rcid, eid)
);
--
-- insert the resources  from the extract stage1_resources
--
insert into AMX.stage2_resources
select
 replace(resource,' ',''),
 context,
 rcid,
 id,
 eid
from
  AMX.stage1_resources
;


--#IGNORE_ERROR
DROP TABLE AMX.stage_resources
;
create table AMX.stage_resources (
  resource  varchar(128),
  context   varchar(64),
  rcid      bigint not null,
  id        bigint not null,
  eid       integer not null,
  Msrc_cd   char(6) not null,
    primary key (rcid, eid)
);

insert into AMX.Stage_resources
select
r.resource,
r.context,
r.rcid,
r.id,
r.eid,
t.msrc_cd
from
AMX.Stage2_resources r,
AMX.Stage_rmprofiles p,
AMX.Category_transl t
where
p.id=r.id and
p.category=t.category and
p.eid=r.eid
group by
r.resource,r.context,r.rcid,r.id,r.eid,t.msrc_cd
;



------------------------------------------------------
-- ///////////////////// PARSING /////////////////////
------------------------------------------------------

------------------------------------------------------
-- ////////////////////// key1 ///////////////////////
------------------------------------------------------

declare global temporary table key1 (
  instance_key  varchar(2096),
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key1      varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key1
select
 CASE
 when LOCATE(';',instance_key) -1 > 0
 then
 substr(instance_key,LOCATE(';',instance_key)+1) concat '@@'
 else
 '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
  when LOCATE(';',instance_key) -1 < 0
  then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
  else substr(instance_key,1,LOCATE(';',instance_key) - 1)
 END as key1
from
 AMX.stage_instances
;

-- select substr(instance_key,1,70),substr(key1,1,508) from session.key1;

declare global temporary table key1_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key1_typ  varchar(508),
  key1_val  varchar(254)
)
with replace on commit preserve rows not logged
;

-- we need a safest approach for the calcualtion of the key1_typ
-- and key1_val fields, because the substr() function fails if
-- the LOCATE('=',key1) returns 0
insert into session.key1_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key1 is not null and LOCATE('=',key1) > 0)
 then
 substr(key1,1,LOCATE('=',key1)-1)
 else
 null
 END as key1_typ,
 CASE
 when (key1 is not null and LOCATE('=',key1) > 0)
 then
 substr(key1,LOCATE('=',key1)+1)
 else
 null
 END as key1_val
from
 session.key1
;

-- select key1_typ, key1_val from session.key1_parsed;

------------------------------------------------------
-- ////////////////////// key2 ///////////////////////
------------------------------------------------------

declare global temporary table key2 (
  instance_key  varchar(2096),
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key2      varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key2
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key2
from
 session.key1
;

-- select substr(instance_key,1,70),substr(key2,1,508) from session.key2;

declare global temporary table key2_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key2_typ  varchar(508),
  key2_val  varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key2_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key2 is not null and LOCATE('=',key2) > 0)
 then
 substr(key2,1,LOCATE('=',key2)-1)
 else
 null
 end as key2_typ,
 CASE
 when (key2 is not null and LOCATE('=',key2) > 0)
 then
 substr(key2,LOCATE('=',key2)+1)
 else
 null
 end as key2_val
from
 session.key2
;

-- select key2_typ, key2_val from session.key2_parsed;

------------------------------------------------------
-- ////////////////////// key3 ///////////////////////
------------------------------------------------------

declare global temporary table key3 (
  instance_key  varchar(2096),
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key3      varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key3
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key3
from
 session.key2
;

declare global temporary table key3_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key3_typ  varchar(508),
  key3_val  varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.key3_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key3 is not null and LOCATE('=',key3) > 0)
 then
 substr(key3,1,LOCATE('=',key3)-1)
 else
 null
 end as key3_typ,
 CASE
 when (key3 is not null and LOCATE('=',key3) > 0)
 then
 substr(key3,LOCATE('=',key3)+1)
 else
 null
 end as key3_val
from
 session.key3
;

-- select key3_typ, key3_val from session.key3_parsed;

------------------------------------------------------
-- ////////////////////// key4 ///////////////////////
------------------------------------------------------

declare global temporary table key4 (
  instance_key  varchar(2096),
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key4          varchar(750)
)
with replace on commit preserve rows not logged
;


insert into session.key4
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key4
from
 session.key3
;

declare global temporary table key4_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key4_typ  varchar(508),
  key4_val  varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key4_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key4 is not null and LOCATE('=',key4) > 0)
 then
 substr(key4,1,LOCATE('=',key4)-1)
 else
 null
 end as key4_typ,
 CASE
 when (key4 is not null and LOCATE('=',key4) > 0)
 then
 substr(key4,LOCATE('=',key4)+1)
 else
 null
 end as key4_val
from
 session.key4
;

-- select key4_typ, key4_val from session.key4_parsed;

------------------------------------------------------
-- ////////////////////// key5 ///////////////////////
------------------------------------------------------

declare global temporary table key5 (
  instance_key  varchar(2096),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  key5          varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key5
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key5
from
 session.key4
;

declare global temporary table key5_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key5_typ  varchar(508),
  key5_val  varchar(254)
  )
with replace on commit preserve rows not logged
;

insert into session.key5_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key5 is not null and LOCATE('=',key5) > 0)
 then
 substr(key5,1,LOCATE('=',key5)-1)
 else
 null
 end as key5_typ,
 CASE
 when (key5 is not null and LOCATE('=',key5) > 0)
 then
 substr(key5,LOCATE('=',key5)+1)
 else
 null
 end as key5_val
from
 session.key5
;

-- select key5_typ, key5_val from session.key5_parsed;

------------------------------------------------------
-- ////////////////////// key6 ///////////////////////
------------------------------------------------------

declare global temporary table key6 (
  instance_key  varchar(2096),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  key6          varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key6
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key6
from
 session.key5
;

declare global temporary table key6_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key6_typ  varchar(508),
  key6_val  varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key6_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key6 is not null and LOCATE('=',key6) > 0)
 then
 substr(key6,1,LOCATE('=',key6)-1)
 else
 null
 end as key6_typ,
 CASE
 when (key6 is not null and LOCATE('=',key6) > 0)
 then
 substr(key6,LOCATE('=',key6)+1)
 else
 null
 end as key6_val
from
 session.key6
 ;

-- select key6_typ, key6_val from session.key6_parsed;

------------------------------------------------------
-- ////////////////////// key7 ///////////////////////
------------------------------------------------------

declare global temporary table key7 (
  instance_key  varchar(2096),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  key7          varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key7
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key7
from
 session.key6
 ;

declare global temporary table key7_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key7_typ  varchar(508),
  key7_val  varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key7_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key7 is not null and LOCATE('=',key7) > 0)
 then
 substr(key7,1,LOCATE('=',key7)-1)
 else
 null
 end as key7_typ,
 CASE
 when (key7 is not null and LOCATE('=',key7) > 0)
 then
 substr(key7,LOCATE('=',key7)+1)
 else
 null
 end as key7_val
from
 session.key7
 ;

-- select key7_typ, key7_val from session.key7_parsed;

------------------------------------------------------
-- ////////////////////// key8 ///////////////////////
------------------------------------------------------

declare global temporary table key8 (
  instance_key  varchar(2096),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  key8          varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key8
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key8
from
 session.key7
;

declare global temporary table key8_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key8_typ  varchar(508),
  key8_val  varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key8_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key8 is not null and LOCATE('=',key8) > 0)
 then
 substr(key8,1,LOCATE('=',key8)-1)
 else
 null
 end as key8_typ,
 CASE
 when (key8 is not null and LOCATE('=',key8) > 0)
 then
 substr(key8,LOCATE('=',key8)+1)
 else
 null
 end as key8_val
from
 session.key8
;

-- select key8_typ, key8_val from session.key8_parsed;

------------------------------------------------------
-- ////////////////////// key9 ///////////////////////
------------------------------------------------------

declare global temporary table key9 (
  instance_key  varchar(2096),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  key9          varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key9
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key9
from
 session.key8
 ;

declare global temporary table key9_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key9_typ  varchar(508),
  key9_val  varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key9_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key9 is not null and LOCATE('=',key9) > 0)
 then
 substr(key9,1,LOCATE('=',key9)-1)
 else
 null
 end as key9_typ,
 CASE
 when (key9 is not null and LOCATE('=',key9) > 0)
 then
 substr(key9,LOCATE('=',key9)+1)
 else
 null
 end as key9_val
from
 session.key9
 ;

-- select key9_typ, key9_val from session.key9_parsed;

------------------------------------------------------
-- ////////////////////// key10 ///////////////////////
------------------------------------------------------

declare global temporary table key10 (
  instance_key  varchar(2096),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  key10         varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key10
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key10
from
 session.key9
 ;

declare global temporary table key10_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key10_typ varchar(508),
  key10_val varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key10_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key10 is not null and LOCATE('=',key10) > 0)
 then
 substr(key10,1,LOCATE('=',key10)-1)
 else
 null
 end as key10_typ,
 CASE
 when (key10 is not null and LOCATE('=',key10) > 0)
 then
 substr(key10,LOCATE('=',key10)+1)
 else
 null
 end as key10_val
from
 session.key10
 ;

-- select key10_typ, key10_val from session.key10_parsed;

------------------------------------------------------
-- ////////////////////// key11 ///////////////////////
------------------------------------------------------

declare global temporary table key11 (
  instance_key  varchar(2096),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  key11         varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key11
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key11
from
 session.key10
 ;

declare global temporary table key11_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key11_typ varchar(508),
  key11_val varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key11_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key11 is not null and LOCATE('=',key11) > 0)
 then
 substr(key11,1,LOCATE('=',key11)-1)
 else
 null
 end as key11_typ,
 CASE
 when (key11 is not null and LOCATE('=',key11) > 0)
 then
 substr(key11,LOCATE('=',key11)+1)
 else
 null
 end as key11_val
from
 session.key11
 ;

-- select key11_typ, key11_val from session.key11_parsed;

------------------------------------------------------
-- ////////////////////// key12 ///////////////////////
------------------------------------------------------

declare global temporary table key12 (
  instance_key  varchar(2096),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  key12         varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key12
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key12
from
 session.key11
 ;

declare global temporary table key12_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key12_typ varchar(508),
  key12_val varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key12_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key12 is not null and LOCATE('=',key12) > 0)
 then
 substr(key12,1,LOCATE('=',key12)-1)
 else
 null
 end as key12_typ,
 CASE
 when (key12 is not null and LOCATE('=',key12) > 0)
 then
 substr(key12,LOCATE('=',key12)+1)
 else
 null
 end as key12_val
from
 session.key12
 ;

-- select key12_typ, key12_val from session.key12_parsed;

------------------------------------------------------
-- ////////////////////// key13 ///////////////////////
------------------------------------------------------

declare global temporary table key13 (
  instance_key  varchar(2096),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  key13         varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key13
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key13
from
 session.key12
 ;

declare global temporary table key13_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key13_typ varchar(508),
  key13_val varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key13_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key13 is not null and LOCATE('=',key13) > 0)
 then
 substr(key13,1,LOCATE('=',key13)-1)
 else
 null
 end as key13_typ,
 CASE
 when (key13 is not null and LOCATE('=',key13) > 0)
 then
 substr(key13,LOCATE('=',key13)+1)
 else
 null
 end as key13_val
from
 session.key13
 ;

-- select key13_typ, key13_val from session.key13_parsed;

------------------------------------------------------
-- ////////////////////// key14 ///////////////////////
------------------------------------------------------

declare global temporary table key14 (
  instance_key  varchar(2096),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  key14         varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key14
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key14
from
 session.key13
;

declare global temporary table key14_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key14_typ varchar(508),
  key14_val varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key14_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key14 is not null and LOCATE('=',key14) > 0)
 then
 substr(key14,1,LOCATE('=',key14)-1)
 else
 null
 end as key14_typ,
 CASE
 when (key14 is not null and LOCATE('=',key14) > 0)
 then
 substr(key14,LOCATE('=',key14)+1)
 else
 null
 end as key14_val
from
 session.key14
 ;

-- select key14_typ, key14_val from session.key14_parsed;

------------------------------------------------------
-- ////////////////////// key15 //////////////////////
------------------------------------------------------

declare global temporary table key15 (
  instance_key  varchar(2096),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  key15         varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key15
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key15
from
 session.key14
 ;

declare global temporary table key15_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key15_typ varchar(508),
  key15_val varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key15_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key15 is not null and LOCATE('=',key15) > 0)
 then
 substr(key15,1,LOCATE('=',key15)-1)
 else
 null
 end as key15_typ,
 CASE
 when (key15 is not null and LOCATE('=',key15) > 0)
 then
 substr(key15,LOCATE('=',key15)+1)
 else
 null
 end as key15_val
from
 session.key15
 ;

-- select key15_typ, key15_val from session.key15_parsed;

------------------------------------------------------
-- ////////////////////// key16 //////////////////////
------------------------------------------------------

declare global temporary table key16 (
  instance_key  varchar(2096),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  key16         varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key16
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key16
from
 session.key15
 ;

declare global temporary table key16_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key16_typ varchar(508),
  key16_val varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key16_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key16 is not null and LOCATE('=',key16) > 0)
 then
 substr(key16,1,LOCATE('=',key16)-1)
 else
 null
 end as key16_typ,
 CASE
 when (key16 is not null and LOCATE('=',key16) > 0)
 then
 substr(key16,LOCATE('=',key16)+1)
 else
 null
 end as key16_val
from
 session.key16
 ;

-- select key16_typ, key16_val from session.key16_parsed;

------------------------------------------------------
-- ////////////////////// key17 //////////////////////
------------------------------------------------------

declare global temporary table key17 (
  instance_key  varchar(2096),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  key17         varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key17
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key17
from
 session.key16
 ;

declare global temporary table key17_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key17_typ varchar(508),
  key17_val varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key17_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key17 is not null and LOCATE('=',key17) > 0)
 then
 substr(key17,1,LOCATE('=',key17)-1)
 else
 null
 end as key17_typ,
 CASE
 when (key17 is not null and LOCATE('=',key17) > 0)
 then
 substr(key17,LOCATE('=',key17)+1)
 else
 null
 end as key17_val
from
 session.key17
 ;

-- select key17_typ, key17_val from session.key17_parsed;

------------------------------------------------------
-- ////////////////////// key18 //////////////////////
------------------------------------------------------

declare global temporary table key18 (
  instance_key  varchar(2096),
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key18     varchar(750)
  )
with replace on commit preserve rows not logged
;

insert into session.key18
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key18
from
 session.key17
 ;

declare global temporary table key18_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key18_typ varchar(508),
  key18_val varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key18_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key18 is not null and LOCATE('=',key18) > 0)
 then
 substr(key18,1,LOCATE('=',key18)-1)
 else
 null
 end as key18_typ,
 CASE
 when (key18 is not null and LOCATE('=',key18) > 0)
 then
 substr(key18,LOCATE('=',key18)+1)
 else
 null
 end as key18_val
from
 session.key18
 ;

-- select key18_typ, key18_val from session.key18_parsed;

------------------------------------------------------
-- ////////////////////// key19 //////////////////////
------------------------------------------------------

declare global temporary table key19 (
  instance_key  varchar(2096),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  key19         varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key19
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key19
from
 session.key18
 ;

declare global temporary table key19_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key19_typ varchar(508),
  key19_val varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key19_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key19 is not null and LOCATE('=',key19) > 0)
 then
 substr(key19,1,LOCATE('=',key19)-1)
 else
 null
 end as key19_typ,
 CASE
 when (key19 is not null and LOCATE('=',key19) > 0)
 then
 substr(key19,LOCATE('=',key19)+1)
 else
 null
 end as key19_val
from
 session.key19
 ;

-- select key19_typ, key19_val from session.key19_parsed;

------------------------------------------------------
-- ////////////////////// key20 //////////////////////
------------------------------------------------------

declare global temporary table key20 (
  instance_key  varchar(2096),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  key20         varchar(750)
)
with replace on commit preserve rows not logged
;

insert into session.key20
select
 CASE
 when instance_key != '@@' and LOCATE(';',instance_key) -1 > 0
 then substr(instance_key,LOCATE(';',instance_key)+1)
 else
  '@@'
 end as instance_key,
 iid,
 eid,
 rcid,
 CASE
 when instance_key='@@'
 then
 null
 else CASE
      when LOCATE(';',instance_key) -1 < 0
      then substr(instance_key,1,LOCATE('@@',instance_key) - 1)
      else substr(instance_key,1,LOCATE(';',instance_key) - 1)
      END
 END as key20
from
 session.key19
 ;

declare global temporary table key20_parsed (
  iid       bigint,
  eid       integer,
  rcid      bigint,
  key20_typ varchar(508),
  key20_val varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.key20_parsed
select
 iid,
 eid,
 rcid,
 CASE
 when (key20 is not null and LOCATE('=',key20) > 0)
 then
 substr(key20,1,LOCATE('=',key20)-1)
 else
 null
 end as key20_typ,
 CASE
 when (key20 is not null and LOCATE('=',key20) > 0)
 then
 substr(key20,LOCATE('=',key20)+1)
 else
 null
 end as key20_val
from
 session.key20
 ;

-- select key20_typ, key20_val from session.key20_parsed;

------------------------------------------------------
-- ///////////////////////////////////////////////////
-- ///////////////// stage_key_parsed ////////////////
-- ///////////////////////////////////////////////////
------------------------------------------------------

--#IGNORE_ERROR
drop table AMX.stage_key_parsed
;
create table AMX.stage_key_parsed (
  key_typ   varchar(254) not null,
  key_val   varchar(254),
  position  integer not null,
  iid       bigint not null,
  eid       integer not null,
  rcid      bigint not null,
  primary key (position,iid,eid,rcid)
  )
;

insert into AMX.stage_key_parsed
select
 key1_typ,
 key1_val,
 1,
 iid,
 eid,
 rcid
from
 session.key1_parsed
where
 key1_typ is not null and
 locate ('.',key1_typ) > 0 and
 key1_val is not null
group by
 iid, eid, rcid, key1_typ, key1_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key1_typ,
 k1.key1_val,
 1,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key1_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key1_typ is not null and
 locate ('.',key1_typ) = 0 and
 key1_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key1_typ, k1.key1_val
;

insert into AMX.stage_key_parsed
select
 key2_typ,
 key2_val,
 2,
 iid,
 eid,
 rcid
from
 session.key2_parsed
where
 key2_typ is not null and
 locate ('.',key2_typ) > 0 and
 key2_val is not null
group by
 iid, eid, rcid, key2_typ, key2_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key2_typ,
 k1.key2_val,
 2,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key2_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key2_typ is not null and
 locate ('.',key2_typ) = 0 and
 key2_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key2_typ, k1.key2_val
;

insert into AMX.stage_key_parsed
select
 key3_typ,
 key3_val,
 3,
 iid,
 eid,
 rcid
from
 session.key3_parsed
where
 key3_typ is not null and
 locate ('.',key3_typ) > 0 and
 key3_val is not null
group by
 iid, eid, rcid, key3_typ, key3_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key3_typ,
 k1.key3_val,
 3,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key3_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key3_typ is not null and
 locate ('.',key3_typ) = 0 and
 key3_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key3_typ, k1.key3_val
;

insert into AMX.stage_key_parsed
select
 key4_typ,
 key4_val,
 4,
 iid,
 eid,
 rcid
from
 session.key4_parsed
where
 key4_typ is not null and
 locate ('.',key4_typ) > 0 and
 key4_val is not null
group by
 iid, eid, rcid, key4_typ, key4_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key4_typ,
 k1.key4_val,
 4,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key4_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key4_typ is not null and
 locate ('.',key4_typ) = 0 and
 key4_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key4_typ, k1.key4_val
;

insert into AMX.stage_key_parsed
select
 key5_typ,
 key5_val,
 5,
 iid,
 eid,
 rcid
from
 session.key5_parsed
where
 key5_typ is not null and
 locate ('.',key5_typ) > 0 and
 key5_val is not null
group by
 iid, eid, rcid, key5_typ, key5_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key5_typ,
 k1.key5_val,
 5,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key5_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key5_typ is not null and
 locate ('.',key5_typ) = 0 and
 key5_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key5_typ, k1.key5_val
;

insert into AMX.stage_key_parsed
select
 key6_typ,
 key6_val,
 6,
 iid,
 eid,
 rcid
from
 session.key6_parsed
where
 key6_typ is not null and
 locate ('.',key6_typ) > 0 and
 key6_val is not null
group by
 iid, eid, rcid, key6_typ, key6_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key6_typ,
 k1.key6_val,
 6,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key6_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key6_typ is not null and
 locate ('.',key6_typ) = 0 and
 key6_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key6_typ, k1.key6_val
;

insert into AMX.stage_key_parsed
select
 key7_typ,
 key7_val,
 7,
 iid,
 eid,
 rcid
from
 session.key7_parsed
where
 key7_typ is not null and
 locate ('.',key7_typ) > 0 and
 key7_val is not null
group by
 iid, eid, rcid, key7_typ, key7_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key7_typ,
 k1.key7_val,
 7,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key7_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key7_typ is not null and
 locate ('.',key7_typ) = 0 and
 key7_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key7_typ, k1.key7_val
;

insert into AMX.stage_key_parsed
select
 key8_typ,
 key8_val,
 8,
 iid,
 eid,
 rcid
from
 session.key8_parsed
where
 key8_typ is not null and
 locate ('.',key8_typ) > 0 and
 key8_val is not null
group by
 iid, eid, rcid, key8_typ, key8_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key8_typ,
 k1.key8_val,
 8,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key8_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key8_typ is not null and
 locate ('.',key8_typ) = 0 and
 key8_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key8_typ, k1.key8_val
;

insert into AMX.stage_key_parsed
select
 key9_typ,
 key9_val,
 9,
 iid,
 eid,
 rcid
from
 session.key9_parsed
where
 key9_typ is not null and
 locate ('.',key9_typ) > 0 and
 key9_val is not null
group by
 iid, eid, rcid, key9_typ, key9_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key9_typ,
 k1.key9_val,
 9,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key9_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key9_typ is not null and
 locate ('.',key9_typ) = 0 and
 key9_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key9_typ, k1.key9_val
;

insert into AMX.stage_key_parsed
select
 key10_typ,
 key10_val,
 10,
 iid,
 eid,
 rcid
from
 session.key10_parsed
where
 key10_typ is not null and
 locate ('.',key10_typ) > 0 and
 key10_val is not null
group by
 iid, eid, rcid, key10_typ, key10_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key10_typ,
 k1.key10_val,
 10,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key10_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key10_typ is not null and
 locate ('.',key10_typ) = 0 and
 key10_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key10_typ, k1.key10_val
;

insert into AMX.stage_key_parsed
select
 key11_typ,
 key11_val,
 11,
 iid,
 eid,
 rcid
from
 session.key11_parsed
where
 key11_typ is not null and
 locate ('.',key11_typ) > 0 and
 key11_val is not null
group by
 iid, eid, rcid, key11_typ, key11_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key11_typ,
 k1.key11_val,
 11,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key11_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key11_typ is not null and
 locate ('.',key11_typ) = 0 and
 key11_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key11_typ, k1.key11_val
;

insert into AMX.stage_key_parsed
select
 key12_typ,
 key12_val,
 12,
 iid,
 eid,
 rcid
from
 session.key12_parsed
where
 key12_typ is not null and
 locate ('.',key12_typ) > 0 and
 key12_val is not null
group by
 iid, eid, rcid, key12_typ, key12_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key12_typ,
 k1.key12_val,
 12,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key12_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key12_typ is not null and
 locate ('.',key12_typ) = 0 and
 key12_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key12_typ, k1.key12_val
;

insert into AMX.stage_key_parsed
select
 key13_typ,
 key13_val,
 13,
 iid,
 eid,
 rcid
from
 session.key13_parsed
where
 key13_typ is not null and
 locate ('.',key13_typ) > 0 and
 key13_val is not null
group by
 iid, eid, rcid, key13_typ, key13_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key13_typ,
 k1.key13_val,
 13,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key13_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key13_typ is not null and
 locate ('.',key13_typ) = 0 and
 key13_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key13_typ, k1.key13_val
;

insert into AMX.stage_key_parsed
select
 key14_typ,
 key14_val,
 14,
 iid,
 eid,
 rcid
from
 session.key14_parsed
where
 key14_typ is not null and
 locate ('.',key14_typ) > 0 and
 key14_val is not null
group by
 iid, eid, rcid, key14_typ, key14_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key14_typ,
 k1.key14_val,
 14,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key14_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key14_typ is not null and
 locate ('.',key14_typ) = 0 and
 key14_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key14_typ, k1.key14_val
;

insert into AMX.stage_key_parsed
select
 key15_typ,
 key15_val,
 15,
 iid,
 eid,
 rcid
from
 session.key15_parsed
where
 key15_typ is not null and
 locate ('.',key15_typ) > 0 and
 key15_val is not null
group by
 iid, eid, rcid, key15_typ, key15_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key15_typ,
 k1.key15_val,
 15,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key15_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key15_typ is not null and
 locate ('.',key15_typ) = 0 and
 key15_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key15_typ, k1.key15_val
;

insert into AMX.stage_key_parsed
select
 key16_typ,
 key16_val,
 16,
 iid,
 eid,
 rcid
from
 session.key16_parsed
where
 key16_typ is not null and
 locate ('.',key16_typ) > 0 and
 key16_val is not null
group by
 iid, eid, rcid, key16_typ, key16_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key16_typ,
 k1.key16_val,
 16,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key16_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key16_typ is not null and
 locate ('.',key16_typ) = 0 and
 key16_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key16_typ, k1.key16_val
;

insert into AMX.stage_key_parsed
select
 key17_typ,
 key17_val,
 17,
 iid,
 eid,
 rcid
from
 session.key17_parsed
where
 key17_typ is not null and
 locate ('.',key17_typ) > 0 and
 key17_val is not null
group by
 iid, eid, rcid, key17_typ, key17_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key17_typ,
 k1.key17_val,
 17,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key17_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key17_typ is not null and
 locate ('.',key17_typ) = 0 and
 key17_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key17_typ, k1.key17_val
;

insert into AMX.stage_key_parsed
select
 key18_typ,
 key18_val,
 18,
 iid,
 eid,
 rcid
from
 session.key18_parsed
where
 key18_typ is not null and
 locate ('.',key18_typ) > 0 and
 key18_val is not null
group by
 iid, eid, rcid, key18_typ, key18_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key18_typ,
 k1.key18_val,
 18,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key18_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key18_typ is not null and
 locate ('.',key18_typ) = 0 and
 key18_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key18_typ, k1.key18_val
;


insert into AMX.stage_key_parsed
select
 key19_typ,
 key19_val,
 19,
 iid,
 eid,
 rcid
from
 session.key19_parsed
where
 key19_typ is not null and
 locate ('.',key19_typ) > 0 and
 key19_val is not null
group by
 iid, eid, rcid, key19_typ, key19_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key19_typ,
 k1.key19_val,
 19,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key19_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key19_typ is not null and
 locate ('.',key19_typ) = 0 and
 key19_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key19_typ, k1.key19_val
;


insert into AMX.stage_key_parsed
select
 key20_typ,
 key20_val,
 20,
 iid,
 eid,
 rcid
from
 session.key20_parsed
where
 key20_typ is not null and
 locate ('.',key20_typ) > 0 and
 key20_val is not null
group by
 iid, eid, rcid, key20_typ, key20_val
;

insert into AMX.stage_key_parsed
select
 r1.resource concat '.' concat k1.key20_typ,
 k1.key20_val,
 20,
 k1.iid,
 k1.eid,
 k1.rcid
from
 session.key20_parsed k1,
 AMX.stage_resources r1
where
 r1.rcid = k1.rcid and
 r1.eid = k1.eid and
 key20_typ is not null and
 locate ('.',key20_typ) = 0 and
 key20_val is not null
group by
 r1.resource,k1.iid, k1.eid, k1.rcid, k1.key20_typ, k1.key20_val
;

-- Update the table AMX.Stage_key_parsed if any key_typ are in
-- the AMX.Inst_key_convert table

update AMX.stage_key_parsed s
set s.key_typ = (select
   distinct c1.key_typ_convert
 from
  AMX.Inst_key_convert c1
 where
  c1.key_typ=s.key_typ)
where upper(s.key_typ) in (select distinct upper(c2.key_typ) from AMX.Inst_key_Convert c2)
;

-- Update the table AMX.Stage_Resources if any Resource are in
-- the AMX.Resources_Convert table

update AMX.Stage_Resources s
set s.Resource = (
 select
   distinct c1.Resource_Convert
 from
  AMX.Resources_Convert c1
 where
  c1.Resource=s.Resource)
where upper(s.Resource) in (select distinct upper(c2.Resource) from AMX.Resources_Convert c2)
;

----------------------------------------------------------
-- Update ETL1_STATUS
------------------------------------------------------------

--#EXECUTE_AT_TARGET
update TWG.Extract_Control set Extctl_to_Dttm= current timestamp - current timezone  where EXTCTL_TARGET='AMX_STATUS_S020_PARSING_STEP';

--#EXECUTE_AT_TARGET
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'AMX_STATUS_S020_PARSING_STEP' AND
 EC.EXTCTL_TARGET = 'AMX_STATUS_S020_PARSING_STEP'
; 






