-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: Common/src/tedw_app/amx/fixpack2/etl/sql/amx_c05_s030_exception.db2, tmnt_etl, tmnt_5.1.1_FP06, 512ITMFP01_0616
-- #   Revision: 1.33
-- #   Date: 4/20/04 15:58:29
-- ############################################################################

--#EXECUTE_AT_TARGET
update TWG.Extract_Control set Extctl_from_Dttm= current timestamp  - current timezone where EXTCTL_TARGET='AMX_STATUS_S030_EXCEPTION_STEP';


select current timestamp from sysibm.sysdummy1;

------------------------------------------------
-- Create a view for the current relation rules
-------------------------------------------------
--#IGNORE_ERROR
drop view AMX.Cur_RelnRul;

create view AMX.Cur_RelnRul as
select *
from TWG.RelnRul
where current timestamp - current timezone
between RelnRul_Strt_DtTm and RelnRul_End_DtTm;

------------------------------------------------
-- Create a view for the current attribute  rules
-------------------------------------------------
--#IGNORE_ERROR
drop view AMX.Cur_AttrRul;

create view AMX.Cur_AttrRul as
select *
from TWG.AttrRul
where current timestamp - current timezone
between AttrRul_Strt_DtTm and AttrRul_End_DtTm;


----------------------------------------------------
-- Find the remote resources
----------------------------------------------------

declare global temporary table remote_resource(
  resource  varchar(254)
)
with replace on commit preserve rows not logged
;

insert into session.remote_resource
select
resource as resource
from
 AMX.Stage_Resources r,
 AMX.Comptyp_Transl ct,
 AMX.Relnrul_Transl rt
where
 locate (';'||r.resource||'.', ';'||ct.itm_key_property) > 0 and
 ct.comptyp_cd = rt.comptyp_target_cd and
 rt.relntyp_cd in ('PROXY','SAME')
group by
 r.resource
;

-- select * from session.remote_resource;

----------------------------------------------------
-- Find the remote components
----------------------------------------------------

declare global temporary table remote_component (
  comptyp_cd  varchar(17)
)
with replace on commit preserve rows not logged
;

insert into session.remote_component
select
 comptyp_target_cd as comptyp_cd
from
 AMX.Relnrul_Transl rt
where
 rt.relntyp_cd in ('PROXY', 'SAME')
;

--select * from session.remote_component;

--------------------------------------------------------
-- Do we have component types in  the AMX.Cur_RelnRul
-- (current view of TWG.RelnRul)
-- that do not exist in the AMX.Comptyp_Transl table ?
-------------------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_CompTyp_Transl_Ex
;
create table AMX.Stage_CompTyp_Transl_Ex (
  CompTyp_Cd  varchar(17),
  Msrc_cd     char(3),
  error_msg   varchar(254),
  timestamp   timestamp
);

insert into AMX.Stage_Comptyp_Transl_Ex
select
 r.comptyp_target_cd,
 substr(r.comptyp_target_cd,1,3),
 'There is no translation for this comptyp_cd in AMX.CompTyp_Transl table',
 current timestamp - current timezone
from
 AMX.Cur_RelnRul r,
 amx.category_transl c
where
 substr(r.comptyp_target_cd,1,3)=c.msrc_cd and
 r.relntyp_cd='PCHILD' and
 not exists (
 select 1
 from
  AMX.comptyp_transl t
 where
  r.comptyp_target_cd=t.comptyp_cd
)
group by
 r.comptyp_target_cd
;

-- select * from AMX.Stage_CompTyp_Transl_Ex;

--------------------------------------------------------
-- Do we have component types in the AMX.Resource_Transl
-- that do not exist in the TWG.Comptyp table ?
-------------------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_Resource_Transl_Ex
;
create table AMX.Stage_Resource_Transl_Ex (
  resource    varchar(128),
  comptyp_cd  varchar(17),
  error_msg   varchar(254),
  timestamp   timestamp
);

insert into AMX.Stage_Resource_Transl_Ex
select
 t.resource,
 t.comptyp_cd,
 'No correspondant CompTyp_Cd in TWG.CompTyp' as error_msg,
 current timestamp - current timezone as timestamp
from
 AMX.RelnRul_Transl r,
 AMX.Resource_Transl t
where
 t.comptyp_cd != r.comptyp_target_cd and
 not exists (
  select 1
  from
  session.remote_component c2
  where
  t.comptyp_cd = c2.comptyp_cd
  ) and
 not exists (
 select 1
 from
  TWG.CompTyp c
 where
 c.comptyp_cd = t.comptyp_cd
 )
group by
t.comptyp_cd,t.resource
;

-----------------------------------------------------------
-- Do we have in the AMX.Relnrul_Transl table a source component
-- type  that does not correspond  to a component type in the metadata
-- table TWG.Comptyp table ?
----------------------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_RelnRul_Transl_Ex
;
create table AMX.Stage_RelnRul_Transl_Ex (
  CompTyp_Source_Cd  varchar(17) not null,
  CompTyp_Target_Cd  varchar(17) not null,
  RelnTyp_Cd         char(6) not null,
  RelnRul_Strt_DtTm  Timestamp not null,
  RelnRul_End_DtTm   Timestamp not null,
  Error_Msg          varchar(254),
  Timestamp          timestamp
);

insert into AMX.Stage_RelnRul_Transl_Ex
select
 t.comptyp_source_cd,
 t.comptyp_target_cd,
 t.relntyp_cd,
 t.relnrul_strt_dttm,
 t.relnrul_end_dttm,
 'No correspondant CompTyp_Cd in TWG.CompTyp for the source component type' as error_msg,
 current timestamp - current timezone as timestamp
from
 AMX.RelnRul_Transl t
where
 t.relntyp_cd in ('PROXY','SAME') and
 not exists (
 select 1
 from
  TWG.CompTyp c
 where
 c.comptyp_cd = t.comptyp_source_cd
 )
group by
t.comptyp_source_cd,t.comptyp_target_cd,t.relntyp_cd,t.relnrul_strt_dttm,t.relnrul_end_dttm
;

-----------------------------------------------------------
-- Do we have in the AMX.Relnrul_Transl table a relation
-- type different from PROXY
----------------------------------------------------------

insert into AMX.Stage_RelnRul_Transl_Ex
select
 t.comptyp_source_cd,
 t.comptyp_target_cd,
 t.relntyp_cd,
 t.relnrul_strt_dttm,
 t.relnrul_end_dttm,
 'Relation type not supported in the current version of the ETL1' as error_msg,
 current timestamp - current timezone as timestamp
from
 AMX.RelnRul_Transl t
where
 t.relntyp_cd not in  ('PROXY', 'PCHILD','SAME')
group by
t.comptyp_source_cd,t.comptyp_target_cd,t.relntyp_cd,t.relnrul_strt_dttm,t.relnrul_end_dttm
;

-----------------------------------------------------------
-- Do we have in the AMX.Relnrul_Transl table a source component
-- type  that does not have a host for parent ?
----------------------------------------------------------

insert into AMX.Stage_RelnRul_Transl_Ex
select
 t.comptyp_source_cd,
 t.comptyp_target_cd,
 t.relntyp_cd,
 t.relnrul_strt_dttm,
 t.relnrul_end_dttm,
 'Only a component source type with a host for parent can have a Proxy relation ship' as error_msg,
 current timestamp - current timezone as timestamp
from
 AMX.RelnRul_Transl t
where
 t.relntyp_cd = 'PROXY' and
 not exists(
 select 1
 from
  AMX.Cur_RelnRul r
 where
  r.comptyp_target_cd = t.comptyp_source_cd and
  r.comptyp_source_cd like '%HOST%' and
  r.relntyp_cd='PCHILD'
 )
group by
t.comptyp_source_cd,t.comptyp_target_cd,t.relntyp_cd,t.relnrul_strt_dttm,t.relnrul_end_dttm
;

-- Defect 40724: new code introduced with defect 36944 was moved
-- forward because it uses objects introduced later in the
-- exception script.

-----------------------------------------------------------
-- Do we have in the source RmProfiles table a category
-- that does not  correspond  to a category in the metadata
-- table AMX.Category_transl table ?
----------------------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_RmProfiles_Ex
;
create table AMX.Stage_RmProfiles_Ex (
  category       varchar(128),
  profile        varchar(256),
  resource_model varchar(128),
  id             bigint not null,
  eid            integer not null,
  error_msg      varchar(254),
  Timestamp      timestamp not null
);

insert into AMX.Stage_RmProfiles_Ex
select
 p1.category as category,
 p1.profile as profile,
 p1.resource_model as resource_model,
 p1.id as id,
 p1.eid as eid,
 'This category is not declared in the metadata' as error_msg,
 current timestamp - current timezone as timestamp
from
 AMX.Stage_RmProfiles p1
where
not exists (
  select 1
  from
   AMX.Category_Transl t1
  where
   t1.category = p1.category
  )
;

-------------------------------------------------------
-- AMX.Comptyp2_Transl contain the component types
-- that do not have a composite key
-----------------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_CompTyp2_Transl
;
create table AMX.Stage_CompTyp2_Transl (
  msrc_cd     char(3),
  long_name   varchar(254),
  comptyp_cd  varchar(17),
  comp_nm     varchar(254)
);

insert into AMX.Stage_CompTyp2_Transl
select
msrc_cd as msrc_cd,
itm_key_property as long_name,
comptyp_cd as comptyp_cd,
comp_format_nm as comp_nm
from
 AMX.CompTyp_Transl
where
 LOCATE(';',itm_key_property) -1 < 0
;

-- select * from AMX.Stage_CompTyp2_Transl;

----------------------------------------------------
-- Do we have in the source Instances table a
-- translation for all  the key properties ?
----------------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_Inst_Comp_PAC_Ex
;
create table AMX.Stage_Inst_Comp_PAC_Ex (
  PAC         char(3),
  property    varchar(254),
  iid         bigint,
  eid         integer,
  rcid        bigint,
  comptyp_cd  varchar(17),
  error_msg   varchar(254),
  Timestamp   timestamp not null
);

-- either the key property is also an attribute type and
-- it is described in the TWG.AttrTyp table
-- or the property is only a key property and it is described in the
-- AMX.stage_comptyp2 table

insert into AMX.Stage_Inst_Comp_PAC_Ex
select
 m2.msrc_cd as PAC,
 a1.key_typ as property,
 a1.iid as iid,
 a1.eid as eid,
 a1.rcid as rcid,
 t1.comptyp_cd as comptyp_cd,
 'property not defined for that PAC' as error_msg,
 current timestamp - current timezone as timestamp
from
 AMX.Stage_Key_Parsed a1,
 AMX.Stage_Resources r1,
 AMX.Resource_Transl t1,
 AMX.Stage_Metrics m1,
 TWG.MsmtTyp m2
 where
 r1.rcid=a1.rcid and
 r1.eid = a1.eid and
 r1.resource=t1.resource and
 m1.name = m2.msmttyp_nm and
 m1.rcid = a1.rcid and
 m1.eid = a1.eid and
 not exists
 ( select 1
   from
   AMX.Stage_CompTyp2_Transl a2
   where
   a1.key_typ=a2.long_name
   ) and
 not exists
 ( select 1
   from
    TWG.AttrTyp a3,
    AMX.AttrTyp_Transl t1
   where
    a1.key_typ=t1.ITM_attr_property and
    t1.attrtyp_cd = a3.attrtyp_cd
  )
 group by
 m2.msrc_cd,a1.key_typ, a1.key_val, a1.iid, a1.eid, a1.rcid ,
 t1.comptyp_cd
  ;


insert into AMX.Stage_Inst_Comp_PAC_Ex
select
 m2.msrc_cd as PAC,
 a1.key_typ as property,
 a1.iid as iid,
 a1.eid as eid,
 a1.rcid as rcid,
 t1.comptyp_cd as comptyp_cd,
 'property val should not be equal to @, you must use a meaningful name for an instance key' as error_msg,
 current timestamp - current timezone as timestamp
from
 AMX.Stage_Key_Parsed a1,
 AMX.Stage_Resources r1,
 AMX.Resource_Transl t1,
 AMX.Stage_Metrics m1,
 TWG.MsmtTyp m2
 where
 r1.rcid=a1.rcid and
 r1.eid = a1.eid and
 r1.resource=t1.resource and
 m1.name = m2.msmttyp_nm and
 m1.rcid = a1.rcid and
 m1.eid = a1.eid and
 a1.key_val=''
 group by
 m2.msrc_cd,a1.key_typ, a1.key_val, a1.iid, a1.eid, a1.rcid ,
 t1.comptyp_cd
  ;


-- select * from AMX.Stage_Inst_Comp_PAC_Ex;

---------------------------------------------------
-- Do we have in the source Metrics table
-- a metric that has not been defined in the
-- metadata table TWG.MsmtTyp?
-- Is there a mismatch between the resource associated with
-- the metric in the source and the component type associated
-- with the metric in  the metadata TWG.MsmtRul ?
-- Is there a component type defined in the metadata table
-- TWG.MsmtTyp for each metric found in the source table Metrics?
--------------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_Metrics_Ex
;
create table AMX.Stage_Metrics_Ex (
 PAC        char(3),
 name       varchar(128),
 rcid       bigint,
 mid        bigint,
 stat       varchar(8),
 eid        integer,
 error_msg 	varchar(254),
 Timestamp	timestamp not null
);

insert into AMX.Stage_Metrics_Ex
select
 s1.msrc_cd as PAC,
 m1.name as name,
 m1.rcid as rcid,
 m1.mid as mid,
 m1.stat as stat,
 m1.eid as eid,
 'Metric name not defined for that PAC or wrong resource logged against that metric or wrong Component type code defined in the table TWG.MsmtRul for that metric.' as error_msg,
 current timestamp - current timezone as timestamp
 from
 AMX.Stage_Metrics m1,
 AMX.Stage_RmProfiles p1,
 AMX.Stage_Resources r1,
 AMX.Category_Transl s1
 where
  m1.rcid = r1.rcid and
  r1.id = p1.id and
  p1.category = s1.category and
  not exists (
  select 1
  from
  session.remote_resource r2
  where
  r1.resource = r2.resource
  ) and
  not exists
 ( select 1
   from
    TWG.MsmtTyp m2,
    TWG.MsmtRul m3,
    AMX.v_Resource_transl t2
   where
    m1.name=m2.msmttyp_nm and
    m2.msmttyp_id=m3.msmttyp_id and
    m3.comptyp_cd= t2.comptyp_cd and
    t2.resource=r1.resource and
    t2.msrc_cd = s1.MSrc_Cd
   )
 group by
  s1.msrc_cd, m1.name, m1.rcid, m1.mid, m1.stat, m1.eid
 ;


-- select * from AMX.Stage_Metrics_Ex;

--------------------------------------------------
-- Do we have this kind of problem ?
--
-- 1.Some attributes of a component type are not 
--  declared in the metadata table AMX.AttrTyp_Transl.
--
-- 2.A component having a unique key has declared this
--   key as an attribute and it should not.
--
-- 3.The ITM attribute name that is part of a composite
--   key is not the same in the metadata tables
--   Comptyp_transl and the AttrTyp_Transl.
------------------------------------------------------

------------------------------------------------------
-- Get all the key properties( parent included) for
-- each component type of an ITM application
--
-- Create a table with all the PCHILD  relations for
-- all the component types that belong to an ITM application
------------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_All_PACs_RelnRul
;
create table AMX.Stage_All_PACs_RelnRul (
  msrc_cd  char(3) not null,
  pkey     varchar(17) not null ,
  ckey     varchar(17) not null 
);

create unique index AMX.RelnRul_x1 on AMX.Stage_All_PACs_RelnRul (ckey, pkey,msrc_cd);

--#IGNORE_ERROR
drop table AMX.Stage_All_Comps_Exp
;
create table AMX.Stage_All_Comps_Exp (
  Msrc_Cd    char(3) not null,
  ckey       varchar(17) not null ,
  pkey       varchar(17) not null ,
  lvl        smallint    not null 
);

create unique index AMX.exp_x1 on AMX.Stage_All_Comps_exp (ckey, pkey,msrc_cd);

create trigger AMX.ExpIns
after insert on AMX.Stage_All_PACs_RelnRul
referencing new as nnn
for each row mode db2sql
  insert into  AMX.Stage_All_Comps_exp
  with temp (msrc_cd, ckey, pkey, lvl) as (
    values  (nnn.msrc_cd, nnn.ckey, nnn.ckey, 0 )
    union all
    select  nnn.msrc_cd, nnn.ckey, n.pkey, t.lvl +1
    from    temp t, AMX.Stage_All_PACs_RelnRul n
    where   n.ckey = t.pkey
    and     n.ckey <> n.pkey  
    and     n.msrc_cd = t.msrc_cd)
  select  msrc_cd, ckey, pkey, lvl
  from    temp
;

create trigger AMX.ExpDel
after delete on AMX.Stage_All_PACs_RelnRul
referencing old as ooo
for each row mode db2sql
  delete from  AMX.Stage_All_Comps_Exp
  where        ckey = ooo.ckey
;

-- J2EE_DOMAIN is only for WAS v4 and it
-- breaks the code as then the J2EE_SERVER 
-- may have 2 parents, so it 
-- is not included in that list
insert into AMX.Stage_All_PACs_RelnRul
select
 t1.msrc_cd as msrc_cd,
 r1.CompTyp_Source_Cd as pkey,
 r1.CompTyp_Target_Cd as ckey
from
 AMX.Cur_RelnRul r1,
 AMX.CompTyp_Transl t1,
 AMX.Comptyp_transl t2
where
 t1.comptyp_cd = r1.Comptyp_Source_cd and
 r1.relntyp_cd = 'PCHILD' and 
 r1.comptyp_source_cd not in ('J2EE_DOMAIN') and
 r1.comptyp_target_cd =t2.comptyp_cd and
 t2.msrc_cd=t1.msrc_cd
 ;
 

-- Include in the list the component HOST for the one
-- that have a host for parent in cur_relnrul
-- the relation type can only be PCHILD 
insert into AMX.Stage_All_PACs_RelnRul
select
 t.msrc_cd as msrc_cd,
 'HOST' as pkey,
 r.comptyp_Target_Cd as ckey
from
 AMX.Cur_RelnRul r,
 AMX.Comptyp_Transl t
where
 r.Comptyp_Source_cd ='IP_HOST' and
 r.relntyp_cd in ('PCHILD') and
 t.comptyp_cd = r.Comptyp_Target_cd 
;

-- Include in the list the component HOST for the one
-- that have a host for parent in  amx.relnrul_transl
-- the relation type is then equal to PROXY 
insert into AMX.Stage_All_Pacs_RelnRul
select
 t.msrc_cd as msrc_cd,
 'HOST' as pkey,
 r.comptyp_Target_Cd as ckey
from
 AMX.RelnRul_Transl r,
 AMX.Comptyp_Transl t
where
 r.relntyp_cd='PROXY' and
 t.comptyp_cd = r.Comptyp_Target_cd 
;

-- Include in the list the remote components
-- A remote component is always in the comptyp_target_cd of 
-- amx.relnrul_transl
-- and the relation type is then equal to PCHILD 
insert into AMX.Stage_All_Pacs_RelnRul
select
 t.msrc_cd as msrc_cd,
 r.CompTyp_Source_Cd as pkey,
 r.CompTyp_Target_Cd as ckey
from
 AMX.RelnRul_Transl r,
 AMX.Comptyp_Transl t
where
 r.relntyp_cd='PCHILD' and
 t.comptyp_cd = r.Comptyp_Target_cd  
;

-- select * from AMX.Stage_All_Pacs_RelnRul order by ckey;


-- select * from AMX.Stage_All_Comps_Exp;

declare global temporary table All_Comps_Exp_Keys (
  ckey     varchar(17) not null ,
  pkey     varchar(255) not null ,
  lvl      smallint    not null ,
  msrc_cd  char(3) not null
)
with replace on commit preserve rows not logged
;

insert into session.All_Comps_Exp_Keys
select
 e.ckey as ckey,
 t.itm_key_property concat '@@' as pkey,
 e.lvl as lvl,
 t.msrc_cd as msrc_cd
from
 AMX.Stage_All_Comps_Exp e,
 AMX.Comptyp_Transl t
where
 t.comptyp_cd = e.pkey AND
 t.msrc_cd=e.msrc_cd
;

insert into session.All_Comps_Exp_Keys
select
 e.ckey as ckey,
 'HOST@@' as pkey,
 e.lvl as lvl,
 t.msrc_cd as msrc_cd
from
 AMX.Stage_All_Comps_Exp e,
 AMX.Comptyp_Transl t
where
 e.pkey='HOST' and
 t.comptyp_cd = e.ckey AND
 t.msrc_cd=e.msrc_cd
;

-- select * from session.All_Comps_Exp_keys;

declare global temporary table All_Levels_PKey1 (
  ckey     varchar(17) not null,
  pkey     varchar(254) not null,
  key1     varchar(254),
  lvl      smallint not null,
  msrc_cd  char(3) not null
)
with replace on commit preserve rows not logged
;

insert into session.All_Levels_PKey1
select
 ckey,
 CASE
 when LOCATE(';',pkey) -1 > 0
 then
 substr(pkey,LOCATE(';',pkey)+1)
 else
 '@@'
 end as pkey,
 CASE
  when LOCATE(';',pkey) -1 < 0
  then
   CASE
   when pkey='@@'
   then null
   else substr(pkey,1,LOCATE('@@',pkey) - 1)
   END
  else substr(pkey,1,LOCATE(';',pkey) - 1)
 END as key1,
 lvl,
 msrc_cd
from
 session.All_Comps_Exp_Keys
 ;

-- select * from session.All_Levels_Pkey1;

declare global temporary table All_Levels_PKey2 (
  ckey     varchar(17) not null,
  pkey     varchar(254) not null,
  key2     varchar(254),
  lvl      smallint not null,
  msrc_cd  char(3) not null
)
with replace on commit preserve rows not logged
;

insert into session.All_Levels_PKey2
select
 ckey,
 CASE
 when LOCATE(';',pkey) -1 > 0
 then
 substr(pkey,LOCATE(';',pkey)+1)
 else
 '@@'
 end as pkey,
 CASE
  when LOCATE(';',pkey) -1 < 0
  then
   CASE
   when pkey='@@'
   then null
   else substr(pkey,1,LOCATE('@@',pkey) - 1)
   END
  else substr(pkey,1,LOCATE(';',pkey) - 1)
 END as key2,
 lvl,
 msrc_cd
from
 session.All_Levels_PKey1
 ;
-- select * from session.All_Levels_Pkey2;
declare global temporary table All_Levels_PKey3 (
  ckey     varchar(17) not null,
  pkey     varchar(254) not null,
  key3     varchar(254),
  lvl      smallint not null,
  msrc_cd  char(3) not null
)
with replace on commit preserve rows not logged
;

insert into session.All_Levels_PKey3
select
 ckey,
 CASE
 when LOCATE(';',pkey) -1 > 0
 then
 substr(pkey,LOCATE(';',pkey)+1)
 else
 '@@'
 end as pkey,
 CASE
  when LOCATE(';',pkey) -1 < 0
  then
   CASE
   when pkey='@@'
   then null
   else substr(pkey,1,LOCATE('@@',pkey) - 1)
   END
  else substr(pkey,1,LOCATE(';',pkey) - 1)
 END as key3,
 lvl,
 msrc_cd
from
 session.All_Levels_PKey2
 ;

-- select * from session.All_Levels_Pkey3;

------------------------------------------------------
-- Create a table with all the keys (parents included)
-- per component type, component level and msrc_cd.
-- The keys are in ITM format (long name)
------------------------------------------------------

declare global temporary table Meta_ITM_Keys (
  comptyp_cd  varchar(17) not null,
  ITM_key     varchar(254) not null,
  lvl         smallint not null,
  msrc_cd     char(3) not null
)
with replace on commit preserve rows not logged
;

insert into session.Meta_ITM_Keys(
select
 ckey as comptyp_cd,
 key1 as ITM_key ,
 lvl,
 msrc_cd
from
 session.All_Levels_PKey1
where
 key1 is not null
)
;

insert into session.Meta_ITM_Keys(
select
 ckey as comptyp_cd,
 key2 as ITM_key ,
 lvl,
 msrc_cd
from
 session.All_Levels_PKey2
where
 key2 is not null
)
;

insert into session.Meta_ITM_Keys(
select
 ckey as comptyp_cd,
 key3 as ITM_key ,
 lvl,
 msrc_cd
from
 session.All_Levels_PKey3
where
 key3 is not null
)
;

--select * from session.Meta_ITM_Keys  where comptyp_cd in ('CTO_INDEX') order by comptyp_cd, lvl;

-----------------------------------------
-- Create a table with all the keys
-- (parents included) per component type,
-- component level and msrc_cd.
-- The keys are in ITM format
------------------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_Meta_Keys
;
create table AMX.Stage_Meta_Keys (
  CompTyp_Cd  varchar(17) not null ,
  ITM_Key     varchar(254)not null,
  lvl             smallint    not null ,
  msrc_cd     char(3) not null
  )
;

insert into AMX.Stage_Meta_Keys
select
 k.comptyp_cd as comptyp_cd,
 k.ITM_key as ITM_key,
 k.lvl as lvl,
 k.msrc_cd as msrc_cd
from
 session.Meta_ITM_Keys k,
 AMX.Stage_CompTyp2_Transl t
where
 t.Long_Name=k.ITM_key and
 t.msrc_cd =k.msrc_cd
group by
 k.comptyp_cd, k.lvl, k.msrc_cd, k.ITM_key
;

insert into AMX.Stage_Meta_Keys
select
 k.comptyp_cd as comptyp_cd,
 k.ITM_key as ITM_key,
 k.lvl as lvl,
 k.msrc_cd as msrc_cd
from
 session.Meta_ITM_Keys k,
 AMX.AttrTyp_Transl t
where
 t.ITM_Attr_property=k.ITM_key and
 t.msrc_cd =k.msrc_cd 
group by
 k.comptyp_cd, t.attrtyp_cd, k.lvl, k.msrc_cd, k.ITM_key
;

--select * from AMX.Stage_Meta_Keys  where comptyp_cd in ('CTO_INDEX')order by comptyp_cd, lvl;

-------------------------------------------------------------
-- Find all the ITM_Keys for the common component J2EE_SERVER
-- As this component is considered as a top level component
-- the NODE and CELL or NODE and DOMAIN keys are not counted
-- we need to add them in that particular case
--------------------------------------------------------------
Declare global temporary table Meta_J2EE_keys(
ITM_key  varchar(254),
msrc_cd     char(3)
)
with replace on commit preserve rows not logged
;

insert into session.Meta_J2EE_keys
select
ITM_Key_Property,
msrc_cd
from
AMX.Comptyp_transl
where
comptyp_cd='J2EE_SERVER'
;
----------------------------------------------
-- Create a table with the number of keys per
-- component type and msrc_cd.
-- Component type is in ITM format ( long name)
----------------------------------------------

Declare global temporary table Meta_ITM_Keys_CompTyp_Count(
comptyp_cd  varchar(17),
msrc_cd     char(3),
key_num     integer
)
with replace on commit preserve rows not logged
;

insert into session.Meta_ITM_Keys_CompTyp_Count
select
comptyp_cd,
msrc_cd,
case
 when
 min(ITM_key) not in ( select ITM_key from session.Meta_J2EE_keys t where t.msrc_cd=s.msrc_cd) 
 then count(*) 
 else count(*) + 2 
 end as key_num
from
 session.Meta_ITM_Keys s
where
 ITM_key != 'HOST'
group by
 comptyp_cd, msrc_cd
 ;

--select * from session.Meta_ITM_Keys_CompTyp_Count where comptyp_cd='CTO_INDEX';

------------------------------------------------------
-- Create a table with the number of keys per
-- component type and msrc_cd
-- Component type is in TEDW format ( 17 characters max)
------------------------------------------------------

Declare global temporary table Meta_Keys_CompTyp_Count(
comptyp_cd  varchar(17),
msrc_cd     char(3),
key_num     integer
)
with replace on commit preserve rows not logged
;

insert into session.Meta_Keys_CompTyp_Count
select
comptyp_cd,
msrc_cd,
count(*) as key_num
from
 AMX.Stage_Meta_Keys
group by
 comptyp_cd, msrc_cd
 ;

-- select * from session.Meta_Keys_CompTyp_Count ;

------------------------------------------------------
-- Number of keys per component type in the source table
-- Session.Meta_ITM_keys_comptyp_count is the same as the
-- number of keys in the metadata table
-- Session.Meta_keys_comptyp_count
--------------------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_AttrTyp_Transl_Ex
;
create table AMX.Stage_AttrTyp_Transl_Ex (
  CompTyp_Cd    varchar(17),
  Msrc_Cd         char(3),
  error_msg   varchar(254),
  timestamp   timestamp
);

insert into AMX.Stage_AttrTyp_Transl_Ex
select
 c1.comptyp_cd,
 c1.msrc_cd,
 'Some attributes are not declared in the AMX.AttrTyp_Transl table for that comptyp_cd or one unique key should not be declared as an attribute or the ITM attribute name is not the same in the Comptyp_transl table and the AttrTyp_Transl table' as error_msg,
 current timestamp - current timezone as timestamp
from
 session.Meta_ITM_Keys_CompTyp_Count c1,
 session.Meta_Keys_CompTyp_Count c2
where
 c1.key_num != c2.key_num and
 c1.comptyp_cd = c2.comptyp_cd 
group by
 c1.comptyp_cd,c1.msrc_cd
;

-- select * from AMX.Stage_AttrTyp_Transl_Ex;

---------------------------------------------------------
-- Do we have in the source Instances table, all the key
-- properties per component type per metric ?
--------------------------------------------------------

---------------------------------------------------------
-- Create a table derived from the source Instances table
-- that include the comptyp and the msrc_cd
--#IGNORE_ERROR
drop table AMX.tmp_resource;

create table AMX.tmp_resource (
  msrc_cd       char(3) not null,
  eid           integer not null,
  rcid          bigint not null,
  id		integer not null,
  comptyp_cd    varchar(17) not null,
primary key(msrc_cd,eid,rcid,id,comptyp_cd)
)
;

insert into AMX.tmp_resource (msrc_cd,eid,rcid,id,comptyp_cd)
select
distinct
a3.msrc_cd,
a2.eid,
a2.rcid,
a2.id,
a3.comptyp_cd
from
 AMX.Stage_Resources a2,
 AMX.V_Resource_Transl a3
where
 a2.resource =  a3.resource
;

--#IGNORE_ERROR
drop table AMX.ITM_Keys;

create table AMX.ITM_Keys (
  PAC           char(3) not null,
  property      varchar(254) not null,
  property_val  varchar(254),
  iid           bigint not null,
  eid           integer not null,
  rcid          bigint not null,
  comptyp_cd    varchar(17) not null,
primary key(iid,eid,rcid,PAC,property,comptyp_cd)
)
;

insert into AMX.ITM_Keys
select
 a5.msrc_cd as PAC,
 a1.key_typ as property,
 a1.key_val as property_val,
 a1.iid as iid,
 a1.eid as eid,
 a1.rcid as rcid,
 a2.comptyp_cd as Comptyp_cd
from
 AMX.Stage_Key_Parsed a1,
 AMX.tmp_resource a2,
 AMX.Stage_RmProfiles a4,
 AMX.Category_Transl a5
where
 a2.rcid = a1.rcid and
 a2.eid = a1.eid and
 a2.msrc_cd=a5.msrc_cd and
 a4.id=a2.id and
 a4.eid=a2.eid and
 a4.category=a5.category
group by
 a5.msrc_cd,a1.key_typ,a1.key_val, a1.iid,
 a1.eid, a1.rcid, a2.comptyp_cd
;


-------------------------------------------------
-- Create a table derived from the source Categories
-- table that include the component type and the msrc_cd
--------------------------------------------------

declare global temporary table Cat_ITM_Comp_PAC (
  PAC           char(3),
  property      varchar(254),
  property_val  varchar(254),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  comptyp_cd    varchar(17)
)
with replace on commit preserve rows not logged
;

insert into session.Cat_ITM_Comp_PAC
select
 a5.msrc_cd as PAC,
 a1.name as property,
 a6.categoryvalue as property_val,
 a6.iid as iid,
 a1.eid as eid,
 a1.rcid as rcid,
 a3.comptyp_cd as comptyp_cd
from
 AMX.Stage_Categories a1,
 AMX.Stage_Resources a2,
 AMX.Resource_Transl a3,
 AMX.Stage_RmProfiles a4,
 AMX.Category_Transl a5,
 AMX.Stage_CategoriesData a6
where
 a2.rcid = a1.rcid and
 a2.eid = a1.eid and
 a2.resource =  a3.resource and
 a4.id=a2.id and
 a4.eid=a2.eid and
 a4.category=a5.category and
 a1.cid =a6.cid
group by
 a5.msrc_cd, a1.name, a6.categoryvalue,a6.iid,a1.eid,
 a1.rcid, a3.comptyp_cd
;


-------------------------------------------------
-- Derived from the source table Session.ITM_keys,
-- count the number of keys per component type,
-- msrc_cd, rcid,eid,iid.
-------------------------------------------------

declare global temporary table Inst_Keys_Count(
  count       integer,
  iid         bigint,
  eid         integer,
  rcid        bigint,
  comptyp_cd  varchar(17),
  msrc_cd     char(3)
)
with replace on commit preserve rows not logged
;

insert into session.Inst_Keys_Count
select
count(property),
iid,
eid,
rcid,
comptyp_cd,
PAC
from
AMX.ITM_Keys
group by
iid,eid,rcid,comptyp_cd,PAC
;


--select * from session.Inst_Keys_Count where comptyp_cd='CTO_INDEX';

--------------------------------------------------
-- Do we have the same count in the metadata table
-- Session.Meta_ITM_keys_Comptyp_count and the source table
-- Session.Inst_keys_count ?
-- select * from session.Inst_Keys_Count;
--------------------------------------------------
insert into AMX.stage_inst_Comp_PAC_Ex
select
 k1.msrc_cd as PAC,
 '' as property,
 k1.iid as iid,
 k1.eid as eid,
 k1.rcid as rcid,
 k1.comptyp_cd as comptyp_cd,
 'Some keys are missing for this comptyp_cd',
 current timestamp - current timezone as timestamp
from
 session.Inst_Keys_Count k1,
 session.Meta_ITM_Keys_CompTyp_Count k2
where
 k1.count!=k2.key_num and
 k1.comptyp_cd=k2.comptyp_cd and
 k1.msrc_cd =k2.msrc_cd 
group by
 k1.msrc_cd, k1.iid,k1.eid,k1.rcid,k1.comptyp_cd
;

--select * from AMX.stage_inst_comp_PAC_Ex;

----------------------------------------------------
-- Do we have in the Instances or Categories source
-- tables all the properties that make a component name ?
------------------------------------------------

declare global temporary table All_Comps_Exp_Names (
  ckey     varchar(17) not null ,
  pkey     varchar(600) not null ,
  lvl      smallint    not null ,
  msrc_cd  char(3) not null
)
with replace on commit preserve rows not logged
;

insert into session.All_Comps_Exp_Names
select
 e.ckey as ckey,
 t.comp_format_nm concat '@@' as pkey,
 e.lvl as lvl,
 t.msrc_cd as msrc_cd
from
 AMX.Stage_All_Comps_Exp e,
 AMX.Comptyp_Transl t
where
 t.comptyp_cd = e.pkey and
 t.msrc_cd=e.msrc_cd
;


--select * from session.ALl_Comps_Exp_Names;

declare global temporary table All_Levels_Name1 (
  ckey     varchar(17) not null,
  pkey     varchar(254) not null,
  key1     varchar(254),
  lvl      smallint not null,
  msrc_cd  char(3) not null
)
with replace on commit preserve rows not logged
;

insert into session.All_Levels_Name1
select
 ckey,
 CASE
 when LOCATE(';',pkey) -1 > 0
 then
 substr(pkey,LOCATE(';',pkey)+1)
 else
 '@@'
 end as pkey,
 CASE
  when LOCATE(';',pkey) -1 < 0
  then
   CASE
   when pkey='@@'
   then null
   else substr(pkey,1,LOCATE('@@',pkey) - 1)
   END
  else substr(pkey,1,LOCATE(';',pkey) - 1)
 END as key1,
 lvl,
 msrc_cd
from
 session.ALl_Comps_Exp_Names
 ;

--select * from session.All_levels_Name1 where ckey='CTO_INDEX';
-- select * from session.All_levels_Name1 ;

declare global temporary table All_Levels_Name2 (
  ckey      varchar(17) not null,
  pkey      varchar(254) not null,
  key2      varchar(254),
  lvl       smallint not null,
  msrc_cd   char(3) not null
)
with replace on commit preserve rows not logged
;

insert into session.All_Levels_Name2
select
 ckey,
 CASE
 when LOCATE(';',pkey) -1 > 0
 then
 substr(pkey,LOCATE(';',pkey)+1)
 else
 '@@'
 end as pkey,
 CASE
  when LOCATE(';',pkey) -1 < 0
  then
   CASE
   when pkey='@@'
   then null
   else substr(pkey,1,LOCATE('@@',pkey) - 1)
   END
  else substr(pkey,1,LOCATE(';',pkey) - 1)
 END as key2,
 lvl,
 msrc_cd
from
 session.All_Levels_Name1
 ;


--select * from session.All_levels_Name2 where ckey='CTO_INDEX';
-- select * from session.All_levels_Name2 ;

declare global temporary table All_Levels_Name3 (
  ckey     varchar(17) not null,
  pkey     varchar(254) not null,
  key3     varchar(254),
  lvl      smallint not null,
  msrc_cd  char(3) not null
)
with replace on commit preserve rows not logged
;

insert into session.All_Levels_Name3
select
 ckey,
 CASE
 when LOCATE(';',pkey) -1 > 0
 then
 substr(pkey,LOCATE(';',pkey)+1)
 else
 '@@'
 end as pkey,
 CASE
  when LOCATE(';',pkey) -1 < 0
  then
   CASE
   when pkey='@@'
   then null
   else substr(pkey,1,LOCATE('@@',pkey) - 1)
   END
  else substr(pkey,1,LOCATE(';',pkey) - 1)
 END as key3,
 lvl,
 msrc_cd
from
 session.All_Levels_Name2
 ;

--select * from session.All_levels_Name3 where ckey='CTO_INDEX';
-- select * from session.All_levels_Name3 ;

declare global temporary table  Meta_ITM_Names(
  comptyp_cd  varchar(17) not null,
  ITM_name    varchar(254) not null,
  lvl         smallint not null,
  msrc_cd     char(3) not null
)
with replace on commit preserve rows not logged
;

insert into  session.Meta_ITM_Names(
select
 ckey as comptyp_cd,
 key1 ,
 lvl,
 msrc_cd
from
 session.All_Levels_Name1
where
 key1 is not null
)
;

-- select * from session.Meta_ITM_Names where comptyp_cd='GWL_WAP_COMP';

insert into  session.Meta_ITM_Names(
select
 ckey as comptyp_cd,
 key2 ,
 lvl,
 msrc_cd
from
 session.All_Levels_Name2
where
 key2 is not null
)
;


-- select * from session.Meta_ITM_Names where comptyp_cd='GWL_WAP_COMP';

insert into session.Meta_ITM_Names(
select
 ckey as comptyp_cd,
 key3 ,
 lvl,
 msrc_cd
from
 session.All_Levels_Name3
where
 key3 is not null
)
;

--select * from session.Meta_ITM_Names where comptyp_cd='GWL_WAP_COMP';
--select * from session.Meta_ITM_Names;

--#IGNORE_ERROR
drop table  AMX.Stage_Meta_Names;
create table  AMX.Stage_Meta_Names (
  CompTyp_Cd  varchar(17) not null ,
  ITM_name    varchar(254) not null,
  lvl         smallint    not null ,
  msrc_cd     char(3) not null )
;

insert into  AMX.Stage_Meta_Names
select
 e.comptyp_cd as comptyp_cd,
 t.ITM_key as ITM_name,
 e.lvl,
 e.msrc_cd
from
 session.Meta_ITM_Names e,
 AMX.Stage_Meta_Keys t
where
 e.ITM_name = t.ITM_key and
 e.comptyp_cd= t.comptyp_cd and
 e.msrc_cd=t.msrc_cd
group by
 e.comptyp_cd,t.ITM_key,e.lvl,e.msrc_cd
;

-- select * from AMX.Stage_Meta_Names where comptyp_cd='GWL_WAP_COMP';

insert into  AMX.Stage_Meta_Names
select
 e.comptyp_cd as comptyp_cd,
 e.ITM_name as ITM_name,
 e.lvl,
 e.msrc_cd
from
 session.Meta_ITM_Names e,
 AMX.AttrTyp_Transl t
where
 e.ITM_name = t.ITM_attr_property and
 e.msrc_cd=t.msrc_cd and
 not exists (
 select 1
 from
  AMX.Stage_Meta_Names e2
 where
  e2.comptyp_cd=e.comptyp_cd and
  e2.ITM_name=e.ITM_name and
  e2.lvl=e.lvl and
  e2.msrc_cd=e.msrc_cd
  )
group by
 e.comptyp_cd,e.ITM_name,e.lvl,e.msrc_cd
;

-- select * from AMX.Stage_Meta_Names where comptyp_cd='GWL_WAP_COMP';
--select * from AMX.Stage_Meta_Names;


-------------------------------------------------------
-- Derived from the Instances or Categories source tables
-- (as names can be part of one table or the other).
-- Create a table with a row per component type, msrc_cd, iid,
-- eid, rcid.
-- When no name is found but a row exists in the instances table,
-- "NoName" is indicated.
-- The component name is in ITM format (long name)
-----------------------------------------------------------

--#IGNORE_ERROR
drop table AMX.T1;

create table AMX.T1(
  PAC           char(3) not null,
  ITM_Name      varchar(254) not null,
  property_val  varchar(254),
  iid           bigint not null,
  eid           integer not null,
  rcid          bigint not null,
  comptyp_cd    varchar(17)not null,
  primary key (PAC,ITM_Name,iid,eid,rcid,comptyp_cd)
)

;

-- Either the names are in the categories table
-- or they are in the instances table
-- T1 tries to find the names in categories that match the metadata

insert into AMX.T1 (PAC,ITM_Name,property_val,iid,eid,rcid,comptyp_cd )
select
  i.PAC ,
  i.property ,
  i.property_val ,
  i.iid,
  i.eid,
  i.rcid    ,
  i.comptyp_cd
from
AMX.ITM_Keys i,
AMX.Stage_Meta_Names e
where
    e.comptyp_cd=i.comptyp_cd
and e.msrc_cd=i.pac
and e.itm_name=i.property
;


insert into AMX.T1 (PAC,ITM_Name,property_val,iid,eid,rcid,comptyp_cd )
select
  i.PAC ,
  i.property ,
  i.property_val ,
  i.iid,
  i.eid,
  i.rcid    ,
  i.comptyp_cd
from
session.Cat_ITM_Comp_PAC i,
AMX.Stage_Meta_Names e
where
    e.comptyp_cd=i.comptyp_cd
and e.msrc_cd=i.pac
and e.itm_name=i.property
;

--select count(*) from AMX.T1;

-- find the difference between the data in instances ( all the keys)
-- and the one where I found names
-- in order to find which ones has no names
--#IGNORE_ERROR
drop table AMX.T2;

create table AMX.T2(
  PAC         char(3) not null,
  iid         bigint not null,
  eid         integer not null,
  rcid        bigint not null,
  comptyp_cd  varchar(17)not null,
  primary key (PAC,iid,eid,rcid,comptyp_cd)
)
;

insert into AMX.T2 (PAC,iid,eid,rcid,comptyp_cd)
select distinct 
i.PAC,  
i.iid , i.eid , i.rcid,
i.comptyp_cd
from
AMX.ITM_Keys i
where not exists (
select 1 from AMX.T1 t1
where
    t1.comptyp_cd=i.comptyp_cd
and t1.pac=i.pac 
)
;

--select count(*) from AMX.t2;

--#IGNORE_ERROR
drop table AMX.T3;

create table AMX.T3(
  PAC           char(3) not null,
  ITM_Name      varchar(254) not null,
  property_val  varchar(254),
  iid           bigint not null,
  eid           integer not null,
  rcid          bigint not null,
  comptyp_cd    varchar(17) not null,
  primary key (PAC,ITM_Name,iid,eid,rcid,comptyp_cd)
)
;

insert into AMX.T3 (PAC,ITM_Name,property_val,iid,eid,rcid,comptyp_cd )
select
t2.PAC,
'NO_NAME',
'NO_NAME',
t2.iid,
t2.eid,
t2.rcid ,
t2.comptyp_cd
from
AMX.T2 t2,
AMX.Stage_Meta_Names e
where
t2.comptyp_cd=e.comptyp_cd and
t2.pac = e.msrc_cd
;

--select count(*) from AMX.T3;


declare global temporary table Comp_Nm(
  PAC           char(3),
  ITM_Name      varchar(254),
  property_val  varchar(254),
  iid           bigint,
  eid           integer,
  rcid          bigint,
  comptyp_cd    varchar(17)
  )
  with replace on commit preserve rows not logged
;

insert into session.Comp_Nm
select * from AMX.T1
union
select * from AMX.T3
;

--select PAC, substr(ITM_Name,1,35) , substr(property_val,1,10) , iid, eid, rcid, comptyp_cd from session.Comp_Nm;

--------------------------------------------
-- Derived from the metadata, count the number
-- of names per component type and msrc_cd
--------------------------------------------

declare global temporary table Names_Count(
  count       integer,
  comptyp_cd  varchar(17),
  msrc_cd     char(3)
)
with replace on commit preserve rows not logged
;

insert into session.Names_Count
select
 count(ITM_name) as count,
 comptyp_cd,
 msrc_cd
from
 session.Meta_ITM_Names s
group by
 comptyp_cd,msrc_cd
;

--select * from session.Names_Count;

------------------------------------------------
-- Derived from the Instances and the Categories
-- source table, count the number of names per
-- component type and msrc_cd
------------------------------------------------

declare global temporary table Comp_Nm_Count(
  count       integer,
  iid         bigint,
  eid         integer,
  rcid        bigint,
  comptyp_cd  varchar(17),
  msrc_cd     char(3)
)
with replace on commit preserve rows not logged
;

insert into session.Comp_Nm_Count
select
count(ITM_Name),
iid,
eid,
rcid,
comptyp_cd,
PAC
from
session.Comp_Nm
where
 ITM_Name!='NO_NAME'
group by
iid,eid,rcid,comptyp_cd,PAC
;

insert into session.Comp_Nm_Count
select
0,
iid,
eid,
rcid,
comptyp_cd,
PAC
from
session.Comp_Nm
where
 ITM_Name='NO_NAME'
group by
iid,eid,rcid,comptyp_cd,PAC
;


--select * from session.Comp_Nm_Count;

--select * from session.Comp_Nm_Count where comptyp_cd='CTO_INDEX';

-------------------------------------------------
-- Do we have the same count in the metadata table
-- Session.names_count and the source table
-- session.Comp_Nm_Count ?
-------------------------------------------------

insert into AMX.Stage_Inst_Comp_PAC_Ex
select
 k1.msrc_cd as PAC,
 '' as property,
 k1.iid as iid,
 k1.eid as eid,
 k1.rcid as rcid,
 k1.comptyp_cd as comptyp_cd,
 'Some properties used for the comp_nm are missing for this comptyp_cd',
 current timestamp - current timezone as timestamp
from
 session.Comp_Nm_Count k1,
 session.Names_Count k2
where
 k1.count!=k2.count and
 k1.comptyp_cd=k2.comptyp_cd and
 k1.msrc_cd =k2.msrc_cd
group by
 k1.msrc_cd, k1.iid,k1.eid,k1.rcid,k1.comptyp_cd
;

--select * from AMX.Stage_Inst_Comp_PAC_Ex;

----------------------------------------------------
-- Do we have properties that are inside the categories
-- table that are not declared as attributes
-- for that component type in the metadata
-- table AMX.AttrTyp_Transl ?
------------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_Categories_Ex
;
create table AMX.Stage_Categories_Ex (
 CompTyp_Cd  varchar(17),
 PAC         char(3),
 name        varchar(128),
 rcid        bigint,
 cid         bigint,
 eid         integer,
 error_msg   varchar(254),
 timestamp   timestamp not null
);

insert into AMX.Stage_Categories_Ex
select
 t1.comptyp_cd as CompTyp_cd,
 s1.msrc_cd as PAC,
 a1.name as name,
 a1.rcid as rcid,
 a1.cid as cid,
 a1.eid as eid,
 'The attribute for that component for that PAC is not declared in the metadata' as error_msg,
 current timestamp - current timezone as timestamp
from
 AMX.Stage_Categories a1,
 AMX.Stage_RmProfiles p1,
 AMX.Stage_Resources r1,
 AMX.Category_Transl s1,
 AMX.Resource_Transl t1,
 AMX.Stage_CompTyp2_Transl k1
 where
  a1.rcid = r1.rcid and
  r1.id = p1.id and
  p1.category = s1.category and
  r1.resource = t1.resource and
-- if not equal to k1.long_name, we are sure it should be an attribute
  a1.name!=k1.long_name and
  not exists (
  select 1
  from
  session.remote_component c2
  where
  t1.comptyp_cd = c2.comptyp_cd
  ) and
  s1.msrc_cd = k1.msrc_cd and
 not exists (
 select 1
 from
 AMX.AttrTyp_Transl a3,
 TWG.AttrTyp a2,
 AMX.Cur_AttrRul r1
where
 a1.name = a3.ITM_Attr_Property and
 a3.attrtyp_cd = a2.attrtyp_cd and
 r1.attrtyp_cd = a2.attrtyp_cd
 )
 group by
 t1.comptyp_cd,s1.msrc_cd, a1.name , a1.rcid ,
 a1.cid , a1.eid
;

--select * from AMX.Stage_Categories_Ex;

----------------------------------------------------
-- Reconstitute the source tables with no exceptions
--------------------------------------------------

--------------------------------------------
-- Derived from the source Instances table.
-- Create a table without inserting the rows
-- that have an exception in
-- AMX.Stage_Inst_Comp_PAC_Ex.
--------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_Inst_No_Ex1;

create table AMX.Stage_Inst_No_Ex1 (
  property      varchar(254) not null,
  property_val  varchar(254),
  iid           bigint not null,
  eid           integer not null,
  rcid          bigint not null
)
;

alter table AMX.Stage_Inst_No_Ex1 add primary key (iid,rcid,eid,property)
;

insert into AMX.Stage_Inst_No_Ex1
select
 a1.key_typ as property,
 a1.key_val as property_val,
 a1.iid as iid,
 a1.eid as eid,
 a1.rcid as rcid
from
  AMX.Stage_Key_Parsed a1
where
 not exists (
  select 1
  from
   AMX.Stage_Inst_Comp_PAC_Ex a2
  where
   a1.iid=a2.iid and
   a1.eid=a2.eid and
   a1.rcid=a2.rcid
  )
;



-- select substr(key_typ,1,25),substr(key_val,1,12),iid,eid,rcid from AMX.Stage_Key_Parsed;
-- select substr(property,1,25),substr(property_val,1,12),iid,eid,rcid from session.Stage_Inst_No_Ex1;
----------------------------------------------------
-- Derived from the Session.Stage_Inst_No_Ex1 table.
-- Create a table without inserting the rows that
-- have an exception in AMX.Stage_Metrics_Ex.
-----------------------------------------------------

--declare global temporary table Stage_Inst_No_Ex2 (
--  property      varchar(254),
--  property_val  varchar(254),
--  iid           bigint,
--  eid           integer,
--  rcid          bigint
--)
--with replace on commit preserve rows not logged
--;

--insert into session.Stage_Inst_No_Ex2
--select
-- a1.property,
-- a1.property_val,
-- a1.iid as iid,
-- a1.eid as eid,
-- a1.rcid as rcid
--from
--  session.Stage_Inst_No_Ex1 a1
--where
-- not exists (
--  select 1
--  from
--   AMX.Stage_Metrics_Ex a2
--  where
--   a1.eid=a2.eid and
--   a1.rcid=a2.rcid
--  )
--;

-- select substr(property,1,25),substr(property_val,1,12),iid,eid,rcid from session.Stage_Inst_No_Ex2;

----------------------------------------------------------
-- Derived from the Session.Stage_Inst_No_Ex2 table.
-- Create a table without inserting the rows that have
-- an exception in AMX.Stage_Categories_Ex.
-----------------------------------------------------------

--declare global temporary table Stage_Inst_No_Ex3 (
--  property      varchar(254),
--  property_val  varchar(254),
--  iid           bigint,
--  eid           integer,
--  rcid          bigint
--)
--with replace on commit preserve rows not logged
--;

--insert into session.Stage_Inst_No_Ex3
--select
-- a1.property,
-- a1.property_val,
-- a1.iid as iid,
-- a1.eid as eid,
-- a1.rcid as rcid
--from
--  session.Stage_Inst_No_Ex2 a1
--where
-- not exists (
--  select 1
--  from
--   AMX.Stage_Categories_Ex a2
--  where
--   a1.eid=a2.eid and
--   a1.rcid=a2.rcid
--  )
--;

-- select * from session.Stage_Inst_No_ex3;

----------------------------------------------------------------------
-- Create the Instances table with no exception and
-- the key property is in ITM format
-- Derived from the Session.Stage_Inst_No_Ex1 table.
-- if the key is an attribute, the translation is in attrtyp_transl
-- if the key is not an attribute, the translation is in comptyp2_transl
-------------------------------------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_InstKey_No_Ex
;
create table AMX.Stage_InstKey_No_Ex (
 ITM_Key       varchar(254) not null,
 property_val  varchar(254),
 iid           bigint not null,
 eid           integer not null,
 rcid          bigint not null,
 comptyp_cd    varchar(17)
);

-- Defect #42962 create primary key
alter table amx.stage_instkey_no_ex add primary key (iid,rcid,eid,itm_key)
;

insert into AMX.Stage_InstKey_No_Ex
select
 a3.ITM_Key,
 a1.property_val,
 a1.iid as iid,
 a1.eid as eid,
 a1.rcid as rcid,
 a1.comptyp_cd as comptyp_cd
from
 AMX.ITM_Keys a1,
 AMX.Stage_Meta_Keys a3
where
 a1.property=a3.ITM_Key and
  exists (
 select 1
 from
    AMX.Stage_Inst_No_Ex1 a4
 where
    a4.iid =a1.iid and
    a4.eid =a1.eid and
    a4.rcid =a1.rcid
  )
group by
 a3.ITM_key,a1.property_val, a1.iid, a1.eid, a1.rcid,
 a1.comptyp_cd
;

--#IGNORE_ERROR
drop table AMX.Stage_Inst_No_Ex
;

create table AMX.Stage_Inst_No_Ex (
  iid           bigint not null,
  eid           integer not null,
  rcid          bigint not null
)
;

alter table AMX.Stage_Inst_No_Ex add primary key (iid,rcid,eid)
;

insert into AMX.Stage_Inst_No_Ex 
select
distinct
iid,
eid,
rcid
from 
AMX.Stage_InstKey_No_Ex;

------------------------------------------------
-- Create the Endpoints table with no exception
-- Derived from the AMX.Stage_Inst_No_Ex table.
----------------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_Ep_No_Ex
;
create table AMX.Stage_Ep_No_Ex (
 eid             integer not null,
 host_nm         varchar(120),
 ip_addr         varchar(20),
 endpoint_label  varchar(64),
 GMT_offset      integer not null,
   primary key (eid)
);

insert into AMX.Stage_Ep_No_Ex
select
 a1.eid,
 a1.host_nm,
 a1.ip_addr,
 a1.endpoint_label,
 a1.GMT_offset
from
 AMX.Stage_Endpoints a1,
 AMX.Stage_Inst_No_Ex a2
where
 a1.eid=a2.eid
group by
 a1.eid,a1.host_nm,a1.ip_addr,a1.endpoint_label,
 a1.GMT_offset
;

-------------------------------------------
-- Create the RmProfiles table with no exception
-----------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_RmProf_No_Ex
;
create table AMX.Stage_RmProf_No_Ex (
 category       varchar(128),
 profile        varchar(256),
 resource_model varchar(128),
 id             bigint not null,
 eid            integer not null,
   primary key (id,eid)
);

insert into AMX.Stage_RmProf_No_Ex
select
 a1.category,
 a1.profile,
 a1.resource_model,
 a1.id,
 a1.eid
from
 AMX.Stage_RmProfiles a1,
 AMX.Stage_Inst_No_Ex a2
where
 a1.eid=a2.eid
group by
 a1.category,a1.profile,a1.resource_model,
 a1.id,a1.eid
;

---------------------------------------------
-- Create a msmt table with no exception. A msmt
-- table is a joint between metrics and metricsdata
-- with 4 columns ( min,max,avg,tot) and
-- it includes the comptyp_cd in TEDW format.
----------------------------------------------

-- JC declare global temporary table Met_No_Ex(
--#IGNORE_ERROR
drop table amx.met_no_ex;

create table amx.met_no_ex (
  name  varchar(128),
  rcid  bigint not null,
  mid   bigint not null,
  stat  varchar(8),
  eid   integer not null
)
;

insert into amx.met_no_ex       
select
 a1.name,
 a1.rcid,
 a1.mid,
 a1.stat,
 a1.eid
from
 AMX.Stage_Metrics a1,
 AMX.Stage_Inst_No_Ex a2
where
 a1.eid=a2.eid and
 a1.rcid=a2.rcid and
 not exists ( select 1
  from
   AMX.Stage_Metrics_Ex a3
  where
   a3.eid=a1.eid and
   a3.rcid=a1.rcid and
   a3.mid=a1.mid
   )
group by
 a1.name,a1.rcid,a1.mid,a1.stat,a1.eid
;

create index met on amx.met_no_ex (eid,mid);

--#IGNORE_ERROR
drop table AMX.MetData_No_Ex;

create table AMX.MetData_No_Ex(
  mid           bigint not null,
  metricvalue   float not null,
  timekey_dttm  timestamp not null,
  iid           bigint not null,
  eid           integer not null
)
;

insert into AMX.MetData_No_Ex
select
 a1.mid,
 a1.metricvalue,
 a1.timekey_dttm,
 a1.iid,
 a1.eid
from
 AMX.Stage_Metricsdata a1,
 AMX.Stage_Inst_No_Ex a2,
 AMX.met_no_ex a3
where
 a1.eid=a2.eid and
 a1.iid=a2.iid and
 a3.mid=a1.mid
group by
 a1.mid,a1.metricvalue, a1.timekey_dttm,a1.iid,a1.eid
;

create index metdata on AMX.MetData_No_Ex (eid,mid);


------------------------------ MIN -------------------------------------

--#IGNORE_ERROR
drop table amx.temp_min_exists;

create table amx.temp_min_exists (
 msmttyp_nm varchar(254),
 min_exists     char(1)
)
;

insert into amx.temp_min_exists
select distinct
 mt.msmttyp_nm,
 'Y' as min_exists
from
 TWG.MgrpMbr mb,
 TWG.MsmtTyp mt,
 amx.met_no_ex m
where
 mb.msmttyp_id=mt.msmttyp_id and
 mt.msmttyp_nm=m.name and
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MIN_E'
;

--#IGNORE_ERROR
drop table amx.temp_min_status;

create table amx.temp_min_status (
 msmttyp_nm varchar(254),
 min_exists     char(1)
)
;

select current timestamp from sysibm.sysdummy1;

-- JC debug
insert into amx.temp_min_status
select distinct
  m.name as msmttyp_nm,
  value(min.min_exists,'N') as min_exists
from
 amx.Met_No_Ex m left outer join amx.temp_min_exists min
 on m.name=min.msmttyp_nm
group by
m.name,min.min_exists
;

--select substr(msmttyp_nm,1,20),min_exists from amx.temp_min_status;

--#IGNORE_ERROR
drop table AMX.stage_met_min;

create table AMX.stage_met_min (
  msmttyp_id    integer not null,
  mid           bigint not null,
  rcid          bigint not null,
  eid           integer not null,
  min_exists    char(1) not null
)
;

insert into AMX.stage_met_min 
select
 mt.msmttyp_id,
 m.mid, 
 m.rcid as rcid,
 m.eid as eid,
 min.min_exists
from
 amx.Met_No_Ex m,
 amx.temp_min_status min,
 twg.msmttyp mt
where
 m.name=min.msmttyp_nm and
 m.stat ='MIN' and
 m.name = mt.msmttyp_nm
group by
 mt.msmttyp_id, m.mid, m.rcid, m.eid, min.min_exists
;

alter table amx.stage_met_min add primary key (
  mid,eid)
;

--#IGNORE_ERROR
drop table AMX.Stage_Msmt_Min;

create table AMX.Stage_Msmt_Min (
  msmttyp_id    integer not null,
  Msmt_Min_Val  float,
  timekey_dttm  timestamp not null,
  iid           bigint not null,
  rcid          bigint not null,
  eid           integer not null
)
;

insert into AMX.Stage_Msmt_Min
select
 m.msmttyp_id,
 Case
 when m.min_exists='Y'
 then
 -- Defect #42962
 min(md1.metricvalue)
 else
  null
 end as Msmt_Min_Val,
 md1.timekey_dttm as timekey_dttm,
 md1.iid as iid,
 m.rcid as rcid,
 m.eid as eid
from
 amx.stage_met_min m,
 AMX.MetData_No_Ex md1
where
 m.mid = md1.mid and
 m.eid = md1.eid 
group by
 -- Defect #42962
 m.msmttyp_id, md1.timekey_dttm, md1.iid, m.rcid, m.eid, m.min_exists
;

-- Defect #42962
alter table amx.stage_msmt_min add primary key (
  timekey_dttm,msmttyp_id,iid,rcid,eid)
;

------------------------------ MAX -------------------------------------

--#IGNORE_ERROR
drop table amx.temp_max_exists;

create table amx.temp_max_exists (
 msmttyp_nm varchar(254),
 max_exists     char(1)
)
;

insert into amx.temp_max_exists
select distinct
 mt.msmttyp_nm,
 'Y' as max_exists
from
 TWG.MgrpMbr mb,
 TWG.MsmtTyp mt,
 amx.met_no_ex m
where
 mb.msmttyp_id=mt.msmttyp_id and
 mt.msmttyp_nm=m.name and
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MAX_E'
;

--#IGNORE_ERROR
drop table amx.temp_max_status;

create table amx.temp_max_status (
 msmttyp_nm varchar(254),
 max_exists     char(1)
)
;

select current timestamp from sysibm.sysdummy1;

-- JC debug
insert into amx.temp_max_status
select distinct
  m.name as msmttyp_nm,
  value(max.max_exists,'N') as max_exists
from
 amx.Met_No_Ex m left outer join amx.temp_max_exists max
 on m.name=max.msmttyp_nm
group by
m.name,max.max_exists
;

--select substr(msmttyp_nm,1,20),max_exists from amx.temp_max_status;

--#IGNORE_ERROR
drop table AMX.stage_met_max;

create table AMX.stage_met_max (
  msmttyp_id    integer not null,
  mid           bigint not null,
  rcid          bigint not null,
  eid           integer not null,
  max_exists    char(1) not null
)
;

insert into AMX.stage_met_max 
select
 mt.msmttyp_id,
 m.mid, 
 m.rcid as rcid,
 m.eid as eid,
 max.max_exists
from
 amx.Met_No_Ex m,
 amx.temp_max_status max,
 twg.msmttyp mt
where
 m.name=max.msmttyp_nm and
 m.stat ='MAX' and
 m.name = mt.msmttyp_nm
group by
 mt.msmttyp_id, m.mid, m.rcid, m.eid, max.max_exists
;

alter table amx.stage_met_max add primary key (
  mid,eid)
;

--#IGNORE_ERROR
drop table AMX.Stage_Msmt_Max;

create table AMX.Stage_Msmt_Max (
  msmttyp_id    integer not null,
  Msmt_Max_Val  float,
  timekey_dttm  timestamp not null,
  iid           bigint not null,
  rcid          bigint not null,
  eid           integer not null
)
;

insert into AMX.Stage_Msmt_Max
select
 m.msmttyp_id,
 Case
 when m.max_exists='Y'
 then
 -- Defect #42962
 max(md1.metricvalue)
 else
  null
 end as Msmt_Max_Val,
 md1.timekey_dttm as timekey_dttm,
 md1.iid as iid,
 m.rcid as rcid,
 m.eid as eid
from
 amx.stage_met_max m,
 AMX.MetData_No_Ex md1
where
 m.mid = md1.mid and
 m.eid = md1.eid 
group by
 -- Defect #42962
 m.msmttyp_id, md1.timekey_dttm, md1.iid, m.rcid, m.eid, m.max_exists
;

-- Defect #42962
alter table amx.stage_msmt_max add primary key (
  timekey_dttm,msmttyp_id,iid,rcid,eid)
;


------------------------------ AVG -------------------------------------

--#IGNORE_ERROR
drop table amx.temp_avg_exists;

create table amx.temp_avg_exists (
 msmttyp_nm varchar(254),
 avg_exists     char(1)
)
;

insert into amx.temp_avg_exists
select distinct
 mt.msmttyp_nm,
 'Y' as avg_exists
from
 TWG.MgrpMbr mb,
 TWG.MsmtTyp mt,
 amx.met_no_ex m
where
 mb.msmttyp_id=mt.msmttyp_id and
 mt.msmttyp_nm=m.name and
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='AVG_E'
;

--#IGNORE_ERROR
drop table amx.temp_avg_status;

create table amx.temp_avg_status (
 msmttyp_nm varchar(254),
 avg_exists     char(1)
)
;

select current timestamp from sysibm.sysdummy1;

-- JC debug
insert into amx.temp_avg_status
select distinct
  m.name as msmttyp_nm,
  value(avg.avg_exists,'N') as avg_exists
from
 amx.Met_No_Ex m left outer join amx.temp_avg_exists avg
 on m.name=avg.msmttyp_nm
group by
m.name,avg.avg_exists
;

--select substr(msmttyp_nm,1,20),avg_exists from amx.temp_avg_status;

--#IGNORE_ERROR
drop table AMX.stage_met_avg;

create table AMX.stage_met_avg (
  msmttyp_id    integer not null,
  mid           bigint not null,
  rcid          bigint not null,
  eid           integer not null,
  avg_exists    char(1) not null
)
;

insert into AMX.stage_met_avg 
select
 mt.msmttyp_id,
 m.mid, 
 m.rcid as rcid,
 m.eid as eid,
 avg.avg_exists
from
 amx.Met_No_Ex m,
 amx.temp_avg_status avg,
 twg.msmttyp mt
where
 m.name=avg.msmttyp_nm and
 m.stat ='AVG' and
 m.name = mt.msmttyp_nm
group by
 mt.msmttyp_id, m.mid, m.rcid, m.eid, avg.avg_exists
;

alter table amx.stage_met_avg add primary key (
  mid,eid)
;

--#IGNORE_ERROR
drop table AMX.Stage_Msmt_Avg;

create table AMX.Stage_Msmt_Avg (
  msmttyp_id    integer not null,
  Msmt_Avg_Val  float,
  timekey_dttm  timestamp not null,
  iid           bigint not null,
  rcid          bigint not null,
  eid           integer not null
)
;

insert into AMX.Stage_Msmt_Avg
select
 m.msmttyp_id,
 Case
 when m.avg_exists='Y'
 then
 -- Defect #42962
 avg(md1.metricvalue)
 else
  null
 end as Msmt_Avg_Val,
 md1.timekey_dttm as timekey_dttm,
 md1.iid as iid,
 m.rcid as rcid,
 m.eid as eid
from
 amx.stage_met_avg m,
 AMX.MetData_No_Ex md1
where
 m.mid = md1.mid and
 m.eid = md1.eid 
group by
 -- Defect #42962
 m.msmttyp_id, md1.timekey_dttm, md1.iid, m.rcid, m.eid, m.avg_exists
;

-- Defect #42962
alter table amx.stage_msmt_avg add primary key (
  timekey_dttm,msmttyp_id,iid,rcid,eid)
;

------------------------------ TOT -------------------------------------

--#IGNORE_ERROR
drop table amx.temp_tot_exists;

create table amx.temp_tot_exists (
 msmttyp_nm varchar(254),
 tot_exists     char(1)
)
;

insert into amx.temp_tot_exists
select distinct
 mt.msmttyp_nm,
 'Y' as tot_exists
from
 TWG.MgrpMbr mb,
 TWG.MsmtTyp mt,
 amx.met_no_ex m
where
 mb.msmttyp_id=mt.msmttyp_id and
 mt.msmttyp_nm=m.name and
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='TOT_E'
;

--#IGNORE_ERROR
drop table amx.temp_tot_status;

create table amx.temp_tot_status (
 msmttyp_nm varchar(254),
 tot_exists     char(1)
)
;

select current timestamp from sysibm.sysdummy1;

-- JC debug
insert into amx.temp_tot_status
select distinct
  m.name as msmttyp_nm,
  value(tot.tot_exists,'N') as tot_exists
from
 amx.Met_No_Ex m left outer join amx.temp_tot_exists tot
 on m.name=tot.msmttyp_nm
group by
m.name,tot.tot_exists
;

--select substr(msmttyp_nm,1,20),tot_exists from amx.temp_tot_status;

--#IGNORE_ERROR
drop table AMX.stage_met_tot;

create table AMX.stage_met_tot (
  msmttyp_id    integer not null,
  mid           bigint not null,
  rcid          bigint not null,
  eid           integer not null,
  tot_exists    char(1) not null
)
;

insert into AMX.stage_met_tot 
select
 mt.msmttyp_id,
 m.mid, 
 m.rcid as rcid,
 m.eid as eid,
 tot.tot_exists
from
 amx.Met_No_Ex m,
 amx.temp_tot_status tot,
 twg.msmttyp mt
where
 m.name=tot.msmttyp_nm and
 m.stat ='TOT' and
 m.name = mt.msmttyp_nm
group by
 mt.msmttyp_id, m.mid, m.rcid, m.eid, tot.tot_exists
;

alter table amx.stage_met_tot add primary key (
  mid,eid)
;

--#IGNORE_ERROR
drop table AMX.Stage_Msmt_Tot;

create table AMX.Stage_Msmt_Tot (
  msmttyp_id    integer not null,
  Msmt_Tot_Val  float,
  timekey_dttm  timestamp not null,
  iid           bigint not null,
  rcid          bigint not null,
  eid           integer not null
)
;

insert into AMX.Stage_Msmt_Tot
select
 m.msmttyp_id,
 Case
 when m.tot_exists='Y'
 then
 -- Defect #42962
 sum(md1.metricvalue)
 else
  null
 end as Msmt_Tot_Val,
 md1.timekey_dttm as timekey_dttm,
 md1.iid as iid,
 m.rcid as rcid,
 m.eid as eid
from
 amx.stage_met_tot m,
 AMX.MetData_No_Ex md1
where
 m.mid = md1.mid and
 m.eid = md1.eid 
group by
 -- Defect #42962
 m.msmttyp_id, md1.timekey_dttm, md1.iid, m.rcid, m.eid, m.tot_exists
;

-- Defect #42962
alter table amx.stage_msmt_tot add primary key (
  timekey_dttm,msmttyp_id,iid,rcid,eid)
;


-- prejoin stage_resouce and resource_transl

--#IGNORE_ERROR
drop  table AMX.stage_res_trans;
create table AMX.stage_res_trans (
  rcid          bigint not null,
  eid           integer not null,
  comptyp_cd    char(17) not null
);

insert into amx.stage_res_trans 
select 
 r.rcid ,
 r.eid ,
 t.comptyp_cd
from
 AMX.Stage_Resources r,
 AMX.V_Resource_Transl t
where
 r.resource=t.resource and
 t.msrc_cd=r.msrc_cd
;

-- join up the 4 tables (min,max,avg,tot) 1 at a time
-- make the intermediary tables as small as possible

-- 1. min to max => stage_msmt_a
-- 2. stage_msmt_a to avg => stage_msmt_b
-- 3. stage_msmt_b to tot => stage_msmt_no_ex
--                here join the extra tables

-- 1. min to max => stage_msmt_a

--#IGNORE_ERROR
drop table AMX.stage_msmt_a;
create table AMX.stage_msmt_a (
  MsmtTyp_id    integer not null,
  Msmt_Min_Val  float,
  Msmt_Max_Val  float,
  timekey_dttm  timestamp not null,
  iid           bigint not null,
  rcid          bigint not null,
  eid           integer not null
);

insert into AMX.stage_msmt_a     
select
 m1.msmttyp_id as msmttyp_id,
 m1.Msmt_Min_Val as Msmt_Min_Val,
 m2.Msmt_Max_Val as Msmt_Max_Val,
 m1.timekey_dttm as timekey_dttm,
 m1.iid as iid,
 m1.rcid as rcid,
 m1.eid as eid
from
 AMX.Stage_Msmt_Min m1,
 AMX.Stage_Msmt_Max m2
where
 m1.timekey_dttm = m2.timekey_dttm and
 m1.msmttyp_id = m2.msmttyp_id and
 m1.iid = m2.iid and
 m1.rcid = m2.rcid and
 m1.eid = m2.eid 
group by
 m1.msmttyp_id, m1.timekey_dttm, m1.iid, m1.rcid, m1.eid,
 m1.Msmt_Min_Val, m2.Msmt_Max_Val 
;

alter table AMX.stage_msmt_a add primary key (eid,rcid,iid,timekey_dttm,msmttyp_id);

-- 2. stage_msmt_a to avg => stage_msmt_b

--#IGNORE_ERROR
drop table AMX.stage_msmt_b;
create table AMX.stage_msmt_b (
  MsmtTyp_id    integer not null,
  Msmt_Min_Val  float,
  Msmt_Max_Val  float,
  Msmt_Avg_Val  float,
  timekey_dttm  timestamp not null,
  iid           bigint not null,
  rcid          bigint not null,
  eid           integer not null
);

insert into AMX.stage_msmt_b     
select
 m1.msmttyp_id as msmttyp_id,
 m1.Msmt_Min_Val as Msmt_Min_Val,
 m1.Msmt_Max_Val as Msmt_Max_Val,
 m2.Msmt_Avg_Val as Msmt_Avg_Val,
 m1.timekey_dttm as timekey_dttm,
 m1.iid as iid,
 m1.rcid as rcid,
 m1.eid as eid
from
 AMX.Stage_Msmt_a m1,
 AMX.Stage_Msmt_avg m2
where
 m1.timekey_dttm = m2.timekey_dttm and
 m1.msmttyp_id = m2.msmttyp_id and
 m1.iid = m2.iid and
 m1.rcid = m2.rcid and
 m1.eid = m2.eid 
group by
 m1.msmttyp_id, m1.timekey_dttm, m1.iid, m1.rcid, m1.eid,
 m1.Msmt_Min_Val, m1.Msmt_Max_Val, m2.msmt_avg_val
;

alter table AMX.stage_msmt_b add primary key (eid,rcid,iid,timekey_dttm,msmttyp_id);

-- 3. stage_msmt_b to tot => stage_msmt_c     

--#IGNORE_ERROR
drop table AMX.stage_msmt_c;
create table AMX.stage_msmt_c (
  MsmtTyp_id    integer not null,
  Msmt_Min_Val  float,
  Msmt_Max_Val  float,
  Msmt_Avg_Val  float,
  Msmt_Tot_Val  float,
  timekey_dttm  timestamp not null,
  iid           bigint not null,
  rcid          bigint not null,
  eid           integer not null
);

insert into AMX.stage_msmt_c     
select
 m1.msmttyp_id as msmttyp_id,
 m1.Msmt_Min_Val as Msmt_Min_Val,
 m1.Msmt_Max_Val as Msmt_Max_Val,
 m1.Msmt_Avg_Val as Msmt_Avg_Val,
 m2.Msmt_Tot_Val as Msmt_Tot_Val,
 m1.timekey_dttm as timekey_dttm,
 m1.iid as iid,
 m1.rcid as rcid,
 m1.eid as eid
from
 AMX.Stage_Msmt_b m1,
 AMX.Stage_Msmt_tot m2
where
 m1.timekey_dttm = m2.timekey_dttm and
 m1.msmttyp_id = m2.msmttyp_id and
 m1.iid = m2.iid and
 m1.rcid = m2.rcid and
 m1.eid = m2.eid 
group by
 m1.msmttyp_id, m1.timekey_dttm, m1.iid, m1.rcid, m1.eid,
 m1.Msmt_Min_Val, m1.Msmt_Max_Val, m1.msmt_avg_val, m2.msmt_tot_val
;

alter table AMX.stage_msmt_c add primary key (eid,rcid,iid,timekey_dttm,msmttyp_id);

-- 4. stage_msmt_c to res_trans => stage_msmt_no_ex 

--#IGNORE_ERROR
drop  table AMX.Stage_Msmt_No_Ex;
create table AMX.Stage_Msmt_No_Ex (
  MsmtTyp_id    integer not null,
  Msmt_Min_Val  float,
  Msmt_Max_Val  float,
  Msmt_Avg_Val  float,
  Msmt_Tot_Val  float,
  CompTyp_Cd    varchar(17) not null,
  timekey_dttm  timestamp not null,
  iid           bigint not null,
  rcid          bigint not null,
  eid           integer not null
);


insert into AMX.Stage_Msmt_No_Ex
select
 m1.msmttyp_id as msmttyp_id,
 m1.Msmt_Min_Val as Msmt_Min_Val,
 m1.Msmt_Max_Val as Msmt_Max_Val,
 m1.Msmt_Avg_Val as Msmt_Avg_Val,
 m1.Msmt_Tot_Val as Msmt_Tot_Val,
 t.comptyp_cd as Comptyp_cd,
 m1.timekey_dttm as timekey_dttm,
 m1.iid as iid,
 m1.rcid as rcid,
 m1.eid as eid
from
 AMX.Stage_Msmt_c m1,
 AMX.Stage_res_trans t
where
 m1.rcid=t.rcid and
 m1.eid=t.eid 
;

-- Defect #42962
alter table AMX.stage_msmt_no_ex add primary key (eid,rcid,iid,timekey_dttm,msmttyp_id);



----------------------------------------------
-- Create an atribute table with no exception.
-- An attribute table is a joint between
-- categories and categoriesdata.The attrtyp_cd
-- is in TEDW format.
----------------------------------------------

declare global temporary table Cat_No_Ex (
  attrtyp_cd  varchar(17),
  name        varchar(128),
  rcid        bigint not null,
  cid         bigint not null,
  eid         integer not null
)
with replace on commit preserve rows not logged
;

insert into session.Cat_No_Ex
select
 a3.attrtyp_cd,
 a3.ITM_attr_property,
 a1.rcid,
 a1.cid,
 a1.eid
from
 AMX.Stage_Categories a1,
 AMX.Stage_Inst_No_Ex a2,
 AMX.AttrTyp_Transl a3
where
 a1.eid=a2.eid and
 a1.rcid=a2.rcid and
 a3.ITM_attr_property= a1.name and
 not exists ( select 1
              from
      AMX.Stage_Categories_Ex a2
        where
           a2.rcid=a1.rcid and
     a2.eid=a1.eid and
     a2.cid=a1.cid
    )
group by
 a3.attrtyp_cd, a3.ITM_attr_property,a1.rcid,a1.cid,a1.eid
;

-- select * from AMX.Stage_Categories;
-- select * from session.Cat_No_Ex;

-- Defect 40724: we have moved here the new code introduced with
-- defect 36944 because it uses objects that are available only at
-- this point of the exception script.

-- Start of new code for defect 36944
---------------------------------------------------------------------------
-- Add an error meassage if the PROXY components do not have the attributes
-- LAST_IP_ADDRESS and <product_code>_HOST logged
----------------------------------------------------------------------------

declare global temporary table Proxy_Comp (
  CompTyp_Target_Cd  varchar(17),
  CompTyp_Source_Cd  varchar(17),
  RelnRul_Strt_DtTm  Timestamp not null,
  RelnRul_End_DtTm   Timestamp not null,
  Itm_Key_Prefix     varchar(128)
 )
with replace on commit preserve rows not logged
;

insert into session.Proxy_Comp
select
 r.CompTyp_Target_Cd as CompTyp_Target_Cd,
 r.Comptyp_Source_Cd as CompTyp_Source_Cd,
 r.RelnRul_Strt_DtTm as RelnRul_Strt_DtTm,
 r.RelnRul_End_DtTm as RelnRul_End_DtTm,
 substr(c.Itm_Key_Property,1,locate('.',c.Itm_Key_Property) -1) as Itm_Key_Prefix
from
 AMX.RelnRul_Transl r,
 AMX.CompTyp_Transl c
where
 r.RelnTyp_cd='PROXY' and
 c.CompTyp_cd=r.CompTyp_Target_Cd
;

--select * from  session.Proxy_Comp;

insert into AMX.Stage_RelnRul_Transl_Ex
select
 c.CompTyp_Source_Cd as CompTyp_Source_Cd,
 c.CompTyp_Target_Cd as CompTyp_Target_Cd,
 'PROXY' as RelnTyp_cd,
 c.RelnRul_Strt_DtTm as RelnRul_Strt_DtTm,
 c.RelnRul_End_DtTm as RelnRul_End_DtTm,
 'LAST_IP_ADDRESS as a compulsory attribute for this proxy component is missing in the Categories and CategoriesData tables.' as Error_Msg,
 current timestamp as Timestamp
-- Need to find Proxy Component in the source first 
from
 session.Proxy_Comp c,
 amx.stage_resources r
where
 r.resource=c.itm_key_prefix and
 not exists (
select 1
from
 session.Cat_No_Ex e
where
 e.AttrTyp_cd='LAST_IP_ADDRESS' and
 substr(e.Name,1,locate('.',e.Name) -1)=c.Itm_Key_Prefix
) and
not exists (
select 1
from
 amx.stage_relnrul_transl_ex t
where
 t.CompTyp_Source_Cd=c.CompTyp_Source_Cd and
 t.CompTyp_Target_Cd=c.CompTyp_Target_Cd and
 error_msg like 'LAST_IP_ADDRESS%'
 )
union
select
 c.CompTyp_Source_Cd as CompTyp_Source_Cd,
 c.CompTyp_Target_Cd as CompTyp_Target_Cd,
 'PROXY' as RelnTyp_cd,
 c.RelnRul_Strt_DtTm as RelnRul_Strt_DtTm,
 c.RelnRul_End_DtTm as RelnRul_End_DtTm,
 'XXX_HOST as a compulsory attribute for this proxy component is missing in the Categories and CategoriesData tables.' as Error_Msg,
 current timestamp as Timestamp
-- Need to find Proxy Component in the source first 
from
 session.Proxy_Comp c,
 amx.stage_resources r
where
 r.resource=c.itm_key_prefix and
 not exists (
select 1
from
 session.Cat_No_Ex e
where
 e.AttrTyp_cd like '%_HOST' and
 substr(e.Name,1,locate('.',e.Name) -1)=c.Itm_Key_Prefix
) and
not exists (
select 1
from
 amx.stage_relnrul_transl_ex t
where
 t.CompTyp_Source_Cd=c.CompTyp_Source_Cd and
 t.CompTyp_Target_Cd=c.CompTyp_Target_Cd and
 error_msg like 'XXX_HOST%'
 )
;

-- select * from AMX.Stage_RelnRul_Transl_Ex;

-- End of new code for defect 36944

declare global temporary table CatData_No_Ex (
  cid            bigint not null,
  categoryvalue  varchar(128),
  timekey_dttm   timestamp not null,
  iid            bigint not null,
  eid            integer not null
)
with replace on commit preserve rows not logged
;

insert into session.CatData_No_Ex
select
 a1.cid,
 a1.categoryvalue,
 a1.timekey_dttm,
 a1.iid,
 a1.eid
from
 AMX.Stage_CategoriesData a1,
 AMX.Stage_Inst_No_Ex a2,
 session.Cat_No_Ex a3
where
 a1.eid=a2.eid and
 a1.iid=a2.iid and
 a3.cid=a1.cid
group by
 a1.cid,a1.categoryvalue, a1.timekey_dttm,a1.iid,a1.eid
;

--select * from AMX.Stage_CategoriesData;
--select * from session.CatData_No_Ex;

--#IGNORE_ERROR
drop table AMX.Stage1_Attr_No_Ex
;
create table AMX.Stage1_Attr_No_Ex(
  attrtyp_cd    varchar(17) not null,
  attr_ITM      varchar(254) not null,
  attr_val      varchar(254),
  timekey_dttm  timestamp not null,
  iid           bigint not null,
  rcid          bigint not null,
  eid           integer not null,
   primary key (attrtyp_cd,attr_ITM,timekey_dttm,iid,rcid,eid)
);

insert into AMX.Stage1_Attr_No_Ex
select
 c.attrtyp_cd,
 c.name,
 cd.categoryvalue,
 cd.timekey_dttm,
 cd.iid,
 c.rcid,
 c.eid
from
 session.Cat_No_Ex c,
 session.CatData_No_Ex cd
where
 c.cid=cd.cid and
 c.eid=cd.eid
group by
 c.attrtyp_cd,c.name,cd.categoryvalue,c.rcid,cd.iid,c.eid,cd.timekey_dttm
 ;

--select * from AMX.stage1_attr_no_ex;
--#IGNORE_ERROR
drop table AMX.Stage_Attr_No_Ex;

create table AMX.Stage_Attr_No_Ex(
  comptyp_cd    varchar(17) not null,
  attrtyp_cd    varchar(17) not null,
  attr_ITM      varchar(254) not null,
  attr_val      varchar(254),
  timekey_dttm  timestamp not null,
  iid           bigint not null,
  rcid          bigint not null,
  eid           integer not null,
   primary key (comptyp_cd,attrtyp_cd,attr_ITM,timekey_dttm,iid,rcid,eid)
);

insert into AMX.Stage_Attr_No_Ex
select
r.comptyp_cd,
a.attrtyp_cd,
a.attr_ITM,
a.attr_val,
a.timekey_dttm,
a.iid,
a.rcid,
a.eid
from
 AMX.Stage1_attr_no_ex a,
 AMX.Stage_InstKey_No_Ex r
where
  a.iid=r.iid and
  a.eid=r.eid
group by
r.comptyp_cd,
a.attrtyp_cd,
a.attr_ITM,
a.attr_val,
a.timekey_dttm,
a.iid,
a.rcid,
a.eid
;

--select * from amx.stage_attr_no_Ex;
-------------------------------------------------------------------
-- Table used in the next step to prepare the comp_msmt sql script
-- Create a table that gives the component level hierarchy of
-- each ITM component type
-------------------------------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_Comp_Level
;
create table AMX.Stage_Comp_Level (
  CompTyp_Cd  varchar(17),
  Msrc_Cd     char(3),
  lvl         integer
);

insert into AMX.Stage_Comp_Level
select
 ckey,
 msrc_cd,
 max(lvl) + 1 as maxlvl
from
 AMX.Stage_All_Comps_Exp
where
 pkey !='HOST'
group by
ckey,msrc_cd
;

-------------------------------------------
-- Does the MetaData for any ITM application
-- change ?
--------------------------------------------
--#IGNORE_ERROR
drop table AMX.Stage_MData_Change
;
create table AMX.Stage_MData_Change (
  table_nm  varchar(40),
  num_rows  integer
);

--------------------------------------------------
--AMX.Stage_Comp_Level / AMX.Stage_Comp_Level_Old
--------------------------------------------------
insert into AMX.Stage_Mdata_Change
select
 'AMX.Stage_Comp_Level' as Table_Nm,
 count(*) as num_rows
from
 AMX.Stage_Comp_Level m1
where
 not exists (
     select 1
     from
       AMX.Stage_Comp_Level_Old m2
     where
       rtrim(m2.comptyp_cd)=rtrim(m1.comptyp_cd) and
       rtrim(m2.msrc_cd)=rtrim(m1.msrc_cd) and
       m2.lvl=m1.lvl
     )
;

insert into AMX.Stage_Mdata_Change
select
 'AMX.Stage_comp_Level_Old' as Table_Nm,
 count(*) as num_rows
from
 AMX.Stage_Comp_Level_Old m2
where
 not exists (
     select 1
     from
       AMX.Stage_Comp_Level m1
     where
       rtrim(m2.comptyp_cd)=rtrim(m1.comptyp_cd) and
       rtrim(m2.msrc_cd)=rtrim(m1.msrc_cd) and
       m2.lvl=m1.lvl
     )
;

-- select * from AMX.Stage_Mdata_Change;

---------------------------------------------------------
--AMX.Stage_Meta_Keys / AMX.Stage_Meta_Keys_Old
---------------------------------------------------------
insert into AMX.Stage_Mdata_Change
select
 'AMX.Stage_Meta_Keys' as Table_Nm,
 count(*) as num_rows
from
 AMX.Stage_Meta_Keys m1
where
 not exists (
     select 1
     from
       AMX.Stage_Meta_Keys_Old m2
     where
       rtrim(m2.comptyp_cd)=rtrim(m1.comptyp_cd) and
       rtrim(m2.ITM_key)=rtrim(m1.ITM_key) and
       m2.lvl=m1.lvl and
       rtrim(m2.msrc_cd)=rtrim(m1.msrc_cd)
           )
;

insert into AMX.Stage_Mdata_Change
select
 'AMX.Stage_Meta_Keys_Old' as Table_Nm,
 count(*) as num_rows
from
 AMX.Stage_Meta_Keys_Old m2
where
 not exists (
     select 1
     from
       AMX.Stage_Meta_Keys m1
     where
       rtrim(m2.comptyp_cd)=rtrim(m1.comptyp_cd) and
       rtrim(m2.ITM_key)=rtrim(m1.ITM_key) and
       m2.lvl=m1.lvl and
       rtrim(m2.msrc_cd)=rtrim(m1.msrc_cd)
     )
;

-- select * from AMX.Mdata_Change;

-----------------------------------------------------------
--AMX.Stage_Meta_Names / AMX.Stage_Meta_Names_Old
-----------------------------------------------------------
insert into AMX.Stage_Mdata_Change
select
 'AMX.Stage_Meta_Names' as Table_Nm,
 count(*) as num_rows
from
 AMX.Stage_Meta_Names m1
where
 not exists (
     select 1
     from
       AMX.Stage_Meta_Names_Old m2
     where
       rtrim(m2.comptyp_cd)=rtrim(m1.comptyp_cd) and
       rtrim(m2.ITM_Name)=rtrim(m1.ITM_Name) and
       m2.lvl=m1.lvl and
       rtrim(m2.msrc_cd)=rtrim(m1.msrc_cd)
           )
;

insert into AMX.Stage_Mdata_Change
select
 'AMX.Stage_Meta_Names_Old' as Table_Nm,
 count(*) as num_rows
from
 AMX.Stage_Meta_Names_Old m2
where
 not exists (
     select 1
     from
       AMX.Stage_Meta_Names m1
     where
       rtrim(m2.comptyp_cd)=rtrim(m1.comptyp_cd) and
       rtrim(m2.ITM_Name)=rtrim(m1.ITM_Name) and
       m2.lvl=m1.lvl and
       rtrim(m2.msrc_cd)=rtrim(m1.msrc_cd)
           )
;

-- select * from AMX.Stage_Mdata_Change;

-----------------------------------------------
-- session.ITM_Comptyp / AMX.Stage_CompTyp_Old
-----------------------------------------------

declare global temporary table ITM_Comptyp (
  CompTyp_Cd           char(17) not null,
  CompTyp_Parent_Cd    char(17),
  CompTyp_Nm           varchar(120) not null,
  CompTyp_Strt_DtTm    timestamp not null,
  CompTyp_End_DtTm     timestamp not null
)
with replace on commit preserve rows not logged
;

insert into session.ITM_Comptyp
select
 m1.comptyp_cd as comptyp_cd,
 m1.CompTyp_Parent_Cd as CompTyp_Parent_Cd,
 m1.CompTyp_Nm as CompTyp_Nm,
 m1.CompTyp_Strt_DtTm as CompTyp_Strt_DtTm,
 m1.CompTyp_End_DtTm as CompTyp_End_DtTm
from
 TWG.CompTyp m1,
 AMX.CompTyp_Transl t,
 TWG.MSrc s
where
 t.comptyp_cd= m1.comptyp_cd and
 t.msrc_cd=s.msrc_cd
group by
 m1.comptyp_cd,m1.comptyp_parent_cd,m1.comptyp_nm,
 m1.comptyp_strt_dttm,m1.comptyp_end_dttm
;

insert into AMX.Stage_Mdata_Change
select
 'session.ITM_CompTyp' as Table_Nm,
 count(*) as num_rows
from
 session.ITM_CompTyp m1
where
 not exists (
     select 1
     from
       AMX.Stage_CompTyp_Old m2
     where
       rtrim(m2.comptyp_cd)=rtrim(m1.comptyp_cd) and
       coalesce(m2.CompTyp_Parent_Cd,'NULL')=coalesce(m1.CompTyp_Parent_Cd,'NULL') and
       rtrim(m2.CompTyp_Nm)=rtrim(m1.CompTyp_Nm) and
       m2.CompTyp_Strt_DtTm=m1.CompTyp_Strt_DtTm and
       m2.CompTyp_End_DtTm=m1.CompTyp_End_DtTm )
;

-- colesce(m2.CompTyp_Parent_Cd,'')=colesce(m1.CompTyp_Parent_Cd,'') and

insert into AMX.Stage_Mdata_Change
select
 'AMX.Stage_CompTyp_Old' as Table_Nm,
 count(*) as num_rows
from
 AMX.Stage_CompTyp_Old m2
where
 not exists (
     select 1
     from
       session.ITM_CompTyp m1
     where
       rtrim(m2.comptyp_cd)=rtrim(m1.comptyp_cd) and
       coalesce(m2.CompTyp_Parent_Cd,'NULL')=coalesce(m1.CompTyp_Parent_Cd,'NULL') and
       rtrim(m2.CompTyp_Nm)=rtrim(m1.CompTyp_Nm) and
       m2.CompTyp_Strt_DtTm=m1.CompTyp_Strt_DtTm and
       m2.CompTyp_End_DtTm=m1.CompTyp_End_DtTm
           )
;

-- select * from AMX.Stage_Mdata_Change;

-----------------------------------------------
-- session.ITM_AttrRul / AMX.Stage_AttrRul_Old
-----------------------------------------------
declare global temporary table ITM_AttrRul (
  CompTyp_Cd         char(17) not null,
  AttrTyp_Cd         char(17) not null,
  AttrRul_Strt_DtTm  timestamp not null,
  AttrRul_End_DtTm   timestamp not null,
  AttrRul_Dom_Ind    char not null
)
with replace on commit preserve rows not logged
;

insert into session.ITM_AttrRul
select
 m1.comptyp_cd as comptyp_cd,
 m1.AttrTyp_Cd as AttrTyp_Cd,
 m1.AttrRul_Strt_DtTm as AttrRul_Strt_DtTm,
 m1.AttrRul_End_DtTm as AttrRul_End_DtTm,
 m1.AttrRul_Dom_Ind as AttrRul_Dom_Ind
from
 AMX.Cur_AttrRul m1,
 AMX.Comptyp_Transl t,
 TWG.Msrc s
where
 m1.comptyp_cd=t.comptyp_cd and
 t.msrc_cd=s.msrc_cd
group by
 m1.comptyp_cd, m1.AttrTyp_Cd,m1.AttrRul_Strt_DtTm,
 m1.AttrRul_End_DtTm,m1.AttrRul_Dom_Ind
;

insert into AMX.Stage_Mdata_Change
select
 'session.ITM_AttrRul' as Table_Nm,
 count(*) as num_rows
from
 session.ITM_AttrRul m1
where
 not exists (
     select 1
     from
       AMX.Stage_AttrRul_Old m2
     where
       rtrim(m2.comptyp_cd)=rtrim(m1.comptyp_cd) and
       rtrim(m2.AttrTyp_Cd)=rtrim(m1.AttrTyp_Cd) and
       m2.AttrRul_Strt_DtTm=m1.AttrRul_Strt_DtTm and
       m2.AttrRul_End_DtTm=m1.AttrRul_End_DtTm and
       m2.AttrRul_Dom_Ind=m1.AttrRul_Dom_Ind )
;

insert into AMX.Stage_Mdata_Change
select
 'AMX.Stage_AttrRul' as Table_Nm,
 count(*) as num_rows
from
 AMX.Stage_AttrRul_Old m2
where
 not exists (
     select 1
     from
       Session.ITM_AttrRul m1
     where
       rtrim(m2.comptyp_cd)=rtrim(m1.comptyp_cd) and
       rtrim(m2.AttrTyp_Cd)=rtrim(m1.AttrTyp_Cd) and
       m2.AttrRul_Strt_DtTm=m1.AttrRul_Strt_DtTm and
       m2.AttrRul_End_DtTm=m1.AttrRul_End_DtTm and
       m2.AttrRul_Dom_Ind=m1.AttrRul_Dom_Ind )
;

-- select * from AMX.Stage_Mdata_Change;

----------------------------------------------------
-- AMX.RelnRul_Transl / AMX.Stage_RelnRul_Transl_Old
----------------------------------------------------
insert into AMX.Stage_Mdata_Change
select
 'AMX.RelnRul_Transl' as Table_Nm,
 count(*) as num_rows
from
 AMX.RelnRul_Transl m1
where
 not exists (
     select 1
     from
       AMX.Stage_RelnRul_Transl_Old m2
     where
       rtrim(m2.CompTyp_Source_Cd)=rtrim(m1.CompTyp_Source_Cd) and
       rtrim(m2.CompTyp_Target_Cd)=rtrim(m1.CompTyp_Target_Cd) and
       rtrim(m2.RelnTyp_cd)=rtrim(m1.RelnTyp_cd) and
       m2.RelnRul_Strt_DtTm=m1.RelnRul_Strt_DtTm and
       m2.RelnRul_End_DtTm=m1.RelnRul_End_DtTm
           )
;

insert into AMX.Stage_Mdata_Change
select
 'AMX.Stage_RelnRul_Transl_Old' as Table_Nm,
 count(*) as num_rows
from
 AMX.Stage_RelnRul_Transl_Old m2
where
 not exists (
     select 1
     from
       AMX.RelnRul_Transl m1
     where
      rtrim(m2.CompTyp_Source_Cd)=rtrim(m1.CompTyp_Source_Cd) and
       rtrim(m2.CompTyp_Target_Cd)=rtrim(m1.CompTyp_Target_Cd) and
       rtrim(m2.RelnTyp_cd)=rtrim(m1.RelnTyp_cd) and
       m2.RelnRul_Strt_DtTm=m1.RelnRul_Strt_DtTm and
       m2.RelnRul_End_DtTm=m1.RelnRul_End_DtTm
           )
;

-- select * from AMX.Stage_Mdata_Change;

--------------------------------------------------------
-- AMX.Stage_All_Comps_Exp / AMX.Stage_All_Comps_Exp_Old
--------------------------------------------------------
insert into AMX.Stage_Mdata_Change
select
 'AMX.Stage_All_Comps_Exp' as Table_Nm,
 count(*) as num_rows
from
 AMX.Stage_All_Comps_Exp m1
where
 not exists (
     select 1
     from
       AMX.Stage_All_Comps_Exp_Old m2
     where
       rtrim(m2.msrc_cd)=rtrim(m1.msrc_cd) and
       rtrim(m2.ckey)=rtrim(m1.ckey) and
       rtrim(m2.pkey)=rtrim(m1.pkey) and
       m2.lvl=m1.lvl
           )
;

insert into AMX.Stage_Mdata_Change
select
 'AMX.Stage_All_Comps_Exp_Old' as Table_Nm,
 count(*) as num_rows
from
 AMX.Stage_All_Comps_Exp_Old m2
where
 not exists (
     select 1
     from
       AMX.Stage_All_Comps_Exp m1
     where
       rtrim(m2.msrc_cd)=rtrim(m1.msrc_cd) and
       rtrim(m2.ckey)=rtrim(m1.ckey) and
       rtrim(m2.pkey)=rtrim(m1.pkey) and
       m2.lvl=m1.lvl
           )
;

-- select * from AMX.Stage_Mdata_Change;


---------------------------------------------------------
-- Update the AMX.Stage_instkey_no_ex
-- so that the comptyp_cd is correct according to the
-- itm_key. This is important because we may have the same
-- attribute name for 2 components in the same hierarchy , so
-- we need to join the amx.stage_instkey_no_ex on the comptyp_cd
--
--
-- We have itm keys of one PAC that are a subset of itm_keys of a different PAC.
-- For instance Domino has DominoServer.ServerName and GWI has Server.ServerName.
-- So we need to join on the AVA code also.
-----------------------------------------------------------------
update amx.stage_instkey_no_ex i set comptyp_cd = (
select
ct.comptyp_cd
from
amx.comptyp_transl ct
where
  locate (';'||i.itm_key||';',';'||ct.itm_key_property||';') != 0
 and
  substr(i.comptyp_cd,1,3)=Substr(ct.comptyp_cd,1,3)
 )
where exists ( select 1
from
amx.comptyp_transl ct
where
  locate (';'||i.itm_key||';',';'||ct.itm_key_property||';') != 0
 and
  substr(i.comptyp_cd,1,3)=Substr(ct.comptyp_cd,1,3)
 )
 ;

----------------------------------------------------------
-- Update ETL1_STATUS
------------------------------------------------------------

--#EXECUTE_AT_TARGET
update TWG.Extract_Control set Extctl_to_Dttm= current timestamp - current timezone  where EXTCTL_TARGET='AMX_STATUS_S030_EXCEPTION_STEP';

--#EXECUTE_AT_TARGET
INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'AMX_STATUS_S030_EXCEPTION_STEP' AND
 EC.EXTCTL_TARGET = 'AMX_STATUS_S030_EXCEPTION_STEP'
; 


