-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: Common/src/tedw_app/amx/fixpack2/etl/sql/amx_c10_s010_rim_prune.db2, tmnt_etl, tmnt_5.1.1_FP06, 512ITMFP01_0616
-- #   Revision: 1.5
-- #   Date: 2/19/04 14:34:12
-- ############################################################################

--
-- //////// display the content of the prune_control table as
-- //////// resulting from the previous run of the prune process...
--
--#EXECUTE_AT_TARGET
SELECT * FROM AMX.PRUNE_CONTROL
;

-- NOTE: the timekey in the Middle Layer database is expressed as
-- the number of seconds since the epoch (in GMT time), so we must
-- find the timekey that is n days less than now...

--#EXECUTE_AT_TARGET
UPDATE AMX.PRUNE_CONTROL SET
PRUNE_KEY =
86400 * ( DAYS(DATE(CURRENT TIMESTAMP - CURRENT TIMEZONE)) - DAYS('01/01/1970')
          - (SELECT AGE_DAYS FROM AMX.PRUNE_CONTROL)
        ) + MIDNIGHT_SECONDS(CURRENT TIME - CURRENT TIMEZONE)
;

--#IGNORE_ERROR
DROP TABLE TEMP_PRUNE_KEY
;

-- 42314: we need two additional fields to store the number of records that
-- must actually be deleted from the metricsdata and categoriesdata tables.
CREATE TABLE TEMP_PRUNE_KEY (
  PRUNE_KEY INTEGER,
  MET_RECS  INTEGER,
  CAT_RECS  INTEGER )
;

--#INSERT_INTO_SOURCE
INSERT INTO TEMP_PRUNE_KEY
  SELECT PRUNE_KEY, 0, 0 FROM AMX.PRUNE_CONTROL
;

UPDATE TEMP_PRUNE_KEY
SET MET_RECS = (SELECT COUNT(*) FROM METRICSDATA WHERE TIMEKEY < TEMP_PRUNE_KEY.PRUNE_KEY),
    CAT_RECS = (SELECT COUNT(*) FROM CATEGORIESDATA WHERE TIMEKEY < TEMP_PRUNE_KEY.PRUNE_KEY)
;
--
-- //////// display the rows that will be deleted...
--
-- 42314: this statement is intended only for debugging/tracing purpose; it can be commented out
-- in a working/production environment to further speed-up the pruning process...
--SELECT
--  DISTINCT TIMEKEY,TIMEKEY_DTTM FROM METRICSDATA
--WHERE
--  TIMEKEY < (SELECT PRUNE_KEY FROM TEMP_PRUNE_KEY)
--;
--
-- //////// delete all records from MetricsData older
-- //////// than prune_key seconds since the epoch...
--
-- 42314: delete records only if it is necessary...
DELETE FROM METRICSDATA
WHERE ((SELECT MET_RECS FROM TEMP_PRUNE_KEY) > 0) AND
      TIMEKEY < (SELECT PRUNE_KEY FROM TEMP_PRUNE_KEY)
;
--
-- //////// display the rows that will be deleted...
--
-- 42314: this statement is intended only for debugging/tracing purpose; it can be commented out
-- in a working/production environment to further speed-up the pruning process...
--SELECT
--  DISTINCT TIMEKEY,TIMEKEY_DTTM FROM CATEGORIESDATA
--WHERE
--  TIMEKEY < (SELECT PRUNE_KEY FROM TEMP_PRUNE_KEY)
--;
--
-- //////// delete all records from CategoriesData older
-- //////// than prune_key seconds since the epoch...
--
-- 42314: delete records only if it is necessary...
DELETE FROM CATEGORIESDATA
WHERE ((SELECT CAT_RECS FROM TEMP_PRUNE_KEY) > 0) AND
      TIMEKEY < (SELECT PRUNE_KEY FROM TEMP_PRUNE_KEY)
;

-- 49346: the cleanup of the parent tables has been externalized, i.e.
-- delegated to an administrative task, because, without appropriate indexes 
-- (removed to speed up the data insertion process) the cleanup SQL statements
-- could be excessively slow.

--
-- //////// record the successful prune (time fields are in UTC)...
--
--#EXECUTE_AT_TARGET
INSERT INTO AMX.PRUNE_LOG
SELECT
  CURRENT TIMESTAMP - CURRENT TIMEZONE,
  AGE_DAYS,
  PRUNE_KEY,
  TIMESTAMP( DATE('01/01/1970') + INTEGER(PRUNE_KEY/86400) DAYS ,
    TIME('00.00.00') + (PRUNE_KEY - (86400 * (INTEGER(PRUNE_KEY/86400)))) SECOND )
FROM
  AMX.PRUNE_CONTROL
;
--
-- //////// show the resulting prune log...
--
--#EXECUTE_AT_TARGET
SELECT * FROM AMX.PRUNE_LOG
;
