#!/bin/sh
##########################################################################
#
#  Licensed Materials - Property of IBM
#  5698-EAS
#
#  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#   File Information: Common/src/tedw_app/amx/fixpack2/misc/amx_app_deinstall.sh, tmnt_etl, tmnt_5.1.1_FP06, 512ITMFP01_0616
#   Revision: 1.2.1.1
#   Date: 10/2/03 21:09:36
############################################################################
#
# Desc: This program should be use to deinstall the amx warehouse application package.
#
# Command Line Args:
#       -v = Release Version
#       -h = Help
#       -r = Show return code messages
#       -d = Run in Debug
#       -n = No warning countdown
#       -l = List applications installed only
#       -z = List application RPI and Mart dependencies
#
#
# Required Config File:
#       twh_app_deinstall.cfg
#
#
# Required Env Vars:
#       None.
#
# Return Codes:
#       * See display_return_code_messages function below
#
#
# Interpreter Required:
#       NT/2000 = BASH
#       Unix    = SH (Bourne Shell)
#
#
# Message Types:
#       (I) - Informational
#       (W) - Warning
#       (F) - Fatal
#
#
# Reference Files for this Installer:
#
# Notes:
#  What will not be done in this script
#	* Data in the CDW will remain (Must be removed manually)
#	* IBM DB2 Data Warehouse Center objects (must be removed manually)
#
#########################################################################
#
###############################################################
################ Custom Functions Section #####################
###############################################################

# Pulls in the generic shared routines
# Note return codes 3-70 reserved for the gen routines
include_gen_routines()
{
# Set context for generic routines (Use Core for now)
TWH_APP_DEINST_CONTEXT=$TRUE; export TWH_APP_DEINST_CONTEXT

# Bug on NT - fix the path back to be unix type path
gen_file_and_path=`echo $PROGRAM | sed 's/\\\\/\//g' `

gen_path=`dirname "$gen_file_and_path" `

# Confirm file
if [ ! -r "$gen_path"/twh_gen_routines.sh ]; then
  echo "      (F) CDWIC0071E Could not locate the twh_gen_routines.sh file."
  exit 71
fi

# pull in the generic routines
. "$gen_path"/twh_gen_routines.sh

return 0;
}


###


# Display Help
display_help()
{
echo ""
echo "  Program:  $PROGNAME"
echo "  Desc:     This is the main program to deinstall a Tivoli Warehouse (TEDW) Application Product"
echo ""
echo "  Usage:    twh_app_deinstall.sh -c config_file [ options... ]"
echo ""
echo "  Options:"
echo "            -c, --config     = The required config file"
echo "            -v, --version    = Version Information"
echo "            -h, --help       = Help Information"
echo "            -r, --retcode    = Return Code messages Information"
echo "            -d, --debug      = Run with Debug turned on"
echo "            -n, --nocount    = Run without countdown turned on"
echo "            -l, --listapps   = List the applications installed only"
echo "            -z, --listrels   = List application RPI and Mart relationships only"
echo ""
echo "  Config File:"
echo "            twh_app_deinstall.cfg"
echo ""
echo "  Message Levels:"
echo "            (I) - Informational"
echo "            (W) - Warning"
echo "            (F) - Fatal"
echo ""

return 0
}


###


# Display return code messages  ??? Review these
display_return_code_messages()
{
echo ""
echo "    Return code messages for this program:"
echo "    ======================================"

gr_display_return_codes;


echo ""
echo "    Application Deinstall specific errors:"
echo "    71 = Could not locate/include twh_generic_routines.sh"
echo "    72 = Could not read/locate the app install list file"
echo "    73 = Could not locate the application media directory from app list file"
echo "    74 = Property missing from the app properties file"
echo "    75 = Could not read application properties file"
echo "    76 = Invalid format in properties file. Should be property=value"
echo "    77 = No value found for property"
echo "    78 = Illegal option found in properties file"
echo "    79 = Could not detect Core tools install required for this application"
echo "    80 = Could not create application working directory top"
echo ""

return 0;
}



###


#
display_warning_message()
{
echo "    ============================================================="
echo "             WARNING!!!  WARNING!!!  WARNING!!!"
echo "                   POSSIBLE DATA LOSS!!!"
echo ""
echo "    You have 30 seconds to CTRL-C to exit this program!"
echo ""
echo "    This program will remove some database objects and data"
echo "    created and used by this Tivoli application."
echo "    These objects include physical media (files) and DB2 database"
echo "    objects including data collected in the reporting databases"
echo "    for this TEDW product (A.K.A. Datamarts)."
echo "    The CDW will not be affected."
echo ""
echo ""
echo "    This will mean the loss of datamarts for this "
echo "    Tivoli Application during the use of this product"
echo "    ============================================================="


# Countdown to allow time to exit
if [ -z "$NO_COUNT_NEEDED" ]; then
  echo "    Starting countdown..."

  loop_count=30
  while [ $loop_count -gt 0 ];
    do
    sleep 1
    echo "    $loop_count"
    loop_count=`expr $loop_count - 1 `
    done
else
  echo "    (I) Bypass countdown command line option detected."
fi

echo ""
echo "    ...No forced exit detected"
echo "    Continuing to execute TEDW Application Deinstallation."
echo "    ============================================================="
echo ""

return 0;
}



###


#
set_private_program_vars()
{

CORE_LOGDIR="$TWH_TOPDIR/install/logs"	#

# App props config file
APP_INSTALL_PROPS_FILE=twh_install_props.cfg


return 0
}


###


#
validate_core_comp_list_file()
{
# Validate all properties are here
if [ -z "$TWH_CORE_INSTALL_TYPE" ]; then
  echo "      (F) CDWIA0106E Error.  Property TWH_CORE_INSTALL_TYPE not found in config file"
  clean_up
  exit 106
elif [ -z "$TWH_CTRL_COMP" ]; then
  echo "      (F) CDWIA0106E Error.  Property TWH_CTRL_COMP not found in config file"
  clean_up
  exit 106
elif [ -z "$TWH_CTRL_HOST" ]; then
  echo "      (F) CDWIA0106E Error.  Property TWH_CTRL_HOST not found in config file"
  clean_up
  exit 106
elif [ -z "$TWH_CDW_HOST" ]; then
  echo "      (F) CDWIA0106E Error.  Property TWH_CDW_HOST not found in config file"
  clean_up
  exit 106
elif [ -z "$TWH_MART_HOST" ]; then
  echo "      (F) CDWIA0106E Error.  Property TWH_MART_HOST not found in config file"
  clean_up
  exit 106
elif [ -z "$TWH_RPI_HOST" ]; then
  echo "      (F) CDWIA0106E Error.  Property TWH_RPI_HOST not found in config file"
  clean_up
  exit 106
elif [ -z "$TWH_CDW_COMP" ]; then
  echo "      (F) CDWIA0106E Error.  Property TWH_CDW_COMP not found in config file"
  clean_up
  exit 106
elif [ -z "$TWH_MART_COMP" ]; then
  echo "      (F) CDWIA0106E Error.  Property TWH_MART_COMP not found in config file"
  clean_up
  exit 106
elif [ -z "$TWH_RPI_COMP" ]; then
  echo "      (F) CDWIA0106E Error.  Property TWH_RPI_COMP not found in config file"
  clean_up
  exit 106
elif [ -z "$TWH_DB2_NODE_MAJIC" ]; then
  echo "      (F) CDWIA0106E Error.  Property TWH_DB2_NODE_MAJIC not found in config file"
  clean_up
  exit 106
elif [ -z "$TWH_CTRL_NODE_ALIAS" ]; then
  echo "      (F) CDWIA0106E Error.  Property TWH_CTRL_NODE_ALIAS not found in config file"
  clean_up
  exit 106
elif [ -z "$TWH_CDW_NODE_ALIAS" ]; then
  echo "      (F) CDWIA0106E Error.  Property TWH_CDW_NODE_ALIAS not found in config file"
  clean_up
  exit 106
elif [ -z "$TWH_MART_NODE_ALIAS" ]; then
  echo "      (F) CDWIA0106E Error.  Property TWH_MART_NODE_ALIAS not found in config file"
  echo "          Ensure a carriage return is not missing from the last line in the config file"
  clean_up
  exit 106
fi


return 0;
}


###


#  Read the supplied core component list file
#  This file will tell us what type of core install was
#  selected and some properties if they did a Custom install
read_core_comp_list_file()
{
echo "==> Reading the Core Component List file located"
echo "    at ($TWH_TOPDIR/install/logs)."


# Is it there, we have to handle this not being here
# because the install may not have made it this far.
if [ ! -r "$TWH_CORE_COMP_FILE" ]; then
  echo "      (F) File ($TWH_CORE_COMP_FILE) not found. This program"
  echo "          requires this file to define what TEDW components"
  echo "          have been installed on this host."
  echo "          Exiting..."
  clean_up
  exit 1;
fi


# Open our config file
exec < "$TWH_CORE_COMP_FILE"


# Parse the core comp file
while :
  do
  # Read a line
  read cur_line

  # Did we hit the end of the file?
  if [ $? -ne 0 ]; then break; fi

  # clean whitespace and look for comment char
  cleaned_line=`echo "$cur_line" | sed "s/        //g" `

  # On Windows, do this to avoid ctrl M issues
  if [ "$INTERP" = "$WIN" ]; then
    blah=`echo "$cleaned_line" | grep -v '[a-zA-Z].*' `
    if [ $? -eq 0 ]; then continue; fi
  fi

  # Goto next line if this is a comment
  echo "$cleaned_line" | grep -i "^#" > /dev/null
  if [ $? -eq 0  -o ! "$cleaned_line" ]; then
    continue
  fi

  # Now parse for properties and validate them
  echo "$cleaned_line" | grep "=" > /dev/null
  if [ ! $? -eq 0 ]; then
    gr_print_conf_read_error "$cleaned_line" ;
    clean_up
    exit 108
  fi

  # Find the property tag and value and upcase the tag
  property_line=`echo "$cleaned_line" | sed "s/#.*//" `
  prop_tag=`echo "$property_line" | sed "s/=.*//" | tr '[a-z]' '[A-Z]' `
  prop_val=`echo "$property_line" | sed "s/.*=//" `

  # Ensure they supplied something
  if [ -z "$prop_val" ]; then
    echo "      (F) CDWIA0108E No value found for property ($prop_tag)."
    clean_up
    exit 108
  fi

  # Now define the property for later use
  case $prop_tag in

    #
    TWH_CORE_INSTALL_TYPE)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_CORE_INSTALL_TYPE="$prop_val"
        echo "      (I) Core installation type was ($TWH_CORE_INSTALL_TYPE)"
        uppr_val=`echo "$TWH_CORE_INSTALL_TYPE" | tr '[a-z]' '[A-Z]'`
        if [ "$uppr_val" = "TWH_CUSTOM" ]; then
          CUSTOM_INSTALL=$TRUE
        fi
        export CUSTOM_INSTALL
        ;;

    #
    TWH_CTRL_COMP)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_CTRL_COMP="$prop_val"
        uppr_val=`echo "$TWH_CTRL_COMP" | tr '[a-z]' '[A-Z]'`
        if [ "$uppr_val" = "TRUE" ]; then
          ADMIN_CHECKED=$TRUE
        fi
        export ADMIN_CHECKED
        ;;

    #
    TWH_CTRL_HOST)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_CTRL_HOST="$prop_val"
        export TWH_CTRL_HOST
        ;;

    #
    TWH_CDW_HOST)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_CDW_HOST="$prop_val"
        export TWH_CDW_HOST
        ;;

    #
    TWH_MART_HOST)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_MART_HOST="$prop_val"
        export TWH_MART_HOST
        ;;

    #
    TWH_RPI_HOST)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_RPI_HOST="$prop_val"
        export TWH_RPI_HOST
        ;;

    #
    TWH_CDW_COMP)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_CDW_COMP="$prop_val"
        uppr_val=`echo "$TWH_CDW_COMP" | tr '[a-z]' '[A-Z]'`
        if [ "$uppr_val" = "TRUE" ]; then
          CDW_CHECKED=$TRUE
        fi
        export CDW_CHECKED
        ;;
    #
    TWH_MART_COMP)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_MART_COMP="$prop_val"
        uppr_val=`echo "$TWH_MART_COMP" | tr '[a-z]' '[A-Z]'`
        if [ "$uppr_val" = "TRUE" ]; then
          MART_CHECKED=$TRUE
        fi
        export MART_CHECKED
        ;;
    #

    TWH_RPI_COMP)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_RPI_COMP="$prop_val"
        uppr_val=`echo "$TWH_RPI_COMP" | tr '[a-z]' '[A-Z]'`
        if [ "$uppr_val" = "TRUE" ]; then
          RPI_CHECKED=$TRUE
        fi
        export RPI_CHECKED
        ;;

    TWH_DB2_NODE_MAJIC)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_DB2_NODE_MAJIC="$prop_val"
        export TWH_DB2_NODE_MAJIC
        ;;

    TWH_CTRL_NODE_ALIAS)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_CTRL_NODE_ALIAS="$prop_val"
        export TWH_CTRL_NODE_ALIAS
        ;;

    TWH_CDW_NODE_ALIAS)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_CDW_NODE_ALIAS="$prop_val"
        export TWH_CDW_NODE_ALIAS
        ;;

    TWH_MART_NODE_ALIAS)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_MART_NODE_ALIAS="$prop_val"
        export TWH_MART_NODE_ALIAS
        ;;

    # Default - is an error
    *)
        echo "      (F) CDWIA0108E Illegal option found."
        echo "          Illegal value is ($prop_tag)"
        clean_up
        exit 108
        ;;
    esac
  done


# Detect any missing properties
validate_core_comp_list_file;

echo "      (I) Completed reading Core Component List file"
return 0;
}


###


check_core_tools_installed()
{
echo "==> Checking the Core Tools Version"

# Prevent from running if Core not there
if [ ! -r "$CORE_VERSION_FILE" ]; then
  echo "      (F) A successful installation of TEDW version 1.1"
  echo "          Core tools has not been detected on this host."
  echo "          You cannot run the application deinstallation"
  echo "          if there was not a sucessful Core tools installation"
  echo "          Exiting..."
  clean_up
  exit 1
fi

return 0;
}


###


#
validate_app_props_file()
{
# Validate all properties are here
if [ -z "$APP_DISPLAY_NAME" ]; then
  echo "      (F) CDWIA0074E Error.  Property APP_DISPLAY_NAME not found in config file"
  clean_up
  exit 74
elif [ -z "$AVA_CODE" ]; then
  echo "      (F) CDWIA0074E Error.  Property AVA_CODE not found in config file"
  clean_up
  exit 74
elif [ -z "$TWH_CORE_PREREQ_VERSION" ]; then
  echo "      (F) CDWIA0074E Error.  Property TWH_CORE_PREREQ_VERSION not found in config file"
  clean_up
  exit 74
elif [ -z "$APP_REL_VERSION" ]; then
  echo "      (F) CDWIA0074E Error.  Property APP_REL_VERSION not found in config file"
  clean_up
  exit 74
elif [ -z "$PATCH_REL_VERSION" ]; then
  echo "      (F) CDWIA0074E Error.  Property PATCH_REL_VERSION not found in config file"
  clean_up
  exit 74
elif [ -z "$AFTER_SCRIPT" ]; then
  echo "      (F) CDWIA0074E Error.  Property AFTER_SCRIPT not found in config file"
  clean_up
  exit 74
elif [ -z "$APP_DATAMART_SCHEMA" ]; then
  echo "      (F) CDWIA0074E Error.  Property APP_DATAMART_SCHEMA not found in config file"
  clean_up
  exit 74
elif [ -z "$REPORTS_INCLUDED" ]; then
  echo "      (F) CDWIA0074E Error.  Property REPORTS_INCLUDED not found in config file"
  echo "          Ensure a carriage return is not missing from the last line in the config file"
  clean_up
  exit 74
fi

return 0;
}


###


###
#  Read the supplied application property file
#  	$1 = Current Application Description
#	$2 = Current application media directory
read_app_props_file()
{
CUR_APP_DIR="$TWH_TOPDIR/apps/$APPLICATION_TO_DELETE"
echo "==> Reading the application property file"
echo "    ($CUR_APP_DIR/$APP_INSTALL_PROPS_FILE)."


# is it there
if [ ! -r "$CUR_APP_DIR/$APP_INSTALL_PROPS_FILE" ]; then
  echo "      (F) CDWIA0075E Could not find or read application properties file"
  echo "          for application deinstallation. File is"
  echo "          ($CUR_APP_DIR/$APP_INSTALL_PROPS_FILE)."
  clean_up
  exit 75
fi

# Open our config file
exec < "$CUR_APP_DIR/$APP_INSTALL_PROPS_FILE"



# Parse the app properties config file
while :
  do
  # Read the config file
  read cur_line

  # Did we hit the end of the file?
  if [ $? -ne 0 ]; then break; fi

  # clean whitespace and look for comment char
  cleaned_line=`echo "$cur_line" | sed "s/        //g" `

  # On Windows, do this to avoid ctrl M issues
  if [ "$INTERP" = "$WIN" ]; then
    blah=`echo "$cleaned_line" | grep -v '[a-zA-Z].*' `
    if [ $? -eq 0 ]; then continue; fi
  fi

  # Goto next line if this is a comment
  echo "$cleaned_line" | grep -i "^#" > /dev/null
  if [ $? -eq 0  -o ! "$cleaned_line" ]; then
    continue
  fi

  # Now parse for properties and validate them
  echo "$cleaned_line" | grep "=" > /dev/null
  if [ ! $? -eq 0 ]; then
    gr_print_conf_read_error "$cleaned_line" ;
    clean_up
    exit 76
  fi

  # Find the property tag and value and upcase the tag
  property_line=`echo "$cleaned_line" | sed "s/#.*//" `
  prop_tag=`echo "$property_line" | sed "s/=.*//" | tr '[a-z]' '[A-Z]' `
  prop_val=`echo "$property_line" | sed "s/.*=//" `

  # Ensure they supplied something
  if [ -z "$prop_val" ]; then
    echo "      (F) CDWIA0077E No value found for property ($prop_tag)."
    clean_up
    exit 77
  fi

  # Now define the property for later use
  case $prop_tag in

    #
    APP_DISPLAY_NAME)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        APP_DISPLAY_NAME="$prop_val"
        export APP_DISPLAY_NAME
        echo "      (I) Application Product is ($APP_DISPLAY_NAME)"
        ;;

    #
    AVA_CODE)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        AVA_CODE="$prop_val"
        export AVA_CODE
        ;;

    #
    TWH_CORE_PREREQ_VERSION)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_CORE_PREREQ_VERSION="$prop_val"
        export TWH_CORE_PREREQ_VERSION
        ;;

    #
    APP_REL_VERSION)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        APP_REL_VERSION="$prop_val"
        export APP_REL_VERSION
        ;;

    #
    PATCH_REL_VERSION)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        PATCH_REL_VERSION="$prop_val"
        export PATCH_REL_VERSION
        ;;

    #
    AFTER_SCRIPT)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        AFTER_SCRIPT="$prop_val"
        export AFTER_SCRIPT
        ;;
    #
    APP_DATAMART_SCHEMA)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        APP_DATAMART_SCHEMA="$prop_val"
        export APP_DATAMART_SCHEMA
        ;;

    # Do they have canned reports?
    REPORTS_INCLUDED)
        if [ $DEBUG ]; then echo "$prop_tag found"; fi
        uppr_val=`echo $prop_val | tr '[a-z]' '[A-Z]'`
        if [ "$uppr_val" = "TRUE" ]; then
          REPORTS_INCLUDED="TRUE"
        else
          REPORTS_INCLUDED="FALSE"
        fi
        export REPORTS_INCLUDED
        ;;

    # Default - is an error
    *)
        echo "      (F) CDWIA0078E Illegal option found."
        echo "          Illegal value is ($prop_tag)"
        clean_up
        exit 78
        ;;
    esac
  done


# Detect any missing properties
validate_app_props_file;


# Shell hack needed to delete other files (frees this file)
# This unlocks the last file used on stdin
touch "$TMPDIR/null_file.txt"
exec < "$TMPDIR/null_file.txt"


# App backup directory
APP_BACKUP_DIR="$TWH_TOPDIR/apps_backups/$AVA_CODE/deinstall"


echo "      (I) Completed reading Application Properties File"
return 0;
}


###

# If the app team has a before script, kick it off
# We pass two parms into the app before script
#	$1 = The TWH config file
#	$2 = the app working directory
exec_before_script()
{
TWH_APP_CONFIG_FILE="$TWH_TOPDIR/install/bin/twh_app_install.cfg"
DEINST_BEFORE_SCRIPT="misc/${AVA_CODE}_deinst_before.sh"
echo "==> Preparing to Execute the Application Deinstall Before Script"

# Set file and path
before_script_file="$APP_WORK_DIR/$DEINST_BEFORE_SCRIPT"

# If the file is not there then skip the afterscript.
if [ ! -f "$before_script_file" ]; then
  echo "      (I) No application deinstall before script specified for this application."
  return 0;
fi

# is the script really here
if [ ! -r "$before_script_file" ]; then
  echo "      (F) Error trying to read application deinstall Before Script."
  echo "          File is ($before_script_file)."
  clean_up
  exit 102
elif [ ! -x "$before_script_file" ]; then
  chmod 777 "$before_script_file"
fi

# Build a log file and fire off the after script
log_file=`basename "$before_script_file"`
log_file_name="${log_file}.log"
tmp_log_file_name="${log_file}.log"
APP_LOGDIR="${APP_WORK_DIR}/install/logs"

echo "      (I) Executing application deinstall before script"
echo "          Application Execution log is ($TMPDIR$tmp_log_file_name)"
"$before_script_file" "$TWH_CONFIG_FILE" "$APP_WORK_DIR" > "$TMPDIR$tmp_log_file_name" 2>&1
b_rc=$?
if [ $b_rc -ne 0 ]; then
  # move log to app logs dir
  if [ -n "$TWH_KEEP_TMP_FILES_TRUE" ]; then
    mv "$TMPDIR"/$tmp_log_file_name "$TMPDIR"/$tmp_log_file_name.org
    cat "$TMPDIR"/$tmp_log_file_name.org | sed -e "s/\(.* using\) .*/\1/g" >"$APP_LOGDIR"/$tmp_log_file_name
    cat "$TMPDIR"/$tmp_log_file_name.org | sed -e "s/\(.* using\) .*/\1/g" >"$TMPDIR"/$tmp_log_file_name
    rm "$TMPDIR"/$tmp_log_file_name.org
  else
    cat "$TMPDIR"$tmp_log_file_name | sed -e "s/\(.* using\) .*/\1/g" >"$APP_LOGDIR"/$tmp_log_file_name
    rm "$TMPDIR"$tmp_log_file_name
  fi

  # Did the prescript detect a prereq problem?
  if [ $b_rc -eq 5 ]; then
  
  	echo "      (F) Application prerequisite problem detected."
  	echo "          Application Deinstall halted."
  	echo "          Check the Application Execution log for details:"
  	echo "          ($APP_LOGDIR/$tmp_log_file_name)"
  	clean_up
  	exit 255
  else
  	echo "      (W) Failure detected during run of application deinstall before script."
  	echo "          Application Deinstall continuing."
  	echo "          Check the Application Execution log for details:"
  	echo "          ($APP_LOGDIR/$tmp_log_file_name)"
  fi
fi


echo "      (I) Completed preparing and executing the application deinstall before script"
return 0;
}


###



# If the app team has a after scirpt, kick it off
# We pass to parms into the app afterscript
#	$1 = The TWH config file
#	$2 = the app working directory
exec_after_script()
{
DEINST_AFTER_SCRIPT="misc/${AVA_CODE}_deinst_after.sh"
echo "==> Preparing to Execute the Application After Script"

# Set file and path
after_script_file="$APP_WORK_DIR/$DEINST_AFTER_SCRIPT"

# If the file is not there then skip the afterscript.
if [ ! -f "$after_script_file" ]; then
  echo "      (I) No application deinstall after script specified for this application."
  return 0;
fi

# is the script really here
if [ ! -r "$after_script_file" ]; then
  echo "      (F) Error trying to read application After Script."
  echo "          File is ($after_script_file)."
  clean_up
  exit 102
elif [ ! -x "$after_script_file" ]; then
  chmod 777 "$after_script_file"
fi

# Build a log file and fire off the after script
log_file=`basename "$after_script_file"`
log_file_name="${log_file}.log"
tmp_log_file_name="tmp_${log_file}.log"

echo "      (I) Executing application after script"
echo "          Application Execution log is ($TMPDIR/$tmp_log_file_name)"
"$after_script_file" "$TWH_CONFIG_FILE" "$APP_WORK_DIR" > "$TMPDIR/$tmp_log_file_name" 2>&1
if [ $? -ne 0 ]; then
  # move log to app logs dir
  if [ -n "$TWH_KEEP_TMP_FILES_TRUE" ]; then
    mv "$TMPDIR"/$tmp_log_file_name "$TMPDIR"/$tmp_log_file_name.org
    cat "$TMPDIR"/$tmp_log_file_name.org | sed -e "s/\(.* using\) .*/\1/g" >"$APP_LOGDIR"/$tmp_log_file_name
    cat "$TMPDIR"/$tmp_log_file_name.org | sed -e "s/\(.* using\) .*/\1/g" >"$TMPDIR"/$tmp_log_file_name
    rm "$TMPDIR"/$tmp_log_file_name.org
  else
    cat "$TMPDIR"/$tmp_log_file_name | sed -e "s/\(.* using\) .*/\1/g" >"$APP_LOGDIR"/$tmp_log_file_name
    rm "$TMPDIR"/$tmp_log_file_name
  fi

  echo "      (F) Failure during run of application after script."
  echo "          Check the Application Execution log for details:"
  echo "          ($APP_LOGDIR/$tmp_log_file_name)"
  clean_up
  exit 255
fi

# move log to app logs dir
if [ -n "$TWH_KEEP_TMP_FILES_TRUE" ]; then
  mv "$TMPDIR"/$tmp_log_file_name "$TMPDIR"/$tmp_log_file_name.org
  cat "$TMPDIR"/$tmp_log_file_name.org | sed -e "s/\(.* using\) .*/\1/g" >"$APP_LOGDIR"/$tmp_log_file_name
  cat "$TMPDIR"/$tmp_log_file_name.org | sed -e "s/\(.* using\) .*/\1/g" >"$TMPDIR"/$tmp_log_file_name
  rm "$TMPDIR"/$tmp_log_file_name.org

else
  cat "$TMPDIR"/$tmp_log_file_name | sed -e "s/\(.* using\) .*/\1/g" >"$APP_LOGDIR"/$tmp_log_file_name
  rm "$TMPDIR"/$tmp_log_file_name
fi

echo "      (I) Completed preparing and executing the application after script"
return 0;
}


###


#
set_deinstall_program_vars()
{

# Top of the specified application
APP_TOPDIR="$TWH_TOPDIR/apps/$AVA_CODE"	# ??? Check this

# Set APP_WORK_DIR for each application
app_rel_ver=`echo $APP_REL_VERSION | sed "s/\.//g" `
APP_WORK_DIR="$APP_TOPDIR/v$app_rel_ver"

return 0
}


###


#
restart_instance()
{
      # Stop db to drop any connections
      blah=`$DB2EXEC_LOG db2stop force `
      if [ $? -ne 0 ]; then
        echo "      (F) CDWDA0002W Could not stop database instance.  Exiting..."
        clean_up
        exit 2
      fi

      # Start it back up
      blah=`$DB2EXEC_LOG db2start `
# Removed for defect 131629
#      if [ $? -ne 0 ]; then
#        echo "      (F) CDWDA0002W Could not start the datbase instance. Exiting..."
#        clean_up
#        exit 2
#      fi

return 0;
}


###


#
list_apps_installed()
{
app_list_file="$TMPDIR"/apps_list.txt
echo ""
echo "          Applications detected on this system are:"
echo ""

ls -d "$TWH_TOPDIR"/apps/* 2> /dev/null > "$app_list_file";

loop_count=1
# List what is out there
while :
  do
    read app
    if [ "$app" = "" ]; then
      if [ $loop_count -eq 1 ]; then
        echo "            < No applications found on this system >"
      fi

      break;
    fi

    app_name=`basename "$app" `
    app_name=`echo $app_name | tr '[a-z]' '[A-Z]'`

    echo "            $loop_count) $app_name - located at ($app)"

    # Was is completely installed?
    blah=`ls "$app"/.*.marker 2> /dev/null `
    if [ $? -ne 0 ]; then
      echo "                     (W) Application may not have fully installed"
    fi

  loop_count=`expr $loop_count + 1 `
  done < "$app_list_file"

# Remove the junk
rm -f "$app_list_file"

return 0;
}


###


#
verify_app_to_delete()
{

if [ -z "$LIST_APPS_ONLY" ]; then
  echo "      (I) Verifying application to delete ($APPLICATION_TO_DELETE)"
else
  echo "==> Checking applications installed"
fi

# Were any apps put on?
if [ ! -d "$TWH_TOPDIR/apps" ]; then
  if [ -z "$LIST_APPS_ONLY" ]; then
    echo "      (W) CDWDA0001W No applications detected on this system"
    echo "          Exiting..."
    clean_up
    exit 1
  else
    echo "      (I) No applications detected on this system"
    clean_up
    exit 0
  fi
fi

# Display the app list?
if [ ! -z "$LIST_APPS_ONLY" ]; then
  list_apps_installed;
  echo ""
  echo "            ** Done listing applications **"
  echo ""
  clean_up
  exit 0
fi

# Now check for this app
if [ ! -d "$TWH_TOPDIR/apps/$APPLICATION_TO_DELETE" ]; then
  echo "      (W) CDWDA0002W Application ($APPLICATION_TO_DELETE) not found"
  echo "          on this system."
  list_apps_installed;
  echo ""
  echo "          Exiting...."
  clean_up
  exit 2
fi


echo "      (I) Application found on host"

return 0
}


###


#
append_to_sql_file()
{
e_file="$1"
sql_stmt="$2"
db_type=$3

echo "      (I) Appending sql statements to sql script $e_file"

# Do we have the sql file?
if [ ! -r "$e_file" ]; then
  echo "      (F) CDWDA0002W Could not find sql file $e_file to append to."
  clean_up
  exit 2
fi

# Set the user and pass based on install type
if [ $db_type -eq $COPT_CTRL_TYPE ]; then
  db_user="$COPT_CTRL_DB2USER"
  db_pass="$COPT_CTRL_DB2PASS"
  db_name="$TWH_CTRL_DB"
elif [ $db_type -eq $COPT_CDW_TYPE ]; then
  db_user="$COPT_CDW_DB2USER"
  db_pass="$COPT_CDW_DB2PASS"
  db_name="$TWH_CDW_DB"
elif [ $db_type -eq $COPT_MART_TYPE ]; then
  db_user="$COPT_MART_DB2USER"
  db_pass="$COPT_MART_DB2PASS"
  db_name="$TWH_DM_DB"
else
  echo "      (F) CDWDA0033E Unknown Custom option component type"
  clean_up
  exit 33
fi

# Set conn string
conn_string="connect to $db_name user $db_user using $db_pass;"

# Add the conn string to file
echo "
" >> "$e_file"
echo "$conn_string" >> "$e_file"

# Add the sql statement to file
echo "$sql_stmt" >> "$e_file"

echo "      (I) Done appending to sql script $e_file"
return 0;
}


###

#
prep_dependencies_sql_file()
{
e_path="$1"
e_file="$2"
db_type=$3
conn_file="$TMPDIR/tmp_conn_file.txt"

echo "      (I) Preparing sql script to run ($e_file)"


# Set the user and pass based on install type
if [ $db_type -eq $COPT_CTRL_TYPE ]; then
  db_user="$COPT_CTRL_DB2USER"
  db_pass="$COPT_CTRL_DB2PASS"
  db_name="$TWH_CTRL_DB"
elif [ $db_type -eq $COPT_CDW_TYPE ]; then
  db_user="$COPT_CDW_DB2USER"
  db_pass="$COPT_CDW_DB2PASS"
  db_name="$TWH_CDW_DB"
elif [ $db_type -eq $COPT_MART_TYPE ]; then
  db_user="$COPT_MART_DB2USER"
  db_pass="$COPT_MART_DB2PASS"
  db_name="$TWH_DM_DB"
else
  echo "      (F) CDWDA0033E Unknown Custom option component type"
  clean_up
  exit 33
fi

# Set conn string
conn_string="connect to $db_name user $db_user using $db_pass;"



# Do we have it?
if [ ! -r "$e_path/$e_file" ]; then
  echo "      (F) CDWDA0002W Could not find sql file to prepare ($e_path/$e_file)."
  clean_up
  exit 2
fi

# Add the conn string to file
echo "$conn_string" > "$conn_file"
cat "$e_path/$e_file" >> "$conn_file"


# Translate the __AVA__ in input file to $AVA_CODE
cat "$conn_file" | sed "s/__AVA__/$AVA_CODE/g" > "$TMPDIR/tmp_${AVA_CODE}_${e_file}"

# Do we have the file now
if [ ! -r "$TMPDIR/tmp_${AVA_CODE}_${e_file}" ]; then
  echo "      (F) CDWDA0002W Failed to build runtime file for sql execution"
  echo "          File should be ($TMPDIR/tmp_${AVA_CODE}_${e_file})"
  echo "          Check the file ($conn_file)"
  TWH_KEEP_TMP_FILES_TRUE=1
  clean_up
  exit 2
fi
rm -f "$conn_file"


# Export a way to get the tmp run file
DEP_FILE_TO_RUN="$TMPDIR/tmp_${AVA_CODE}_$e_file"; export DEP_FILE_TO_RUN


echo "      (I) Done preparing sql script to run"
return 0;
}


###


#
drop_deps_tmp_table()
{
tmp_table_file="$TMPDIR/tmp_deps_clean_table.sql"
conn_string="connect to $TWH_CTRL_DB user $COPT_CTRL_DB2USER using $COPT_CTRL_DB2PASS;"

drop_tmp_table="$conn_string
drop table rpi.tempDatamarts;"

create_tmp_table="$conn_string
create table rpi.tempDatamarts (
   datamart_name varchar(45),
   datamart_id char(13) for bit data
);"


# Drop tmp table (Ignore errors)
echo "      (I) Cleaning tmp table"
echo "$drop_tmp_table" > "$tmp_table_file"
blah=`$DB2EXEC_LOG_DDL \"$tmp_table_file\" `
rm "$tmp_table_file"

# Now Create it
echo "$create_tmp_table" > "$tmp_table_file"
blah=`$DB2EXEC_LOG_DDL \"$tmp_table_file\" `
if [ $? -ne 0 ]; then
  echo "      (F) CDWDA0002W Failed to create the runtime tmp table rpi.tempDatamarts"
  rm -f "$exec_file"
  clean_up
  exit 2
fi
rm "$tmp_table_file"


return 0;
}


###


#
verify_no_rpi_mart_deps()
{
exec_path="$TWH_TOPDIR/install/sql"
run_report_problems="$TMPDIR/${AVA_CODE}_problems.report"
run_report_deletions="$TMPDIR/${AVA_CODE}_deletions.report"
tmp_run_file="$TMPDIR/tmp_deps_runtime.txt"


echo "==> Preparing a list of objects that are going to be deleted for ($AVA_CODE)"

prep_dependencies_sql_file "$exec_path" "list_deletions.sql" $COPT_CTRL_TYPE;
exec_file="$DEP_FILE_TO_RUN"

# List tables that will be deleted from the mart db
append_to_sql_file "$exec_file" "select name from sysibm.systables where creator = UCASE('$AVA_CODE');
" $COPT_MART_TYPE;

# List tables that will be deleted from the cdw db
append_to_sql_file "$exec_file" "select name from sysibm.systables where creator = UCASE('$AVA_CODE');
" $COPT_CDW_TYPE;

rm -f "$run_report_deletions" 			# Remove last report

echo "      (I) Running script..."
$DB2EXEC_LOG_DDL \"$exec_file\" > "$run_report_deletions" 2>&1
rc=$?

if [ $rc -gt 1 ]; then
  echo "      (F) CDWDA0002W Failure detected during sql report generation."
  echo "          Check the file ($run_report_deletions) for details."
  gr_clean_conn_string "$exec_file" "$TMPDIR";
  TWH_KEEP_TMP_FILES_TRUE=1
  clean_up
  exit 2
fi


echo "==> Verifying the Application RPI and Datamart dependencies for ($AVA_CODE)"

# Now let's dump a report for the user on the dependencies
echo "      (I) Generating report for new dependencies by executing sql script."
prep_dependencies_sql_file "$exec_path" "list_problems.sql" $COPT_CTRL_TYPE;
exec_file="$DEP_FILE_TO_RUN"
rm -f "$run_report_problems" 			# Remove last report

echo "      (I) Running script..."
$DB2EXEC_LOG_DDL \"$exec_file\" > "$run_report_problems" 2>&1
rc=$?

if [ $rc -eq 0 -o $rc -eq 1 ]; then
  echo ""
  echo "      (I) Report gerenated in file ($run_report_problems)."
  echo "          Please review the information provided by this report."
  echo "          Any non vendor supplied relationships need to be deleted"
  echo "          before this program can remove this application."
  echo ""

  if [ ! -z "$LIST_APP_DEPENDENCIES" ]; then
    echo ""
    echo "          Done listing Application dependencies and"
    echo "          generating reports as requested:"
    echo "             $run_report_deletions"
    echo "             $run_report_problems"
    echo ""
    return
  fi
else
  echo "      (F) CDWDA0002W Failure detected during sql report generation."
  echo "          Check the file ($run_report_problems) for details."
  gr_clean_conn_string "$exec_file" "$TMPDIR";
  TWH_KEEP_TMP_FILES_TRUE=1
  clean_up
  exit 2
fi


# Countdown to allow time to exit
if [ -z "$NO_COUNT_NEEDED" ]; then
  echo "    You have 30 seconds to cancel this program if you'd like to "
  echo "    review the report before deletions occur."
  echo "    Starting countdown..."

  loop_count=30
  while [ $loop_count -gt 0 ];
    do
    sleep 1
    echo "    $loop_count"
    loop_count=`expr $loop_count - 1 `
    done
else
  echo "      (I) Bypass countdown command line option detected."
fi

drop_deps_tmp_table;

# Now check the dependencies to see if there are any
echo "      (I) Checking for datamarts by executing sql script."
prep_dependencies_sql_file "$exec_path" "list_deletions_step1.sql" $COPT_CTRL_TYPE;
exec_file="$DEP_FILE_TO_RUN"
rm -f "$tmp_run_file" 			# Remove last run

echo "      (I) Running script..."
$DB2EXEC_LOG_DDL \"$exec_file\" > "$tmp_run_file" 2>&1
rc=$?

if [ $rc -gt 1 ]; then
  echo "      (F) CDWDA0002W Unexpected Failure during execution of sql script ($exec_file)"
  echo "          Details found in ($tmp_run_file)"
  gr_clean_conn_string "$exec_file" "$TMPDIR";
  TWH_KEEP_TMP_FILES_TRUE=1
  clean_up
  exit 2
fi

# Checking for entries in the rpi.tempDatamarts table identified in list_deletions_step1.
prep_dependencies_sql_file "$exec_path" "list_deletions_step1a.sql" $COPT_CTRL_TYPE;
exec_file="$DEP_FILE_TO_RUN"
rm -f "$tmp_run_file" 			# Remove last run

echo "      (I) Running script..."
$DB2EXEC_LOG_DDL \"$exec_file\" > "$tmp_run_file" 2>&1
rc=$?

if [ $rc -eq 0 ]; then
  echo "          Datamarts detected."
  rm -f "$exec_file"

  echo "      (I) Checking for invalid datamarts by executing sql script."
  prep_dependencies_sql_file "$exec_path" "list_deletions_step2.sql" $COPT_CTRL_TYPE;
  exec_file="$DEP_FILE_TO_RUN"
  rm -f "$tmp_run_file" 		 # Remove last run

  echo "      (I) Running script..."
  $DB2EXEC_LOG_DDL \"$exec_file\" > "$tmp_run_file" 2>&1
  rc=$?

  if [ $rc -eq 0 ]; then
    echo "      (E) Datamarts that will be invalid after star schemas"
    echo "          are deleted were detected.  You must"
    echo "          remove star schemas that begin with $AVA_CODE"
    echo "          from datamarts that don't begin with $AVA_CODE"
    echo "          before we can delete this application."
    echo ""
    echo "          Please review the ($run_report_problems)"
    echo "          for the details of the relationships"
    echo "          that must manually be deleted before"
    echo "          this program can delete the entire"
    echo "          applicaiton".
    echo "          Exiting..."
    TWH_KEEP_TMP_FILES_TRUE=1
    clean_up
    exit 1
  elif [ $rc -eq 1 ]; then
    echo "      (I) No invalid datamarts were detected."
    echo "          Continuing."

    # Now check to see if there are any star schemas that are potentially
    # no longer in use and warn the user, but continue.
    # Case where datamart begins w/ ava and has a schema that
    # doesn't begin w/ ava...this schema may no longer be used, but we
    # won't delete it.

    rm -f "$exec_file"

    echo "      (I) Checking for potential unreferenced star schemas by executing sql script."
    prep_dependencies_sql_file "$exec_path" "list_deletions_step3.sql" $COPT_CTRL_TYPE;
    exec_file="$DEP_FILE_TO_RUN"
    rm -f "$tmp_run_file" 			# Remove last run

    echo "      (I) Running script..."
    $DB2EXEC_LOG_DDL \"$exec_file\" > "$tmp_run_file" 2>&1
    rc=$?

    if [ $rc -eq 0 ]; then
      echo "      (W) After datamarts that begin with $AVA_CODE are deleted"
      echo "          there may be Star Schemas left which are no longer"
      echo "          referenced - they don't begin with $AVA_CODE and"
      echo "          will not be deleted. "
      echo ""
      echo "          Please review the ($run_report_problems)"
      echo "          for the details of the relationships"
      echo "          that may leave dangling star schemas."
      echo "          Continuing..."
    elif [ $rc -gt 1 ]; then
      echo "      (F) CDWDA0002W Unexpected Failure during execution of sql script ($exec_file)"
      echo "          Details found in ($tmp_run_file)"
      gr_clean_conn_string "$exec_file" "$TMPDIR";
      TWH_KEEP_TMP_FILES_TRUE=1
      clean_up
      exit 2
    fi

    # Delete the data
    echo "      (I) Deleting the vendor supplied data and relationships"
    prep_dependencies_sql_file "$exec_path" "delete_data.sql" $COPT_CTRL_TYPE;
    exec_file="$DEP_FILE_TO_RUN"
    rm -f "$tmp_run_file" 			# Remove last run

    echo "      (I) Running script..."
    $DB2EXEC_LOG_DDL \"$exec_file\" > "$tmp_run_file" 2>&1
    if [ $? -lt 2 ]; then
      echo "      (I) Data dependencies deleted."
    else
      echo "      (F) CDWDA0002W Unexpected Failure during execution of sql script ($exec_file)"
      echo "          Details found in ($tmp_run_file)"
      gr_clean_conn_string "$exec_file" "$TMPDIR";
      TWH_KEEP_TMP_FILES_TRUE=1
      clean_up
      exit 2
    fi
  else
    echo "      (F) CDWDA0002W Unexpected Failure during execution of sql script ($exec_file)"
    echo "          Details found in ($tmp_run_file)"
    gr_clean_conn_string "$exec_file" "$TMPDIR";
    TWH_KEEP_TMP_FILES_TRUE=1
    clean_up
    exit 2
  fi
elif [ $rc -eq 1 ]; then
  echo "          No datamarts detected."
  rm -f "$exec_file"
  rm -f "$tmp_run_file"
else
  echo "      (F) CDWDA0002W Unexpected Failure during execution of sql script ($exec_file)"
  echo "          Details found in ($tmp_run_file)"
  gr_clean_conn_string "$exec_file" "$TMPDIR";
  TWH_KEEP_TMP_FILES_TRUE=1
  clean_up
  exit 2
fi


# Delete the Tables and Views in the Mart db

echo ""
echo "      (I) Finding the vendor supplied tables and views to delete in the datamart database"
prep_dependencies_sql_file "$exec_path" "amx_delete_tables_list.sql" $COPT_MART_TYPE;
exec_file="$DEP_FILE_TO_RUN"
rm -f "$tmp_run_file" 			# Remove last run
echo "      (I) Running script..."
$DB2EXEC_LOG -txf \"$exec_file\" > "$tmp_run_file" 2>&1
rc=$?
rm -f "$exec_file"
if [ $rc -eq 0 ]; then
  echo "      (I) Found tables.  Running the deletion."

  cat "$tmp_run_file"  > "$TMPDIR/amx_delete_tables_runtime.txt"

  # delete the tables
  cat "$TMPDIR/amx_delete_tables_runtime.txt" | sed 's/ .*$//' | sed 's/ //g' | sed '/^$/d' | sed '/^[^0-9A-Za-z]/d' | sed "1,\$s/^/drop table __AVA__\./" | sed '1,$s/$/;/' > "$TMPDIR/amx_delete_tables_runtime.sql"
  rm -f "$TMPDIR/amx_delete_tables_runtime.txt"
  rm -f "$tmp_run_file" 			# Remove last run

  prep_dependencies_sql_file "$TMPDIR" "amx_delete_tables_runtime.sql" $COPT_MART_TYPE;
  exec_file="$DEP_FILE_TO_RUN"

  rm -f "$TMPDIR/amx_delete_tables_runtime.sql"

  echo "      (I) Running script to delete tables..."
  $DB2EXEC_LOG -tvf \"$exec_file\" > "$tmp_run_file" 2>&1
  if [ $? -lt 2 ]; then
    echo "      (I) Tables dropped"
  else
    echo "      (F) CDWDA0002W Unexpected Failure during execution of sql script ($exec_file)"
    echo "          Details found in ($tmp_run_file)"
    gr_clean_conn_string "$exec_file" "$TMPDIR";
    TWH_KEEP_TMP_FILES_TRUE=1
    clean_up
    exit 2
  fi

  rm -f "$exec_file"
  rm -f "$tmp_run_file"

elif [ $rc -eq 1 ]; then
  echo "          No tables detected to delete."
else
  echo "      (F) CDWDA0002W Unexpected Failure during execution of sql script ($exec_file)"
  echo "          Details found in ($tmp_run_file)"
  gr_clean_conn_string "$exec_file" "$TMPDIR";
  TWH_KEEP_TMP_FILES_TRUE=1
  clean_up
  exit 2
fi

rm -f "$exec_file"
rm -f "$tmp_run_file"

  # Now delete the views....

prep_dependencies_sql_file "$exec_path" "amx_delete_views_list.sql" $COPT_MART_TYPE;
exec_file="$DEP_FILE_TO_RUN"
rm -f "$tmp_run_file" 			# Remove last run

echo "      (I) Running script..."
$DB2EXEC_LOG -txf \"$exec_file\" > "$tmp_run_file" 2>&1
rc=$?

rm -f "$exec_file"
if [ $rc -eq 0 ]; then
  echo "      (I) Found views.  Running the deletion."

  cat "$tmp_run_file"  > "$TMPDIR/amx_delete_views_runtime.txt"

  # delete the views
  cat "$TMPDIR/amx_delete_views_runtime.txt" | sed 's/ .*$//' | sed 's/ //g' | sed '/^$/d' | sed '/^[^0-9A-Za-z]/d' | sed "1,\$s/^/drop view __AVA__\./" | sed '1,$s/$/;/' > "$TMPDIR/amx_delete_views_runtime.sql"

  rm -f "$TMPDIR/amx_delete_views_runtime.txt"

  prep_dependencies_sql_file "$TMPDIR" "amx_delete_views_runtime.sql" $COPT_MART_TYPE;
  exec_file="$DEP_FILE_TO_RUN"
  rm -f "$TMPDIR/amx_delete_views_runtime.sql"

  echo "      (I) Running script to delete views..."
  $DB2EXEC_LOG -tvf \"$exec_file\" > "$tmp_run_file" 2>&1
  if [ $? -lt 2 ]; then
    echo "      (I) Views dropped"
  else
    echo "      (F) CDWDA0002W Unexpected Failure during execution of sql script ($exec_file)"
    echo "          Details found in ($tmp_run_file)"
    gr_clean_conn_string "$exec_file" "$TMPDIR";
    TWH_KEEP_TMP_FILES_TRUE=1
    clean_up
    exit 2
  fi

  rm -f "$exec_file"
  rm -f "$tmp_run_file"

elif [ $rc -eq 1 ]; then
  echo "          No views detected to delete."
else
  echo "      (F) CDWDA0002W Unexpected Failure during execution of sql script ($exec_file)"
  echo "          Details found in ($tmp_run_file)"
  gr_clean_conn_string "$exec_file" "$TMPDIR";
  TWH_KEEP_TMP_FILES_TRUE=1
  clean_up
  exit 2
fi
rm -f "$exec_file"
rm -f "$tmp_run_file"


# Delete the Tables for this app in the generic CDW

echo ""
echo "      (I) Finding the vendor supplied tables and views to delete in the CDW database"
prep_dependencies_sql_file "$exec_path" "amx_delete_tables_list.sql" $COPT_CDW_TYPE;
exec_file="$DEP_FILE_TO_RUN"
rm -f "$tmp_run_file" 			# Remove last run

echo "      (I) Running script..."
$DB2EXEC_LOG -txf \"$exec_file\" > "$tmp_run_file" 2>&1
rc=$?

rm -f "$exec_file"
if [ $rc -eq 0 ]; then
  echo "      (I) Found tables.  Running the deletion."

  cat "$tmp_run_file"  > "$TMPDIR/amx_delete_tables_runtime.txt"

  # delete the tables
  cat "$TMPDIR/amx_delete_tables_runtime.txt" | sed 's/ .*$//' | sed 's/ //g' | sed '/^$/d' | sed '/^[^0-9A-Za-z]/d' | sed "1,\$s/^/drop table __AVA__\./" | sed '1,$s/$/;/' > "$TMPDIR/amx_delete_tables_runtime.sql"

  rm -f "$TMPDIR/amx_delete_tables_runtime.txt"
  rm -f "$tmp_run_file" 			# Remove last run

  prep_dependencies_sql_file "$TMPDIR" "amx_delete_tables_runtime.sql" $COPT_CDW_TYPE;
  exec_file="$DEP_FILE_TO_RUN"
  rm -f "$TMPDIR/amx_delete_tables_runtime.sql"

  echo "      (I) Running script to delete tables..."
  $DB2EXEC_LOG -tvf \"$exec_file\" > "$tmp_run_file" 2>&1
  if [ $? -lt 2 ]; then
    echo "      (I) Tables dropped"
  else
    echo "      (F) CDWDA0002W Unexpected Failure during execution of sql script ($exec_file)"
    echo "          Details found in ($tmp_run_file)"
    gr_clean_conn_string "$exec_file" "$TMPDIR";
    TWH_KEEP_TMP_FILES_TRUE=1
    clean_up
    exit 2
  fi

  rm -f "$exec_file"
  rm -f "$tmp_run_file"

elif [ $rc -eq 1 ]; then
  echo "          No tables detected to delete."
else
  echo "      (F) CDWDA0002W Unexpected Failure during execution of sql script ($exec_file)"
  echo "          Details found in ($tmp_run_file)"
  gr_clean_conn_string "$exec_file" "$TMPDIR";
  TWH_KEEP_TMP_FILES_TRUE=1
  clean_up
  exit 2
fi

rm -f "$exec_file"
rm -f "$tmp_run_file"

  # Now delete the views....

prep_dependencies_sql_file "$exec_path" "amx_delete_views_list.sql" $COPT_CDW_TYPE;
exec_file="$DEP_FILE_TO_RUN"
rm -f "$tmp_run_file" 			# Remove last run

echo "      (I) Running script..."
$DB2EXEC_LOG -txf \"$exec_file\" > "$tmp_run_file" 2>&1
rc=$?

rm -f "$exec_file"
if [ $rc -eq 0 ]; then
  echo "      (I) Found views.  Running the deletion."

  cat "$tmp_run_file"  > "$TMPDIR/amx_delete_views_runtime.txt"

  # delete the views
  cat "$TMPDIR/amx_delete_views_runtime.txt" | sed 's/ .*$//' | sed 's/ //g' | sed '/^$/d' | sed '/^[^0-9A-Za-z]/d' | sed "1,\$s/^/drop view __AVA__\./" | sed '1,$s/$/;/' > "$TMPDIR/amx_delete_views_runtime.sql"

  rm -f "$TMPDIR/amx_delete_views_runtime.txt"

  prep_dependencies_sql_file "$TMPDIR" "amx_delete_views_runtime.sql" $COPT_CDW_TYPE;
  exec_file="$DEP_FILE_TO_RUN"
  rm -f "$TMPDIR/amx_delete_views_runtime.sql"

  echo "      (I) Running script to delete views..."
  $DB2EXEC_LOG -tvf \"$exec_file\" > "$tmp_run_file" 2>&1
  if [ $? -lt 2 ]; then
    echo "      (I) Views dropped"
  else
    echo "      (F) CDWDA0002W Unexpected Failure during execution of sql script ($exec_file)"
    echo "          Details found in ($tmp_run_file)"
    gr_clean_conn_string "$exec_file" "$TMPDIR";
    TWH_KEEP_TMP_FILES_TRUE=1
    clean_up
    exit 2
  fi

  rm -f "$exec_file"
  rm -f "$tmp_run_file"

elif [ $rc -eq 1 ]; then
  echo "          No views detected to delete."
else
  echo "      (F) CDWDA0002W Unexpected Failure during execution of sql script ($exec_file)"
  echo "          Details found in ($tmp_run_file)"
  gr_clean_conn_string "$exec_file" "$TMPDIR";
  TWH_KEEP_TMP_FILES_TRUE=1
  clean_up
  exit 2
fi
rm -f "$exec_file"
rm -f "$tmp_run_file"


echo "      (I) Done deleting the Application RPI and Datamart data"
return 0;
}


###


# Dump report for user
list_rpi_mart_deps_only()
{
props_file="$TWH_TOPDIR/apps/$APPLICATION_TO_DELETE/$APP_INSTALL_PROPS_FILE"

echo "==> Executing lookup of dependencies"

if [ $ADMIN_CHECKED -eq $FALSE ]; then
  echo "      (F) CDWDA0001W The Admin (Control Sever) is not detected on this system."
  echo "          This command option is not valid on a host that"
  echo "          does not have the control server on it."
  echo "          Exiting..."
  clean_up
  exit 1
fi


if [ ! -r "$props_file" ]; then
    echo "      (F) CDWDA0001W The application may not have been fully installed."
    echo "          Cannot locate the applications properties file."
    echo "          Cannot list any RPI or Mart dependencies without this file."
    echo "          Exiting..."
    clean_up
    exit 1
fi


# NT only for this component
gr_check_interp_by_class $CLASS_WIN;

read_app_props_file;
set_deinstall_program_vars;

verify_no_rpi_mart_deps;
clean_up;

return 0;
}


###


# This will run the ISMP uninstall since this app was installed through
# the GUI.  Should allow them to reinstall.  Does not do much but
# fixup the ISMP product registry.  The real work is done in this # script.
exec_ismp_uninstall()
{
uninst_prog="${APP_TOPDIR}/uninstall/TWHUninstall.jar"

echo "==> Running the ISMP Uninstall program for this application"


# Set path
if [ "$INTERP" = "$AIX" -o "$INTERP" = "$LINUX" ]; then
  echo "      (I) Setting Java path to include jre"
  j_path="${TWH_TOPDIR}"/_jvm/jre/bin
else
  j_path="${TWH_TOPDIR}"/_jvm/bin
fi

# Set prog name
if [ $UNIX_INTERP -eq $FALSE ]; then
  j_prog="java.exe"
else
  j_prog="java"
fi


# Find java
if [ ! -r "$j_path/$j_prog" ]; then
  echo "      (W) Could not locate Java at ($j_path/$j_prog)"
  echo "          Cannot run ISMP Uninstall program."
  echo "          Continuing..."
else
  # Find our program.
  if [ -r "$uninst_prog" ]; then
    echo "      (I) Found program.  Running..."

    # Invoke the Java ISMP uninstall jar
    blah=`"$j_path/$j_prog" -jar "$uninst_prog" -silent  2>&1 `
    if [ $? -ne 0 ]; then
      echo "      (W) ISMP Uninstall returned failure.  Continuing to deinstall other objects"
      echo "          Error Info was:"
      echo "          $blah"
    fi
  else
    echo "      (W) No Uninstall program detected"
  fi
fi


echo "      (I) Done with ISMP Uninstall"
return 0;
}


###


# Look for all exported files
exec_app_export_health()
{
export_dir1="$APP_WORK_DIR/etl/export"
file_list="AGENTSITE.del
ATTRIBUTE.del
ATTRIBUTELINK.del
BINARYDATA.del
BUSINESSVIEW.del
BVALIAS.del
BVSCHEDULE.del
CALDATE.del
CONFIGURATION.del
CONVERSIONATTR.del
CORRELATION.del
CUSTCAL.del
DATARESOURCE.del
EDITION.del
EDITIONREL.del
FINDATTRDB2.del
INFORESOURCE.del
IWHSTRINGSlong.del
IWHSTRINGSshort.del
KEY.del
KEYMAP.del
LOGMSGS.del
MAP.del
OLAPCUBE.del
PROCESS.del
PROGFUNC2.del
PROGPARM.del
PROGTYPE.del
RELATIONSHIP.del
SECURITYGROUP.del
STARSCHEMA.del
STATISTICS.del
SUBJECT.del
UDPGROUP.del
USERFUNCTION.del
VWUSER.del
"

echo "      (I) Checking that all App DB export files exist"

# Spin through the list and ensure the file is there (36 files)
for file_to_find in $file_list
  do
  if [ ! -r "$export_dir1/$file_to_find" ]; then
    echo "      (W) Export file ($file_to_find) missing."
    return $FALSE;
  fi

done


echo "      (I) Done checking for export files"
return $TRUE;
}


####


# Remove the physical media the the script installers laid down
# Leave the rest for InstallShield
delete_product_media()
{
echo "      (I) Starting delete of product media"

# Remove any application installation files
if [ -d "$TWH_TOPDIR/apps" ]; then
  echo "      (I) Application installation media detected.  Removing..."
fi


# Try to remove regardless
rm -rf "$TWH_TOPDIR"/apps/$APPLICATION_TO_DELETE

# Note - Keep the backup in the apps_backups directory for a restore
# situation.  Even though this may seem like it should not be
# there after the app is deinstalled.


echo "      (I) Completed delete of product media"

return 0
}


###


#
deinstall_lang_files()
{
# This function will not be provided in this release.


return 0
}


###

exec_cdw_del_sql()
{
dml_cdw_del_script="${AVA_CODE}_cdw_del_data.sql"
exec_dir="${APP_WORK_DIR}/cdw"

MAJOR=`echo $TWH_CORE_PREREQ_VERSION | awk 'BEGIN { FS = "." }; { print $1 }'`
MINOR=`echo $TWH_CORE_PREREQ_VERSION | awk 'BEGIN { FS = "." }; { print $2 }'`
PATCH=`echo $TWH_CORE_PREREQ_VERSION | awk 'BEGIN { FS = "." }; { print $3 }'`

if [ $MAJOR -eq 1 ]; then
  if [ $MINOR -eq 1 ]; then
    if [ $PATCH -eq 0 ]; then
      echo "      (I) cdw delete data script is not supported on this version of the application.  Skipping..."
      return 0;
    fi
  fi
fi

# If the file is not there then skip the afterscript.
if [ ! -f "$exec_dir/dml/$dml_cdw_del_script" ]; then
  echo "      (I) No application cdw delete data script specified for this appliction."
  return 0;
fi

### Data/DML time
echo "==> Deleting Application Specific information from the CDW"

# Insert TWH data (static script managed by TEDW team)
gr_build_script_name "$dml_cdw_del_script" "$exec_dir/dml";
gr_build_exec_script "$TWH_CDW_DB" "$exec_dir/dml" "$NAMMED_SCRIPT" $COPT_CDW_TYPE $CONN_TYPE_CONNECT;
gr_exec_sql_script "$TWH_CDW_DB" $TRUE;
}


###


#
delete_md_data_for_dwc()
{
etl_sql_dir="$TWH_TOPDIR/install/sql"
sql_error1="SQL0204N"
sql_db_not_started="SQL1032N"

echo ""
echo "==> Removing the application design (ETL) from the Metadata database."
echo ""

# If they do not have a backup, skip this section
if [ ! -r "$TWH_TOPDIR/apps_backups/$AVA_CODE/install/$TWH_CTRL_DB.0"  ]; then
  echo "      (W) No DB backup found.  Must not have run metadata DB"
  echo "          process steps during this application's install."
  echo "          Continuing..."
  echo ""

  return 0;
fi


# Check to see if they made it to the export on the install of this App
exec_app_export_health;
have_all=$?

# If they have a backup and no export, tell them they need to restore
if [ $have_all -eq $FALSE ]; then
  echo ""
  echo ""
  echo ""
  echo ""
  echo ""
  echo ""
  echo "      (W) Could not locate all application export files to restore"
  echo "          the ($TWH_CTRL_DB) to the state it was in before this"
  echo "          application installation."
  echo ""
  echo "          You need to manually restore the database back to"
  echo "          it's state before the last application installation."
  echo ""
  echo "          To recover to the state prior to this application"
  echo "          installation:"
  echo ""
  echo "          1).  Allow this deinstall to finish after this pause"
  echo ""
  echo "          2).  Restore the DWC MD database manually by doing"
  echo "               the following:"
  echo ""
  echo "            db2 -v restore db $TWH_CTRL_DB from"
  echo "            $TWH_TOPDIR/apps_backups/$AVA_CODE/install/$TWH_CTRL_DB.0"
  echo ""
  echo "          3).  Before reinstalling, determine the reason"
  echo "               why the application failed and resolve it."
  echo ""
  echo "          <Pausing for 60 seconds to allow you to read this warning>"
  echo ""
  echo ""
  echo ""
  echo ""
  echo ""
  echo ""

  sleep 60
  echo "          Continuing with deinstall..."

  return 0;		# exit this routine
fi


# Stop services first
echo "      (I) Stopping DB2 DWC NT services"
err_txt=`$DB2REGI 16 2>&1 `
if [ $? -ne 0 ]; then
  echo "      (F) CDWIA0086E Failed to stop NT Service vwkernel and vwlogger"
  echo "          Error is:"
  echo "          $err_txt"
  echo "          Exiting..."
  clean_up
  exit 86
fi

# Stop DB2
echo "      (I) Stopping DB2"
err_txt=`$DB2CMD db2stop force 2>&1 `
if [ $? -ne 0 ]; then
  blah=`echo $err_txt | grep -i $sql_db_not_started `
  if [ $? -eq 0 ]; then
    :;			# If db not started that is OK
  else
    echo "      (F) CDWIA0087E Failed to stop DB2."
    echo "          Error is:"
    echo "          $err_txt"
    echo "          Exiting..."
    clean_up
    exit 87
  fi
fi

# Start DB2
echo "      (I) Starting DB2"
err_txt=`$DB2CMD db2start 2>&1 `
# Removed for defect 131629
#if [ $? -ne 0 ]; then
#  echo "      (F) CDWIA0088E Failed to start DB2."
#  echo "          Error is:"
#  echo "          $err_txt"
#  echo "          Exiting..."
#  clean_up
#  exit 88
#fi

# Clean out old backups  (keep only one)
echo "      (I) Cleaning up application backup directory"
blah=`rm -rf "$APP_BACKUP_DIR"/* 2>&1 `
if [ $? -ne 0 ]; then
  echo "      (F) CDWIA0089E Failed trying to clean the ($APP_BACKUP_DIR) directory"
  clean_up
  exit 89
fi

# Make the backup
echo "      (I) Making Backup"
blah=`$DB2EXEC_LOG -v backup db "$TWH_CTRL_DB" to \'$APP_BACKUP_DIR\' `
if [ $? -ne 0 ]; then
  echo "      (F) CDWIA0090E Failure detected during backup"
  echo "          for Database ($TWH_CTRL_DB)."
  echo "          Check messages in DB2 log ($DB2_INSTALL_LOG)."
  echo "          Exiting..."
  TWH_KEEP_TMP_FILES_TRUE=1
  clean_up
  exit 90
fi

# Test a connection
echo "      (I) Testing the DB connection"
err_txt=`$DB2EXEC_LOG connect to "$TWH_CTRL_DB" user "$DB2USER" using "$DB2PASS" 2>&1 `
if [ $? -ne 0 ]; then
  echo "      (F) CDWIA0091E Unable to connect to database ($TWH_CTRL_DB)."
  echo "          Error is:"
  echo "          $err_txt"
  echo "          Exiting..."
  clean_up
  exit 91
fi

# Have to do this again in case db2bp thread was forced
err_txt=`$DB2EXEC_LOG connect to "$TWH_CTRL_DB" user "$COPT_CTRL_DB2USER" using "$COPT_CTRL_DB2PASS" 2>&1 `
if [ $? -ne 0 ]; then
  echo "      (F) CDWIA0091E Unable to connect to database ($TWH_CTRL_DB)."
  echo "          Error is:"
  echo "          $err_txt"
  echo "          Exiting..."
  clean_up
  exit 91
fi

# Check for IWH not in known list (script requires 35 tables)
gr_build_exec_script "$TWH_CTRL_DB" "$etl_sql_dir" "iwhcheck1.sql" $COPT_CTRL_TYPE $CONN_TYPE_CONNECT;
gr_exec_sql_script "$TWH_CTRL_DB" $FALSE;

# Check for IWH not in known list
gr_build_exec_script "$TWH_CTRL_DB" "$etl_sql_dir" "iwhcheck2.sql" $COPT_CTRL_TYPE $CONN_TYPE_CONNECT;
gr_exec_sql_script "$TWH_CTRL_DB" $FALSE;

# Drop the delta tables
gr_build_exec_script "$TWH_CTRL_DB" "$etl_sql_dir" "drop_delta.sql" $COPT_CTRL_TYPE $CONN_TYPE_CONNECT;
gr_exec_sql_script "$TWH_CTRL_DB" $FALSE;

# Create the Delta table
gr_build_exec_script "$TWH_CTRL_DB" "$etl_sql_dir" "create_delta.sql" $COPT_CTRL_TYPE $CONN_TYPE_CONNECT;
gr_exec_sql_script "$TWH_CTRL_DB" $FALSE;


# Import the delta tables from the export
# Move to the correct dir to support
# relative import path
echo "      (I) Starting the import to delete the App data from the"
echo "          $TWH_CTRL_DB.  If this fails:"
echo ""
echo "          A backup of the database will be taken before this"
echo "          action is executed."
echo "          To restore data, execute the following DB2 command:"
echo ""
echo "            db2 -v restore db $TWH_CTRL_DB from"
echo "            $TWH_TOPDIR/apps_backups/$AVA_CODE/deinstall/$TWH_CTRL_DB.0"
echo ""

cur_dir=`pwd`
cd "$APP_WORK_DIR/etl"
gr_build_exec_script "$TWH_CTRL_DB" "$etl_sql_dir" "import.sql" $COPT_CTRL_TYPE $CONN_TYPE_CONNECT;
gr_exec_sql_script "$TWH_CTRL_DB" $FALSE;
cd "$cur_dir"


# Drop tables for the clean script
gr_build_exec_script "$TWH_CTRL_DB" "$etl_sql_dir" "clean_drop_tables.sql" $COPT_CTRL_TYPE $CONN_TYPE_CONNECT;
gr_exec_sql_script "$TWH_CTRL_DB" $FALSE;


# Run the clean script
gr_build_exec_script "$TWH_CTRL_DB" "$etl_sql_dir" "clean.sql" $COPT_CTRL_TYPE $CONN_TYPE_CONNECT;
gr_exec_sql_script "$TWH_CTRL_DB" $FALSE;


# Drop tables after the clean script
gr_build_exec_script "$TWH_CTRL_DB" "$etl_sql_dir" "clean_drop_tables.sql" $COPT_CTRL_TYPE $CONN_TYPE_CONNECT;
gr_exec_sql_script "$TWH_CTRL_DB" $FALSE;


# DO THE REMOVE!!!
gr_build_exec_script "$TWH_CTRL_DB" "$etl_sql_dir" "remove.sql" $COPT_CTRL_TYPE $CONN_TYPE_CONNECT;
gr_exec_sql_script "$TWH_CTRL_DB" $FALSE;


# Drop the delta tables
gr_build_exec_script "$TWH_CTRL_DB" "$etl_sql_dir" "drop_delta.sql" $COPT_CTRL_TYPE $CONN_TYPE_CONNECT;
gr_exec_sql_script "$TWH_CTRL_DB" $FALSE;


# Start services (logger has to be first!)
echo "      (I) Starting DB2 DWC NT services"
blah=`net start vwlogger `
if [ $? -ne 0 ]; then
  echo "      (F) CDWIA0094E Failed to start NT Service vwlogger"
  echo "          Exiting..."
  clean_up
  exit 94
fi

blah=`net start vwkernel `
if [ $? -ne 0 ]; then
  echo "      (F) CDWIA0095E Failed to start NT Service vwkernel"
  echo "          Exiting..."
  clean_up
  exit 95
fi


echo "      (I) Completed removing the Metadata database objects"
return 0
}


###


#
drop_app_db_marts()
{
ddl_drop_script="*_mart_drop_schema.sql"
drop_triggers_script="*_mart_drop_triggers.sql"
exec_dir="$APP_WORK_DIR/mart"


echo "==> Dropping Datamart database tables and objects"

# Drop Triggers
gr_build_script_name "$drop_triggers_script" "$exec_dir/ddl";
gr_build_exec_script "$TWH_DM_DB" "$exec_dir/ddl" "$NAMMED_SCRIPT" $COPT_MART_TYPE $CONN_TYPE_CONNECT;
gr_exec_sql_script "$TWH_DM_DB" $FALSE;

# Drop Schema
gr_build_script_name "$ddl_drop_script" "$exec_dir/ddl";
gr_build_exec_script "$TWH_DM_DB" "$exec_dir/ddl" "$NAMMED_SCRIPT" $COPT_MART_TYPE $CONN_TYPE_CONNECT;
gr_exec_sql_script "$TWH_DM_DB" $FALSE;

echo "      (I) Completed dropping datamart datbase tables and objects"
return 0
}


###


#
post_details()
{
inst_type="Typical"
if [ "$TWH_CORE_INSTALL_TYPE" = "TWH_CUSTOM" ]; then
  inst_type="Custom"
fi

echo "==> TEDW Application Deinstallation Details:"
echo ""


if [ -n "$TWH_KEEP_TMP_FILES_TRUE" ]; then
  echo "          <Keeping tmp files>"
fi
echo ""
echo "       (I) TEDW Application Deintstaller Details completed"
echo ""
return 0;
}


###


# Driver function for deinstall by component
# Tech Notes:
#	We use the NT DWC host as the anchor for all DB work for all
#	DB's (i.e. MD, CDW, and Mart).  So the other custom options would
#	be physical objects like copying files.
execute_component_driver()
{
props_file="$TWH_TOPDIR/apps/$APPLICATION_TO_DELETE/$APP_INSTALL_PROPS_FILE"

echo "==> Executing Application deinstallation by component"


# This section for all options pre-component


# Now install each component they requested - this is in order
# Admin server (DWC control server NT host)
if [ $ADMIN_CHECKED -eq $TRUE ]; then
  # For this option we will do all the DB work for all components
  echo ""
  echo ""
  echo "==> Admin component deinstall detected on this host. Removing...";

  # NT only for this component
  gr_check_interp_by_class $CLASS_WIN;

  # Need to be able to find the property file for this section
  if [ -r "$props_file" ]; then
    read_app_props_file;
    set_deinstall_program_vars;
    exec_before_script;
    verify_no_rpi_mart_deps;
    drop_app_db_marts;
    delete_md_data_for_dwc;
    exec_cdw_del_sql;
    exec_ismp_uninstall;	# should see ISMP GUI
    exec_after_script;
  else
    echo "      (W) Cannot delete any datbase objects, properties file not found."
  fi
fi


# CDW
if [ $CDW_CHECKED -eq $TRUE ]; then
# For later code expansion
  echo ""
  echo ""
  echo "==> CDW component deinstall detected on this host";
  echo "      (I) There is nothing needed to be done for an application deinstall on this host."

  # Check acceptable interps
  gr_check_interp_by_class $CLASS_TYPE_1;
fi


# Mart DB
if [ $MART_CHECKED -eq $TRUE ]; then
# For later code expansion
  echo ""
  echo ""
  echo "==> Mart component deinstall detected on this host";
  echo "      (I) There is nothing needed to be done for an application install on this host."

  # Check acceptable interps
  gr_check_interp_by_class $CLASS_TYPE_1;
fi


# RPI
if [ $RPI_CHECKED -eq $TRUE ]; then
  echo ""
  echo ""
  echo "==> RPI component deinstall detected on this host. Removing...";

  # Check acceptable interps
  gr_check_interp_by_class $CLASS_TYPE_2;

  # Need to be able to find the property file for this section
  if [ -r "$props_file" ]; then
    read_app_props_file;
    set_deinstall_program_vars;

    exec_ismp_uninstall;	# should see ISMP GUI
    deinstall_lang_files;
  else
    echo "      (W) No application properties file detected."
  fi
fi


# This section for all options post-component
delete_product_media;


return 0;
}


###


# Clean up
clean_up()
{
tmp_conf_file="tmp_$TWH_CONFIG_FILE_NAME"

echo ""
echo "==> Starting post-deinstaller cleanup"


# Shell hack needed to delete other files
# This unlocks the last file used on stdin
touch "$TMPDIR/null_file.txt"
exec < "$TMPDIR/null_file.txt"


# Remove the password from the deinstall config file
cat "$TWH_CONFIG_FILE" | sed "s/DB2PASS=.*/DB2PASS=/" > "$TMPDIR/$tmp_conf_file"
rm -f "$TWH_CONFIG_FILE"
mv "$TMPDIR/$tmp_conf_file" "$TWH_CONFIG_FILE"
# make a copy of it
cp -r "$TWH_CONFIG_FILE" "$CORE_LOGDIR/$TWH_CONFIG_FILE_NAME.done"


# Safety net - Remove the connect strings from any remaining files
echo "      (I) Cleaning up any remaining tmp sql files"
ls "$TMPDIR"/tmp_*.sql 2> /dev/null > "$TMPDIR"/sqlfiles.txt;
ls "$TMPDIR"/tmp_twh*.sql 2> /dev/null >> "$TMPDIR"/sqlfiles.txt;
ls "$TMPDIR"/tmp_${AVA_CODE}*.sql 2> /dev/null >> "$TMPDIR"/sqlfiles.txt;

# only do if we have records
while :
  do
    read sql_file
    if [ "$sql_file" = "" ]; then
        break
    fi

    if [ -n "$TWH_KEEP_TMP_FILES_TRUE" ]; then
     # keep tmp files but remove connection strings
     mv $sql_file $sql_file.org
     cat "$sql_file.org" | sed -e "s/\(.* using\) .*/\1/g" > $sql_file
     rm -f $sql_file.org

    else
    rm -f "$sql_file";
    fi
  done < "$TMPDIR"/sqlfiles.txt

rm -f "$TMPDIR"/sqlfiles.txt

# turn off this context
unset TWH_APP_DEINST_CONTEXT


echo "      (I) Post deinstaller cleanup completed"
return 0;
}


###############################################################
############## Driver Code Section ############################
###############################################################

### Set Program Vars
# Non configurable vars
# Required in all files using Generic Routines (gr_)
ARGS_RUN="$@"
ARGS_IN=$*
ARGS_NO=$#
PROGRAM=$0
gen_file_and_path=`echo $0 | sed 's/\\\\/\//g' `	# NT fix
PROGNAME=`basename "$gen_file_and_path"`
TRUE=1
FALSE=0
CUSTOM_INSTALL=$FALSE
ADMIN_CHECKED=$FALSE
RPI_CHECKED=$FALSE
CDW_CHECKED=$FALSE
MART_CHECKED=$FALSE


############
### Main ###
############

# Bring in the generic routines
include_gen_routines;

# Loop flags
args_found=0
conf_val_found=$FALSE

while [ $# -ne 0 ]; do
  # Now look for the command line option
  case $1 in

        # deinstall Config file
        --config|--CONFIG|--Config|-C|-c)
            # Set flag for value found
            conf_val_found=$TRUE
            shift
            TWH_CONFIG_FILE="$1"
		if [ ! -r "$TWH_CONFIG_FILE" ]; then
		  echo "      (F) CDWIA0105E Value not valid for config file name ($TWH_CONFIG_FILE)"
		  exit 105
		fi
            shift
            args_found=`expr $args_found + 2`
            continue
            ;;

        # Version Info
        --version|--VERSION|--Version|-V|-v)
            echo ""
            echo "  $PROGNAME"
            echo "  Version 1.1.0"
            echo "  A Tivoli Warehouse utility"
		echo "  IBM Software"
            echo ""
            exit 0
            ;;

        # Help Info
        --help|--HELP|-Help|-H|-h)
            display_help;
            exit 0
            ;;

        # Display the return code messages
        --retcode|--RETCODE|--Retcode|-R|-r)
            gr_display_generic_header "TEDW Application Deinstaller";
            display_return_code_messages;
            exit 0
            ;;

        # Run in Debug
        --debug|--DEBUG|--Debug|-D|-d)
            DEBUG=defined
            gr_set_debug_mode;
		shift
		continue
            ;;

        # Run without the warning countdown
        --nocount|--NOCOUNT|--Nocount|-N|-n)
            NO_COUNT_NEEDED=defined; export NO_COUNT_NEEDED
		shift
	      continue
            ;;

        # List apps on system
        --listapps|--LISTAPPS|--Listapps|-L|-l)
            LIST_APPS_ONLY=defined; export LIST_APPS_ONLY
		BYPASS_PASSWORD_REQUIRED=true; export BYPASS_PASSWORD_REQUIRED
            echo ""
            echo ""
            echo "    <<< THIS RUN WILL LIST INSTALLED APPLICATIONS ONLY >>>"
		shift
	      continue
            ;;

        # List app dependancies
        --listrels|--LISTRELS|--Listrels|-Z|-z)
            LIST_APP_DEPENDENCIES=defined; export LIST_APP_DEPENDENCIES
            echo ""
            echo ""
            echo "    <<< THIS RUN WILL LIST THE RPI AND DATAMART DEPENDENCIES ONLY >>>"
		shift
	      continue
            ;;

        # Error - not valid option
        -*)
            echo "      (F) CDWIA0104E Unknown Command option ($1)"
            echo "          < Displaying Help >"
              echo ""
            display_help;
            exit 104
            ;;

        # Default
        *)
            echo "      (F) CDWIA0104E Unknown option ($1)"
            echo "          < Displaying Help >"
              echo ""
            display_help;
            exit 104
            ;;
  esac
done


gr_process_args 2 $args_found;
gr_display_generic_header "TEDW Application Deinstaller";
if [ -z "$LIST_APPS_ONLY" -a -z "$LIST_APP_DEPENDENCIES" ]; then display_warning_message; fi
gr_set_debug_mode;
gr_set_interp;
gr_read_config_file;
gr_set_program_vars;
set_private_program_vars;
gr_extend_path;
gr_check_user;
verify_app_to_delete;
read_core_comp_list_file;
check_core_tools_installed;
gr_test_db2exec;
gr_mark_db2_log_for_install "MARKADEL";
if [ ! -z "$LIST_APP_DEPENDENCIES" ]; then
  list_rpi_mart_deps_only;
fi
execute_component_driver;
#post_details;
clean_up;

echo ""
echo "==> TEDW Deinstallation Successfully Completed!!!"


if [ $WARNING_FLAG -eq $TRUE ]; then
  exit 1					# Warnings detected during run
else
  exit 0
fi
