#!/bin/sh
############################################################################
#
#  Licensed Materials - Property of IBM
#  Product ID = 5724-C04
#
#  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#   File Information: Common/src/tedw_app/amx/fixpack2/misc/amx_create_comp_msmt.sh, tmnt_etl, tmnt_5.1.1_FP06, 512ITMFP01_0616
#   Revision: 1.16
#   Date: 2/6/04 23:50:41
############################################################################

# Description:
# wrapper script to call amx create comp msmt step

# Source data in the CDW database ( AMX.Stage_xxx tables)
# Target data in the CDW database ( TWG.xxx tables)

# Inputs:
# 1. AVA, scriptname, dbname, user, pwd of twh_cdw

# Function:
# Create the AMX_c05_s040_comp_msmt.$DBTYPE script from the metadata
# This script does the following for each warehouse pack
# 1. Insert the following (local or remote) components in TWG.COMP:
#     - component level1 : host is the parent
#     - component level2 : host is the grand parent
#     - component level3 : host is the great grand parent
#     - component level4 : host is the great great grand parent
#     - component level5 : host is the great great great grand parent
# 2. Insert the Parent-Child relations for each component in TWG.COMPRELN 
# 3. Insert the attributes for each component in TWG.COMPATTR
# 4. Insert the measurements for each component in TWG.MSMT

# Parameters
AVACODE="$1"
SCRIPTNAME="$2"
SRCDB=$3
SRCUSER=$4
SRCPWD=$5
TRGDB=$6
TRGUSER=$7
TRGPWD=$8

# start debug
#set -x

# Source the twh_run.sh to obtain perl in the path

if [ -f "$TWH_TOPDIR/tools/bin/twh_run.sh" ]; then
. "$TWH_TOPDIR/tools/bin/twh_run.sh"
fi

# setting VWP_LOG allows testing from the command line
# but it must be commented out when running from the DWC
#VWP_LOG="$VWS_LOGGING/vwp_temp"
# end debug

VWS_LOGGING=` echo "$VWS_LOGGING" | sed 's/\\\\/\//g' `

APPDIR=` echo "$TWH_TOPDIR/apps/$AVACODE" | sed 's/\\\\/\//g' `

cmdResult=`ls -1 "$APPDIR" | grep '^v' | wc -l | sed -e 's/ *//g'`

if [ "$cmdResult" != "1" ]; then
   echo "<MSG>AMX8200E Bad directory structure. Only one directory beginning with 'v' should exist in $APPDIR </MSG>" >> "$VWP_LOG"
   echo "<RC>8200</RC>" >> "$VWP_LOG"
   exit 8200
fi

cmdResult=`ls -d "$APPDIR"/v*`
version=`basename "$cmdResult" `

FULLSCRIPT="$APPDIR/$version/etl/sql/$SCRIPTNAME"
FULLLOG="$VWS_LOGGING/$SCRIPTNAME.log"
FULLDIR="$APPDIR/$version/misc"

# CDW database type
DBTYPE=db2

# Variables used to run sql commands as temporary scripts
diag1Output=""$VWS_LOGGING"/"$SCRIPTNAME"_diag1"
diag2Output=""$VWS_LOGGING"/"$SCRIPTNAME"_diag2"
tempSqlScript=""$VWS_LOGGING"/"$SCRIPTNAME"_sqltemp"
tempSqlOutput=""$VWS_LOGGING"/"$SCRIPTNAME"_sqltemp1.out"


echo "-------------------------------------------"  >> "$diag1Output"
echo `date` >> "$diag1Output"
echo "-------------------------------------------"  >> "$diag1Output"
echo "ARGS PASSED: $1, $2, $3, $4, $5" >> "$diag1Output"

if [ -f "$SCRIPTNAME.$DBTYPE" ]
then
  rm "$SCRIPTNAME.$DBTYPE"
fi

#---------------------------------------------------------------------------
# METADATA_CHANGE_ROWS 
#---------------------------------------------------------------------------
METADATA_CHANGE_ROWS()
{
echo "SQL: 8226"  >> "$diag1Output"
echo "select sum(num_rows) from AMX.Stage_Mdata_Change;"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8226E Select from AMX.Mdata_Change failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8226</RC>" >> "$VWP_LOG"
  exit 8226
fi

METADATA_CHANGE_ROWS=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `	
 
if [ "$METADATA_CHANGE_ROWS" -ne 0  ]  
then
  echo "-------------------------------------------"  > "$diag1Output"
  echo `date` >> "$diag1Output"
  echo "-------------------------------------------"  >> "$diag1Output"
  echo "     METADATA_CHANGE_ROWS: $METADATA_CHANGE_ROWS"  >> "$diag1Output"
  echo "-------------------------------------------"  >> "$diag1Output"
else
  echo "-------------------------------------------"  >> "$diag2Output"
  echo `date` >> "$diag2Output"
  echo "-------------------------------------------"  >> "$diag2Output"
  echo "     METADATA_CHANGE_ROWS: $METADATA_CHANGE_ROWS"  >> "$diag1Output"
  echo "     METADATA_CHANGE_ROWS: $METADATA_CHANGE_ROWS"  >> "$diag2Output"
  echo "-------------------------------------------"  >> "$diag2Output"
fi
  
}


#---------------------------------------------------------------------------
# PAC_LIST
#---------------------------------------------------------------------------
PAC_LIST()
{
echo "SQL: 8201"  >> "$diag1Output"
echo "select distinct msrc_cd from AMX.comptyp_transl;"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8201E Select from twg.msrc failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8201</RC>" >> "$VWP_LOG"
  exit 8201
fi

PAC_LIST=` cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -d '\12'| tr -s ' ' ' '  `

echo "     PAC_LIST: $PAC_LIST"  >> "$diag1Output"
}

#---------------------------------------------------------------------------
# APPLICATION
#---------------------------------------------------------------------------
APPLICATION()
{
echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8202 PAC: $p"  >> "$diag1Output"
echo "select msrc_nm from twg.msrc where msrc_cd='$p';"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8202E Select from twg.msrc failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8202</RC>" >> "$VWP_LOG"
  exit 8202
fi
APPLICATION=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -s ' ' ' ' `

echo "     Application: $APPLICATION" >> "$diag1Output" 
echo "     Application code: $p" >> "$diag1Output" 
}

#---------------------------------------------------------------------------
#INSERT_HOSTS
#---------------------------------------------------------------------------
INSERT_HOSTS()
{
APPLICATION;

echo "     Insert Hosts for this application" >> "$diag1Output"

if [ -f "$VWS_LOGGING/insert_host.$DBTYPE" ]
then 
  rm "$VWS_LOGGING/insert_host.$DBTYPE"
fi

perl "$FULLDIR/insert_host.pl" "$FULLDIR/insert_host.$DBTYPE.template" "$VWS_LOGGING/insert_host.$DBTYPE" "$p"
# concatenate insert_host.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

cat "$VWS_LOGGING/insert_host.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"
}	

#---------------------------------------------------------------------------
#INSERT_HOST_ATTRS
#---------------------------------------------------------------------------
INSERT_HOST_ATTRS()
{

echo "     Insert Host Attributes " >> "$diag1Output"

cat "$FULLDIR/insert_host_attrs.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"
}

#---------------------------------------------------------------------------
# RESOURCE
#---------------------------------------------------------------------------
RESOURCE()
{
echo "SQL: 8228"  >> "$diag1Output"
echo "select distinct resource from AMX.resource_transl where comptyp_cd='$i';" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8228E Select from AMX.resource_transl failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8228</RC>" >> "$VWP_LOG"
  exit 8228
fi
RESOURCE=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g'`
echo "     RESOURCE:..$RESOURCE.." >> "$diag1Output"

}

#---------------------------------------------------------------------------
# ALL_KEYS
#---------------------------------------------------------------------------
ALL_KEYS()
{
echo "SQL: 8203"  >> "$diag1Output"
echo " select itm_key from AMX.stage_meta_keys where comptyp_cd='$i' and msrc_cd='$p' order by lvl;"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8203E Select from AMX.stage_meta_keys failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8203</RC>" >> "$VWP_LOG"
  exit 8203
fi
ALL_KEYS=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -d '\12' | tr -s ' ' ' '  `
echo "     ALL_KEYS: $ALL_KEYS" >> "$diag1Output"
}

#---------------------------------------------------------------------------
# NUM_ALL_KEYS
#---------------------------------------------------------------------------
NUM_ALL_KEYS()
{

echo "SQL: 8204"  >> "$diag1Output"
echo "select count(*) from AMX.stage_meta_keys where comptyp_cd='$i' and msrc_cd='$p' group by comptyp_cd,msrc_cd;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ] 
then
      errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8204E Select from AMX.stage_meta_keys failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
    echo "<RC>8204</RC>" >> "$VWP_LOG"
    exit 8204
fi
NUM_ALL_KEYS=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `	

echo "     NUM_ALL_KEYS: $NUM_ALL_KEYS" >> "$diag1Output"
}

#---------------------------------------------------------------------------
# KEYS_BY_LVL
#---------------------------------------------------------------------------
KEYS_BY_LVL()
{
LEVEL_MINUS1=`expr $LEVEL - 1`

echo "SQL: 8205"  >> "$diag1Output"
echo "select itm_key from AMX.stage_meta_keys where comptyp_cd='$i' and msrc_cd='$p' and lvl=$LEVEL_MINUS1;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8205E Select from AMX.stage_meta_keys failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8205</RC>" >> "$VWP_LOG"
  exit 8205
fi
KEYS_BY_LVL=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -d '\12' | tr -s ' ' ' ' `
echo "     KEYS_LVL$LEVEL: $KEYS_BY_LVL " >> "$diag1Output"
}

#---------------------------------------------------------------------------
# NUM_KEYS_BY_LVL
#---------------------------------------------------------------------------
NUM_KEYS_BY_LVL()
{
LEVEL_MINUS1=`expr $LEVEL - 1`

echo "SQL: 8206"  >> "$diag1Output"
echo "select count(*) from AMX.stage_meta_keys where comptyp_cd='$i' and msrc_cd='$p' and lvl=$LEVEL_MINUS1 group by comptyp_cd,msrc_cd;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ] 
then
      errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8206E Select from AMX.stage_meta_keys failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
    echo "<RC>8206</RC>" >> "$VWP_LOG"
    exit 8206
fi
NUM_KEYS_BY_LVL=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `

echo "     NUM_KEYS_LVL$LEVEL: $NUM_KEYS_BY_LVL " >> "$diag1Output"
}

#---------------------------------------------------------------------------
# NAMES
#---------------------------------------------------------------------------
NAMES()
{

echo "SQL: 8207"  >> "$diag1Output"
echo "select itm_name from AMX.stage_meta_names where comptyp_cd='$i' and msrc_cd='$p' and lvl=0;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8207E Select from AMX.stage_meta_names failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8207</RC>" >> "$VWP_LOG"
  exit 8207
fi
NAMES=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -d '\12' | tr -s ' ' ' '  `
echo "     NAMES: $NAMES" >> "$diag1Output"
}

#---------------------------------------------------------------------------
# NUM_NAMES
#---------------------------------------------------------------------------
NUM_NAMES()
{
echo "SQL: 8208"  >> "$diag1Output"
echo "select count(*) from AMX.stage_meta_names where comptyp_cd='$i' and msrc_cd='$p' and lvl=0 group by comptyp_cd,msrc_cd;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8208E Select from AMX.stage_meta_names failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8208</RC>" >> "$VWP_LOG"
  exit 8208
fi
NUM_NAMES=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `

echo "     NUM_NAMES: ..$NUM_NAMES.." >> "$diag1Output"
}

#---------------------------------------------------------------------------
# ATTRTYPCD_LIST
#---------------------------------------------------------------------------
ATTRTYPCD_LIST()
{
echo "SQL: 8209"  >> "$diag1Output"
echo "select r.attrtyp_cd from twg.comptyp c, AMX.Cur_AttrRul r where c.comptyp_cd='$i' and c.comptyp_cd = r.comptyp_cd group by r.attrtyp_cd,c.comptyp_cd;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>CDW8209E Select from twg.comptyp failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8209</RC>" >> "$VWP_LOG"
  exit 8209
fi
ATTRTYPCD_LIST=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -d '\12' | tr -s ' ' ' '  `

echo "     --------------------------------------"  >> "$diag1Output"
echo "     ATTRTYPCD_LIST: $ATTRTYPCD_LIST" >> "$diag1Output"
}


#---------------------------------------------------------------------------
# ITM_KEY_ATTR
#---------------------------------------------------------------------------
ITM_KEY_ATTR()
{
echo "SQL: 8227"  >> "$diag1Output"
echo "select itm_attr_property from amx.stage_meta_keys m, amx.attrtyp_transl t where m.comptyp_cd='$i' and m.lvl=0 and attrtyp_cd='$a' and m.itm_key=t.itm_attr_property  ;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>CDW8227E Select ITM_KEY_ATTR failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8209</RC>" >> "$VWP_LOG"
  exit 8227
fi
ITM_KEY_ATTR=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `	


echo "     --------------------------------------"  >> "$diag1Output"
echo "     ITM_KEY_ATTR: ..$ITM_KEY_ATTR.." >> "$diag1Output"
}

#---------------------------------------------------------------------------
# NUM_ATTR
#---------------------------------------------------------------------------
NUM_ATTR()
{
echo "SQL: 8210"  >> "$diag1Output"
echo "select count(*) from twg.comptyp c, AMX.Cur_AttrRul r where c.comptyp_cd='$i' and c.comptyp_cd = r.comptyp_cd group by c.comptyp_cd;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8210E Select from twg.comptyp failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8210</RC>" >> "$VWP_LOG"
  exit 8210
fi
NUM_ATTR=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g'  `
echo "     NUM_ATTR: $NUM_ATTR" >> "$diag1Output"
}		

#---------------------------------------------------------------------------
# COMPTYP_CD_SAME
#---------------------------------------------------------------------------
COMPTYP_CD_SAME()
{
echo "SQL: 8211"  >> "$diag1Output"
echo "select comptyp_source_cd from AMX.RelnRul_Transl  where relntyp_cd in ('PROXY','SAME') and comptyp_target_cd='$i' ;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8211E Select from AMX.stage_all_comps_exp failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8211</RC>" >> "$VWP_LOG"
  exit 8211
fi
COMPTYP_CD_SAME=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `

echo "     --------------------------------------"  >> "$diag1Output"
echo "     same component : $COMPTYP_CD_SAME" >> "$diag1Output"
}

#---------------------------------------------------------------------------
# COMPTYP_PARENT_CD
#---------------------------------------------------------------------------
COMPTYP_PARENT_CD()
{
echo "SQL: 8212"  >> "$diag1Output"
echo "select pkey from AMX.stage_all_comps_exp where ckey='$i' and lvl=1;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8212E Select from AMX.stage_all_comps_exp failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8212</RC>" >> "$VWP_LOG"
  exit 8212
fi
COMPTYP_PARENT_CD=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `

echo "     parent: $COMPTYP_PARENT_CD" >> "$diag1Output"
}

#---------------------------------------------------------------------------
# SAMECOMPTYP_PARENT_CD
#---------------------------------------------------------------------------
SAMECOMPTYP_PARENT_CD()
{
echo "SQL: 8213"  >> "$diag1Output"
echo "select t.comptyp_source_cd from AMX.stage_all_comps_exp e, AMX.RelnRul_Transl t where e.pkey = t.comptyp_target_cd and t.relntyp_cd in ('PROXY','SAME') and e.ckey='$i' and e.lvl=1;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8213E Select from AMX.stage_all_comps_exp failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8213</RC>" >> "$VWP_LOG"
  exit 8213
fi
SAMECOMPTYP_PARENT_CD=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `

echo "     --------------------------------------"  >> "$diag1Output"
echo "     same parent: $SAMECOMPTYP_PARENT_CD" >> "$diag1Output"
}

#---------------------------------------------------------------------------
# COMPTYP_GRAND_PARENT_CD
#---------------------------------------------------------------------------
COMPTYP_GRAND_PARENT_CD()
{
echo "SQL: 8214"  >> "$diag1Output"
echo "select pkey from AMX.stage_all_comps_exp where ckey='$i' and lvl=2;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8214E Select from AMX.stage_all_comps_exp failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8214</RC>" >> "$VWP_LOG"
  exit 8214
fi
COMPTYP_GRAND_PARENT_CD=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `
 
echo "     --------------------------------------"  >> "$diag1Output"
echo "     grand parent: $COMPTYP_GRAND_PARENT_CD" >> "$diag1Output"
}

#---------------------------------------------------------------------------
# SAMECOMPTYP_GRAND_PARENT_CD
#---------------------------------------------------------------------------
SAMECOMPTYP_GRAND_PARENT_CD()
{
echo "SQL: 8215"  >> "$diag1Output"
echo "select t.comptyp_source_cd from AMX.stage_all_comps_exp e, AMX.RelnRul_Transl t where e.pkey = t.comptyp_target_cd and t.relntyp_cd in ('SAME', 'PROXY') and e.ckey='$i' and e.lvl=2;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8215E Select from AMX.stage_all_comps_exp failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8215</RC>" >> "$VWP_LOG"
  exit 8215
fi
SAMECOMPTYP_GRAND_PARENT_CD=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `
 
echo "     --------------------------------------"  >> "$diag1Output"
echo "     same grand parent: $SAMECOMPTYP_GRAND_PARENT_CD" >> "$diag1Output"
}

#---------------------------------------------------------------------------
# COMPTYP_G2_PARENT_CD
#---------------------------------------------------------------------------
COMPTYP_G2_PARENT_CD()
{
echo "SQL: 8220"  >> "$diag1Output"
echo "select pkey from AMX.stage_all_comps_exp where ckey='$i' and lvl=3;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8220E Select from AMX.stage_all_comps_exp failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8220</RC>" >> "$VWP_LOG"
  exit 8220
fi
COMPTYP_G2_PARENT_CD=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `
 
echo "     --------------------------------------"  >> "$diag1Output"
echo "     grand grand parent: $COMPTYP_G2_PARENT_CD" >> "$diag1Output"
}

#---------------------------------------------------------------------------
# SAMECOMPTYP_G2_PARENT_CD
#---------------------------------------------------------------------------
SAMECOMPTYP_G2_PARENT_CD()
{
echo "SQL: 8221"  >> "$diag1Output"
echo "select t.comptyp_source_cd from AMX.stage_all_comps_exp e, AMX.RelnRul_Transl t where e.pkey = t.comptyp_target_cd and t.relntyp_cd in ('SAME', 'PROXY') and e.ckey='$i' and e.lvl=3;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8221E Select from AMX.stage_all_comps_exp failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8221</RC>" >> "$VWP_LOG"
  exit 8221
fi
SAMECOMPTYP_G2_PARENT_CD=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `
 
echo "     --------------------------------------"  >> "$diag1Output"
echo "     same grand grand parent: $SAMECOMPTYP_G2_PARENT_CD" >> "$diag1Output"
}

#---------------------------------------------------------------------------
# COMPTYP_G3_PARENT_CD
#---------------------------------------------------------------------------
COMPTYP_G3_PARENT_CD()
{
echo "SQL: 8222"  >> "$diag1Output"
echo "select pkey from AMX.stage_all_comps_exp where ckey='$i' and lvl=4;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8222E Select from AMX.stage_all_comps_exp failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8222</RC>" >> "$VWP_LOG"
  exit 8222
fi
COMPTYP_G3_PARENT_CD=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `
 
echo "     --------------------------------------"  >> "$diag1Output"
echo "     grand grand grand parent: $COMPTYP_G3_PARENT_CD" >> "$diag1Output"
}

#---------------------------------------------------------------------------
# SAMECOMPTYP_G3_PARENT_CD
#---------------------------------------------------------------------------
SAMECOMPTYP_G3_PARENT_CD()
{
echo "SQL: 8223"  >> "$diag1Output"
echo "select t.comptyp_source_cd from AMX.stage_all_comps_exp e, AMX.RelnRul_Transl t where e.pkey = t.comptyp_target_cd and t.relntyp_cd in ('SAME','PROXY') and e.ckey='$i' and e.lvl=4;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8223E Select from AMX.stage_all_comps_exp failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8223</RC>" >> "$VWP_LOG"
  exit 8223
fi
SAMECOMPTYP_G3_PARENT_CD=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `
 
echo "     --------------------------------------"  >> "$diag1Output"
echo "     same grand grand grand parent: $SAMECOMPTYP_G3_PARENT_CD" >> "$diag1Output"
}


#---------------------------------------------------------------------------
# FAMILY_COMPTYPCD
#---------------------------------------------------------------------------
FAMILY_COMPTYPCD()
{
echo "SQL: 8224"  >> "$diag1Output"
echo "select ckey from AMX.stage_all_comps_exp where pkey='$i' and msrc_cd='$p';" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8224E Select from AMX.stage_all_comps failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8224</RC>" >> "$VWP_LOG"
  exit 8224
fi

FAMILY_LIST=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -d '\12' | tr -s ' ' ' '  `
echo "     FAMILY_LIST: $FAMILY_LIST" >> "$diag1Output"  

echo "SQL: 8225"  >> "$diag1Output"
echo "select count(*) from AMX.stage_all_comps_exp where pkey='$i' and msrc_cd='$p' group by pkey ;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8225E Select from AMX.stage_all_comps failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8225</RC>" >> "$VWP_LOG"
  exit 8224
fi

FAMILY_COUNT=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `
echo "     FAMILY_COUNT: $FAMILY_COUNT" >> "$diag1Output" 

FAMILY_COMPTYPCD=""
COUNT=1

for g in $FAMILY_LIST
do
  ITEM=`echo "$g" | sed -e 's/ //g' -e "s/^/'/" -e "s/$/'/" `
  if [ "$COUNT" -lt "$FAMILY_COUNT" ]
  then	
    
    FAMILY_COMPTYPCD=`echo "$FAMILY_COMPTYPCD" "$ITEM" ","`
    COUNT=`expr "$COUNT" + 1`
  else
    FAMILY_COMPTYPCD=`echo "$FAMILY_COMPTYPCD" "$ITEM"`
  fi	
done	
echo "     Family Comptypcd: $FAMILY_COMPTYPCD" >> "$diag1Output"  
}

#---------------------------------------------------------------------------
# COMP_LIST
#---------------------------------------------------------------------------
COMP_LIST()
{
#-- Modified for the COMMON COMPONENTS:J2EE_SERVER, WAS_NODE_AGENT
echo "SQL: 8216"  >> "$diag1Output"
echo "select comptyp_cd from AMX.Stage_Comp_Level c where lvl=$LEVEL and msrc_cd='$p' and not exists ( select 1 from AMX.Stage_CompTyp_Transl_ex e2 where e2.comptyp_cd=c.comptyp_cd and msrc_cd='$p') and not exists ( select 1 from AMX.Stage_attrtyp_transl_ex e2 where e2.comptyp_cd=c.comptyp_cd and msrc_cd='$p') and not exists ( select 1 from AMX.Relnrul_Transl rt where rt.comptyp_target_cd=c.comptyp_cd and rt.relntyp_cd in ('PROXY','SAME')) and comptyp_cd not in ('WAS_NODE_AGENT','J2EE_SERVER', 'J2EE_NODE','J2EE_CELL') and comptyp_cd not in (select ckey from amx.stage_all_comps_exp where pkey in ('J2EE_SERVER', 'WAS_NODE_AGENT'));" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8216E Select from AMX.stage_all_comps failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8216</RC>" >> "$VWP_LOG"
  exit 8216
fi

COMP_LIST=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -d '\12' | tr -s ' ' ' '  `

echo "     COMP_LIST LEVEL$LEVEL : $COMP_LIST" >> "$diag1Output"  
}

#---------------------------------------------------------------------------
# COMP_PROXY_LIST
#---------------------------------------------------------------------------
COMP_PROXY_LIST()
{
COMP_PROXY_LIST=""

echo "SQL: 8217"  >> "$diag1Output"
echo "select r.comptyp_target_cd from AMX.RelnRul_transl r, AMX.CompTyp_Transl t where r.relntyp_cd='PROXY' and r.comptyp_source_cd=t.comptyp_cd and t.msrc_cd='$p' group by r.comptyp_target_cd ;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8217E Select from AMX.RelnRul_Transl failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8217</RC>" >> "$VWP_LOG"
  exit 8217
fi

COMP_PROXY_LIST=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -d '\12' | tr -s ' ' ' '  `

echo "     COMP_PROXY_LIST : $COMP_PROXY_LIST" >> "$diag1Output"  
}

#---------------------------------------------------------------------------
# COMP_REMOTE_LIST
#---------------------------------------------------------------------------
COMP_REMOTE_LIST()
{
echo "SQL: 8218"  >> "$diag1Output"
echo "select r.comptyp_target_cd from AMX.RelnRul_transl r, AMX.Stage_Comp_Level c where c.lvl=$LEVEL and c.msrc_cd='$p' and c.comptyp_cd=r.comptyp_source_cd and r.relntyp_cd='SAME' group by r.comptyp_target_cd;" > "$tempSqlScript.$DBTYPE" 
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8218E Select from AMX.RelnRul_Transl failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8218</RC>" >> "$VWP_LOG"
  exit 8218
fi

COMP_REMOTE_LIST=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -d '\12' | tr -s ' ' ' '  `

echo "     COMP_REMOTE_LIST LEVEL$LEVEL : $COMP_REMOTE_LIST" >> "$diag1Output"  
}


#---------------------------------------------------------------------------
# COMP_CORR_VAL
#---------------------------------------------------------------------------
COMP_CORR_VAL()
{
COUNT1=1
COMP_CORR_VAL=''

LEVEL=1
NUM_KEYS_BY_LVL;
NUM_KEYS_LVL1="$NUM_KEYS_BY_LVL"
  
if [ "$NUM_KEYS_LVL1" -ne 1 ]
then	
  while [ "$COUNT1" -lt "$NUM_KEYS_LVL1" ] 
  do	
    COMP_CORR_VAL=`echo "$COMP_CORR_VAL c$COUNT1.property_val concat '@'  concat "`
    COUNT1=`expr $COUNT1 + 1`
  done
  COMP_CORR_VAL=`echo "$COMP_CORR_VAL c$COUNT1.property_val"`

else
  COMP_CORR_VAL=`echo "c$COUNT1.property_val"`
fi	
COUNT2=`expr $NUM_KEYS_LVL1 + 1`
}

#---------------------------------------------------------------------------
# COMP_PARENT_CORR_VAL
#---------------------------------------------------------------------------
COMP_PARENT_CORR_VAL()
{
COUNT1=1
COMP_PARENT_CORR_VAL=''

LEVEL=2
NUM_KEYS_BY_LVL;
NUM_KEYS_LVL2="$NUM_KEYS_BY_LVL"

if [ "$NUM_KEYS_LVL2" -ne 1 ]
then	
  while [ $COUNT1 -lt $NUM_KEYS_LVL2 ] 
  do	
    COMP_PARENT_CORR_VAL=`echo "$COMP_PARENT_CORR_VAL c$COUNT2.property_val concat '@'  concat "`
    COUNT1=`expr $COUNT1 + 1`
    COUNT2=`expr $COUNT2 + 1`
  done
    COMP_PARENT_CORR_VAL=`echo "$COMP_PARENT_CORR_VAL c$COUNT2.property_val"`

else
  COMP_PARENT_CORR_VAL=`echo "c$COUNT2.property_val"`
fi	
COUNT2=`expr $NUM_KEYS_LVL1 + $NUM_KEYS_LVL2 + 1`
}

#---------------------------------------------------------------------------
# COMP_GRAND_PARENT_CORR_VAL
#---------------------------------------------------------------------------
COMP_GRAND_PARENT_CORR_VAL()
{
COUNT1=1
COMP_GRAND_PARENT_CORR_VAL=''

LEVEL=3
NUM_KEYS_BY_LVL;
NUM_KEYS_LVL3="$NUM_KEYS_BY_LVL"

if [ "$NUM_KEYS_LVL3" -ne 1 ]
then	
  while [ $COUNT1 -lt $NUM_KEYS_LVL3 ] 
  do	
    COMP_GRAND_PARENT_CORR_VAL=`echo "$COMP_GRAND_PARENT_CORR_VAL c$COUNT2.property_val concat '@'  concat "`
    COUNT1=`expr $COUNT1 + 1`
    COUNT2=`expr $COUNT2 + 1`
  done
    COMP_GRAND_PARENT_CORR_VAL=`echo "$COMP_GRAND_PARENT_CORR_VAL c$COUNT2.property_val"`

else
  COMP_GRAND_PARENT_CORR_VAL=`echo "c$COUNT2.property_val"`
fi
COUNT2=`expr $NUM_KEYS_LVL1 + $NUM_KEYS_LVL2 + $NUM_KEYS_LVL3 + 1`
}

#---------------------------------------------------------------------------
# COMP_G2_PARENT_CORR_VAL
#---------------------------------------------------------------------------
COMP_G2_PARENT_CORR_VAL()
{
COUNT1=1
COMP_G2_PARENT_CORR_VAL=''

LEVEL=4
NUM_KEYS_BY_LVL;
NUM_KEYS_LVL4="$NUM_KEYS_BY_LVL"

if [ "$NUM_KEYS_LVL4" -ne 1 ]
then	
  while [ $COUNT1 -lt $NUM_KEYS_LVL4 ] 
  do	
    COMP_G2_PARENT_CORR_VAL=`echo "$COMP_G2_PARENT_CORR_VAL c$COUNT2.property_val concat '@'  concat "`
    COUNT1=`expr $COUNT1 + 1`
    COUNT2=`expr $COUNT2 + 1`
  done
    COMP_G2_PARENT_CORR_VAL=`echo "$COMP_G2_PARENT_CORR_VAL c$COUNT2.property_val"`

else
  COMP_G2_PARENT_CORR_VAL=`echo "c$COUNT2.property_val"`
fi
COUNT2=`expr $NUM_KEYS_LVL1 + $NUM_KEYS_LVL2 + $NUM_KEYS_LVL3 + $NUM_KEYS_LVL4 + 1`
}

#---------------------------------------------------------------------------
# COMP_G3_PARENT_CORR_VAL
#---------------------------------------------------------------------------
COMP_G3_PARENT_CORR_VAL()
{
COUNT1=1
COMP_G3_PARENT_CORR_VAL=''

LEVEL=5
NUM_KEYS_BY_LVL;
NUM_KEYS_LVL5="$NUM_KEYS_BY_LVL"

if [ "$NUM_KEYS_LVL5" -ne 1 ]
then	
  while [ $COUNT1 -lt $NUM_KEYS_LVL5 ] 
  do	
    COMP_G3_PARENT_CORR_VAL=`echo "$COMP_G3_PARENT_CORR_VAL c$COUNT2.property_val concat '@'  concat "`
    COUNT1=`expr $COUNT1 + 1`
    COUNT2=`expr $COUNT2 + 1`
  done
    COMP_G3_PARENT_CORR_VAL=`echo "$COMP_G3_PARENT_CORR_VAL c$COUNT2.property_val"`

else
  COMP_G3_PARENT_CORR_VAL=`echo "c$COUNT2.property_val"`
fi
COUNT2=`expr $NUM_KEYS_LVL1 + $NUM_KEYS_LVL2 + $NUM_KEYS_LVL3 + $NUM_KEYS_LVL4 + $NUM_KEYS_LVL5 + 1`
}

#---------------------------------------------------------------------------
# COMP_CORR_VAL_CASE
#---------------------------------------------------------------------------
COMP_CORR_VAL_CASE()
{
 case $LEVEL in
   #
    1)  
        COMP_CORR_VAL;
        ;;
    2)
      COMP_CORR_VAL;
  COMP_PARENT_CORR_VAL;
       ;;
    3)
      COMP_CORR_VAL;
  COMP_PARENT_CORR_VAL;
  COMP_GRAND_PARENT_CORR_VAL;
       ;;
    4)
      COMP_CORR_VAL;
  COMP_PARENT_CORR_VAL;
  COMP_GRAND_PARENT_CORR_VAL;
  COMP_G2_PARENT_CORR_VAL;
       ;; 
    
    5)
      COMP_CORR_VAL;
  COMP_PARENT_CORR_VAL;
  COMP_GRAND_PARENT_CORR_VAL;
  COMP_G2_PARENT_CORR_VAL;
  COMP_G3_PARENT_CORR_VAL;
       ;;   

   # Default - is an error
    *)
      echo "<MSG>AMX8219E  error in the component level: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8219</RC>" >> "$VWP_LOG"
  exit 8219
        exit 
        ;;
    esac
}
#---------------------------------------------------------------------------
# COMP_NM
#---------------------------------------------------------------------------
COMP_NM()
{
NAMES;

NUM_NAMES;

LEVEL=1
KEYS_BY_LVL;
KEYS_LVL1="$KEYS_BY_LVL"

COUNT=0
COUNT1=1
COMP_NM=''
NAMES_IN_KEYS="FALSE"


for f in $NAMES
do 
  for j in $KEYS_LVL1
  do
    if [ "$f" = "$j" ]
    then 
      COUNT=`expr "$COUNT" + 1`
    fi
  done
done


# all the keys appears in the name
if [ "$COUNT" -eq "$NUM_KEYS_LVL1" ]
then
  NAMES_IN_KEYS="TRUE"
  COMP_NM="$COMP_CORR_VAL"
else
  if [ "$COUNT" -eq 0 ]
  then
    # the name is not part of the key, so it is an attribute
    NAMES_IN_KEYS="FALSE"
    while [ "$COUNT1" -lt "$NUM_NAMES" ]
    do	
      COMP_NM=`echo "$COMP_NM a$COUNT1.attr_val concat '@' concat "`
      COUNT1=`expr $COUNT1 + 1`
    done	
    COMP_NM=`echo "$COMP_NM a$COUNT1.attr_val"`
  else
    # some of the keys appear in the name
    NAMES_IN_KEYS="TRUE"
    for f in $NAMES
    do 	
      POSITION=1	
      for j in $KEYS_LVL1
      do
        if [ "$f" = "$j" ]
        then 
          if [ "$COUNT1" -lt "$NUM_NAMES" ]
          then	
            COMP_NM=`echo "$COMP_NM c$POSITION.property_val concat '@' concat "`
            COUNT1=`expr $COUNT1 + 1`
          else	
            COMP_NM=`echo "$COMP_NM c$POSITION.property_val"`
          fi	
        fi
        POSITION=`expr "$POSITION" + 1`
      done
    done	
  fi	
  
fi
}

#---------------------------------------------------------------------------
# FROM_TABLE
#---------------------------------------------------------------------------
FROM_TABLE()
{
FROM_TABLE=""
COUNT=1
COUNT2=1

while [ "$COUNT" -le "$NUM_ALL_KEYS" ]
do
  if [  "$COUNT" -ne "$NUM_ALL_KEYS" ]
  then
  	FROM_TABLE=`echo "$FROM_TABLE AMX.Stage_instkey_no_Ex c$COUNT,"`
	
  else
	FROM_TABLE=`echo "$FROM_TABLE AMX.Stage_instkey_no_Ex c$COUNT"`
  fi
  COUNT=`expr $COUNT + 1`
done

    
if [ "$NAMES_IN_KEYS" = "FALSE" ]
then	
  while [ "$COUNT2" -le "$NUM_NAMES" ]
      do
	      if [ $COUNT2 -ne "$NUM_NAMES" ]
	      then
    			FROM_TABLE=`echo "$FROM_TABLE, AMX.Stage_attr_no_ex a$COUNT2"`
	      else
		      	FROM_TABLE=`echo "$FROM_TABLE, AMX.Stage_attr_no_ex a$COUNT2"`
	      fi
    			COUNT2=`expr $COUNT2 + 1`
      done
fi
}

#---------------------------------------------------------------------------
#WHERE_CLAUSE
#---------------------------------------------------------------------------
WHERE_CLAUSE()
{
WHERE_CLAUSE=""
WHERE_CLAUSE1=""
COUNT=1
COUNT_PLUS1=2

for u in `echo "$ALL_KEYS"`
do
  if [ "$COUNT" -ne "$NUM_ALL_KEYS" ]
  then	
    WHERE_CLAUSE=`echo "$WHERE_CLAUSE c$COUNT.itm_key='$u' and c$COUNT.iid=c$COUNT_PLUS1.iid and c$COUNT.eid=c$COUNT_PLUS1.eid and c$COUNT.rcid=c$COUNT_PLUS1.rcid and"`
          
  else	
    WHERE_CLAUSE=`echo "$WHERE_CLAUSE c$COUNT.itm_key='$u' "`
  fi
  COUNT=`expr $COUNT + 1`
  COUNT_PLUS1=`expr $COUNT_PLUS1 + 1`
done
WHERE_CLAUSE1=$WHERE_CLAUSE

COUNT=1

if [ "$NAMES_IN_KEYS" = "FALSE" ]
then	
    
  if [ "$NUM_NAMES" -ge 1 ]
  then 
    for u in `echo "$NAMES"`
    do	
      WHERE_CLAUSE=`echo "$WHERE_CLAUSE and a$COUNT.attr_itm='$u' "`
      COUNT=`expr $COUNT + 1`
    done
  fi	
fi	

}

#---------------------------------------------------------------------------
# GROUPBY
#---------------------------------------------------------------------------
GROUPBY()
{
GROUPBY=''
GROUPBY1=''
COUNT=1
COUNT2=1

while [ "$COUNT" -le "$NUM_ALL_KEYS" ]
do
  GROUPBY=`echo "$GROUPBY  c$COUNT.property_val,"`
  COUNT=`expr $COUNT + 1`
done
GROUPBY1="$GROUPBY"	

if [ "$NAMES_IN_KEYS" = "FALSE" ]
then

  while [ "$COUNT2" -le "$NUM_NAMES" ]
      do
    GROUPBY=`echo "$GROUPBY  a$COUNT2.attr_val,"`
    COUNT2=`expr $COUNT2 + 1`
      done
fi
}

#---------------------------------------------------------------------------
# ATTR_ARGS
#---------------------------------------------------------------------------
ATTR_ARGS()
{
  #---------------------------------------------------------------------------
  #There are multiple cases
  # either the attribute is part of the key because it is a composite key
  # either the attribute is part of the categories table because it is not a key
  # for the comp_corr_val it can relate to one key or  multiple keys
  #---------------------------------------------------------------------------
  ATTR=""
  TIME=""
  FROM_TABLE2=""
  WHERE_CLAUSE2=""
  GROUPBY2=""


  if [ "$ITM_KEY_ATTR" = "" ] 
# The attribute is not a key	  
  then	
      FROM_TABLE2=`echo "AMX.Stage_attr_no_ex a2"`
      ATTR=`echo "a2.attrtyp_cd,a2.attr_val,"`
      WHERE_CLAUSE2=`echo "a2.attrtyp_cd='$a' and c1.eid=a2.eid and c1.rcid=a2.rcid and c1.iid=a2.iid"` GROUPBY2=`echo "a2.attrtyp_cd,a2.attr_val,"`
      TIME=`echo "min(a2.timekey_dttm)"`
# The attribute is a key      
   else
    FROM_TABLE2=`echo "AMX.Attrtyp_Transl t, AMX.Stage_instkey_no_Ex b1"`
    ATTR=`echo "t.attrtyp_cd, b1.property_val,"`
    WHERE_CLAUSE2=`echo "b1.ITM_Key='$ITM_KEY_ATTR' and t.itm_attr_property=b1.ITM_key and c1.eid=b1.eid and c1.rcid=b1.rcid and c1.iid=b1.iid "`
    GROUPBY2=`echo "t.attrtyp_cd,b1.property_val,"`
    TIME=`echo "current timestamp - current timezone"`
   fi

}


#---------------------------------------------------------------------------
# COMP_TEMPLATE_CASE
#---------------------------------------------------------------------------
COMP_TEMPLATE_CASE()
{
 if [ "$NUM_KEYS_LVL1" -eq 1 ]
 then 
   KEY_P1=`echo "$KEYS_LVL1"| sed -e 's/ //g'`
   echo "     KEY_P1: ..$KEY_P1.. " >> "$diag1Output" 
 else
   for k in `echo "$KEYS_LVL1"` 
   do
	KEY_P1="$k"
	echo "     KEY_P1: ..$KEY_P1.. " >> "$diag1Output"
		   
   done
 fi
 case $LEVEL in
   #
    1)
		   
      if [ -f "$VWS_LOGGING/insert_comp_level1.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_comp_level1.$DBTYPE"
  fi

      perl "$FULLDIR/insert_comp_level1.pl" "$FULLDIR/insert_comp_level1.$DBTYPE.template" "$VWS_LOGGING/insert_comp_level1.$DBTYPE" "$COMPTYPCD" "$COMP_CORR_VAL" "$COMP_NM" "$FROM_TABLE" "$WHERE_CLAUSE" "$GROUPBY" "$PAC" "$KEY_P1"

  # concatenate insert_comp_level1.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_comp_level1.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE" 
        ;;
    2)  
      COMPTYP_PARENT_CD;

        if [ -f "$VWS_LOGGING/insert_comp_level2.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_comp_level2.$DBTYPE"
  fi

  perl "$FULLDIR/insert_comp_level2.pl" "$FULLDIR/insert_comp_level2.$DBTYPE.template" "$VWS_LOGGING/insert_comp_level2.$DBTYPE" "$COMPTYPCD" "$COMP_CORR_VAL" "$COMP_PARENT_CORR_VAL" "$COMP_NM" "$FROM_TABLE" "$WHERE_CLAUSE" "$GROUPBY" "$COMPTYP_PARENT_CD" "$PAC" "$KEY_P1"

  # concatenate insert_comp_level2.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_comp_level2.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"
       ;;
    3)
      COMPTYP_PARENT_CD;
  COMPTYP_GRAND_PARENT_CD;

      
      if [ -f "$VWS_LOGGING/insert_comp_level3.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_comp_level3.$DBTYPE"
  fi

  perl "$FULLDIR/insert_comp_level3.pl" "$FULLDIR/insert_comp_level3.$DBTYPE.template" "$VWS_LOGGING/insert_comp_level3.$DBTYPE" "$COMPTYPCD" "$COMP_CORR_VAL" "$COMP_PARENT_CORR_VAL" "$COMP_GRAND_PARENT_CORR_VAL" "$COMP_NM" "$FROM_TABLE" "$WHERE_CLAUSE" "$GROUPBY" "$COMPTYP_PARENT_CD" "$COMPTYP_GRAND_PARENT_CD" "$PAC" "$KEY_P1"

  # concatenate insert_comp_level3.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_comp_level3.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"

       ;;
    
    4)
      COMPTYP_PARENT_CD;
      COMPTYP_GRAND_PARENT_CD;
      COMPTYP_G2_PARENT_CD;
      
      if [ -f "$VWS_LOGGING/insert_comp_level4.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_comp_level4.$DBTYPE"
  fi

  perl "$FULLDIR/insert_comp_level4.pl" "$FULLDIR/insert_comp_level4.$DBTYPE.template" "$VWS_LOGGING/insert_comp_level4.$DBTYPE" "$COMPTYPCD" "$COMP_CORR_VAL" "$COMP_PARENT_CORR_VAL" "$COMP_GRAND_PARENT_CORR_VAL" "$COMP_G2_PARENT_CORR_VAL" "$COMP_NM" "$FROM_TABLE" "$WHERE_CLAUSE" "$GROUPBY" "$COMPTYP_PARENT_CD" "$COMPTYP_GRAND_PARENT_CD" "$COMPTYP_G2_PARENT_CD" "$PAC" "$KEY_P1"
  

  # concatenate insert_comp_level4.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_comp_level4.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"

       ;;  

    5)
      COMPTYP_PARENT_CD;
  COMPTYP_GRAND_PARENT_CD;
  COMPTYP_G2_PARENT_CD;
  COMPTYP_G3_PARENT_CD;

      
      if [ -f "$VWS_LOGGING/insert_comp_level5.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_comp_level5.$DBTYPE"
  fi

  perl "$FULLDIR/insert_comp_level5.pl" "$FULLDIR/insert_comp_level5.$DBTYPE.template" "$VWS_LOGGING/insert_comp_level5.$DBTYPE" "$COMPTYPCD" "$COMP_CORR_VAL" "$COMP_PARENT_CORR_VAL" "$COMP_GRAND_PARENT_CORR_VAL" "$COMP_G2_PARENT_CORR_VAL" "$COMP_G3_PARENT_CORR_VAL" "$COMP_NM" "$FROM_TABLE" "$WHERE_CLAUSE" "$GROUPBY" "$COMPTYP_PARENT_CD" "$COMPTYP_GRAND_PARENT_CD" "$COMPTYP_G2_PARENT_CD" "$COMPTYP_G3_PARENT_CD" "$PAC" "$KEY_P1"

  # concatenate insert_comp_level5.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_comp_level5.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"

       ;;     

   # Default - is an error
    *)
      echo "<MSG>CDW8219E error in the component level: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8219</RC>" >> "$VWP_LOG"
  exit 8219
        exit 
        ;;
    esac
}

#---------------------------------------------------------------------------
# COMP_PROXY_TEMPLATE
#---------------------------------------------------------------------------
COMP_PROXY_TEMPLATE()
{
 if [ "$NUM_KEYS_LVL1" -eq 1 ]
 then 
   KEY_P1=`echo "$KEYS_LVL1"| sed -e 's/ //g'`
   echo "     KEY_P1: ..$KEY_P1.. " >> "$diag1Output" 
 else
   for k in `echo "$KEYS_LVL1"` 
   do
	KEY_P1="$k"
	echo "     KEY_P1: ..$KEY_P1.. " >> "$diag1Output"
		   
   done
 fi  
 
if [ -f "$VWS_LOGGING/insert_comp_level1_proxy.$DBTYPE" ]
then 
  rm "$VWS_LOGGING/insert_comp_level1_proxy.$DBTYPE"
fi

perl "$FULLDIR/insert_comp_level1_proxy.pl" "$FULLDIR/insert_comp_level1_proxy.$DBTYPE.template" "$VWS_LOGGING/insert_comp_level1_proxy.$DBTYPE" "$COMPTYPCD" "$COMP_CORR_VAL" "$COMP_NM" "$FROM_TABLE" "$WHERE_CLAUSE" "$GROUPBY" "$PAC" "$FAMILY_COMPTYPCD" "$KEY_P1" 

# concatenate insert_comp_level1_proxy.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

cat "$VWS_LOGGING/insert_comp_level1_proxy.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE" 
}

#---------------------------------------------------------------------------
# COMP_SAME_TEMPLATE
#---------------------------------------------------------------------------
COMP_SAME_TEMPLATE()
{

 if [ "$NUM_KEYS_LVL1" -eq 1 ]
 then 
   KEY_P1=`echo "$KEYS_LVL1"| sed -e 's/ //g'`
   echo "     KEY_P1: ..$KEY_P1.. " >> "$diag1Output" 
 else
   for k in `echo "$KEYS_LVL1"` 
   do
	KEY_P1="$k"
	echo "     KEY_P1: ..$KEY_P1.. " >> "$diag1Output"
		   
   done
 fi
case $LEVEL in
 #
    2)
        
        COMPTYP_CD_SAME;
        COMPTYP_PARENT_CD;
        SAMECOMPTYP_PARENT_CD;


  if [ -f "$VWS_LOGGING/insert_comp_level2_same.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_comp_level2_same.$DBTYPE"
  fi

  perl "$FULLDIR/insert_comp_level2_same.pl" "$FULLDIR/insert_comp_level2_same.$DBTYPE.template" "$VWS_LOGGING/insert_comp_level2_same.$DBTYPE" "$COMPTYPCD" "$COMPTYP_CD_SAME" "$COMP_CORR_VAL" "$COMP_PARENT_CORR_VAL" "$COMP_NM" "$FROM_TABLE" "$WHERE_CLAUSE" "$GROUPBY" "$COMPTYP_PARENT_CD" "$SAMECOMPTYP_PARENT_CD" "$PAC" "$KEY_P1" 


  # concatenate insert_comp_level2_same.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_comp_level2_same.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"
  ;;
#
    3)
        COMPTYP_CD_SAME;
        COMPTYP_PARENT_CD;
        SAMECOMPTYP_PARENT_CD;
  COMPTYP_GRAND_PARENT_CD;
  SAMECOMPTYP_GRAND_PARENT_CD;
  if [ -f "$VWS_LOGGING/insert_comp_level3_same.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_comp_level3_same.$DBTYPE"
  fi

  perl "$FULLDIR/insert_comp_level3_same.pl" "$FULLDIR/insert_comp_level3_same.$DBTYPE.template" "$VWS_LOGGING/insert_comp_level3_same.$DBTYPE" "$COMPTYPCD" "$COMPTYP_CD_SAME" "$COMP_CORR_VAL" "$COMP_PARENT_CORR_VAL" "$COMP_GRAND_PARENT_CORR_VAL" "$COMP_NM" "$FROM_TABLE" "$WHERE_CLAUSE" "$GROUPBY" "$COMPTYP_PARENT_CD" "$SAMECOMPTYP_PARENT_CD" "$COMPTYP_GRAND_PARENT_CD" "$SAMECOMPTYP_GRAND_PARENT_CD" "$PAC" "$KEY_P1" 


  # concatenate insert_comp_level3_same.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_comp_level3_same.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"
  ;;
   4)
        COMPTYP_CD_SAME;
        COMPTYP_PARENT_CD;
        SAMECOMPTYP_PARENT_CD;
  COMPTYP_GRAND_PARENT_CD;
  SAMECOMPTYP_GRAND_PARENT_CD;
  COMPTYP_G2_PARENT_CD;
  SAMECOMPTYP_G2_PARENT_CD;

  if [ -f "$VWS_LOGGING/insert_comp_level4_same.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_comp_level4_same.$DBTYPE"
  fi

  perl "$FULLDIR/insert_comp_level4_same.pl" "$FULLDIR/insert_comp_level4_same.$DBTYPE.template" "$VWS_LOGGING/insert_comp_level4_same.$DBTYPE" "$COMPTYPCD" "$COMPTYP_CD_SAME" "$COMP_CORR_VAL" "$COMP_PARENT_CORR_VAL" "$COMP_GRAND_PARENT_CORR_VAL" "$COMP_G2_PARENT_CORR_VAL" "$COMP_NM" "$FROM_TABLE" "$WHERE_CLAUSE" "$GROUPBY" "$COMPTYP_PARENT_CD" "$SAMECOMPTYP_PARENT_CD" "$COMPTYP_GRAND_PARENT_CD" "$SAMECOMPTYP_GRAND_PARENT_CD" "$COMPTYP_G2_PARENT_CD" "$SAMECOMPTYP_G2_PARENT_CD" "$PAC" "$KEY_P1" 


  # concatenate insert_comp_level4_same.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_comp_level4_same.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"
  ;;

   5)
        COMPTYP_CD_SAME;
        COMPTYP_PARENT_CD;
        SAMECOMPTYP_PARENT_CD;
  COMPTYP_GRAND_PARENT_CD;
  SAMECOMPTYP_GRAND_PARENT_CD;
  COMPTYP_G2_PARENT_CD;
  SAMECOMPTYP_G2_PARENT_CD;
  COMPTYP_G3_PARENT_CD;
  SAMECOMPTYP_G3_PARENT_CD;

  if [ -f "$VWS_LOGGING/insert_comp_level5_same.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_comp_level5_same.$DBTYPE"
  fi

  perl "$FULLDIR/insert_comp_level5_same.pl" "$FULLDIR/insert_comp_level5_same.$DBTYPE.template" "$VWS_LOGGING/insert_comp_level5_same.$DBTYPE" "$COMPTYPCD" "$COMPTYP_CD_SAME" "$COMP_CORR_VAL" "$COMP_PARENT_CORR_VAL" "$COMP_GRAND_PARENT_CORR_VAL" "$COMP_G2_PARENT_CORR_VAL" "$COMP_G3_PARENT_CORR_VAL" "$COMP_NM" "$FROM_TABLE" "$WHERE_CLAUSE" "$GROUPBY" "$COMPTYP_PARENT_CD" "$SAMECOMPTYP_PARENT_CD" "$COMPTYP_GRAND_PARENT_CD" "$SAMECOMPTYP_GRAND_PARENT_CD" "$COMPTYP_G2_PARENT_CD" "$SAMECOMPTYP_G2_PARENT_CD" "$COMPTYP_G3_PARENT_CD" "$SAMECOMPTYP_G3_PARENT_CD" "$PAC" "$KEY_P1" 


  # concatenate insert_comp_level5_same.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_comp_level5_same.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"
  ;;	
  

   # Default - is an error
   
    *)
      echo "<MSG>CDW8219E error in the component level: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8219</RC>" >> "$VWP_LOG"
  exit 8219
        exit 
        ;;
    esac
}

#---------------------------------------------------------------------------
# ATTR_PROXY_SAME_TEMPLATE_CASE
#---------------------------------------------------------------------------
ATTR_PROXY_SAME_TEMPLATE_CASE()
{
 case $LEVEL in
   #
    1)  
    
    if [ -f "$VWS_LOGGING/insert_attr_level1_proxy.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_attr_level1_proxy.$DBTYPE"
  fi

  perl "$FULLDIR/insert_attr_level1_proxy.pl" "$FULLDIR/insert_attr_level1_proxy.$DBTYPE.template" "$VWS_LOGGING/insert_attr_level1_proxy.$DBTYPE" "$COMPTYPCD" "$COMPTYP_CD_SAME" "$ATTRTYPCD" "$ATTR" "$TIME" "$FROM_TABLE2" "$WHERE_CLAUSE2" "$GROUPBY2"   

  # concatenate insert_attr_level1_proxy.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_attr_level1_proxy.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"
        ;;
    2)
        if [ -f "$VWS_LOGGING/insert_attr_level2_same.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_attr_level2_same.$DBTYPE"
  fi


  # replace tokens template insert_attr_level2_same with current values  #

  perl "$FULLDIR/insert_attr_level1_proxy.pl" "$FULLDIR/insert_attr_level2_same.$DBTYPE.template" "$VWS_LOGGING/insert_attr_level2_same.$DBTYPE" "$COMPTYPCD" "$COMPTYP_CD_SAME"  "$ATTRTYPCD" "$ATTR" "$TIME" "$FROM_TABLE2" "$WHERE_CLAUSE2" "$GROUPBY2"   

  # concatenate insert_attr_level2_same.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_attr_level2_same.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"
       ;;
    3)
      if [ -f "$VWS_LOGGING/insert_attr_level3_same.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_attr_level3_same.$DBTYPE"
  fi

  # replace tokens template insert_attr_level3_same with current values  #
   

  perl "$FULLDIR/insert_attr_level1_proxy.pl" "$FULLDIR/insert_attr_level3_same.$DBTYPE.template" "$VWS_LOGGING/insert_attr_level3_same.$DBTYPE" "$COMPTYPCD" "$COMPTYP_CD_SAME"  "$ATTRTYPCD" "$ATTR" "$TIME" "$FROM_TABLE2" "$WHERE_CLAUSE2" "$GROUPBY2"   

  # concatenate insert_attr_level3_same.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_attr_level3_same.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"

       ;;

    4)
      if [ -f "$VWS_LOGGING/insert_attr_level4_same.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_attr_level4_same.$DBTYPE"
  fi

  # replace tokens template insert_attr_level4_same with current values  #


  perl "$FULLDIR/insert_attr_level1_proxy.pl" "$FULLDIR/insert_attr_level4_same.$DBTYPE.template" "$VWS_LOGGING/insert_attr_level4_same.$DBTYPE" "$COMPTYPCD" "$COMPTYP_CD_SAME"  "$ATTRTYPCD" "$ATTR" "$TIME" "$FROM_TABLE2" "$WHERE_CLAUSE2" "$GROUPBY2"   

  # concatenate insert_attr_level4_same.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_attr_level4_same.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"

       ;;

    5)
      if [ -f "$VWS_LOGGING/insert_attr_level5_same.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_attr_level5_same.$DBTYPE"
  fi

  # replace tokens template insert_attr_level5_same with current values  #

  perl "$FULLDIR/insert_attr_level1_proxy.pl" "$FULLDIR/insert_attr_level5_same.$DBTYPE.template" "$VWS_LOGGING/insert_attr_level5_same.$DBTYPE" "$COMPTYPCD" "$COMPTYP_CD_SAME"  "$ATTRTYPCD" "$ATTR" "$TIME" "$FROM_TABLE2" "$WHERE_CLAUSE2" "$GROUPBY2"   

  # concatenate insert_attr_level5_same.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_attr_level5_same.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"

       ;;   
   
   # Default - is an error
    *)
      echo "<MSG>CDW8219E  error in the component level: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8219</RC>" >> "$VWP_LOG"
  exit 8219
        exit 
        ;;
    esac
}

#---------------------------------------------------------------------------
# ATTR_TEMPLATE_CASE
#---------------------------------------------------------------------------
ATTR_TEMPLATE_CASE()
{
 case $LEVEL in
   #
    1)
      if [ -f "$VWS_LOGGING/insert_attr_level1.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_attr_level1.$DBTYPE"
  fi

      perl "$FULLDIR/insert_attr_level1.pl" "$FULLDIR/insert_attr_level1.$DBTYPE.template" "$VWS_LOGGING/insert_attr_level1.$DBTYPE" "$COMPTYPCD" "$ATTRTYPCD" "$ATTR" "$TIME" "$FROM_TABLE2" "$WHERE_CLAUSE2" "$GROUPBY2" 

  # concatenate insert_attr_level1.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_attr_level1.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"
        ;;
    2)
        if [ -f "$VWS_LOGGING/insert_attr_level2.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_attr_level2.$DBTYPE"
  fi

  # replace tokens template insert_attr_level2 with current values  #

  perl "$FULLDIR/insert_attr_level1.pl" "$FULLDIR/insert_attr_level2.$DBTYPE.template" "$VWS_LOGGING/insert_attr_level2.$DBTYPE" "$COMPTYPCD" "$ATTRTYPCD" "$ATTR" "$TIME" "$FROM_TABLE2" "$WHERE_CLAUSE2" "$GROUPBY2" 
  # concatenate insert_attr_level2.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_attr_level2.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"
       ;;
    3)
      if [ -f "$VWS_LOGGING/insert_attr_level3.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_attr_level3.$DBTYPE"
  fi

  # replace tokens template insert_attr_level3 with current values  #

  perl "$FULLDIR/insert_attr_level1.pl" "$FULLDIR/insert_attr_level3.$DBTYPE.template" "$VWS_LOGGING/insert_attr_level3.$DBTYPE" "$COMPTYPCD" "$ATTRTYPCD" "$ATTR" "$TIME" "$FROM_TABLE2" "$WHERE_CLAUSE2" "$GROUPBY2"  

  # concatenate insert_attr_level3.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_attr_level3.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"

       ;;
    
    4)
      if [ -f "$VWS_LOGGING/insert_attr_level4.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_attr_level4.$DBTYPE"
  fi

  # replace tokens template insert_attr_level4 with current values  #

  perl "$FULLDIR/insert_attr_level1.pl" "$FULLDIR/insert_attr_level4.$DBTYPE.template" "$VWS_LOGGING/insert_attr_level4.$DBTYPE" "$COMPTYPCD" "$ATTRTYPCD" "$ATTR" "$TIME" "$FROM_TABLE2" "$WHERE_CLAUSE2" "$GROUPBY2"  

  # concatenate insert_attr_level4.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_attr_level4.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"

       ;;

    5)
      if [ -f "$VWS_LOGGING/insert_attr_level5.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_attr_level5.$DBTYPE"
  fi

  # replace tokens template insert_attr_level5 with current values  #

  perl "$FULLDIR/insert_attr_level1.pl" "$FULLDIR/insert_attr_level5.$DBTYPE.template" "$VWS_LOGGING/insert_attr_level5.$DBTYPE" "$COMPTYPCD" "$ATTRTYPCD" "$ATTR" "$TIME" "$FROM_TABLE2" "$WHERE_CLAUSE2" "$GROUPBY2"  

  # concatenate insert_attr_level5.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_attr_level5.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"

       ;;   
   

   # Default - is an error
    *)
      echo "<MSG>CDW8219E  error in the component level: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8219</RC>" >> "$VWP_LOG"
  exit 8219
        exit 
        ;;
    esac
}


#---------------------------------------------------------------------------
# ALL_ATTRS_BY_LVL
#---------------------------------------------------------------------------
ALL_ATTR_BY_LVL()
{
if [ "$ATTRTYPCD_LIST" != "" ] 
then 

# Loop Start for all the attributes of a LEVEL$LEVEL component #

echo "     --------------------------------------"  >> "$diag1Output"
    
  for a in `echo $ATTRTYPCD_LIST` 
  do
   	ATTRTYPCD=$a
    	ITM_KEY_ATTR;
    	echo "     Attribute $ATTRTYPCD for comptyp_cd $COMPTYPCD" >> "$diag1Output"

        ATTR_ARGS;
    if [ "$PROXY_SAME" = "TRUE" ] 
    then
      	ATTR_PROXY_SAME_TEMPLATE_CASE;
    else
	    #-- Modified for the COMMON COMPONENTS:J2EE_SERVER, WAS_NODE_AGENT
      	if [ "$NO_HOST_CASE" = "TRUE" ]
	then
		ATTR_NO_HOST_CASE;
	else	
      		ATTR_TEMPLATE_CASE;
	 		
	fi
    fi	

  done
# Loop End for all the attributes of a LEVEL$LEVEL component #
fi
}

#---------------------------------------------------------------------------
# INSERT_MSMT
#---------------------------------------------------------------------------
MSMT()
{
echo "     --------------------------------------"  >> "$diag1Output"
echo "     Start Msmt comp Level$LEVEL $COMPTYPCD" >> "$diag1Output"

PAC="$p"
    

if [ -f "$VWS_LOGGING/insert_msmt.$DBTYPE" ]
then 
  rm "$VWS_LOGGING/insert_msmt.$DBTYPE"
fi	
# replace tokens template insert_attr with current values  #

perl "$FULLDIR/insert_msmt.pl" "$FULLDIR/insert_msmt.$DBTYPE.template" "$VWS_LOGGING/insert_msmt.$DBTYPE" "$COMPTYPCD" "$PAC" 
  
# concatenate insert_msmt.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

cat "$VWS_LOGGING/insert_msmt.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"

echo "     End Msmt comp Level$LEVEL $COMPTYPCD" >> "$diag1Output"
echo "     --------------------------------------"  >> "$diag1Output"
}

#---------------------------------------------------------------------------
# MSMT_PROXY
#---------------------------------------------------------------------------
MSMT_PROXY()
{
echo "     --------------------------------------"  >> "$diag1Output"
echo "     Start Msmt comp Level$LEVEL $COMPTYPCD" >> "$diag1Output"

PAC="$p"
    

if [ -f "$VWS_LOGGING/insert_msmt_proxy.$DBTYPE" ]
then 
  rm "$VWS_LOGGING/insert_msmt_proxy.$DBTYPE"
fi	
# replace tokens template insert_attr with current values  #

perl "$FULLDIR/insert_msmt.pl" "$FULLDIR/insert_msmt_proxy.$DBTYPE.template" "$VWS_LOGGING/insert_msmt_proxy.$DBTYPE" "$COMPTYPCD" "$PAC"
  
# concatenate insert_msmt_proxy.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

cat "$VWS_LOGGING/insert_msmt_proxy.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"

echo "     End Msmt comp Level$LEVEL $COMPTYPCD" >> "$diag1Output"
echo "     --------------------------------------"  >> "$diag1Output"
}

#-- Modified for the COMMON COMPONENTS:J2EE_SERVER, WAS_NODE_AGENT
#---------------------------------------------------------------------------
# COMMON_COMP_LIST
#---------------------------------------------------------------------------
COMMON_COMP_LIST()
{
COMMON_COMP_LIST=""

echo "SQL: 8217"  >> "$diag1Output"
echo "select distinct comptyp_cd from amx.comptyp_transl_common ;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8217E Select from amx.comptyp_transl_common failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8217</RC>" >> "$VWP_LOG"
  exit 8217
fi

COMMON_COMP_LIST=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -d '\12' | tr -s ' ' ' '  `

echo "     COMMON_COMP_LIST : $COMMON_COMP_LIST" >> "$diag1Output"  
}

#---------------------------------------------------------------------------
# SUB_COMMON_COMP_LIST
#---------------------------------------------------------------------------
SUB_COMMON_COMP_LIST()
{
SUB_COMMON_COMP_LIST=""

echo "SQL: 8217"  >> "$diag1Output"
echo "select ckey from amx.stage_all_comps_exp where pkey in ('J2EE_SERVER', 'WAS_NODE_AGENT') and lvl=$LEVEL  and msrc_cd='$p';" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8217E Select from amx.stage_all_comps_exp failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8217</RC>" >> "$VWP_LOG"
  exit 8217
fi

SUB_COMMON_COMP_LIST=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -d '\12' | tr -s ' ' ' '  `

echo "     SUB_COMMON_COMP_LIST : $SUB_COMMON_COMP_LIST" >> "$diag1Output"  
}

#---------------------------------------------------------------------------
# COMMON_COMP_CASE
#---------------------------------------------------------------------------
COMMON_COMP_CASE()
{
	case "$COMPTYPCD" in
#J2EE_CELL	
'J2EE_CELL')

  # concatenate Insert_comp_level1_j2ee_cell.$DBTYPE  to the AMX_c05_s040_comp_msmt.$DBTYPE file #

  cat "$FULLDIR/insert_comp_level1_j2ee_cell.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE" 
  MSMT;
;;

#J2EE_NODE	
'J2EE_NODE')

  # concatenate Insert_comp_level2_j2ee_node.$DBTYPE  to the AMX_c05_s040_comp_msmt.$DBTYPE file #

  cat "$FULLDIR/insert_comp_level2_j2ee_node.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE" 
  MSMT;
;;

#J2EE_SERVER	
'J2EE_SERVER')

  # concatenate Insert_comp_level3_j2ee_server.$DBTYPE  to the AMX_c05_s040_comp_msmt.$DBTYPE file #

  cat "$FULLDIR/insert_comp_level3_j2ee_server.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE" 
  MSMT;
;;
#WAS_NODE_AGENT 
'WAS_NODE_AGENT') 


  # concatenate Insert_comp_level3_was_node_agent.$DBTYPE  to the AMX_c05_s040_comp_msmt.$DBTYPE file #

  cat "$FULLDIR/insert_comp_level3_was_node_agent.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE" 
  MSMT;
     ;; 
   *)
      echo "<MSG>CDW8219E Common Component Type UNKNOWN: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8219</RC>" >> "$VWP_LOG"
        ;;
    esac 
}	
#---------------------------------------------------------------------------
# COMP_NO_HOST_CASE
#---------------------------------------------------------------------------
COMP_NO_HOST_CASE()
{
 case $LEVEL in
   #
    4)
      COMPTYPCD="$i"
      COMPTYP_PARENT_CD;
      COMPTYP_GRAND_PARENT_CD;
      COMPTYP_G2_PARENT_CD;
      
      if [ -f "$VWS_LOGGING/insert_comp_level4_no_host.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_comp_level4_no_host.$DBTYPE"
  fi

  perl "$FULLDIR/insert_comp_level4_no_host.pl" "$FULLDIR/insert_comp_level4_no_host.$DBTYPE.template" "$VWS_LOGGING/insert_comp_level4_no_host.$DBTYPE" "$COMPTYPCD" "$COMP_CORR_VAL" "$COMP_PARENT_CORR_VAL" "$COMP_GRAND_PARENT_CORR_VAL" "$COMP_G2_PARENT_CORR_VAL" "$COMP_NM" "$FROM_TABLE" "$WHERE_CLAUSE" "$GROUPBY" "$COMPTYP_PARENT_CD" "$COMPTYP_GRAND_PARENT_CD" "$COMPTYP_G2_PARENT_CD" "$PAC" 


  # concatenate Insert_comp_level4_no_host.$DBTYPE  to the AMX_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_comp_level4_no_host.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"

       ;;  

    5)
      COMPTYPCD="$i"
      COMPTYP_PARENT_CD;
      COMPTYP_GRAND_PARENT_CD;
      COMPTYP_G2_PARENT_CD;
      COMPTYP_G3_PARENT_CD;

      
      if [ -f "$VWS_LOGGING/insert_comp_level5_no_host.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_comp_level5_no_host.$DBTYPE"
  fi

  perl "$FULLDIR/insert_comp_level5_no_host.pl" "$FULLDIR/insert_comp_level5_no_host.$DBTYPE.template" "$VWS_LOGGING/insert_comp_level5_no_host.$DBTYPE" "$COMPTYPCD" "$COMP_CORR_VAL" "$COMP_PARENT_CORR_VAL" "$COMP_GRAND_PARENT_CORR_VAL" "$COMP_G2_PARENT_CORR_VAL" "$COMP_G3_PARENT_CORR_VAL" "$COMP_NM" "$FROM_TABLE" "$WHERE_CLAUSE" "$GROUPBY" "$COMPTYP_PARENT_CD" "$COMPTYP_GRAND_PARENT_CD" "$COMPTYP_G2_PARENT_CD" "$COMPTYP_G3_PARENT_CD" "$PAC" 

  # concatenate Insert_comp_level5.$DBTYPE  to the AMX_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_comp_level5_no_host.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"

       ;;     

   # Default - is an error
    *)
      echo "<MSG>CDW8219E error in the component level: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8219</RC>" >> "$VWP_LOG"
  exit 8219
        exit 
        ;;
    esac
}

#---------------------------------------------------------------------------
# ATTR_NO_HOST_CASE
#---------------------------------------------------------------------------
ATTR_NO_HOST_CASE()
{
 case $LEVEL in
   #
    
    4)
      if [ -f "$VWS_LOGGING/insert_attr_level4_no_host.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_attr_level4_no_host.$DBTYPE"
  fi

  # replace tokens template insert_attr_level4_no_host with current values  #

  perl "$FULLDIR/insert_attr_level1.pl" "$FULLDIR/insert_attr_level4_no_host.$DBTYPE.template" "$VWS_LOGGING/insert_attr_level4_no_host.$DBTYPE" "$COMPTYPCD" "$ATTRTYPCD" "$ATTR" "$TIME" "$FROM_TABLE2" "$WHERE_CLAUSE2" "$GROUPBY2"  

  # concatenate insert_attr_level4_no_host.$DBTYPE  to the AMX_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_attr_level4_no_host.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"

       ;;

    5)
      if [ -f "$VWS_LOGGING/insert_attr_level5_no_host.$DBTYPE" ]
  then 
    rm "$VWS_LOGGING/insert_attr_level5_no_host.$DBTYPE"
  fi

  # replace tokens template insert_attr_level5_no_host with current values  #

  perl "$FULLDIR/insert_attr_level1.pl" "$FULLDIR/insert_attr_level5_no_host.$DBTYPE.template" "$VWS_LOGGING/insert_attr_level5_no_host.$DBTYPE" "$COMPTYPCD" "$ATTRTYPCD" "$ATTR" "$TIME" "$FROM_TABLE2" "$WHERE_CLAUSE2" "$GROUPBY2"  

  # concatenate insert_attr_level5_no_host.$DBTYPE  to the AMX_c05_s040_comp_msmt.$DBTYPE file #

  cat "$VWS_LOGGING/insert_attr_level5_no_host.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"

       ;;   
   

   # Default - is an error
    *)
      echo "<MSG>CDW8219E  error in the component level: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8219</RC>" >> "$VWP_LOG"
  exit 8219
        exit 
        ;;
    esac
}

#-- End Modification for the COMMON COMPONENTS:J2EE_SERVER, WAS_NODE_AGENT

##############################################
##    Main
#############################################

PROXY_SAME="FALSE"
#-- Modified for the COMMON COMPONENTS:J2EE_SERVER, WAS_NODE_AGENT
NO_HOST_CASE="FALSE"

# if the metadata has changed or if the prepare script does not exist
METADATA_CHANGE_ROWS;
if [ "$METADATA_CHANGE_ROWS" -ne 0  ] || [ ! -a  "$FULLSCRIPT.$DBTYPE" ]
then	
#---------------------------------------------------
# Drop the old metadata copy tables and 
# replace them  by the new ones
# Create the temporary msmt table for all the PACs
#---------------------------------------------------

# concatenate copy_new_mdata_into_old.$DBTYPE  to the amx_c05_s040_comp_msmt.$DBTYPE file #

cat "$FULLDIR/copy_new_mdata_into_old.$DBTYPE" > "$FULLSCRIPT.$DBTYPE"

#----------------------------------
# Find the list of ITM applications
#----------------------------------


PAC_LIST;

# DEBUG PAC_LIST="IZY GWL"

#----------------------------------------------
#  Start loop to add the Hosts for all the PACs
#----------------------------------------------
if [ "$PAC_LIST" != "" ]
then

 for p in `echo $PAC_LIST` 
 do
  INSERT_HOSTS;

 done

fi

#-------------------------------------------------------------------
#Insert the attributes (AMX_EID, AMX_GMT_OFFSET, LAST_IP_ADDRESS)
#for all the hosts
#-------------------------------------------------------------------
  INSERT_HOST_ATTRS;

#----------------------------------------------
#  End loop to add the Hosts for all the PACs
#----------------------------------------------

#-------------------------------
# If Common Components exist
# Insert them
#-------------------------------
COMMON_COMP_LIST;
if [ "$COMMON_COMP_LIST" != "" ]
  then
    for COMPTYPCD in `echo $COMMON_COMP_LIST` 
    do
          COMMON_COMP_CASE;
    done	  
  
fi   
#-------------------------------
# End Insertion Common Components
#-------------------------------

#------------------------------------------------------- 
# Start Component/attr/reln/msmt Loop for all the PACs #
#-------------------------------------------------------
if [ "$PAC_LIST" != "" ]
then
  
  for p in `echo $PAC_LIST` 
  do
 
  PAC="$p"

  APPLICATION;

  echo >> "$diag1Output" 

  LEVEL=0
  COUNT2=0
  #DEBUG LEVEL=1
  #---------------------------
  # Start loop for all LEVELs
  #--------------------------

    while [ "$LEVEL" -lt 5 ]
    do	  
      LEVEL=`expr "$LEVEL" + 1` 
    LEVEL_ORIG="$LEVEL"
    
    COMP_LIST;


    if [ "$COMP_LIST" != "" ]
    then	 
    #DEBUG COMP_LIST="GWL_CNTOR_COMP"  
    
  #-------------------------------------------
  # Loop Start for all the LEVEL x components #
  #-------------------------------------------

      for i in `echo "$COMP_LIST" `
      do

          #COMPTYPCD
          COMPTYPCD="$i"
	  RESOURCE;
      echo "     --------------------------------------"  >> "$diag1Output"
      echo "     Comp LEVEL$LEVEL: ..$i.." >> "$diag1Output"
      echo "     --------------------------------------"  >> "$diag1Output"

      # KEYS_BY_LVL
      KEYS_BY_LVL;	

      # KEYS
      ALL_KEYS;
      NUM_ALL_KEYS;

      #COMP_CORR_VAL, COMP_PARENT_CORR_VAL, COMP_GRAND_PARENT_CORR_VAL ....
          COMP_CORR_VAL_CASE;
  
          # COMP_NM
      COMP_NM;
  
          #FROM_TABLE
      LEVEL="$LEVEL_ORIG"
      FROM_TABLE;

          #WHERE_CLAUSE
      WHERE_CLAUSE;

      #GROUPBY
      GROUPBY;
    
      COMP_TEMPLATE_CASE;

      # ATTRIBUTES
      ATTRTYPCD_LIST;
      if [ "$ATTRTYPCD_LIST" != "" ] 
      then  
        NUM_ATTR;
        ALL_ATTR_BY_LVL;
      fi	

      # MEASUREMENTS
      MSMT;

    done	
  fi	

#-- Modified for the COMMON COMPONENTS:J2EE_SERVER, WAS_NODE_AGENT
   
 LEVEL="$LEVEL_ORIG" 
      echo "     --------------------------------------"  >> "$diag1Output"
      echo "     LEVEL=$LEVEL" >> "$diag1Output"
      echo "     --------------------------------------"  >> "$diag1Output"
      
 SUB_COMMON_COMP_LIST;

 #COMPTYPCD
 COMPTYPCD="$i"

  if [ "$SUB_COMMON_COMP_LIST" != "" ]
  then
        NO_HOST_CASE="TRUE"
    for i in `echo "$SUB_COMMON_COMP_LIST" `
      do

        
      echo "     --------------------------------------"  >> "$diag1Output"
      echo "     Comp LEVEL$LEVEL: ..$i.." >> "$diag1Output"
      echo "     --------------------------------------"  >> "$diag1Output"
      
           # KEYS_BY_LVL
           KEYS_BY_LVL;	

           # KEYS
           ALL_KEYS;
           NUM_ALL_KEYS;
           
	   LEVEL=`expr $LEVEL_ORIG + 3`

	 echo "     --------------------------------------"  >> "$diag1Output"
     	 echo "     EQUIVALENT LEVEL=$LEVEL" >> "$diag1Output"
      	 echo "     --------------------------------------"  >> "$diag1Output"
      
           #COMP_CORR_VAL, COMP_PARENT_CORR_VAL, COMP_GRAND_PARENT_CORR_VAL ....
           COMP_CORR_VAL_CASE;
  
           # COMP_NM
           COMP_NM;
  
          #FROM_TABLE
	  
	  LEVEL=`expr $LEVEL_ORIG + 3`

	 echo "     --------------------------------------"  >> "$diag1Output"
     	 echo "     EQUIVALENT LEVEL=$LEVEL" >> "$diag1Output"
      	 echo "     --------------------------------------"  >> "$diag1Output"
   
          FROM_TABLE;
          #WHERE_CLAUSE
          WHERE_CLAUSE;

          #GROUPBY
          GROUPBY;
          COMP_NO_HOST_CASE;


          # ATTRIBUTES
          ATTRTYPCD_LIST;
          if [ "$ATTRTYPCD_LIST" != "" ] 
          then  
            NUM_ATTR;
            ALL_ATTR_BY_LVL;
          fi	

          # MEASUREMENTS
          MSMT;
	  LEVEL="$LEVEL_ORIG"

	 echo "     --------------------------------------"  >> "$diag1Output"
     	 echo "     LEVEL=$LEVEL" >> "$diag1Output"
      	 echo "     --------------------------------------"  >> "$diag1Output"
         
      done	
   fi
   NO_HOST_CASE="FALSE" 
   #-- End Modification for the COMMON COMPONENTS:J2EE_SERVER, WAS_NODE_AGENT

   #-- PROXY
   
  if [ "$LEVEL" = 1 ] 
  then
    COMP_PROXY_LIST;

    if [ "$COMP_PROXY_LIST" != "" ]
    then
      PROXY_SAME="TRUE" 
      for i in `echo "$COMP_PROXY_LIST"`
      do
        #COMPTYPCD
        
        COMPTYPCD="$i"
        RESOURCE;
        FAMILY_COMPTYPCD;

        echo "     --------------------------------------"  >> "$diag1Output"
        echo "     Comp Proxy LEVEL1 $i" >> "$diag1Output"
        echo "     --------------------------------------"  >> "$diag1Output"
          
        # KEYS_BY_LVL	
        KEYS_BY_LVL;

        #KEYS
        ALL_KEYS;
        NUM_ALL_KEYS;

        #COMP_CORR_VAL 
            COMP_CORR_VAL_CASE;
  
            # COMP_NM
        COMP_NM;
  
            #FROM_TABLE
        LEVEL="$LEVEL_ORIG"
        FROM_TABLE;

            #WHERE_CLAUSE
        WHERE_CLAUSE;

        #GROUPBY
        GROUPBY;
        COMP_PROXY_TEMPLATE;

        # ATTRIBUTES
	COMPTYP_CD_SAME;
	COMPTYP_CD="$i"
        i="$COMPTYP_CD_SAME"
        ATTRTYPCD_LIST;
        if [ "$ATTRTYPCD_LIST" != "" ] 
              then  
          NUM_ATTR;
	  i="$COMPTYP_CD"
          ALL_ATTR_BY_LVL;
        fi

        # MEASUREMENTS
        MSMT_PROXY;
      done	
    fi

    PROXY_SAME="FALSE"
      
        
  else
    COMP_REMOTE_LIST;
        
    if [ "$COMP_REMOTE_LIST" != "" ]
    then
      PROXY_SAME="TRUE" 
      for i in `echo "$COMP_REMOTE_LIST"`
      do
        #COMPTYPCD
        
	COMPTYPCD="$i"
        RESOURCE;  
        echo "     --------------------------------------"  >> "$diag1Output"
        echo "     Remote Component LEVEL$LEVEL: ..$i.." >> "$diag1Output"
        echo "     --------------------------------------"  >> "$diag1Output"
          
        # KEYS_BY_LVL	
        KEYS_BY_LVL;

        #KEYS
        ALL_KEYS;
        NUM_ALL_KEYS;

        #COMP_CORR_VAL 
            COMP_CORR_VAL_CASE;
  
            # COMP_NM
        COMP_NM;
  
            #FROM_TABLE
        LEVEL="$LEVEL_ORIG"
        FROM_TABLE;

            #WHERE_CLAUSE
        WHERE_CLAUSE;

        #GROUPBY
        GROUPBY;
        
        COMP_SAME_TEMPLATE;

        # ATTRIBUTES
	COMPTYP_CD_SAME;
	COMPTYP_CD="$i"
        i="$COMPTYP_CD_SAME"
        ATTRTYPCD_LIST;
        if [ "$ATTRTYPCD_LIST" != "" ] 
        then  
          NUM_ATTR;
	  i="$COMPTYP_CD"
          ALL_ATTR_BY_LVL;
        fi

        # MEASUREMENTS
        i="$COMPTYP_CD_SAME"
        MSMT_PROXY;
      done
    fi	
    PROXY_SAME="FALSE"

  fi
  #-----------------------------------------
  # Loop End for all the  LEVEL x component #
  #-----------------------------------------
  done
  #------------------------------
  # Loop End for all the LEVELs 
  #------------------------------
 done
#-------------------------------------------------------
# Add the measurements of all PACs in the TWG.Msnt table
#-------------------------------------------------------

cat >> "$FULLSCRIPT.$DBTYPE" <<!!!
insert into TWG.msmt 
select  
 0 as msmt_id,
 Comp_id,  
 MsmtTyp_Id,  
 TmSum_Cd,  
 Msmt_Strt_Dt,  
 Msmt_Strt_Tm,  
 Msmt_Min_Val,  
 Msmt_Max_Val,  
 Msmt_Avg_Val,  
 Msmt_Tot_Val,  
 Msmt_Smpl_Cnt,
 Msmt_Err_Cnt
from  
 session.temp_msmt  
; 

----------------------------------------------------------
-- Update ETL1_STATUS
------------------------------------------------------------

update TWG.Extract_Control set Extctl_to_Dttm= current timestamp - current timezone  where EXTCTL_TARGET='AMX_STATUS_S040_COMP_MSMT_STEP';

INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'AMX_STATUS_S040_COMP_MSMT_STEP' AND
 EC.EXTCTL_TARGET = 'AMX_STATUS_S040_COMP_MSMT_STEP'
; 


update TWG.Extract_Control set Extctl_to_Dttm= current timestamp - current timezone  where EXTCTL_TARGET='AMX_STATUS_ETL1_PROCESS';

INSERT INTO TWG.EXTRACT_LOG
SELECT
 EC.EXTCTL_SOURCE AS EXTLOG_SOURCE,
 EC.EXTCTL_TARGET AS EXTLOG_TARGET,
 CURRENT TIMESTAMP - CURRENT TIMEZONE AS EXTLOG_DONE_DTTM,
 EC.EXTCTL_FROM_RAWSEQ AS EXTLOG_FROM_RAWSEQ,
 EC.EXTCTL_TO_RAWSEQ AS EXTLOG_TO_RAWSEQ,
 EC.EXTCTL_FROM_INTSEQ AS EXTLOG_FROM_INTSEQ,
 EC.EXTCTL_TO_INTSEQ AS EXTLOG_TO_INTSEQ,
 EC.EXTCTL_FROM_DTTM AS EXTLOG_FROM_DTTM,
 EC.EXTCTL_TO_DTTM AS EXTLOG_TO_DTTM
FROM 
 TWG.EXTRACT_CONTROL EC
WHERE
 EC.EXTCTL_SOURCE = 'AMX_STATUS_ETL1_PROCESS' AND
 EC.EXTCTL_TARGET = 'AMX_STATUS_ETL1_PROCESS'
; 

!!!
fi 
#------------------------------------------------------- 
# End Component/attr/reln/msmt Loop for all the PACs #
#-------------------------------------------------------

# Run execsql via sqlscript.sh 
bash sqlscript.sh $AVACODE $SCRIPTNAME $SRCDB $SRCUSER $SRCPWD $TRGDB $TRGUSER $TRGPWD 

else
  
# Run execsql via sqlscript.sh 
bash sqlscript.sh $AVACODE $SCRIPTNAME $SRCDB $SRCUSER $SRCPWD $TRGDB $TRGUSER $TRGPWD
fi
  
exit $?              
