#!/bin/sh
############################################################################
#
#  Licensed Materials - Property of IBM
#  Product ID = 5724-C04
#
#  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#   File Information: Common/src/tedw_app/amx/fixpack2/misc/amx_deinst_before.sh, tmnt_etl, tmnt_5.1.1_FP06, 512ITMFP01_0616
#   Revision: 1.1.1.2
#   Date: 10/3/03 23:55:47
############################################################################

############################################################################
# Command Line Args:
#   1 = the path and name of the TWH Application config file
#   2 = Application working directory or install base directory
#       $TWH_TOPDIR/apps/ava_code_for_app/vapp_version (look at install tree)
#
# Required Config File:
#       twh_app_install.cfg
#
# Installation Logs (Default names):
#       A log will be generated for this script called amx_after.sh.log
#
# Required Env Vars:
#       None.
#
# Return Codes:
#       0 = Success
#       255 = Failure
#
# Interpreter Required:
#       NT/2000 = BASH
#       Unix    = SH (Bourne Shell)
#
# Message Types:
#       (I) - Informational
#       (W) - Warning
#       (F) - Fatal
#
# Install Steps Required Before this Script Executes:
#        - TWH Core tools and application components must be
#          successfully installed
#
# What is accomplished:
#  * Remove AMX_1_Process_dwc_data.inp and AMX_1_Process_dwc_data.tag
#    because the patch installer may fail to do this on case sensitive
#    environments.
#
# Note - Caution needs to be taken for NT paths that have a space.  This
#        is a limitation that requires double quoting around all
#        variables that contain a path.  Testing should be done to ensure
#        this script runs with a space in any of the paths that are used.
#########################################################################

echo "        ** Before Uninstall Script Log **          "
echo ""
echo "****************************************"
echo "* Application Uninstall Before Script Start point *"
echo "****************************************"
echo ""

# Pulls in the generic shared routines

# Set parms
echo "      Parm 1 = $1"; TWH_CONFIG_FILE="$1"; export TWH_CONFIG_FILE
echo "      Parm 2 = $2"; APP_WORK_DIR="$2"; export APP_WORK_DIR
echo ""

# TWH_TOPDIR needs to always be in the environment
if [ -z "$TWH_TOPDIR" ]; then
  echo "      (F) Could not locate Env var TWH_TOPDIR"
  exit 255
fi

# Read the config file given to us by the app deinstaller.
if [ -z "$TWH_APP_DEINST_CONTEXT" ]; then
  TWH_APP_DEINST_CONTEXT=1; export TWH_APP_DEINST_CONTEXT
fi
gen_path="$TWH_TOPDIR/install/bin"
# pull in the generic routines
. "$gen_path"/twh_gen_routines.sh
gr_set_interp;
gr_read_config_file;
gr_set_program_vars;
gr_extend_path;
gr_check_user;
gr_test_db2exec;
echo "      **  Done Reading the Deinstall Config File"

#####################################################
######## Add application code below here ONLY #######
#####################################################

#
# Define local variables used by the before script
#


set_amx_program_vars()
{
AMX_MISC_DIR="$APP_WORK_DIR/misc"     # path to bash script to be copied
tmp_sql_file="amx_tmp_sql"        # name of the temporary sql file
output_file="amx_tmp_output"

TRUE=1
FALSE=0

return 0;
}

# Check if dependent AMX WEP are installed
list_dependent_wep_installed()
{

  # Test a connection
  echo "      (I) Testing the DB connection"
  err_txt=`$DB2EXEC_LOG connect to "$TWH_CDW_DB" user "$COPT_CDW_DB2USER" using "$COPT_CDW_DB2PASS" 2>&1 `
  if [ $? -ne 0 ]; then
    echo "      (F) Unable to connect to database ($TWH_CDW_DB)."
    echo "          Error is:"
    echo "          $err_txt"
    echo "          Exiting..."
    exit 5
  fi

  echo "==> Check if AMX dependent ITM WEPs are installed in $TWH_CDW_DB"

  cat "$AMX_MISC_DIR/list_dependent_wep_installed.sql" >> "$TMPDIR/$tmp_sql_file".db2
  execsql "$TMPDIR/$tmp_sql_file" "$TMPDIR/$output_file" $TWH_CDW_DB $COPT_CDW_DB2USER $COPT_CDW_DB2PASS 
  WEP_LIST=`cat "$TMPDIR/$output_file" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -d '\12'| tr -s ' ' ' '  `

  
  if [ "$WEP_LIST" != "" ] ; then
	  echo ""
	  echo "      (E) The AMX Warehouse Enablement Package cannot be uninstalled." 
	  echo "          Dependent Warehouse Enablement Packages are still installed."
	  echo "          They will need to be uninstalled before uninstalling the"
	  echo "          AMX Warehouse Enablement Package."
	  echo ""
	  echo "Dependent AMX Warehouse Enablement Package(s): $WEP_LIST"
	  echo "          Exiting..."
	  exit  5
  else
    rm -f "$TMPDIR/$tmp_sql_file".db2
    rm -f "$TMPDIR/$output_file"
    echo "      (I) No AMX dependent ITM WEPs found. Program will continue."
  fi
return 0;
}

############
### Main ###
############


  set_amx_program_vars;
  list_dependent_wep_installed;


echo ""
echo "==> Completed executing application uninstall before script"
exit 0
