#!/bin/sh
############################################################################
#
#  Licensed Materials - Property of IBM
#  Product ID = 5724-C04
#
#  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#   File Information: Common/src/tedw_app/amx/fixpack2/misc/amx_extract.sh, tmnt_etl, tmnt_5.1.1_FP06, 512ITMFP01_0616
#   Revision: 1.10.1.1
#   Date: 12/15/03 17:57:21
############################################################################

# Description:
# wrapper script to create the AMX extract step

# Source data in the RIM database  
# Target data in the CDW database ( AMX.STAGE_xxx tables)

# Inputs:
# 1. AVA, scriptname, dbname, user, pwd of twh_cdw

# Function:
# Create the amx_c05_s010_rim_extract.$DBTYPE script from the metadata
# This script does the following for each warehouse pack
# 1. Extract the application pack RIM data from these tables:
#     - ENDPOINTS 
#     - RESOURCES
#     - INSTANCES
#     - METRICS
#     - METRICSDATA
#     - CATEGORIES
#     - CATEGORIESDATA
# Parameters
AVACODE="$1"
SCRIPTNAME="$2"
SRCDB=$3
SRCUSER=$4
SRCPWD=$5
TRGDB=$6
TRGUSER=$7
TRGPWD=$8


# start debug
#set -x

# Source the twh_run.sh to obtain perl in the path
if [ -f "$TWH_TOPDIR/tools/bin/twh_run.sh" ]; then
. "$TWH_TOPDIR/tools/bin/twh_run.sh"
fi


# setting VWP_LOG allows testing from the command line
# but it must be commented out when running from the DWC
#VWP_LOG="$VWS_LOGGING/vwp_temp"
# end debug

VWS_LOGGING=` echo "$VWS_LOGGING" | sed 's/\\\\/\//g' `

APPDIR=` echo "$TWH_TOPDIR/apps/$AVACODE" | sed 's/\\\\/\//g' `

cmdResult=`ls -1 "$APPDIR" | grep '^v' | wc -l | sed -e 's/ *//g'`

if [ "$cmdResult" != "1" ]; then
   echo "<MSG>AMX8200E Bad directory structure. Only one directory beginning with 'v' should exist in $APPDIR </MSG>" >> "$VWP_LOG"
   echo "<RC>8200</RC>" >> "$VWP_LOG"
   exit 8200
fi

cmdResult=`ls -d "$APPDIR"/v*`
version=`basename "$cmdResult" `

FULLSCRIPT="$APPDIR/$version/etl/sql/$SCRIPTNAME"
TOOLPATH="$APPDIR/$version/misc/tools"
TOOLSCRIPT="AMX_reset_extract_window"
FULLLOG="$VWS_LOGGING/$SCRIPTNAME.log"
FULLDIR="$APPDIR/$version/misc"

# RIM database type
DBTYPE=db2

# Variables used to run sql commands as temporary scripts
diag1Output=""$VWS_LOGGING"/"$SCRIPTNAME"_diag1"
diag2Output=""$VWS_LOGGING"/"$SCRIPTNAME"_diag2"
tempSqlScript=""$VWS_LOGGING"/"$SCRIPTNAME"_sqltemp"
tempSqlScript2=""$VWS_LOGGING"/"$SCRIPTNAME"_sqltemp2"
tempSqlOutput=""$VWS_LOGGING"/"$SCRIPTNAME"_sqltemp1.out"
tempSqlOutput2=""$VWS_LOGGING"/"$SCRIPTNAME"_sqltemp2.out"


echo "-------------------------------------------"  >> "$diag1Output"
echo `date` >> "$diag1Output"
echo "-------------------------------------------"  >> "$diag1Output"
echo "ARGS PASSED: $1, $2, $3, $4, $5 $6 $7 $8" >> "$diag1Output"



#---------------------------------------------------------------------------
# PAC_LIST
#---------------------------------------------------------------------------
PAC_LIST()
{
echo "SQL: 8250"  >> "$diag1Output"
echo "select distinct msrc_cd from AMX.category_transl;"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8250E Select from AMX.category_transl failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8250</RC>" >> "$VWP_LOG"
  exit 8250
fi

PAC_LIST=` cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -d '\12'| tr -s ' ' ' '  `

echo "     PAC_LIST: $PAC_LIST"  >> "$diag1Output"
}

#---------------------------------------------------------------------------
# APPLICATION
#---------------------------------------------------------------------------
APPLICATION()
{
echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8251 PAC: $p"  >> "$diag1Output"
echo "select msrc_nm from twg.msrc where msrc_cd='$p';"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8251E Select from twg.msrc failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8251</RC>" >> "$VWP_LOG"
  exit 8251
fi
APPLICATION=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -s ' ' ' ' `

echo "     Application: $APPLICATION" >> "$diag1Output" 
echo "     Application code: $p" >> "$diag1Output" 
}

#---------------------------------------------------------------------------
EXTRACT_BY_PAC()
{
APPLICATION;

echo "      extract script core" >> "$diag1Output"

if [ -f "$VWS_LOGGING/extract.$DBTYPE" ]
then 
  rm "$VWS_LOGGING/extract.$DBTYPE"
fi

perl "$FULLDIR/extract.pl" "$FULLDIR/rim_extract.$DBTYPE.template" "$VWS_LOGGING/extract.$DBTYPE" "$p"


cat "$VWS_LOGGING/extract.$DBTYPE" >> "$FULLSCRIPT.$DBTYPE"
}	

EXTRACT_START()
{
echo "     Create extract script for this application" >> "$diag1Output"
cat "$FULLDIR/rim_extract_start.$DBTYPE.template" > "$FULLSCRIPT.$DBTYPE"
}

EXTRACT_END()
{
cat "$FULLDIR/rim_extract_end.$DBTYPE.template" >> "$FULLSCRIPT.$DBTYPE"
echo "      extract script end" >> "$diag1Output"
}

COPY_FILES()
{
	cp "$FULLSCRIPT.$DBTYPE"  "$FULLSCRIPT".oracle
	cp "$FULLSCRIPT.$DBTYPE"  "$FULLSCRIPT".informix
	cp "$FULLSCRIPT.$DBTYPE"  "$FULLSCRIPT".mssql
	cp "$FULLSCRIPT.$DBTYPE"  "$FULLSCRIPT".sybase
echo "     all database vendors extract scripts created" >> "$diag1Output"
}

AMX_RESOURCES_EXTRACT_LOG()
{
echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8252 PAC: $p"  >> "$diag1Output"
echo "select count(*) from twg.extract_log where extlog_target='AMX.STAGE1_RESOURCES' and extlog_source='RESOURCES';"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8252E Select from twg.extract_log failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8252</RC>" >> "$VWP_LOG"
  exit 8252
fi
AMX_RESOURCES_EXTRACT_LOG=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `	

echo "     Number of AMX RESOURCES entries in EXTRACT_LOG: $AMX_RESOURCES_EXTRACT_LOG" >> "$diag1Output" 
}

TO_RESOURCES()
{
echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8253 PAC: $p"  >> "$diag1Output"
echo "select e1.extlog_to_intseq from twg.extract_log e1 where e1.extlog_target='AMX.STAGE1_RESOURCES' and e1.extlog_source='RESOURCES' and e1.extlog_done_dttm in (select max(e2.extlog_done_dttm) from twg.extract_log e2 where e2.extlog_target='AMX.STAGE1_RESOURCES' and e2.extlog_source='RESOURCES' group by e2.extlog_target, e2.extlog_source); "  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8253E Select from twg.extract_log failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8253</RC>" >> "$VWP_LOG"
  exit 8253
fi
TO_RESOURCES=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -s ' ' ' ' `	

echo "     Last AMX RESOURCES values in EXTRACT_LOG: $TO_RESOURCES" >> "$diag1Output" 
}

AMX_INSTANCES_EXTRACT_LOG()
{
echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8254 PAC: $p"  >> "$diag1Output"
echo "select count(*) from twg.extract_log where extlog_target='AMX.STAGE1_INSTANCES' and extlog_source='INSTANCES';"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8254E Select from twg.extract_log failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8254</RC>" >> "$VWP_LOG"
  exit 8254
fi
AMX_INSTANCES_EXTRACT_LOG=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `	

echo "     Number of AMX INSTANCES entries in EXTRACT_LOG: $AMX_INSTANCES_EXTRACT_LOG" >> "$diag1Output" 
}

TO_INSTANCES()
{
echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8255 PAC: $p"  >> "$diag1Output"
echo "select e1.extlog_to_intseq from twg.extract_log e1 where e1.extlog_target='AMX.STAGE1_INSTANCES' and e1.extlog_source='INSTANCES' and e1.extlog_done_dttm in (select max(e2.extlog_done_dttm) from twg.extract_log e2 where e2.extlog_target='AMX.STAGE1_INSTANCES' and e2.extlog_source='INSTANCES' group by e2.extlog_target, e2.extlog_source);"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8255E Select from twg.extract_log failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8255</RC>" >> "$VWP_LOG"
  exit 8255
fi
TO_INSTANCES=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -s ' ' ' ' `	

echo "     Last AMX INSTANCES values in EXTRACT_LOG: $TO_INSTANCES" >> "$diag1Output" 
}

AMX_METRICS_EXTRACT_LOG()
{
echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8256 PAC: $p"  >> "$diag1Output"
echo "select count(*) from twg.extract_log where extlog_target='AMX.STAGE1_METRICS' and extlog_source='METRICS';"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8256E Select from twg.extract_log failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8256</RC>" >> "$VWP_LOG"
  exit 8256
fi
AMX_METRICS_EXTRACT_LOG=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `	

echo "     Number of AMX METRICS entries in EXTRACT_LOG: $AMX_METRICS_EXTRACT_LOG" >> "$diag1Output" 
}

TO_METRICS()
{
echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8257 PAC: $p"  >> "$diag1Output"
echo "select e1.extlog_to_intseq from twg.extract_log e1 where e1.extlog_target='AMX.STAGE1_METRICS' and e1.extlog_source='METRICS' and e1.extlog_done_dttm in (select max(e2.extlog_done_dttm) from twg.extract_log e2 where e2.extlog_target='AMX.STAGE1_METRICS' and e2.extlog_source='METRICS' group by e2.extlog_target, e2.extlog_source);"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8257E Select from twg.extract_log failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8257</RC>" >> "$VWP_LOG"
  exit 8257
fi
TO_METRICS=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -s ' ' ' ' `	

echo "     Last AMX METRICS values in EXTRACT_LOG: $TO_METRICS" >> "$diag1Output" 
}

AMX_METRICSDATA_EXTRACT_LOG()
{
echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8258 PAC: $p"  >> "$diag1Output"
echo "select count(*) from twg.extract_log where extlog_target='AMX.STAGE_METRICSDATA' and extlog_source='METRICSDATA';"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8258E Select from twg.extract_log failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8258</RC>" >> "$VWP_LOG"
  exit 8258
fi
AMX_METRICSDATA_EXTRACT_LOG=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `	

echo "     Number of AMX METRICSDATA entries in EXTRACT_LOG: $AMX_METRICSDATA_EXTRACT_LOG" >> "$diag1Output" 
}

TO_METRICSDATA()
{
echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8259 PAC: $p"  >> "$diag1Output"
echo "select e1.extlog_to_intseq from twg.extract_log e1 where e1.extlog_target='AMX.STAGE_METRICSDATA' and e1.extlog_source='METRICSDATA' and e1.extlog_done_dttm in (select max(e2.extlog_done_dttm) from twg.extract_log e2 where e2.extlog_target='AMX.STAGE_METRICSDATA' and e2.extlog_source='METRICSDATA' group by e2.extlog_target, e2.extlog_source);"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8259E Select from twg.extract_log failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8259</RC>" >> "$VWP_LOG"
  exit 8259
fi
TO_METRICSDATA=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -s ' ' ' ' `	

echo "     Last AMX METRICSDATA values in EXTRACT_LOG: $TO_METRICSDATA" >> "$diag1Output" 
}

AMX_CATEGORIES_EXTRACT_LOG()
{
echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8260 PAC: $p"  >> "$diag1Output"
echo "select count(*) from twg.extract_log where extlog_target='AMX.STAGE1_CATEGORIES' and extlog_source='CATEGORIES';"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8260E Select from twg.extract_log failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8260</RC>" >> "$VWP_LOG"
  exit 8260
fi
AMX_CATEGORIES_EXTRACT_LOG=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `	

echo "     Number of AMX CATEGORIES entries in EXTRACT_LOG: $AMX_CATEGORIES_EXTRACT_LOG" >> "$diag1Output" 
}


TO_CATEGORIES()
{
echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8261 PAC: $p"  >> "$diag1Output"
echo "select e1.extlog_to_intseq from twg.extract_log e1 where e1.extlog_target='AMX.STAGE1_CATEGORIES' and e1.extlog_source='CATEGORIES' and e1.extlog_done_dttm in (select max(e2.extlog_done_dttm) from twg.extract_log e2 where e2.extlog_target='AMX.STAGE1_CATEGORIES' and e2.extlog_source='CATEGORIES' group by e2.extlog_target, e2.extlog_source);"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8261E Select from twg.extract_log failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8261</RC>" >> "$VWP_LOG"
  exit 8261
fi
TO_CATEGORIES=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -s ' ' ' ' `	

echo "     Last AMX CATEGORIES values in EXTRACT_LOG: $TO_CATEGORIES" >> "$diag1Output" 
}

AMX_CATEGORIESDATA_EXTRACT_LOG()
{
echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8262 PAC: $p"  >> "$diag1Output"
echo "select count(*) from twg.extract_log where extlog_target='AMX.STAGE_CATEGORIESDATA' and extlog_source='CATEGORIESDATA';"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8262E Select from twg.extract_log failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8262</RC>" >> "$VWP_LOG"
  exit 8262
fi
AMX_CATEGORIESDATA_EXTRACT_LOG=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `	

echo "     Number of AMX CATEGORIESDATA entries in EXTRACT_LOG: $AMX_CATEGORIESDATA_EXTRACT_LOG" >> "$diag1Output" 
}


TO_CATEGORIESDATA()
{
echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8263 PAC: $p"  >> "$diag1Output"
echo "select e1.extlog_to_intseq from twg.extract_log e1 where e1.extlog_target='AMX.STAGE_CATEGORIESDATA' and e1.extlog_source='CATEGORIESDATA' and e1.extlog_done_dttm in (select max(e2.extlog_done_dttm) from twg.extract_log e2 where e2.extlog_target='AMX.STAGE_CATEGORIESDATA' and e2.extlog_source='CATEGORIESDATA' group by e2.extlog_target, e2.extlog_source); "  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8263E Select from twg.extract_log failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8263</RC>" >> "$VWP_LOG"
  exit 8263
fi
TO_CATEGORIESDATA=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -s ' ' ' ' `	

echo "     Last AMX CATEGORIESDATA values in EXTRACT_LOG: $TO_CATEGORIESDATA" >> "$diag1Output" 
}

ADD_EXTRACT_WINDOW()
{

echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8264 "  >> "$diag1Output"


echo "
declare global temporary table Extract_Control ( ExtCtl_Source         varchar(120) not null, ExtCtl_Target         varchar(120) not null, ExtCtl_From_RawSeq    char(10) for bit data, ExtCtl_To_RawSeq      char(10) for bit data, ExtCtl_From_IntSeq    bigint, ExtCtl_To_IntSeq      bigint, ExtCtl_From_DtTm     	timestamp not null, ExtCtl_To_DtTm       	timestamp not null) with replace on commit preserve rows not logged ;
insert into session.extract_control values ( '"$p"_ENDPOINTS' , 'AMX.STAGE1_ENDPOINTS' , x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'); 
insert into session.extract_control values ( '"$p"_RMPROFILES' , 'AMX.STAGE2_RMPROFILES' , x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'); " > "$tempSqlScript2.$DBTYPE"

AMX_RESOURCES_EXTRACT_LOG;

case $AMX_RESOURCES_EXTRACT_LOG in
     0)

	echo "
	insert into session.extract_control values ( '"$p"_RESOURCES' , 'AMX.STAGE1_RESOURCES' , x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'); " >> "$tempSqlScript2.$DBTYPE"
     
      ;;
      *)
      TO_RESOURCES;

	echo "
	insert into session.extract_control values ( '"$p"_RESOURCES' , 'AMX.STAGE1_RESOURCES' , x'', x'', "$TO_RESOURCES", "$TO_RESOURCES", '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'); " >> "$tempSqlScript2.$DBTYPE"
	;;
esac	

AMX_INSTANCES_EXTRACT_LOG;
case $AMX_INSTANCES_EXTRACT_LOG in
   0)

	echo "
	insert into session.extract_control values ( '"$p"_INSTANCES' , 'AMX.STAGE1_INSTANCES' , x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000');" >> "$tempSqlScript2.$DBTYPE"
     
      ;;
      *)
      TO_INSTANCES;

	echo "
	insert into session.extract_control values ( '"$p"_INSTANCES' , 'AMX.STAGE1_INSTANCES' , x'', x'', "$TO_INSTANCES", "$TO_INSTANCES", '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'); " >> "$tempSqlScript2.$DBTYPE"
	;;
esac	

AMX_METRICS_EXTRACT_LOG;
case $AMX_METRICS_EXTRACT_LOG in
   0)

	echo "
	insert into session.extract_control values ( '"$p"_METRICS' , 'AMX.STAGE1_METRICS' , x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'); " >> "$tempSqlScript2.$DBTYPE"
     
      ;;
      *)
      TO_METRICS;

	echo "
	insert into session.extract_control values ( '"$p"_METRICS' , 'AMX.STAGE1_METRICS' , x'', x'', "$TO_METRICS", "$TO_METRICS", '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'); " >> "$tempSqlScript2.$DBTYPE"
	;;
esac

AMX_METRICSDATA_EXTRACT_LOG;
case $AMX_METRICSDATA_EXTRACT_LOG in
   0)

	echo "
	insert into session.extract_control values ( '"$p"_METRICSDATA' , 'AMX.STAGE_METRICSDATA' , x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'); " >> "$tempSqlScript2.$DBTYPE"
     
      ;;
      *)
      TO_METRICSDATA;

	echo "
	insert into session.extract_control values ( '"$p"_METRICSDATA' , 'AMX.STAGE_METRICSDATA' , x'', x'', "$TO_METRICSDATA", "$TO_METRICSDATA", '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'); " >> "$tempSqlScript2.$DBTYPE"
	;;
esac	

AMX_CATEGORIES_EXTRACT_LOG;
case $AMX_CATEGORIES_EXTRACT_LOG in
   0)

	echo "
	insert into session.extract_control values ( '"$p"_CATEGORIES' , 'AMX.STAGE1_CATEGORIES' , x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'); " >> "$tempSqlScript2.$DBTYPE"
     
      ;;
      *)
      TO_CATEGORIES;

	echo "
	insert into session.extract_control values ( '"$p"_CATEGORIES' , 'AMX.STAGE1_CATEGORIES' , x'', x'', "$TO_CATEGORIES", "$TO_CATEGORIES", '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'); " >> "$tempSqlScript2.$DBTYPE"
	;;
esac

AMX_CATEGORIESDATA_EXTRACT_LOG;
case $AMX_CATEGORIESDATA_EXTRACT_LOG in
   0)

	echo "
	insert into session.extract_control values ( '"$p"_CATEGORIESDATA' , 'AMX.STAGE_CATEGORIESDATA' , x'', x'', -1, -1, '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'); " >> "$tempSqlScript2.$DBTYPE"
     
      ;;
      *)
      TO_CATEGORIESDATA;

	echo "
	insert into session.extract_control values ( '"$p"_CATEGORIESDATA' , 'AMX.STAGE_CATEGORIESDATA' , x'', x'', "$TO_CATEGORIESDATA", "$TO_CATEGORIESDATA", '1970-01-01-00.00.00.000000', '9999-01-01-00.00.00.000000'); " >> "$tempSqlScript2.$DBTYPE"
	;;
esac	

echo "insert into TWG.Extract_control select m.ExtCtl_Source as ExtCtl_Source, m.ExtCtl_Target as ExtCtl_Target, m.ExtCtl_From_RawSeq as ExtCtl_From_RawSeq, m.ExtCtl_To_RawSeq as ExtCtl_To_RawSeq, m.ExtCtl_From_IntSeq as ExtCtl_From_IntSeq, m.ExtCtl_To_IntSeq as ExtCtl_To_IntSeq, m.ExtCtl_From_DtTm as ExtCtl_From_DtTm, m.ExtCtl_To_DtTm as ExtCtl_To_DtTm  from session.Extract_Control m where not exists ( select 1 from TWG.Extract_Control t where t.ExtCtl_Source=m.ExtCtl_Source  and t.ExtCtl_Target=m.ExtCtl_Target) ; "  >> "$tempSqlScript2.$DBTYPE"

execsql "$tempSqlScript2" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8264E Insert extract entries failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8264</RC>" >> "$VWP_LOG"
  exit 8264
fi

echo "      Extract window entries for $p created" >> "$diag1Output"
}

NEW_WEP_LIST()
{
echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8265 PAC: $p"  >> "$diag1Output"
echo "select msrc_cd from amx.category_transl where msrc_cd not in (select msrc_cd from amx.stage_wep_installed_old) ;"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8265E Select from amx.category_transl failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8265</RC>" >> "$VWP_LOG"
  exit 8265
fi
NEW_WEP_LIST=` cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -d '\12'| tr -s ' ' ' '  `

echo "     New Wep installed: $NEW_WEP_LIST" >> "$diag1Output" 
}

NUM_WEP()
{
echo "-------------------------------------------"  >> "$diag1Output"
echo "SQL: 8266 PAC: $p"  >> "$diag1Output"
echo "select count(*) from amx.category_transl ;"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8266E Select from amx.category_transl failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8266</RC>" >> "$VWP_LOG"
  exit 8266
fi
NUM_WEP=` cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `	

echo "     Number of ITM Application WEP installed: $NUM_WEP" >> "$diag1Output" 
echo "     Remark: Zero Application WEP makes the AMX ETL1 Process to fail" >> "$diag1Output"
}

CREATE_EXTRACT_RESET_TOOL()
{
echo "     Create extract reset tool script for this application" >> "$diag1Output"

if [ -f "$VWS_LOGGING/extract_tool.$DBTYPE" ]
then 
  rm "$VWS_LOGGING/extract_tool.$DBTYPE"
fi

perl "$FULLDIR/extract.pl" "$FULLDIR/amx_reset_extract_window.$DBTYPE.template" "$VWS_LOGGING/extract_tool.$DBTYPE" "$p"

cat "$VWS_LOGGING/extract_tool.$DBTYPE" > "$TOOLPATH"/"$p"_"$TOOLSCRIPT"."$DBTYPE"

echo "      create reset extract window tool for $p" >> "$diag1Output"
}

##############################################
##    MAIN
#############################################

NUM_WEP;
if [ "$NUM_WEP" = "0" ]; then
   echo "<MSG>AMX8267E The AMX_c05_ETL1_Process cannot be run. At least one Warehouse Enablement Package that requires IBM Tivoli Monitoring must be installed before running the AMX_c05_ETL1_Process.</MSG>" >> "$VWP_LOG"
   echo "<RC>8267</RC>" >> "$VWP_LOG"
   exit 8267
fi

NEW_WEP_LIST;


# We will create a new extract script only if we have installed a new wep: 
# if the new wep list is not empty 
# or if the extract script does not exist
if [ "$NEW_WEP_LIST" != ""  ] || [ ! -a  "$FULLSCRIPT.$DBTYPE" ]
then	

#----------------------------------
# Find the new PACs to create the 
# extract window only for these new 
# PACs
#----------------------------------


#----------------------------------------------
#  Start loop to recreate the extract step for all the PACs
#----------------------------------------------
 if [ "$NEW_WEP_LIST" != "" ]
  then

    for p in `echo "$NEW_WEP_LIST"` 
    do
      ADD_EXTRACT_WINDOW;
      CREATE_EXTRACT_RESET_TOOL;
    done

  fi

#----------------------------------
# Find the list of ITM applications
#----------------------------------

PAC_LIST;

# DEBUG PAC_LIST=GWL

 EXTRACT_START;
#----------------------------------------------
#  Start loop to recreate the extract step for all the PACs
#----------------------------------------------
if [ "$PAC_LIST" != "" ]
then

 for p in `echo $PAC_LIST` 
 do
  EXTRACT_BY_PAC;
 done

fi

 EXTRACT_END;
 COPY_FILES;

# Run execsql via sqlscript.sh 
bash sqlscript.sh $AVACODE $SCRIPTNAME $SRCDB $SRCUSER $SRCPWD $TRGDB $TRGUSER $TRGPWD 

else
  
# Run execsql via sqlscript.sh 
bash sqlscript.sh $AVACODE $SCRIPTNAME $SRCDB $SRCUSER $SRCPWD $TRGDB $TRGUSER $TRGPWD
fi
  
exit $?              
