#!/bin/sh
############################################################################
#
#  Licensed Materials - Property of IBM
#  Product ID = 5724-C04
#
#  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#   File Information: Common/src/tedw_app/amx/fixpack2/misc/amx_pre_extract.sh, tmnt_etl, tmnt_5.1.1_FP06, 512ITMFP01_0616
#   Revision: 1.1
#   Date: 12/2/03 22:04:35
############################################################################

# Description:
# wrapper script to create the AMX extract step

# Source data in the RIM database  
# Target data in the CDW database ( AMX.STAGE_xxx tables)

# Inputs:
# 1. AVA, scriptname, dbname, user, pwd of twh_cdw

# Function:
# Create the AMX_c05_s010_rim_extract.$DBTYPE script from the metadata
# This script does the following for each warehouse pack
# 1. Extract the application pack RIM data from these tables:
#     - ENDPOINTS 
#     - RESOURCES
#     - INSTANCES
#     - METRICS
#     - METRICSDATA
#     - CATEGORIES
#     - CATEGORIESDATA
# Parameters
AVACODE="$1"
SCRIPTNAME="$2"
SRCDB=$3
SRCUSER=$4
SRCPWD=$5
TRGDB=$6
TRGUSER=$7
TRGPWD=$8

# start debug
#set -x

# Source the twh_run.sh to obtain perl in the path

if [ -f "$TWH_TOPDIR/tools/bin/twh_run.sh" ]; then
. "$TWH_TOPDIR/tools/bin/twh_run.sh"
fi


# setting VWP_LOG allows testing from the command line
# but it must be commented out when running from the DWC
#VWP_LOG="$VWS_LOGGING/vwp_temp"
# end debug

VWS_LOGGING=` echo "$VWS_LOGGING" | sed 's/\\\\/\//g' `

APPDIR=` echo "$TWH_TOPDIR/apps/$AVACODE" | sed 's/\\\\/\//g' `

cmdResult=`ls -1 "$APPDIR" | grep '^v' | wc -l | sed -e 's/ *//g'`

if [ "$cmdResult" != "1" ]; then
   echo "<MSG>AMX8200E Bad directory structure. Only one directory beginning with 'v' should exist in $APPDIR </MSG>" >> "$VWP_LOG"
   echo "<RC>8200</RC>" >> "$VWP_LOG"
   exit 8200
fi

cmdResult=`ls -d "$APPDIR"/v*`
version=`basename "$cmdResult" `

# RIM database type
DBTYPE=db2

# Variables used to run sql commands as temporary scripts
diag1Output=""$VWS_LOGGING"/"$SCRIPTNAME"_diag1"
tempSqlScript=""$VWS_LOGGING"/"$SCRIPTNAME"_sqltemp"
tempSqlOutput=""$VWS_LOGGING"/"$SCRIPTNAME"_sqltemp1.out"


echo "-------------------------------------------"  >> "$diag1Output"
echo `date` >> "$diag1Output"
echo "-------------------------------------------"  >> "$diag1Output"
echo "ARGS PASSED: $1, $2, $3, $4, $6 $7 " >> "$diag1Output"


#---------------------------------------------------------------------------
# ETL1_END_DTTM
#---------------------------------------------------------------------------
ETL1_END_DTTM()
{
echo "SQL: 8280"  >> "$diag1Output"
 echo "SELECT EXTCTL_TO_DTTM FROM TWG.EXTRACT_CONTROL WHERE EXTCTL_SOURCE='AMX_STATUS_ETL1_PROCESS';"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8280E Select from TWG.EXTRACT_CONTROL failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8280</RC>" >> "$VWP_LOG"
  exit 8280
fi

ETL1_END_DTTM=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' `

echo "     ETL1_END_DTTM: ..$ETL1_END_DTTM.."  >> "$diag1Output"
}

#---------------------------------------------------------------------------
# ETL1_STRT_DTTM
#---------------------------------------------------------------------------
ETL1_STRT_DTTM()
{
echo "SQL: 8281"  >> "$diag1Output"
echo "SELECT EXTCTL_FROM_DTTM FROM TWG.EXTRACT_CONTROL WHERE EXTCTL_SOURCE='AMX_STATUS_ETL1_PROCESS';"  > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput" $TRGDB $TRGUSER $TRGPWD  
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8281E Select from AMX.ETL1_RUN failed with the following message: $errOut </MSG>" >> "$VWP_LOG"
  echo "<RC>8281</RC>" >> "$VWP_LOG"
  exit 8281
fi

ETL1_STRT_DTTM=`cat "$tempSqlOutput" | sed -e '1,/^  --/d' -e '/^  --/,$d' -e 's/ //g' ` 

echo "     ETL1_STRT_DTTM: ..$ETL1_STRT_DTTM.."  >> "$diag1Output"
}

##############################################
##    MAIN
#############################################

ETL1_STRT_DTTM;
ETL1_END_DTTM;
if [ "$ETL1_STRT_DTTM" != "1970-01-01-00.00.00.000000" ] && [ "$ETL1_END_DTTM" != "$ETL1_STRT_DTTM" ]
then	   
   	echo "<MSG>AMX8267E The AMX_c05_ETL1_Pre_Extract Step cannot be executed. All the steps of the AMX_c05_ETL1_Process must have been executed successfully before running the pre_extract step.</MSG>" >> "$VWP_LOG"
   	echo "<RC>8267</RC>" >> "$VWP_LOG"
   	exit 8267
else
# Run execsql via sqlscript.sh 
bash sqlscript.sh $AVACODE $SCRIPTNAME $SRCDB $SRCUSER $SRCPWD $TRGDB $TRGUSER $TRGPWD
fi
