#!/bin/sh
############################################################################
#
#  Licensed Materials - Property of IBM
#  Product ID = 5724-C04
#
#  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#   File Information: Common/src/tedw_app/amx/fixpack2/misc/amx_rim_extract.sh, tmnt_etl, tmnt_5.1.1_FP06, 512ITMFP01_0616
#   Revision: 1.6
#   Date: 4/22/04 19:27:52
############################################################################
#
# Wrapper script to launch the amx_rim_extract.pl perl script.
# 
# Parameters:
#   AVACODE    - the AVA_CODE of the caller application
#   SCRIPTNAME - the name of the script to be executed by the execsql engine
#   SRCDB      - source database ODBC alias
#   SRCUSER    - source database user
#   SRCPWD     - source database password
#   TRGDB      - target database ODBC alias
#   TRGUSER    - target database user
#   TRGPWD     - target database password
#
# Returns:
#   -
############################################################################

AVACODE="$1"
SCRIPTNAME="$2"
SRCDB=$3
SRCUSER=$4
SRCPWD=$5
TRGDB=$6
TRGUSER=$7
TRGPWD=$8

########################################################################################
################ CONFIGURABLE PARAMETER FOR ENVIRONMENTAL TUNInG #######################
########################################################################################
# The default commit period is 10000; each extraction slice will move a maximum of
# 10000 records towards the AMX.STAGE_METRICSDATA and AMX.STAGE_CATEGORIESDATA
# tables before a commit occurs. If you want to further limit the growth of the 
# transaction log or you are concerned about the concurrency impact that a long 
# transaction may have, you can reduce the commit rate, i.e. increase the commit period,
# according to your specific needs. You can also increase the commit rate, i.e reduce 
# the commit period, if you can accept a larger transaction log or you don't have much
# concurrency issues, for innstance because the ETL1 runs in a disjoined time interval 
# from the RIM handler activity period.
# NOTE: don't use spaces between the variable and its value!
COMMITPERIOD=10000  # default is 10000 
########################################################################################

# start debug
#set -x

# Source the twh_run.sh to obtain perl in the path
if [ -f "$TWH_TOPDIR/tools/bin/twh_run.sh" ]; then
. "$TWH_TOPDIR/tools/bin/twh_run.sh"
fi

# retrieve the path to the logging directory registered for TEDW
VWS_LOGGING=` echo "$VWS_LOGGING" | sed 's/\\\\/\//g' `

APPDIR=` echo "$TWH_TOPDIR/apps/$AVACODE" | sed 's/\\\\/\//g' `

# validate the application directory structure
cmdResult=`ls -1 "$APPDIR" | grep '^v' | wc -l | sed -e 's/ *//g'`
if [ "$cmdResult" != "1" ]; then
   echo "AMX8200E Bad directory structure. Only one directory beginning with 'v' should exist in $APPDIR"
   exit 8200
fi

# determine the application version
cmdResult=`ls -d "$APPDIR"/v*`
VERSION=`basename "$cmdResult" `

MISCPATH="$APPDIR/$VERSION/misc"

# invoke the perl interpreter to execute the script that generates the extract statements
os=`uname`;
if [ "$os" != "Windows_NT" ]; then
	PERL="perl"
else
	PERL="perl5"
fi

if [ -d "$TWH_TOPDIR/tools/lib/perl5" ]; then
	OPTIONS="-I$TWH_TOPDIR/tools/lib/perl5"
fi

$PERL $OPTIONS "$MISCPATH/amx_rim_extract.pl" "$AVACODE" "$SCRIPTNAME" "$SRCDB" "$SRCUSER" "$SRCPWD" "$TRGDB" "$TRGUSER" "$TRGPWD" "$COMMITPERIOD" "$APPDIR" "$VERSION" "$VWS_LOGGING"