#!/bin/sh
############################################################################
#
#  Licensed Materials - Property of IBM
#  Product ID = 5724-C04
#
#  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#   File Information: Common/src/tedw_app/amx/fixpack2/misc/amx_rollup.sh, tmnt_etl, tmnt_5.1.1_FP06, 512ITMFP01_0616
#   Revision: 1.1.1.1
#   Date: 12/15/03 17:59:10
############################################################################

# Description:
# wrapper script to call AMX create comp msmt step

# Source data in the CDW database ( AMX.Stage_xxx tables)
# Target data in the CDW database ( TWG.xxx tables)

# Inputs:
# 1. AVA, scriptname, dbname, user, pwd of twh_cdw

# Function:
# Create the amx_c05_s040_comp_msmt.$DBTYPE script from the metadata
# This script does the following for each warehouse pack
# 1. Insert the following (local or remote) components in TWG.COMP:
#     - component level1 : host is the parent
#     - component level2 : host is the grand parent
#     - component level3 : host is the great grand parent
#     - component level4 : host is the great great grand parent
#     - component level5 : host is the great great great grand parent
# 2. Insert the Parent-Child relations for each component in TWG.COMPRELN 
# 3. Insert the attributes for each component in TWG.COMPATTR
# 4. Insert the measurements for each component in TWG.MSMT

#set -x

# Parameters
AVACODE="$1"
SCRIPTNAME="$2"
SRCDB=$3
SRCUSER=$4
SRCPWD=$5
TRGDB=$6
TRGUSER=$7
TRGPWD=$8

# start debug
#set -x
# ava code is passed lower case from the DWC but the value stored in the table AMX.Rollup_tables
# is upper case
AVACODE=` echo "$AVACODE" | tr '[a-z]' '[A-Z]' `

# setting VWP_LOG allows testing from the command line
# but it must be commented out when running from the DWC
#VWP_LOG="$VWS_LOGGING/vwp_temp"
# end debug

VWS_LOGGING=` echo "$VWS_LOGGING" | sed 's/\\\\/\//g' `

# CDW database type
DBTYPE=db2

# Variables used to run sql commands as temporary scripts
diag1Output=""$VWS_LOGGING"/"$SCRIPTNAME"_diag1"
tempSqlScript=""$VWS_LOGGING"/"$SCRIPTNAME"_sqltemp"
tempSqlOutput1=""$VWS_LOGGING"/"$SCRIPTNAME"_sqltemp1.out"
tempSqlOutput2=""$VWS_LOGGING"/"$SCRIPTNAME"_sqltemp2.out"


echo "-------------------------------------------"  >> "$diag1Output"
echo `date` >> "$diag1Output"
echo "-------------------------------------------"  >> "$diag1Output"
echo "ARGS PASSED: $1, $2, $3, $4, $5" >> "$diag1Output"

echo "amx_rollup.sh started at `date`" >> "$diag1Output"

if [ -f "$SCRIPTNAME.$DBTYPE" ]
then
  rm "$SCRIPTNAME.$DBTYPE"
fi

echo "SQL: 8301"  >> "$diag1Output"
echo "select Hourly_Fact_Table, Stage_Fact_table from AMX.Rollup_tables where msrc_cd='$AVACODE' order by Stage_Fact_table ;" > "$tempSqlScript.$DBTYPE"
execsql "$tempSqlScript" "$tempSqlOutput1" $SRCDB $SRCUSER $SRCPWD 
if [ $? -ne 0 ]
then
  errOut=` cat "$tempSqlOutput" | grep CDW `
  echo "<MSG>AMX8301E Select from AMX.Rollup_tables failed with the following message: $errOut </MSG>" >> "$VWP_LOG" 
  echo "<RC>8301</RC>" >> "$VWP_LOG"
  exit 8301
fi
cat "$tempSqlOutput1" | sed -e '1,/^  --/d' -e '/^  --/,$d' | tr -s ' ' ' '  > "$tempSqlOutput2"
cat "$tempSqlOutput2" | while read LINE; do
    FTAB="`echo $LINE | cut -d' ' -f1`"
    STAB="`echo $LINE | cut -d' ' -f2`"
bash rollup.sh $AVACODE $FTAB $STAB $SRCDB $SRCUSER $SRCPWD $TRGDB $TRGUSER $TRGPWD "$FTAB"_"$SCRIPTNAME" 
if [ "$?" -ne "0" ] ; then
 exit
fi
done

echo "amx_rollup.sh ended at `date`" >> "$diag1Output"

