-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: Common/src/tedw_app/amx/fixpack2/misc/insert_comp_level3_was_node_agent.db2, tmnt_etl, tmnt_5.1.1_FP06, 512ITMFP01_0616
-- #   Revision: 1.6
-- #   Date: 4/8/04 11:03:10
-- ############################################################################

------------------
-- WAS_NODE_AGENT
------------------
-- Find all the rcid,eid, iid that have a WAS_NODE_AGENT for parent
DECLARE GLOBAL TEMPORARY TABLE inst_was_node_agent(
  iid INTEGER,
  eid INTEGER,
  rcid INTEGER
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;

insert into session.inst_was_node_agent select distinct iid, eid, rcid from amx.stage_instkey_no_ex where itm_key in ( select itm_key_property from amx.comptyp_transl where COMPTYP_CD='WAS_NODE_AGENT' );

-- create a table with different WAS_NODE_AGENT 
-- a WAS_NODE_AGENT is unique by its agent name , node name, cell name, and MANUFACTURER  can only be IBM
-- it should not be possible to have 2 WAS_NODE_AGENT with the same agent name, node name, cell name on 2 different endpoints 

--#IGNORE_ERROR
DROP TABLE AMX.stage1_was_node_agent;

CREATE TABLE AMX.stage1_was_node_agent(
  was_node_agent VARCHAR(120) not null,
  j2ee_node   VARCHAR(100) not null,
  j2ee_node_os VARCHAR(254),
  j2ee_cell   VARCHAR(100) not null,
  host_nm	VARCHAR(254),
  was_node_agent_type CHAR(3),
  was_node_agent_vers VARCHAR(254),
  iid INTEGER not null,
  rcid INTEGER not null,
  eid INTEGER not null,
primary key(was_node_agent,j2ee_node,j2ee_cell,iid,rcid,eid)
)
;

-- A WAS_NODE_AGENT is a common component that can have been created 
-- by another application 


-- agent + node + cell (IBM/Websphere 5.x or more)
insert into AMX.stage1_was_node_agent (was_node_agent, j2ee_node, j2ee_node_os, j2ee_cell, host_nm, was_node_agent_type, was_node_agent_vers,iid,rcid,eid)
select
a1.key_val as j2ee_was_node_agent,
e1.key_val as j2ee_node,
'UNKNOWN' as j2ee_node_os,
d1.key_val as j2ee_cell,
case 
when
e.host_nm != ''
then
e.host_nm
else
e.ip_addr
end as host_nm, 
'IBM' as was_node_agent_type ,
'UNKNOWN' as was_node_agent_vers,
a1.iid as iid,
a1.rcid as rcid,
a1.eid as eid
from
  amx.stage_key_parsed a1,
  amx.stage_key_parsed d1,
  amx.stage_key_parsed e1,
  session.inst_was_node_agent a2,
  amx.comptyp_transl a3,
  amx.comptyp_transl a5,
  amx.comptyp_transl a6,
  amx.stage_ep_no_ex e
where
  a1.iid=a2.iid and a1.rcid=a2.rcid and a1.eid=a2.eid and
  a1.iid=d1.iid and a1.rcid=d1.rcid and a1.eid=d1.eid and
  a1.iid=e1.iid and a1.rcid=e1.rcid and a1.eid=e1.eid and
  a3.comptyp_cd='WAS_NODE_AGENT' and
  a3.msrc_cd=a5.msrc_cd and
  a6.msrc_cd=a5.msrc_cd and
  a3.ITM_Key_Property=a1.key_typ and
  a5.comptyp_cd='J2EE_CELL' and
  a5.ITM_Key_Property=d1.key_typ  and
  a6.comptyp_cd='J2EE_NODE' and 
  a6.ITM_Key_Property=e1.key_typ and 
  e.eid=a1.eid and
  not exists ( select 1 from amx.stage1_was_node_agent z
  where z.was_node_agent=a1.key_val  and
        z.j2ee_node=d1.key_val  and
	z.j2ee_cell=e1.key_val  and
	z.was_node_agent_type='IBM'
	) 
group by
a1.key_val, d1.key_val, e1.key_val, e.host_nm, e.ip_addr,
a1.rcid,a1.iid,a1.eid
;

--OS_NAME
DECLARE GLOBAL TEMPORARY TABLE attr_was_node_agent_os(
  attr_val      varchar(254),
  iid           bigint not null,
  rcid          bigint not null,
  eid           integer not null
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;

insert into session.attr_was_node_agent_os (attr_val, iid, rcid,eid)
select distinct s1.attr_Val, s1.iid,  s1.rcid, s1.eid from amx.stage_attr_no_ex s1, session.inst_was_node_agent a1 where a1.iid=s1.iid and a1.rcid=s1.rcid and a1.eid=s1.eid and s1.attrtyp_cd='OS_NAME'  ;

update amx.stage1_was_node_agent s1 set s1.j2ee_node_os= (
select 
a1.attr_val 
from 
 session.attr_was_node_agent_os a1
where
a1.iid=s1.iid and a1.rcid=s1.rcid and a1.eid=s1.eid 
)
where exists ( select 1 from session.attr_was_node_agent_os a1 where a1.iid=s1.iid and a1.rcid=s1.rcid and a1.eid=s1.eid )
;

--VERSION
DECLARE GLOBAL TEMPORARY TABLE attr_was_node_agent_vs(
  attr_val      varchar(254),
  iid           bigint not null,
  rcid          bigint not null,
  eid           integer not null
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;

insert into session.attr_was_node_agent_vs (attr_val, iid, rcid,eid)
select distinct s1.attr_Val, s1.iid,  s1.rcid, s1.eid from amx.stage_attr_no_ex s1, session.inst_was_node_agent a1 where a1.iid=s1.iid and a1.rcid=s1.rcid and a1.eid=s1.eid and s1.attrtyp_cd='VERSION'  ;

update amx.stage1_was_node_agent s1 set s1.was_node_agent_vers= (
select 
a1.attr_val 
from 
 session.attr_was_node_agent_vs a1
where
a1.iid=s1.iid and a1.rcid=s1.rcid and a1.eid=s1.eid 
)
where exists ( select 1 from session.attr_was_node_agent_vs a1 where a1.iid=s1.iid and a1.rcid=s1.rcid and a1.eid=s1.eid )
;

--#IGNORE_ERROR
DROP TABLE AMX.stage_was_node_agent;

CREATE TABLE AMX.stage_was_node_agent(
  was_node_agent VARCHAR(120) not null,
  j2ee_node   VARCHAR(100) not null,
  j2ee_node_os VARCHAR(254),
  j2ee_cell   VARCHAR(100) not null,
  host_nm	VARCHAR(254),
  was_node_agent_type CHAR(3),
  was_node_agent_vers VARCHAR(254),
primary key(was_node_agent,j2ee_node,j2ee_cell)
)
;
insert into AMX.stage_was_node_agent
select 
was_node_agent,
j2ee_node,
min(j2ee_node_os),
j2ee_cell,
min(host_nm),
min(was_node_agent_type) ,
min(was_node_agent_vers) 
from
AMX.stage1_was_node_agent
group by 
was_node_agent,j2ee_node, j2ee_cell
;

--select * from amx.stage_was_node_agent;
----------------------------------
-- CDW
----------------------------------

----------------------
-- WAS_NODE_AGENT
---------------------

DECLARE GLOBAL TEMPORARY TABLE temp1_comp_WAS_NODE_AGENT(
  Comp_id INTEGER,
  Comp_Corr_Val VARCHAR(254),
  Comp_Parent_Corr_Val   VARCHAR(254),
  Comp_Grand_Parent_Corr_Val   VARCHAR(254)
) WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;


-- agent + node + cell 

INSERT INTO session.temp1_comp_WAS_NODE_AGENT
SELECT
c1.comp_id as Comp_id,
c1.comp_nm as Comp_Corr_Val,
c2.comp_nm as Comp_Parent_Corr_Val,
c3.comp_nm as Comp_Grand_Parent_Corr_Val
FROM
    twg.cur_comp c1,
    twg.cur_compreln r1,
    twg.cur_comp c2,
    twg.cur_comp c3,
    twg.cur_compreln r2
WHERE
    c1.comptyp_cd = 'WAS_NODE_AGENT' and
    r1.comp_source_id = c2.comp_id and
    c2.comptyp_cd = 'J2EE_NODE' and
    r1.comp_target_id = c1.comp_id and
    r1.relntyp_cd ='PCHILD' and
    r2.relntyp_cd ='PCHILD' and
    r2.comp_source_id = c3.comp_id and
    r2.comp_target_id =  c2.comp_id and
    c3.comptyp_cd ='J2EE_CELL' 
group by
c1.comp_id, c1.comp_nm, c2.comp_nm, c3.comp_nm
    ;

--select substr(Comp_Corr_Val,1,25) as was_node_agent, substr(Comp_Parent_Corr_Val,1,15) as j2ee_node, substr(Comp_Grand_Parent_Corr_Val,1,15) as j2ee_cell from session.temp1_comp_WAS_NODE_AGENT;



INSERT INTO twg.comp(comp_id, comptyp_cd, centr_cd, cust_id, comp_nm,comp_corr_val,comp_strt_dttm,comp_end_dttm,comp_ds)
SELECT
    0 AS comp_id,
    'WAS_NODE_AGENT' AS comptyp_cd,
    ce.centr_cd AS centr_cd,
    u.cust_id AS cust_id,
    t1.was_node_agent AS comp_nm,
    'FROM_ITM!!' concat t1.j2ee_node concat '##' concat t1.j2ee_cell as comp_corr_val,
    CURRENT TIMESTAMP - CURRENT TIMEZONE AS comp_start_dttm,
    '9999-01-01-00.00.00.000000' AS comp_end_dttm,
    '' AS comp_ds
FROM
    amx.stage_was_node_agent t1,
    amx.cust_lookup cu,
    amx.centr_lookup ce,
    TWG.CUST u,
    TWG.CENTR e
WHERE
  ((cu.value=t1.host_nm and u.cust_acct_cd = cu.cust_acct_cd) or (cu.value = '@')) AND
  ((ce.value=t1.host_nm and e.centr_cd = ce.centr_cd) or (ce.value = '@')) AND
  NOT EXISTS (
   SELECT 1
   FROM
     session.temp1_comp_was_node_agent t2
   WHERE
     t1.was_node_agent = t2.Comp_Corr_Val and
     t1.j2ee_node =  t2.Comp_Parent_Corr_Val and
     t1.j2ee_cell = t2.Comp_Grand_Parent_Corr_Val
     )
   GROUP BY
  t1.was_node_agent, t1.j2ee_node , t1.j2ee_cell,  ce.centr_cd, u.cust_id
;



-----------------------------------------------------------
-- Add CompReln for J2EE Node to WAS_NODE_AGENT (PCHILD)
-----------------------------------------------------------

INSERT INTO TWG.CompReln (Compreln_id, comp_source_id, comp_target_id, relntyp_cd, compreln_strt_dttm, compreln_end_dttm)
SELECT DISTINCT
    0 AS Compreln_id,
    c2.comp_id AS comp_source_id,
    c1.comp_id AS comp_target_id,
    'PCHILD' AS relntyp_cd,
    c1.comp_strt_dttm AS compreln_strt_dttm,
   '9999-01-01-00.00.00.000000' AS compreln_end_dttm
FROM
    twg.cur_comp c1,
    twg.cur_comp c2,
    amx.stage_was_node_agent c4
WHERE
    c1.CompTyp_Cd = 'WAS_NODE_AGENT' and
    c2.CompTyp_Cd = 'J2EE_NODE' and
    c4.j2ee_node=c2.comp_nm and
    c4.was_node_agent=c1.comp_nm and
    locate ('FROM_ITM!!',c1.comp_corr_val)!=0 and
      -- Agent(Cell)=Node(Cell)
    substr(c1.comp_corr_val, locate('##',c1.comp_corr_val) + 2,length(c1.comp_corr_val) - locate('##',c1.comp_corr_val) -1 )= substr(c2.comp_corr_val,locate('!!',c2.comp_corr_val) + 2, length(c2.comp_corr_val) - locate('!!',c2.comp_corr_val) - 1)  AND
    -- Agent(Node)=Node
    substr(c1.comp_corr_val, locate('!!',c1.comp_corr_val) + 2,locate('##',c1.comp_corr_val) - locate ('!!',c1.comp_corr_val) - 2)=c2.comp_nm   and   
    NOT EXISTS(
    SELECT 1 FROM twg.cur_compreln c3
    WHERE
    c2.comp_id = c3.comp_source_id and
    c1.comp_id = c3.comp_target_id and
    c3.relntyp_cd='PCHILD')
;

-----------------------------------------------------------
-- Add CompReln for J2EE CELL to J2EE NODE (PCHILD)
-----------------------------------------------------------

INSERT INTO TWG.CompReln (Compreln_id, comp_source_id, comp_target_id, relntyp_cd, compreln_strt_dttm, compreln_end_dttm)
SELECT DISTINCT
    0 AS Compreln_id,
    c2.comp_id AS comp_source_id,
    c1.comp_id AS comp_target_id,
    'PCHILD' AS relntyp_cd,
    c1.comp_strt_dttm AS compreln_strt_dttm,
   '9999-01-01-00.00.00.000000' AS compreln_end_dttm
FROM
    twg.cur_comp c1,
    twg.cur_comp c2,
    amx.stage_was_node_agent c4
WHERE
    c1.CompTyp_Cd = 'J2EE_NODE' AND
    c2.CompTyp_Cd = 'J2EE_CELL' AND
    c4.j2ee_cell=c2.comp_nm and
    c4.j2ee_node=c1.comp_nm AND
    locate ('FROM_ITM!!',c1.comp_corr_val)!=0 and
    --cell=cell(node)
    substr(c1.comp_corr_val, locate('!!',c1.comp_corr_val) + 2,length(c1.comp_corr_val) - locate('!!',c1.comp_corr_val) -1 )=c2.comp_nm and
    NOT EXISTS(
    SELECT 1 FROM twg.cur_compreln c3
    WHERE
    c2.comp_id = c3.comp_source_id
    AND c1.comp_id = c3.comp_target_id
    AND c3.relntyp_cd='PCHILD')
;
-----------------------------------------------------------
-- Add CompReln for WAS_NODE_AGENT to HOST (RUNSON)
-----------------------------------------------------------

INSERT INTO TWG.CompReln (Compreln_id, comp_source_id, comp_target_id, relntyp_cd, compreln_strt_dttm, compreln_end_dttm)
SELECT DISTINCT
    0 AS Compreln_id,
    c1.comp_id AS comp_source_id,
    c2.comp_id AS comp_target_id,
    'RUNSON' AS relntyp_cd,
    c1.comp_strt_dttm AS compreln_strt_dttm,
   '9999-01-01-00.00.00.000000' AS compreln_end_dttm
FROM
    twg.cur_comp c1,
    twg.cur_comp c2,
    amx.stage_was_node_agent t1
WHERE
    c1.CompTyp_Cd = 'WAS_NODE_AGENT' AND
    (c2.CompTyp_Cd ='IP_INTERFACE' OR c2.comptyp_cd like '%HOST%') AND
    t1.was_node_agent=c1.comp_nm and
    locate ('FROM_ITM!!',c1.comp_corr_val)!=0 and
    t1.j2ee_node=substr(c1.comp_corr_val, locate('!!',c1.comp_corr_val) + 2,locate('##',c1.comp_corr_val) - locate ('!!',c1.comp_corr_val) - 2) and
    t1.j2ee_cell=substr(c1.comp_corr_val, locate('##',c1.comp_corr_val) + 2,length(c1.comp_corr_val) - locate('##',c1.comp_corr_val) -1 ) and
    t1.host_nm=c2.comp_nm and
    NOT EXISTS(
    SELECT 1 FROM twg.cur_compreln c3
    WHERE
    c1.comp_id = c3.comp_source_id AND
    c2.comp_id = c3.comp_target_id AND
    c3.relntyp_cd='RUNSON')
;

--------------------------------------------------------
-- Recreate a temporary table with all the new WAS_NODE_AGENT
-- inserted in TWG.COMP
---------------------------------------------------------
DECLARE GLOBAL TEMPORARY TABLE temp2_comp_WAS_NODE_AGENT(
  Comp_id INTEGER,
  Comp_Corr_Val VARCHAR(254),
  Comp_Parent_Corr_Val   VARCHAR(254),
  Comp_Grand_Parent_Corr_Val   VARCHAR(254),
  centr_cd VARCHAR(6),
  cust_id INTEGER
) WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;


-- was_node_agent + node + cell 

INSERT INTO session.temp2_comp_WAS_NODE_AGENT
SELECT
c1.comp_id as Comp_id,
c1.comp_nm as  Comp_Corr_Val,
c2.comp_nm as  Comp_Parent_Corr_Val,
c3.comp_nm as Comp_Grand_Parent_Corr_Val,
c1.centr_cd as centr_cd,
c1.cust_id as cust_id
FROM
    twg.cur_comp c1,
    twg.cur_compreln r1,
    twg.cur_comp c2,
    twg.cur_comp c3,
    twg.cur_compreln r2
WHERE
    c1.comptyp_cd = 'WAS_NODE_AGENT' and
    r1.comp_source_id = c2.comp_id and
    c2.comptyp_cd = 'J2EE_NODE' and
    r1.comp_target_id = c1.comp_id and
    r1.relntyp_cd ='PCHILD' and
    r2.relntyp_cd ='PCHILD' and
    r2.comp_source_id = c3.comp_id and
    r2.comp_target_id =  c2.comp_id and
    c3.comptyp_cd ='J2EE_CELL' 
group by
c1.comp_id, c1.comp_nm, c2.comp_nm, c3.comp_nm,c1.centr_cd,c1.cust_id;

--select * from session.temp2_comp_WAS_NODE_AGENT;

---------------------------------------------------------
--- Add MANUFACTURER='IBM' as a Component Attribute
-- of the  WAS_NODE_AGENT
-- This attribute is a constant and will never change
---------------------------------------------------------
DECLARE GLOBAL TEMPORARY TABLE temp3_comp_WAS_NODE_AGENT(
  Comp_id INTEGER
) WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;


-- was_node_agent + node + cell 

INSERT INTO session.temp3_comp_WAS_NODE_AGENT
SELECT
c1.comp_id as Comp_id
FROM
    twg.cur_comp c1
WHERE
    c1.comptyp_cd = 'WAS_NODE_AGENT' 
group by
c1.comp_id ;

--select * from session.temp3_comp_WAS_NODE_AGENT;

insert into twg.compattr(compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.Comp_id as comp_id,
 'MANUFACTURER' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 'IBM' as CompAttr_Val
from
  session.temp3_comp_WAS_NODE_AGENT c1
where
  not exists ( select 1 from  twg.cur_compattr ca1
  where ca1.comp_id=c1.Comp_id and
  ca1.attrtyp_cd='MANUFACTURER' and
  ca1.compattr_val='IBM'
  )
;

--select * from twg.compattr;

---------------------------------------------------------
--- Add Version as a Component Attribute
-- of the  WAS_NODE_AGENT
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_was_node_agent_version(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_was_node_agent_version
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'WAS_NODE_AGENT' and
    ca.attrtyp_cd = 'VERSION' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_was_node_agent_version (
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_was_node_agent_version
select
 c1.Comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.temp2_comp_WAS_NODE_AGENT c1 left outer join session.tmp1_was_node_agent_version ca1
 on ( c1.Comp_id = ca1.comp_id)
;

-- select * from session.tmp2_was_node_agent_version;

insert into twg.compattr(compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.Comp_id as comp_id,
 'VERSION' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 s1.was_node_agent_vers as CompAttr_Val
from
 amx.stage_was_node_agent s1,
 session.temp2_comp_WAS_NODE_AGENT c1,
 session.tmp2_was_node_agent_version ca1
where
  s1.was_node_agent = c1.Comp_Corr_Val and
  s1.j2ee_node =  c1.Comp_Parent_Corr_Val and
  s1.j2ee_cell = c1.Comp_Grand_Parent_Corr_Val and
  ca1.comp_id=c1.Comp_id and
  ca1.last_value is null
group by
  c1.Comp_id, s1.was_node_agent_vers
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.Comp_id as comp_id,
 'VERSION' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 s1.was_node_agent_vers as CompAttr_Val
from
 amx.stage_was_node_agent s1,
 session.temp2_comp_WAS_NODE_AGENT c1,
 session.tmp2_j2ee_version ca1
where
  s1.was_node_agent = c1.Comp_Corr_Val and
  s1.j2ee_node =  c1.Comp_Parent_Corr_Val and
  s1.j2ee_cell = c1.Comp_Grand_Parent_Corr_Val and
  ca1.last_value is not null and
  ca1.comp_id=c1.Comp_id and
  ca1.last_value != s1.was_node_agent_vers
group by
  c1.Comp_id,  s1.was_node_agent_vers
;

--select * from twg.compattr;

--#IGNORE_ERROR
drop table AMX.STG_CDW_WAS_NODE_AGENT;

create table AMX.STG_CDW_WAS_NODE_AGENT (
comp_id 	integer not null,
iid 		integer not null,
eid		integer not null,
rcid		integer not null,
primary key (iid,rcid,eid,comp_id)
);

insert into AMX.STG_CDW_WAS_NODE_AGENT
select
 c1.comp_id,
 o.iid,
 o.eid,
 o.rcid
from
 AMX.stage1_WAS_NODE_AGENT o,
 session.temp2_comp_WAS_NODE_AGENT c1
where
c1.comp_corr_val=o.was_node_agent and 
c1.comp_parent_corr_val=o.j2ee_node and
c1.comp_grand_parent_corr_val=o.j2ee_cell 
group by
c1.comp_id,o.eid,o.rcid,o.iid
;

--select * from amx.stg_cdw_WAS_NODE_AGENT;


