-- ##########################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: Common/src/tedw_app/amy/fixpack5/cdw/ddl/amy_cdw_schema.sql, tmnt_etl, tmnt_5.1.1
-- #   Revision: 1.10
-- #   Date: 4/19/04 11:15:16
-- ############################################################################

--#iftag fixpack_21
-- do nothing...
--#endtag fixpack_21

--#iftag fixpack_400
-- do nothing...
--#endtag fixpack_400

--#iftag fixpack_500

--
-- Here we create some support views used to perform the hostname decomposition into
-- network_domain, network_subdomain and eventually second level network_subdomain
-- with a different approach in order to avoid the usage of the Com_Ds field, not
-- always updated by the ETL1 process...
--
create view AMY.hostname_v1 as
select
  c1.Comp_ID as host_id,
  c1.Comp_Nm as hostname,
  LOCATE('.',c1.Comp_Nm) + 1 as name_b_beg,
  LOCATE('.',c1.Comp_Nm,LOCATE('.',c1.Comp_Nm) + 1) + 1 as name_c_beg,
  LOCATE('.',c1.Comp_Nm,LOCATE('.',c1.Comp_Nm,LOCATE('.',c1.Comp_Nm) + 1) + 1) + 1 as name_d_beg,
  LOCATE('.',c1.Comp_Nm,LOCATE('.',c1.Comp_Nm,LOCATE('.',c1.Comp_Nm,LOCATE('.',c1.Comp_Nm) + 1) + 1) + 1) + 1 as name_e_beg
from
  TWG.Cur_Comp c1
where
  c1.comptyp_cd in ('AMY_HOST','IP_HOST')
group by
  c1.Comp_ID, c1.Comp_Nm
;

create view AMY.hostname_v2 as
select
  host_id,
  hostname,
  name_b_beg,
  name_c_beg,
  name_d_beg,
  name_e_beg,
  case when (name_b_beg > 1 and name_c_beg > 1 and name_d_beg > 1 and name_e_beg > 1) then 5
       when (name_b_beg > 1 and name_c_beg > 1 and name_d_beg > 1 and name_e_beg = 1) then 4
       when (name_b_beg > 1 and name_c_beg > 1 and name_d_beg = 1 ) then 3
       when (name_b_beg > 1 and name_c_beg = 1 ) then 2
       when (name_b_beg = 1 ) then 1
  end  as name_parts
from
  AMY.hostname_v1
;

create view AMY.hostname_decomp as
select
  host_id,
  hostname,
  CASE
    when name_parts = 5 then substr(hostname,name_d_beg)
    when name_parts = 4 then substr(hostname,name_c_beg)
    when name_parts = 3 then substr(hostname,name_b_beg)
    else 'no value'
  END as network_domain,
  CASE
    when name_parts = 5 then substr(hostname,name_c_beg)
    when name_parts = 4 then substr(hostname,name_b_beg)
    else 'no value'
  END as network_subdomain,
  CASE
    when name_parts = 5 then substr(hostname,name_b_beg)
    else 'no value'
  END as network_subdomain2,
  CASE
    when hostname is null THEN null
    when name_b_beg > 1 THEN SUBSTR(hostname, 1, name_b_beg - 2)
    else hostname
  END as short_hostname
from  AMY.hostname_v2
;

--------------------
--- Host
--------------------

-- VE VIEW
create view AMY.ve_host (max_value) as
select max(c.comp_id)
from twg.cur_comp c
where c.comptyp_cd in ('IP_HOST', 'IP_INTERFACE', 'AMY_HOST')
;

-- VD VIEW
create view AMY.vd_host (
  orig_host_id,
  hostname,
  network_domain,
  network_subdomain,
  network_subdomain2,
  short_hostname,
  customer_name,
  center_name ) as
select
  c1.comp_id            as orig_host_id,
  c1.comp_nm            as hostname,
  h.network_domain      as network_domain,
  h.network_subdomain   as network_subdomain,
  h.network_subdomain2  as network_subdomain2,
  h.short_hostname      as short_hostname,
  cu.cust_nm            as customer_name,
  ce.centr_nm           as center_name
from
  amy.hostname_decomp h,
  twg.cur_comp c1,
  twg.cust cu,
  twg.centr ce
where
  cu.cust_id=c1.cust_id and
  ce.centr_cd=c1.centr_cd and
  c1.comptyp_cd in ('IP_HOST', 'AMY_HOST')  and
  h.host_id=c1.comp_id
group by
  c1.comp_id, c1.comp_nm, cu.cust_nm, ce.centr_nm,
  h.network_domain,h.network_subdomain,h.network_subdomain2,
  h.short_hostname
union
select
  c1.comp_id  as orig_host_id,
  c1.comp_nm  as host_name,
  'N/A'       as network_domain,
  'N/A'       as network_subdomain,
  'N/A'       as network_subdomain2,
  'N/A'       as short_hostname,
  cu.cust_nm  as customer_name,
  ce.centr_nm as center_name
from
  twg.cur_comp c1,
  twg.cust cu,
  twg.centr ce
where
  cu.cust_id=c1.cust_id and
  ce.centr_cd=c1.centr_cd and
  c1.comptyp_cd in ('IP_INTERFACE')
;

--------------------
---  CPU
--------------------

create table AMY.stg_CPU_met (
  insert_dttm     timestamp,
  metric_id       integer        not null,
  met_category    varchar(254),
  met_name        varchar(254)   not null,
  met_desc        varchar(254),
  met_units       varchar(254),
  min_exists      char(1)        not null,
  max_exists      char(1)        not null,
  avg_exists      char(1)        not null,
  total_exists    char(1)        not null,
  msrc_nm         varchar(254),
      primary key (metric_id)
);

-- VE VIEW
create view AMY.ve_CPU_met (max_value) as
select max(metric_id)
  from AMY.stg_CPU_met
;

-- VD VIEW
create view AMY.vd_CPU_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select
  d.metric_id     as orig_metric_id,
  d.met_category  as met_category,
  d.met_desc      as met_desc,
  d.met_name      as met_name,
  d.met_units     as met_units,
  d.min_exists    as min_exists,
  d.max_exists    as max_exists,
  d.avg_exists    as avg_exists,
  d.total_exists  as total_exists,
  d.msrc_nm       as msrc_nm
from
  AMY.stg_CPU_met d
;

-- VE VIEW
create view AMY.ve_CPU (max_value) as
select max(c.comp_id)
  from twg.cur_comp c
 where c.comptyp_cd in ('AMY_OS400BCPU', 'AMY_OS400DBCPU','AMY_OS400ICPU','AMY_OS400IFCPU','AMY_CPU')
;

-- VD VIEW
create view AMY.vd_CPU(
 orig_CPU_id,
 CPU_Nm,
 CPU_Type) as
select
 c1.comp_id as orig_CPU_id,
 c1.comp_nm as CPU_Nm,
 case
  when c1.comptyp_cd='AMY_CPU'
  then
   'Unix/Windows'
  else
   substr(c1.comptyp_cd,5,length(c1.comptyp_cd) - 4)
  end as CPU_Type
from
 twg.cur_comp c1
where
 c1.comptyp_cd in ('AMY_OS400BCPU', 'AMY_OS400DBCPU','AMY_OS400ICPU','AMY_OS400IFCPU','AMY_CPU')
group by
 c1.comp_id,
 c1.comp_nm,
 c1.comptyp_cd
;

-- VE VIEW
create view AMY.ve_stg_CPU_hr (max_value) as
select max(m.msmt_id)
  from twg.cur_comp c, twg.msmt m
 where c.comptyp_cd in ('AMY_OS400BCPU', 'AMY_OS400DBCPU','AMY_OS400ICPU','AMY_OS400IFCPU','AMY_CPU')
   and c.comp_id = m.comp_id
;

-- VF VIEW
create view AMY.vf_stg_CPU_hr (
 msmt_id,
 orig_CPU_id,
 orig_host_id,
 host_ip_ad,
 orig_metric_id,
 meas_hour,
 min_value,
 max_value,
 avg_value,
 total_value,
 sample_count ) as
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_CPU_id,
 min(c1.comp_corr_id) as orig_host_id,
 value (min(ca2.compattr_val), 'UNKNOWN') as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2
 left outer join
 twg.cur_compattr ca2
 on ca2.comp_id=c2.comp_id and
 ca2.attrtyp_cd='LAST_IP_ADDRESS',
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd in ('AMY_OS400BCPU', 'AMY_OS400DBCPU','AMY_OS400ICPU','AMY_OS400IFCPU','AMY_CPU')
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_HOST', 'AMY_HOST')
group by
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
  m.msmt_strt_dt,m.msmt_strt_tm
union
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_CPU_id,
 min(c1.comp_corr_id) as orig_host_id,
 min(c2.comp_nm) as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2,
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd in ('AMY_OS400BCPU', 'AMY_OS400DBCPU','AMY_OS400ICPU','AMY_OS400IFCPU','AMY_CPU')
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd='IP_INTERFACE'
group by
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
  m.msmt_strt_dt,m.msmt_strt_tm
;

--------------------
---  FILE
--------------------

create table AMY.STG_FS_MET (
 insert_dttm    timestamp,
 metric_id      integer        not null,
 met_category   varchar(254),
 met_name       varchar(254)   not null,
 met_desc       varchar(254),
 met_units      varchar(254),
 min_exists     char(1)        not null,
 max_exists     char(1)        not null,
 avg_exists     char(1)        not null,
 total_exists   char(1)        not null,
 msrc_nm        varchar(254),
      primary key (metric_id)
);

-- VE VIEW
create view AMY.ve_FS_met (max_value) as
select max(metric_id)
  from AMY.stg_FS_met
;

-- VD VIEW
create view AMY.vd_FS_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from
 AMY.STG_FS_MET d
;

-- VE VIEW
create view AMY.ve_FILE (max_value) as
select max(c.comp_id)
  from twg.cur_comp c
 where c.comptyp_cd = 'AMY_FILE'
;

-- VD VIEW
create view AMY.vd_FILE (
 orig_FILE_id,
 FILE_Nm) as
select
 c1.comp_id as orig_FILE_id,
 c1.comp_nm as FILE_Nm
from
 twg.cur_comp c1
where
 c1.comptyp_cd ='AMY_FILE'
group by
 c1.comp_id,
 c1.comp_nm
;

-- VE VIEW
create view AMY.ve_stg_FILE_hr (max_value) as
select max(m.msmt_id)
  from twg.cur_comp c, twg.msmt m
 where c.comptyp_cd ='AMY_FILE'
   and c.comp_id = m.comp_id
;

-- VF VIEW
create view AMY.vf_stg_FILE_hr (
 msmt_id,
 orig_FILE_id,
 FMode,
 FOwner,
 FGroup,
 orig_host_id,
 host_ip_ad,
 orig_metric_id,
 meas_hour,
 min_value,
 max_value,
 avg_value,
 total_value,
 sample_count ) as
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_FILE_id,
 value (min(ca1.compattr_val), 'UNKNOWN') as FMode,
 value (min(ca2.compattr_val), 'UNKNOWN') as FOwner,
 value (min(ca3.compattr_val), 'UNKNOWN') as FGroup,
 min(c1.comp_corr_id) as orig_host_id,
 value (min(ca4.compattr_val), 'UNKNOWN') as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2
 left outer join
 twg.cur_compattr ca4
 on ca4.comp_id=c2.comp_id and
 ca4.attrtyp_cd='LAST_IP_ADDRESS',
 twg.msmt m1
 left outer join
 twg.cur_compattr ca1
 on m1.comp_id = ca1.comp_id and
 ca1.attrtyp_cd = 'AMY_FMODE',
 twg.msmt m2
 left outer join
 twg.cur_compattr ca2
 on m2.comp_id = ca2.comp_id and
 ca2.attrtyp_cd = 'AMY_FOWNER',
 twg.msmt m3
 left outer join
 twg.cur_compattr ca3
 on m3.comp_id = ca3.comp_id and
 ca3.attrtyp_cd = 'AMY_FGROUP',
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_FILE'
where
 m1.msmt_id=m.msmt_id and
 m2.msmt_id=m.msmt_id and
 m3.msmt_id=m.msmt_id and
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_HOST', 'AMY_HOST')
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
union
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_FILE_id,
 value (min(ca1.compattr_val), 'UNKNOWN') as FMode,
 value (min(ca2.compattr_val), 'UNKNOWN') as FOwner,
 value (min(ca3.compattr_val), 'UNKNOWN') as FGroup,
 min(c1.comp_corr_id) as orig_host_id,
 min(c2.comp_nm) as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2,
 twg.msmt m1
 left outer join
 twg.cur_compattr ca1
 on m1.comp_id = ca1.comp_id and
 ca1.attrtyp_cd = 'AMY_FMODE',
 twg.msmt m2
 left outer join
 twg.cur_compattr ca2
 on m2.comp_id = ca2.comp_id and
 ca2.attrtyp_cd = 'AMY_FOWNER',
 twg.msmt m3
 left outer join
 twg.cur_compattr ca3
 on m3.comp_id = ca3.comp_id and
 ca3.attrtyp_cd = 'AMY_FGROUP',
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_FILE'
where
 m1.msmt_id=m.msmt_id and
 m2.msmt_id=m.msmt_id and
 m3.msmt_id=m.msmt_id and
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_INTERFACE')
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
;

--------------------
---  FS
--------------------

-- VE VIEW
create view AMY.ve_FS (max_value) as
select max(c.comp_id)
  from twg.cur_comp c
 where c.comptyp_cd = 'AMY_FS'
;

-- VD VIEW
create view AMY.vd_FS (
 orig_FS_id,
 FS_Nm) as
select
 c1.comp_id as orig_FS_id,
 c1.comp_nm as FS_Nm
from
 twg.cur_comp c1
where
 c1.comptyp_cd='AMY_FS'
group by
 c1.comp_id,
 c1.comp_nm
;

-- VE VIEW
create view AMY.ve_stg_FS_hr (max_value) as
select max(m.msmt_id)
  from twg.cur_comp c, twg.msmt m
 where c.comptyp_cd = 'AMY_FS'
   and c.comp_id = m.comp_id
;

-- VF VIEW
create view AMY.vf_stg_FS_hr (
 msmt_id,
 orig_FS_id,
 orig_host_id,
 host_ip_ad,
 orig_metric_id,
 meas_hour,
 min_value,
 max_value,
 avg_value,
 total_value,
 sample_count ) as
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_FS_id,
 min(c1.comp_corr_id) as orig_host_id,
 value (min(ca2.compattr_val), 'UNKNOWN') as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2
 left outer join
 twg.cur_compattr ca2
 on ca2.comp_id=c2.comp_id and
 ca2.attrtyp_cd='LAST_IP_ADDRESS',
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_FS'
where
 m.tmsum_cd='H'  and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_HOST', 'AMY_HOST')
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
union
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_FS_id,
 min(c1.comp_corr_id) as orig_host_id,
 min(c2.comp_nm) as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2,
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_FS'
where
 m.tmsum_cd='H'  and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_INTERFACE')
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
;

--------------------
---  IP
--------------------

create table AMY.STG_NET_MET (
 insert_dttm    timestamp,
 metric_id      integer        not null,
 met_category   varchar(254),
 met_name       varchar(254)   not null,
 met_desc       varchar(254),
 met_units      varchar(254),
 min_exists     char(1)        not null,
 max_exists     char(1)        not null,
 avg_exists     char(1)        not null,
 total_exists   char(1)        not null,
 msrc_nm        varchar(254),
      primary key (metric_id)
);

-- VE VIEW
create view AMY.ve_NET_met (max_value) as
select max(metric_id)
  from AMY.stg_NET_met
;

-- VD VIEW
create view AMY.vd_NET_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from
  AMY.STG_NET_MET d
;

-- VE VIEW
create view AMY.ve_NETWORK (max_value) as
select max(c.comp_id)
  from twg.cur_comp c
 where c.comptyp_cd IN ('AMY_NETWORK','AMY_IP','AMY_TCPIP','AMY_NFS','AMY_RPC','AMY_NETSEG','AMY_REDIR')
;

-- VD VIEW
create view AMY.vd_NETWORK(
 orig_NET_id,
 NET_Nm,
 NET_Type) as
select
 c1.comp_id as orig_NET_id,
 c1.comp_nm as NET_Nm,
 substr(c1.comptyp_cd,5,length(c1.comptyp_cd) - 4) as NET_type
from
 twg.cur_comp c1
where
 c1.comptyp_cd IN ('AMY_NETWORK','AMY_IP','AMY_TCPIP','AMY_NFS','AMY_RPC','AMY_NETSEG','AMY_REDIR')
group by
 c1.comp_id,
 c1.comp_nm,
 c1.comptyp_cd
;

-- VE VIEW
create view AMY.ve_stg_NETWORK_hr (max_value) as
select max(m.msmt_id)
  from twg.cur_comp c, twg.msmt m
 where c.comptyp_cd IN ('AMY_NETWORK','AMY_IP','AMY_TCPIP','AMY_NFS','AMY_RPC','AMY_NETSEG','AMY_REDIR')
   and c.comp_id = m.comp_id
;

-- VF VIEW
create view AMY.vf_stg_NETWORK_hr (
 msmt_id,
 orig_NET_id,
 orig_host_id,
 host_ip_ad,
 orig_metric_id,
 meas_hour,
 min_value,
 max_value,
 avg_value,
 total_value,
 sample_count ) as
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_NET_id,
 min(c1.comp_corr_id) as orig_host_id,
 value (min(ca2.compattr_val), 'UNKNOWN') as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2
 left outer join
 twg.cur_compattr ca2
 on ca2.comp_id=c2.comp_id and
 ca2.attrtyp_cd='LAST_IP_ADDRESS',
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd IN ('AMY_NETWORK','AMY_IP','AMY_TCPIP','AMY_NFS','AMY_RPC','AMY_NETSEG','AMY_REDIR')
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_HOST', 'AMY_HOST')
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
union
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_NET_id,
 min(c1.comp_corr_id) as orig_host_id,
 min(c2.comp_nm) as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2,
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd IN ('AMY_NETWORK','AMY_IP','AMY_TCPIP','AMY_NFS','AMY_RPC','AMY_NETSEG','AMY_REDIR')
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd = 'IP_INTERFACE'
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
;

--------------------
---  LDISK
--------------------

create table AMY.STG_IO_MET (
 insert_dttm    timestamp,
 metric_id      integer        not null,
 met_category   varchar(254),
 met_name       varchar(254)   not null,
 met_desc       varchar(254),
 met_units      varchar(254),
 min_exists     char(1)        not null,
 max_exists     char(1)        not null,
 avg_exists     char(1)        not null,
 total_exists   char(1)        not null,
 msrc_nm        varchar(254),
      primary key (metric_id)
);

-- VE VIEW
create view AMY.ve_IO_met (max_value) as
select max(metric_id)
  from AMY.stg_IO_met
;

-- VD VIEW
create view AMY.vd_IO_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from
  AMY.STG_IO_MET d
;

-- VE VIEW
create view AMY.ve_LDISK (max_value) as
select max(c.comp_id)
  from twg.cur_comp c
 where c.comptyp_cd = 'AMY_LDISK'
;

-- VD VIEW
create view AMY.vd_LDISK(
 orig_LDISK_id,
 LDISK_Nm) as
select
 c1.comp_id as orig_LDISK_id,
 c1.comp_nm as LDISK_Nm
from
 twg.cur_comp c1
where
 c1.comptyp_cd='AMY_LDISK'
group by
 c1.comp_id,
 c1.comp_nm
;

-- VE VIEW
create view AMY.ve_stg_LDISK_hr (max_value) as
select max(m.msmt_id)
  from twg.cur_comp c, twg.msmt m
 where c.comptyp_cd = 'AMY_LDISK'
   and c.comp_id = m.comp_id
;

-- VF VIEW
create view AMY.vf_stg_LDISK_hr (
 msmt_id,
 orig_LDISK_id,
 orig_host_id,
 host_ip_ad,
 orig_metric_id,
 meas_hour,
 min_value,
 max_value,
 avg_value,
 total_value,
 sample_count ) as
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_LDISK_id,
 min(c1.comp_corr_id) as orig_host_id,
 value (min(ca2.compattr_val), 'UNKNOWN') as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2
 left outer join
 twg.cur_compattr ca2
 on ca2.comp_id=c2.comp_id and
 ca2.attrtyp_cd='LAST_IP_ADDRESS',
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_LDISK'
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_HOST', 'AMY_HOST')
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
union
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_LDISK_id,
 min(c1.comp_corr_id) as orig_host_id,
 min(c2.comp_nm) as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2 ,
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_LDISK'
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_INTERFACE')
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
;

--------------------
---  MEMORY
--------------------

create table AMY.STG_MEM_MET (
 insert_dttm    timestamp,
 metric_id      integer        not null,
 met_category   varchar(254),
 met_name       varchar(254)   not null,
 met_desc       varchar(254),
 met_units      varchar(254),
 min_exists     char(1)        not null,
 max_exists     char(1)        not null,
 avg_exists     char(1)        not null,
 total_exists   char(1)        not null,
 msrc_nm        varchar(254),
      primary key (metric_id)
);

-- VE VIEW
create view AMY.ve_MEM_met (max_value) as
select max(metric_id)
  from AMY.stg_MEM_met
;

-- VD VIEW
create view AMY.vd_MEM_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from
  AMY.STG_MEM_MET d
;

-- VE VIEW
--
-- This view is created in a more performant flavor in the 
-- protected section for 5.1.2-ITM-FP01
--
-- create view AMY.ve_MEMORY (max_value) as
-- select max(c.comp_id)
--   from twg.cur_comp c
--  where c.comptyp_cd = 'AMY_MEMORY'
-- ;

-- VD VIEW
create view AMY.vd_MEMORY(
 orig_MEMORY_id,
 MEMORY_Nm,
 MEMORY_Type) as
select
 c1.comp_id as orig_MEMORY_id,
 c1.comp_nm as MEMORY_Nm,
 case
 when c1.comptyp_cd='AMY_MEMORY'
 then 'Unix/Windows'
 else 'OS400 Storage Pool'
 end as MEMORY_Type
from
 twg.cur_comp c1
where
 c1.comptyp_cd in ('AMY_MEMORY','AMY_OS400SPOOL')
group by
 c1.comp_id,
 c1.comp_nm,
 c1.comptyp_cd
;

-- VE VIEW
create view AMY.ve_stg_MEMORY_hr (max_value) as
select max(m.msmt_id)
  from twg.cur_comp c, twg.msmt m
 where c.comptyp_cd in ('AMY_MEMORY','AMY_OS400SPOOL')
   and c.comp_id = m.comp_id
;

-- VF VIEW
create view AMY.vf_stg_MEMORY_hr (
 msmt_id,
 orig_MEMORY_id,
 orig_host_id,
 host_ip_ad,
 orig_metric_id,
 meas_hour,
 min_value,
 max_value,
 avg_value,
 total_value,
 sample_count ) as
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_MEMORY_id,
 min(c1.comp_corr_id) as orig_host_id,
 value (min(ca2.compattr_val), 'UNKNOWN') as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2
 left outer join
 twg.cur_compattr ca2
 on ca2.comp_id=c2.comp_id and
 ca2.attrtyp_cd='LAST_IP_ADDRESS',
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd in ('AMY_MEMORY','AMY_OS400SPOOL')
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_HOST', 'AMY_HOST')
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
union
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_MEMORY_id,
 min(c1.comp_corr_id) as orig_host_id,
 min(c2.comp_nm) as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2,
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd in ('AMY_MEMORY','AMY_OS400SPOOL')
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_INTERFACE')
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
;

--------------------
---  OS400ASP
--------------------

-- metrics in FS_MET

-- VE VIEW
create view AMY.ve_OS400ASP (max_value) as
select max(c.comp_id)
  from twg.cur_comp c
 where c.comptyp_cd = 'AMY_OS400ASP'
;

-- VD VIEW
create view AMY.vd_OS400ASP(
 orig_OS400ASP_id,
 OS4KASP_Nm) as
select
 c1.comp_id as orig_OS400ASP_id,
 c1.comp_nm as OS4KASP_Nm
from
 twg.cur_comp c1
where
 c1.comptyp_cd='AMY_OS400ASP'
group by
 c1.comp_id,
 c1.comp_nm
;

-- VE VIEW
create view AMY.ve_stg_OS400ASP_hr (max_value) as
select max(m.msmt_id)
  from twg.cur_comp c, twg.msmt m
 where c.comptyp_cd = 'AMY_OS400ASP'
   and c.comp_id = m.comp_id
;

-- VF VIEW
create view AMY.vf_stg_OS400ASP_hr (
 msmt_id,
 orig_OS400ASP_id,
 orig_host_id,
 host_ip_ad,
 orig_metric_id,
 meas_hour,
 min_value,
 max_value,
 avg_value,
 total_value,
 sample_count ) as
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_OS400ASP_id,
 min(c1.comp_corr_id) as orig_host_id,
 value (min(ca2.compattr_val), 'UNKNOWN') as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2
 left outer join
 twg.cur_compattr ca2
 on ca2.comp_id=c2.comp_id and
 ca2.attrtyp_cd='LAST_IP_ADDRESS',
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_OS400ASP'
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_HOST', 'AMY_HOST')
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
union
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_OS400ASP_id,
 min(c1.comp_corr_id) as orig_host_id,
 min(c2.comp_nm) as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2,
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_OS400ASP'
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_INTERFACE')
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
;

---------------------------------------------
---  OS4KBCPU, OS4KDBCPU, OS4KICPU, OS4KIFCPU
---------------------------------------------

-- metrics in CPU_MET

--------------------
---  OS4KDBCPU
--------------------
-- metrics in CPU_MET

--------------------
---  OS4KDISK
--------------------

-- metrics in IO_MET

-- VE VIEW
create view AMY.ve_OS4KDISK (max_value) as
select max(c.comp_id)
  from twg.cur_comp c
 where c.comptyp_cd = 'AMY_OS400DISK'
;

-- VD VIEW
create view AMY.vd_OS4KDISK(
 orig_OS4KDISK_id,
 OS4KDISK_Nm) as
select
 c1.comp_id as orig_OS4KDISK_id,
 c1.comp_nm as OS4KDISK_Nm
from
 twg.cur_comp c1
where
 c1.comptyp_cd='AMY_OS400DISK'
group by
 c1.comp_id,
 c1.comp_nm
;

-- VE VIEW
create view AMY.ve_stg_OS4KDISK_hr (max_value) as
select max(m.msmt_id)
  from twg.cur_comp c, twg.msmt m
 where c.comptyp_cd = 'AMY_OS400DISK'
   and c.comp_id = m.comp_id
;

-- VF VIEW
create view AMY.vf_stg_OS4KDISK_hr (
 msmt_id,
 orig_OS4KDISK_id,
 orig_host_id,
 host_ip_ad,
 orig_metric_id,
 meas_hour,
 min_value,
 max_value,
 avg_value,
 total_value,
 sample_count ) as
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_OS4KDISK_id,
 min(c1.comp_corr_id) as orig_host_id,
 value (min(ca2.compattr_val), 'UNKNOWN') as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2
 left outer join
 twg.cur_compattr ca2
 on ca2.comp_id=c2.comp_id and
 ca2.attrtyp_cd='LAST_IP_ADDRESS',
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_OS400DISK'
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_HOST', 'AMY_HOST')
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
union
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_OS4KDISK_id,
 min(c1.comp_corr_id) as orig_host_id,
 min(c2.comp_nm) as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2 ,
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_OS400DISK'
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd ='IP_INTERFACE'
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
;

--------------------
---  OS4KICPU
--------------------

-- metrics in CPU_MET

--------------------
---  OS4KIFCPU
--------------------

-- metrics in CPU_MET

--------------------
---  OS4KSPOOL
--------------------

-- metrics in MEMORY_MET

--------------------
---  PDISK
--------------------

-- metrics in IO_MET

-- VE VIEW
create view AMY.ve_PDISK (max_value) as
select max(c.comp_id)
  from twg.cur_comp c
 where c.comptyp_cd = 'AMY_PDISK'
;

-- VD VIEW
create view AMY.vd_PDISK(
 orig_PDISK_id,
 PDISK_Nm) as
select
 c1.comp_id as orig_PDISK_id,
 c1.comp_nm as PDISK_Nm
from
 twg.cur_comp c1
where
 c1.comptyp_cd='AMY_PDISK'
group by
 c1.comp_id,
 c1.comp_nm
;

-- VE VIEW
create view AMY.ve_stg_PDISK_hr (max_value) as
select max(m.msmt_id)
  from twg.cur_comp c, twg.msmt m
 where c.comptyp_cd = 'AMY_PDISK'
   and c.comp_id = m.comp_id
;

-- VF VIEW
create view AMY.vf_stg_PDISK_hr (
 msmt_id,
 orig_PDISK_id,
 orig_host_id,
 host_ip_ad,
 orig_metric_id,
 meas_hour,
 min_value,
 max_value,
 avg_value,
 total_value,
 sample_count ) as
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_PDISK_id,
 min(c1.comp_corr_id) as orig_host_id,
 value (min(ca2.compattr_val), 'UNKNOWN') as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2
 left outer join
 twg.cur_compattr ca2
 on ca2.comp_id=c2.comp_id and
 ca2.attrtyp_cd='LAST_IP_ADDRESS',
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_PDISK'
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_HOST', 'AMY_HOST')
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
union
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_PDISK_id,
 min(c1.comp_corr_id) as orig_host_id,
 min(c2.comp_nm) as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2,
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_PDISK'
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd='IP_INTERFACE'
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
;

--------------------
---  PORT
--------------------

-- there is no metric logged for this component
-- so there is no need for dimension or fact tables

--------------------
---  PRNQUEUE
--------------------

create table AMY.STG_PRN_MET (
 insert_dttm    timestamp,
 metric_id      integer        not null,
 met_category   varchar(254),
 met_name       varchar(254)   not null,
 met_desc       varchar(254),
 met_units      varchar(254),
 min_exists     char(1)        not null,
 max_exists     char(1)        not null,
 avg_exists     char(1)        not null,
 total_exists   char(1)        not null,
 msrc_nm        varchar(254),
      primary key (metric_id)
);

-- VE VIEW
create view AMY.ve_PRN_met (max_value) as
select max(metric_id)
  from AMY.stg_PRN_met
;

-- VD VIEW
create view AMY.vd_PRN_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from
  AMY.STG_PRN_MET d
;

-- VE VIEW
create view AMY.ve_PRINTER (max_value) as
select max(c.comp_id)
  from twg.cur_comp c
 where c.comptyp_cd = 'AMY_PRNQUEUE'
;

-- VD VIEW
create view AMY.vd_PRINTER(
 orig_PRN_id,
 PRN_Nm) as
select
 c1.comp_id as orig_PRN_id,
 c1.comp_nm as PRN_Nm
from
 twg.cur_comp c1
where
 c1.comptyp_cd='AMY_PRNQUEUE'
group by
 c1.comp_id,
 c1.comp_nm
;

-- VE VIEW
create view AMY.ve_stg_PRN_hr (max_value) as
select max(m.msmt_id)
  from twg.cur_comp c, twg.msmt m
 where c.comptyp_cd = 'AMY_PRNQUEUE'
   and c.comp_id = m.comp_id
;

-- VF VIEW
create view AMY.vf_stg_PRN_hr (
 msmt_id,
 orig_PRN_id,
 orig_host_id,
 host_ip_ad,
 orig_metric_id,
 meas_hour,
 min_value,
 max_value,
 avg_value,
 total_value,
 sample_count ) as
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_PRN_id,
 min(c1.comp_corr_id) as orig_host_id,
 value (min(ca2.compattr_val), 'UNKNOWN') as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2
 left outer join
 twg.cur_compattr ca2
 on ca2.comp_id=c2.comp_id and
 ca2.attrtyp_cd='LAST_IP_ADDRESS',
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_PRNQUEUE'
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_HOST', 'AMY_HOST')
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
union
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_PRN_id,
 min(c1.comp_corr_id) as orig_host_id,
 min(c2.comp_nm) as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2,
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_PRNQUEUE'
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd='IP_INTERFACE'
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
;

--------------------
---  PROCESS
--------------------

-- metrics in CPU_MET


-- VE VIEW
create view AMY.ve_PROCESS (max_value) as
select max(c.comp_id)
  from twg.cur_comp c
 where c.comptyp_cd = 'AMY_PROCESS'
;

-- VD VIEW
--
-- This view is created in a more performant flavor in the 
-- fixpack_600 protected section...
--
-- create view AMY.vd_PROCESS(
--  orig_PROCESS_id,
--  PROC_Nm) as
-- select
--  ca1.comp_id as orig_PROCESS_id,
--  ca1.compattr_val as PROC_Nm
-- from
--  twg.cur_compattr ca1
-- where
--  ca1.attrtyp_cd='AMY_PROCNM'  and
--  ca1.comp_id in (
--  select min(ca2.comp_id) from twg.cur_compattr ca2
--  where ca2.compattr_val=ca1.compattr_val and
--  ca2.attrtyp_cd='AMY_PROCNM')
-- group by
--  ca1.compattr_val,
--  ca1.comp_id
-- ;


--VE VIEW
create view AMY.ve_stg_PROCESS_hr (max_value) as
select max(m.msmt_id)
from   twg.cur_comp c, twg.msmt m
where  c.comptyp_cd = 'AMY_PROCESS'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view AMY.vf_stg_PROCESS_hr (
 msmt_id,
 orig_PROCESS_id,
 orig_host_id,
 host_ip_ad,
 orig_metric_id,
 meas_hour,
 min_value,
 max_value,
 avg_value,
 total_value,
 sample_count ) as
select
 min(m.msmt_id) as msmt_id,
 min(c1.comp_id) as orig_PROCESS_id,
 min(c1.comp_corr_id) as orig_host_id,
 value (min(ca2.compattr_val), 'UNKNOWN') as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2
 left outer join
 twg.cur_compattr ca2
 on ca2.comp_id=c2.comp_id and
 ca2.attrtyp_cd='LAST_IP_ADDRESS',
 twg.msmt m,
 TWG.CUR_COMP c1
where
 c1.comp_id=m.comp_id and
 c1.comptyp_cd='AMY_PROCESS' and
 m.tmsum_cd='H'  and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_HOST', 'AMY_HOST')
group by
 m.msmttyp_id, c1.comp_nm, m.msmt_strt_dt, m.msmt_strt_tm,
 c1.comp_corr_id, m.tmsum_cd
union
select
 min(m.msmt_id) as msmt_id,
 min(c1.comp_id) as orig_PROCESS_id,
 min(c1.comp_corr_id) as orig_host_id,
 min(c2.comp_nm) as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2,
 twg.msmt m,
 TWG.CUR_COMP c1
where
 c1.comp_id=m.comp_id and
 c1.comptyp_cd='AMY_PROCESS' and
 m.tmsum_cd='H'  and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd='IP_INTERFACE'
group by
 m.msmttyp_id, c1.comp_nm, m.msmt_strt_dt, m.msmt_strt_tm,
 c1.comp_corr_id, m.tmsum_cd
;

--------------------
---  REDIR
--------------------

-- metrics in NET_MET

--------------------
---  RPC
--------------------

-- metrics in NET_MET

--------------------
---  SERVER
--------------------

create table AMY.STG_SERVER_MET (
 insert_dttm    timestamp,
 metric_id      integer        not null,
 met_category   varchar(254),
 met_name       varchar(254)   not null,
 met_desc       varchar(254),
 met_units      varchar(254),
 min_exists     char(1)        not null,
 max_exists     char(1)        not null,
 avg_exists     char(1)        not null,
 total_exists   char(1)        not null,
 msrc_nm        varchar(254),
      primary key (metric_id)
);

-- VE VIEW
create view AMY.ve_SERVER_met (max_value) as
select max(metric_id)
  from AMY.stg_SERVER_met
;

-- VD VIEW
create view AMY.vd_SERVER_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from
  AMY.STG_SERVER_MET d
;

-- VE VIEW
create view AMY.ve_SERVER (max_value) as
select max(c.comp_id)
  from twg.cur_comp c
 where c.comptyp_cd = 'AMY_SERVER'
;

-- VD VIEW
create view AMY.vd_SERVER(
 orig_SERVER_id,
 SERVER_Nm) as
select
 c1.comp_id as orig_SERVER_id,
 c1.comp_nm as SERVER_Nm
from
 twg.cur_comp c1
where
 c1.comptyp_cd='AMY_SERVER'
group by
 c1.comp_id,
 c1.comp_nm
;

-- VE VIEW
create view AMY.ve_stg_SERVER_hr (max_value) as
select max(m.msmt_id)
  from twg.cur_comp c, twg.msmt m
 where c.comptyp_cd = 'AMY_SERVER'
   and c.comp_id = m.comp_id
;

-- VF VIEW
create view AMY.vf_stg_SERVER_hr (
 msmt_id,
 orig_SERVER_id,
 orig_host_id,
 host_ip_ad,
 orig_metric_id,
 meas_hour,
 min_value,
 max_value,
 avg_value,
 total_value,
 sample_count ) as
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_SERVER_id,
 min(c1.comp_corr_id) as orig_host_id,
 value (min(ca2.compattr_val), 'UNKNOWN') as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2
 left outer join
 twg.cur_compattr ca2
 on ca2.comp_id=c2.comp_id and
 ca2.attrtyp_cd='LAST_IP_ADDRESS',
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_SERVER'
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_HOST', 'AMY_HOST')
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
union
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_SERVER_id,
 min(c1.comp_corr_id) as orig_host_id,
 min(c2.comp_nm) as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2,
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_SERVER'
where
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd='IP_INTERFACE'
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
;

--------------------
---  SERVICE
--------------------

-- there is no metric logged for this component
-- so there is no need for dimension or fact tables

--------------------
---  USER
--------------------

create table AMY.STG_USER_MET (
 insert_dttm    timestamp,
 metric_id      integer        not null,
 met_category   varchar(254),
 met_name       varchar(254)   not null,
 met_desc       varchar(254),
 met_units      varchar(254),
 min_exists     char(1)        not null,
 max_exists     char(1)        not null,
 avg_exists     char(1)        not null,
 total_exists   char(1)        not null,
 msrc_nm        varchar(254),
      primary key (metric_id)
);

-- VE VIEW
create view AMY.ve_USER_met (max_value) as
select max(metric_id)
  from AMY.stg_USER_met
;

-- VD VIEW
create view AMY.vd_USER_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from
  AMY.STG_USER_MET d
;

-- VE VIEW
create view AMY.ve_USER (max_value) as
select max(c.comp_id)
  from twg.cur_comp c
 where c.comptyp_cd = 'AMY_USER'
;

-- VD VIEW
create view AMY.vd_USER(
 orig_USER_id,
 USER_Nm) as
select
 c1.comp_id as orig_USER_id,
 c1.comp_nm as USER_Nm
from
 twg.cur_comp c1
where
 c1.comptyp_cd='AMY_USER'
group by
 c1.comp_id,
 c1.comp_nm
;

-- VE VIEW
create view AMY.ve_stg_USER_hr (max_value) as
select max(m.msmt_id)
  from twg.cur_comp c, twg.msmt m
 where c.comptyp_cd = 'AMY_USER'
   and c.comp_id = m.comp_id
;

-- VF VIEW
create view AMY.vf_stg_USER_hr (
 msmt_id,
 orig_USER_id,
 UserId,
 orig_host_id,
 host_ip_ad,
 orig_metric_id,
 meas_hour,
 min_value,
 max_value,
 avg_value,
 total_value,
 sample_count ) as
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_USER_id,
 value (min(ca1.compattr_val), 'UNKNOWN') as UserId,
 min(c1.comp_corr_id) as orig_host_id,
 value (min(ca2.compattr_val), 'UNKNOWN') as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2
 left outer join
 twg.cur_compattr ca2
 on ca2.comp_id=c2.comp_id and
 ca2.attrtyp_cd='LAST_IP_ADDRESS',
 twg.msmt m2
 left outer join
 twg.cur_compattr ca1
 on m2.comp_id = ca1.comp_id and
 ca1.attrtyp_cd = 'AMY_USRID',
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_USER'
where
 m2.msmt_id=m.msmt_id and
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd in ('IP_HOST', 'AMY_HOST')
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
union
select
 m.msmt_id as msmt_id,
 m.comp_id as orig_USER_id,
 value (min(ca1.compattr_val), 'UNKNOWN') as UserId,
 min(c1.comp_corr_id) as orig_host_id,
 min(c2.comp_nm) as Host_ip_ad,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 twg.cur_comp c2,
 twg.msmt m2
 left outer join
 twg.cur_compattr ca1
 on m2.comp_id = ca1.comp_id and
 ca1.attrtyp_cd = 'AMY_USRID',
 twg.msmt m
 inner join
 twg.cur_comp c1
 on c1.comp_id=m.comp_id and c1.comptyp_cd = 'AMY_USER'
where
 m2.msmt_id=m.msmt_id and
 m.tmsum_cd='H' and
 c1.comp_corr_id=c2.comp_id and
 c2.comptyp_cd='IP_INTERFACE'
group by
 m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd,
 m.msmt_strt_dt,m.msmt_strt_tm
;

--#endtag fixpack_500

--#iftag fixpack_600
--
-- create a more performer vd_process view to support 
-- the new implemenation of the mart_load process
--
-- create view amy.vd_process(
--  orig_PROCESS_id,
--  PROC_Nm) as
-- select
--  c1.comp_id,
--  c1.comp_nm
-- from
--  twg.cur_comp c1
-- where
--  c1.comptyp_cd='AMY_PROCESS'
-- ;

--------------------
---  SYSTEM
--------------------

create table AMY.stg_SYSTEM_met (
  insert_dttm     timestamp,
  metric_id       integer        not null,
  met_category    varchar(254),
  met_name        varchar(254)   not null,
  met_desc        varchar(254),
  met_units       varchar(254),
  min_exists      char(1)        not null,
  max_exists      char(1)        not null,
  avg_exists      char(1)        not null,
  total_exists    char(1)        not null,
  msrc_nm         varchar(254),
      primary key (metric_id)
);

-- VE VIEW
create view AMY.ve_SYSTEM_met (max_value) as
select max(metric_id)
  from AMY.stg_SYSTEM_met
;

-- VD VIEW
create view AMY.vd_SYSTEM_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select
  d.metric_id     as orig_metric_id,
  d.met_category  as met_category,
  d.met_desc      as met_desc,
  d.met_name      as met_name,
  d.met_units     as met_units,
  d.min_exists    as min_exists,
  d.max_exists    as max_exists,
  d.avg_exists    as avg_exists,
  d.total_exists  as total_exists,
  d.msrc_nm       as msrc_nm
from
  AMY.stg_SYSTEM_met d
;

-- VE VIEW
create view AMY.ve_SYSTEM (max_value) as
select max(c.comp_id)
  from twg.cur_comp c
 where c.comptyp_cd in ('AMY_SYSTEM')
;

-- VD VIEW
create view AMY.vd_SYSTEM(
 orig_SYSTEM_id,
 SYSTEM_Nm,
 SYSTEM_Type) as
select
 c1.comp_id as orig_SYSTEM_id,
 c1.comp_nm as SYSTEM_Nm,
 'Unix/Windows' as SYSTEM_Type
from
 twg.cur_comp c1
where
 c1.comptyp_cd ='AMY_SYSTEM'
group by
 c1.comp_id,
 c1.comp_nm,
 c1.comptyp_cd
;

-- VE VIEW
create view AMY.ve_stg_SYSTEM_hr (max_value) as
select max(m.msmt_id)
  from twg.cur_comp c, twg.msmt m
 where c.comptyp_cd ='AMY_SYSTEM'
   and c.comp_id = m.comp_id
;

--#endtag fixpack_600


--#iftag fixpack_616
create view amy.vd_process(
 orig_PROCESS_id,
 PROC_Nm,
 PROC_Ds) as
select
 c1.comp_id,
 c1.comp_nm,
 c1.COMP_CORR_VAL
from
 twg.cur_comp c1
where
 c1.comptyp_cd='AMY_PROCESS'
;
--#endtag fixpack_616

--#iftag fixpack_660
create view AMY.ve_MEMORY (
 max_value) as
select 
 max(c.comp_id) 
from 
 twg.cur_comp c 
where 
 c.comptyp_cd in ('AMY_MEMORY','AMY_OS400SPOOL')
;
--#iftag fixpack_660
