-- ##########################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: Common/src/tedw_app/amy/fixpack5/cdw/dml/amy_cdw_data.sql, tmnt_etl, tmnt_5.1.1_FP06, 512ITMFP01_0503
-- #   Revision: 1.4.1.4
-- #   Date: 3/4/04 15:16:12
-- ############################################################################

--#iftag fixpack_600

---------------------------------------------------
-- Static data for ITM for Operating System v 5.1.1
---------------------------------------------------

--
-- NOTE: as a general rule, we use a where-not-exist clause to avoid
-- duplicate entries and subsequent unique constraint violation...
--

-----------
-- TWG.MSrc
-----------
--
-- Measurement Source Codes:
-- The monitoring tool that collected the measurements; the MSrc_Cd field should
-- match the three-letter product component prefix required by the Tivoli Message
-- Standard.
--
-- In order to identify Operating System Resource Models we use use the AMY AVA_CODE
--
declare global temporary table AMY_MSrc (
  MSrc_Cd          CHAR(6) NOT NULL,
  MSrc_Parent_Cd   CHAR(6) NOT NULL,
  MSrc_Nm          VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.AMY_MSrc values ('AMY', 'AMX',    'IBM Tivoli Monitoring for Operating Systems');

insert into TWG.MSrc (
  MSrc_Cd, MSrc_Parent_Cd , MSrc_Nm )
select * from session.AMY_MSrc s
where not exists (
  select 1 from
  TWG.MSrc t
  where
  t.MSrc_Cd = s.MSrc_Cd )
;

-----------------------------------------
-- Update the TWG.Prune_Msmt_Control
-- to prune oracle measurements when data is older than 3 months (300)
-- Age_In_Days represents s date duration whose format is yyyymmdd.
-- 300 represents 0 year 3 months 0 day
-------------------------------------------------------------------
declare global temporary table Prune_Msmt_Control (
       MSrc_Cd              CHAR(6) NOT NULL,
       TmSum_Cd             CHAR NOT NULL,
       PMsmtC_Age_In_Days   DECIMAL(8,0) NOT NULL
) 
with replace on commit preserve rows not logged
;

insert into session.Prune_Msmt_Control values ('AMY','H', 300) ;
insert into session.Prune_Msmt_Control values ('AMY', 'D', 00000300);
insert into session.Prune_Msmt_Control values ('AMY', 'W', 00010000);
insert into session.Prune_Msmt_Control values ('AMY', 'M', 00010000);

insert into TWG.Prune_Msmt_Control(MSrc_Cd,TmSum_Cd,PMsmtC_Age_In_Days)
select 
 s.MSrc_Cd,
 s.TmSum_Cd,
 s.PMsmtC_Age_In_Days
from 
 session.Prune_Msmt_Control s
where not exists
( select 1 from
  TWG.Prune_Msmt_Control t
  where
  t.MSrc_Cd = s.MSrc_Cd and
  t.TmSum_Cd = s.TmSum_Cd
     )
; 

--------------
-- TWG.CompTyp
--------------
--
-- Component Type:
-- Defines the type of components or sub-components being monitored.
-- NOTE: CompTyp_Cd is the primary key
--
declare global temporary table AMY_CompTyp (
  CompTyp_Cd           CHAR(17) NOT NULL,
  CompTyp_Parent_Cd    CHAR(17),
  CompTyp_Nm           VARCHAR(120) NOT NULL,
  CompTyp_Strt_DtTm    TIMESTAMP NOT NULL,
  CompTyp_End_DtTm     TIMESTAMP NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.AMY_CompTyp values ('AMY_HOST',      null , 'Host monitored by ITM', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

-- ////////////////////////////////////////////////////
-- /////////// Windows NT/2000/XP Resources ///////////
-- ////////////////////////////////////////////////////

insert into session.AMY_CompTyp values ('AMY_PDISK',     null , 'Physical Disk', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_LDISK',     null , 'Logical Disk', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_PROCESS',   null , 'Process', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_MEMORY',    null , 'Memory', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_REDIR',     null , 'Network Redirector', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_NETSEG',    null , 'Network Segment', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_SERVER',    null , 'Server', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_SERVICE',   null , 'Service', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_PORT',      null , 'Port', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_PRNQUEUE',  null , 'Printer', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_TCPIP',     null , 'TCPIP Protocol', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_IP',        null , 'IP Protocol', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.AMY_CompTyp values ('AMY_SYSTEM',        null , 'System', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

-- ////////////////////////////////////////////////////
-- /////////////// Unix/Linux Resources ///////////////
-- ////////////////////////////////////////////////////

insert into session.AMY_CompTyp values ('AMY_CPU',       null , 'System Processor', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_FILE',      null , 'File', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_FS',        null , 'File System', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_NETWORK',   null , 'Network', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_NFS',       null , 'Network File System', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_RPC',       null , 'Remote Procedure Call', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_USER',      null , 'User', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

-- NOTE: Memory and Process are common to both Windows and UNIX_Linux Resource Models

-- ///////////////////////////////////////
-- //////// OS400 Resource Models ////////
-- ///////////////////////////////////////

insert into session.AMY_CompTyp values ('AMY_OS400DISK',   null , 'System Disk', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_OS400IFCPU',  null , 'Interactive Feature CPU', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_OS400DBCPU',  null , 'Database CPU', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_OS400ICPU',   null , 'Basic Interactive CPU', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_OS400BCPU',   null , 'Basic Average CPU', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_OS400ASP',    null , 'Auxiliary Storage Pool', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.AMY_CompTyp values ('AMY_OS400SPOOL',  null , 'Storage Pools', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into TWG.CompTyp (
  CompTyp_Cd, CompTyp_Parent_Cd,
  CompTyp_Nm, CompTyp_Strt_DtTm,
  CompTyp_End_DtTm )
select * from session.AMY_CompTyp s
where not exists (
  select 1 from
  TWG.Cur_CompTyp t
  where
  t.CompTyp_Cd = s.CompTyp_Cd )
;

--------------
-- TWG.MsmtTyp
--------------
--
-- Measurement Type (this is unique for each application):
-- Defines a type of mesurement that may be collected for a component, based
-- on its Component Type.
--
-- NOTE: records added to TWG.MsmtTyp are enumerated by an ascending sequence
-- on the field MsmtTyp_ID, which is also the primary key of the table; there is
-- also a unique index on the MsmtTyp_Nm field
--
declare global temporary table AMY_MsmtTyp (
  MUnit_Cd             CHAR(6)      NOT NULL,
  MSrc_Cd              CHAR(6)      NOT NULL,
  MsmtTyp_Nm           VARCHAR(120) NOT NULL,
  MsmtTyp_Ds           VARCHAR(254)
)
with replace on commit preserve rows not logged
;

-- ////////////////////////////////////////////////////
-- //////// Windows NT/2000/XP Resource Models ////////
-- ////////////////////////////////////////////////////

--
-- ///////////////
-- TMW_LogicalDisk
-- ///////////////
--
insert into session.AMY_MsmtTyp values ('Bps', 'AMY', 'DiskBytesSec',     'Amount of bytes per second being written or read');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'AvgQLength',       'Average queue length for jobs');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'PercentFreeSpace', 'Percentage of free space on the logical disk');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'PercentDiskTime',  'Percentage of time that the logical drive is being used');

insert into session.AMY_MsmtTyp values ('MB', 'AMY', 'LogicalDiskFreeSpace',  'Amount of free space on locical disks');
insert into session.AMY_MsmtTyp values ('MB', 'AMY', 'LogicalDiskTotalSize',  'Total size of logical disks');
--
-- /////////////////////
-- TMW_PhysicalDiskModel
-- /////////////////////
--
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'WorkingSet',     'Working set');
insert into session.AMY_MsmtTyp values ('B',   'AMY', 'PrivateBytes',   'Number of private bytes used by the process');
insert into session.AMY_MsmtTyp values ('B',   'AMY', 'VirtualBytes',   'Number of virtual bytes used by the process');
insert into session.AMY_MsmtTyp values ('MB',  'AMY', 'TotalAvail',     'Total available memory');
insert into session.AMY_MsmtTyp values ('KB',  'AMY', 'TotalCache',     'Total cache memory');
insert into session.AMY_MsmtTyp values ('B',   'AMY', 'CommittedBytes', 'Bytes committed to this memory');
insert into session.AMY_MsmtTyp values ('Qps', 'AMY', 'PagesSec',       'Number of pages per second');
insert into session.AMY_MsmtTyp values ('Qps', 'AMY', 'PageFaultsSec',  'Rate of page faults per second');
--
-- //////////////////
-- TMW_NetworkIntCard
-- //////////////////
--
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'PercentNetworkUtil',     'Percent of the network being used');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'PercentBroadcastFrames', 'Percent of the network that is broadcast frames');
insert into session.AMY_MsmtTyp values ('Bps', 'AMY', 'BytesTotalSec',          'Rate at which the redirector is processing data');
insert into session.AMY_MsmtTyp values ('Bps', 'AMY', 'CurrentBandwidth',       'Network bandwidth');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'ServerTotalSessions',    'Number of sessions on the server');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'SessionsErroredOut',     'Number of sessions that ended in error');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'SessionsForcedOff',      'Number of sessions forced offline');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'SessionsLoggedOff',      'Number of sessions logged off');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'WorkItemShortages',      'Identifies work item shortages');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'OutputQueueLength',      'Length of the queue for output');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'CurrentCommands',        'Number of requests that are currently queued for the redirector');
--
-- /////////
-- TMW_TCPIP
-- /////////
--
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'SegmentsRetrasmitted', 'Number of segments retransmitted');
insert into session.AMY_MsmtTyp values ('Qps', 'AMY', 'SegmentSentSec',       'Number of segments sent per second');
insert into session.AMY_MsmtTyp values ('Qps', 'AMY', 'SegmentsSec',          'Number of segments per second');
insert into session.AMY_MsmtTyp values ('Qps', 'AMY', 'SegmentRcvdSec',       'Number of segments received per second');
insert into session.AMY_MsmtTyp values ('Qps', 'AMY', 'DGSentSec',            'Number of datagrams sent per second');
insert into session.AMY_MsmtTyp values ('Qps', 'AMY', 'DGSec',                'Number of datagrams per second');
insert into session.AMY_MsmtTyp values ('Qps', 'AMY', 'DGReceivedSec',        'Number of datagrams received per second');
insert into session.AMY_MsmtTyp values ('Qps', 'AMY', 'FragmentsReceivedSec', 'Number of fragments received per second');
--
-- /////////////////
-- TMW_ParamServices
-- /////////////////
--
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'JobErrors',        'Number of jobs in error');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'NotReadyErrors',   'Number of not ready errors');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'OutOfPaperErrors', 'Number of Out-of-Paper errors');
--
-- ///////////
-- TMW_Process
-- ///////////
--
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'HandleCount',           'Number of handles allocated to the process');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'PercentUserTime',       'Percentage usage of the CPU that is being used by the process');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'PercentPrivilegedTime', 'Percentage privileged time of the CPU that is being used by the process');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'PercentProcessorTime',  'Percent of processor time used by the process');
--
-- /////////////
-- TMW_Processor
-- /////////////
--
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'ProcessorQueueLength',  'Queue length of the processor');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'HighestPercentUsage',   'Identifies what percent of the most used processor is being used');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'LowestPercentUsage',    'Identifies what percent of the least used processor is being used');
insert into session.AMY_MsmtTyp values ('Qps', 'AMY', 'InterruptsSec',         'Number of interrupts per second that are passed to the CPU');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'PercentInterruptTime',  'Current percentage usage of the CPU as it handles interrupt requests');

insert into session.AMY_MsmtTyp values ('Sec', 'AMY', 'SystemUpTime',  'Amount of time the system has been running');

-- ////////////////////////////////////////////
-- //////// UNIX_Linux Resource Models ////////
-- ////////////////////////////////////////////

--
-- //////
-- DMXCpu
-- //////
--
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'loadAvg1',    'Number of processes running every minute');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'loadAvg5',    'Number of processes running every 5 minutes');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'loadAvg15',   'Number of processes running every 15 minutes');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'prcIdleTime', 'Percent of the time that the CPU is idle');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'prcSysTime',  'Percent of the time that the CPU is in system mode');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'prcUserTime', 'Percent of the time that the CPU is in user mode');

--
-- ///////
-- DMXFile
-- ///////
--
insert into session.AMY_MsmtTyp values ('B',   'AMY', 'size',             'File size');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'checksum',         'File checksum');
insert into session.AMY_MsmtTyp values ('Sec', 'AMY', 'modificationTime', 'Time when the contents of file change');
insert into session.AMY_MsmtTyp values ('Sec', 'AMY', 'changeTime',       'Time when the file attributes change');
--
-- /////////////
-- DMXFileSystem
-- /////////////
--
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'percUsed',       'Percent of file system space that is being used');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'percInodesUsed', 'Percent of i-nodes being used');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'percAvail',      'Percent of file system space available');

insert into session.AMY_MsmtTyp values ('MB', 'AMY', 'fileSystemFreeSpace', 'Amount of free space on the logical file system');
insert into session.AMY_MsmtTyp values ('MB', 'AMY', 'fileSystemTotalSpace', 'Amount of space allocated for the logical file system');
--
-- /////////
-- DMXMemory
-- /////////
--
insert into session.AMY_MsmtTyp values ('Qps', 'AMY', 'PageInsRate',     'Rate of paging in for the cycle');
insert into session.AMY_MsmtTyp values ('Qps', 'AMY', 'PageOutsRate',    'Rate of paging out for the cycle');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'PrcAvailSwap',    'Percent of swap space that is available');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'PrcAvailStorage', 'Percentage of storage space that is available');

insert into session.AMY_MsmtTyp values ('MB', 'AMY', 'CommitLimit', 'Amount of virtual memory that can be committed without having to extend the paging file(s)');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'PercentCommittedBytesInUse', 'Percentage of committed bytes in relation to the committed limit');
insert into session.AMY_MsmtTyp values ('MB', 'AMY', 'TotalPageFileSize', 'Total amount of page file (swap space) available on all logical disks');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'PercentMemoryUsage', 'Percentage of committed bytes in relation to the total physical memory (RAM) available to the operating system');

--
-- ///////////////////
-- DMXNetworkInterface
-- ///////////////////
--
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'InPacks',     'Total number of input packets');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'InPacksErr',  'Percent of input packets in error');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'OutPacks',    'Total number of output packets');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'OutPackErr',  'Percent of output packets in error');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'OutPackColl', 'Percent of output packets colliding');
--
-- ///////////////////
-- DMXNetworkRPCNFS
-- ///////////////////
--
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'NFScalls',       'NFS calls');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'NFSbadcalls',    'NFS calls that are timed out');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'NFSgetattr',     'NFS requests to read the client attribute cache');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'NFSread',        'NFS read operations');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'NFSwrite',       'NFS write operations');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'NFSlookup',      'Lookup calls on the NFS server');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'NFSreadlink',    'NFS server calls for readlink operations');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'RPCcalls',       'Client RPC calls');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'RPCbadcalls',    'Number of timed-out client RPC calls');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'RPCretrans',     'RPC client calls being retransmitted');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'RPCbadxids',     'Bad xids');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'RPCtimeouts',    'Client RPC calls that timed out');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'RPCDuprequests', 'RPC server calls that are duplicate requests');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'RPCDupchecks',   'Number of RPC server calls that are looked up in the duplicate request cache');
--
-- //////////
-- DMXProcess
-- //////////
--
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'PercentProcessUsage', 'Percentage of CPU that the process is using');

--
-- ///////////
-- DMXSecurity
-- ///////////
--
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'numLogged', 'Number of times the user is logged in');
--
-- //////
-- DMXSpp
-- //////
--

-- ////////////////////////////////////////////
-- ////////// OS400 Resource Models ///////////
-- ////////////////////////////////////////////

--
-- /////////////////
-- ASPUtilization400
-- /////////////////
--
insert into session.AMY_MsmtTyp values ('MB',  'AMY', 'overflowStorageMBytes',          'Number of megabytes exceeding the ASP capacity');
insert into session.AMY_MsmtTyp values ('PRC', 'AMY', 'totalAvailableMBytesPercentage', 'Percentage of total available megabytes in the ASP');
--
-- ///////////
-- BasicCPU400
-- ///////////
--
insert into session.AMY_MsmtTyp values ('PRC',  'AMY', 'basicAverageCPUPct', 'Percentage of overall CPU utilization');
insert into session.AMY_MsmtTyp values ('QTY',  'AMY', 'numOfProcessors',    'Number of available CPUs for the system or partition');
--
-- //////////////////////
-- BasicInteractiveCPU400
-- //////////////////////
--
insert into session.AMY_MsmtTyp values ('PRC',  'AMY', 'basicInteractiveCPUPct', 'Percentage of interactive CPU utilization');
--
-- /////////////////////////
-- DatabaseCPUUtilization400
-- /////////////////////////
--
insert into session.AMY_MsmtTyp values ('PRC',  'AMY', 'databaseCapabilityCPUPct', 'Percentage of database CPU utilization');
insert into session.AMY_MsmtTyp values ('PRC',  'AMY', 'databaseThresholdPct', 'Percentage of database CPU utilization allowed before performance problems occur');
--
-- ///////////////////////////////////
-- InteractiveFeatureCPUUtilization400
-- ///////////////////////////////////
--
insert into session.AMY_MsmtTyp values ('PRC',  'AMY', 'interactiveThresholdPct', 'Percentage of interactive CPU utilization allowed before performance problems occur');
--
-- //////////////////////
-- SystemDiskResources400
-- //////////////////////
--
insert into session.AMY_MsmtTyp values ('PRC',  'AMY', 'systemASPUsedPct', 'Percentage of the system ASP which is used');
insert into session.AMY_MsmtTyp values ('PRC',  'AMY', 'totalAuxiliaryStorageAvailablePercentage', 'Percentage of total auxiliary storage available');
--
-- ///////////////
-- StoragePools400
-- ///////////////
--
insert into session.AMY_MsmtTyp values ('Qps', 'AMY', 'databaseFaults', 'Rate of database page faults in page faults per second');
insert into session.AMY_MsmtTyp values ('Qps', 'AMY', 'nonDatabaseFaults', 'Rate of Non-database page faults in page faults per second');
insert into session.AMY_MsmtTyp values ('Qps', 'AMY', 'databasePages', 'Rate at which database pages are brought into the storage pool in pages per second');
insert into session.AMY_MsmtTyp values ('Qps', 'AMY', 'nonDatabasePages', 'Rate at which Non-database pages are brought into the storage pool in pages per second');
insert into session.AMY_MsmtTyp values ('Qpm', 'AMY', 'activeToWaitTransitions', 'Rate of transitions of threads from an active condition to a waiting condition in transitions per minute');
insert into session.AMY_MsmtTyp values ('Qpm', 'AMY', 'activeToIneligibleTransitions', 'Rate of transitions of threads from an active condition to an ineligible condition in transitions per minute');
insert into session.AMY_MsmtTyp values ('Qpm', 'AMY', 'waitToIneligibleTransitions', 'Rate of transitions of threads from a waiting condition to an ineligible condition in transitions per minute');
insert into session.AMY_MsmtTyp values ('QTY', 'AMY', 'activityLevel', 'Maximum number of threads that can be active in the pool at any one time');
insert into session.AMY_MsmtTyp values ('MB',  'AMY', 'totalSizeMBytes', 'Amount of main storage in the pool');

insert into TWG.MsmtTyp (
  MUnit_Cd, MSrc_Cd,
  MsmtTyp_Nm, MsmtTyp_Ds )
select * from session.AMY_MsmtTyp s
where not exists (
  select 1 from
  TWG.MsmtTyp t
  where
  t.MsmtTyp_Nm = s.MsmtTyp_Nm )
;

--------------
-- TWG.MsmtRul
--------------
--
-- Measurement Rule: (this is unique for each application)
-- Defines which types of measurements are appropriate for which types of components.
--
declare global temporary table AMY_MsmtRul (
  CompTyp_Cd   char(17) not null,
  MsmtTyp_ID   integer not null
)
with replace on commit preserve rows not logged
;

-- ////////////////////////////////////////////////////
-- //////// Windows NT/2000/XP Resource Models ////////
-- ////////////////////////////////////////////////////

insert into session.AMY_MsmtRul
select 'AMY_PDISK', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'DiskBytesSec', 'AvgQLength', 'PercentDiskTime' );

insert into session.AMY_MsmtRul
select 'AMY_LDISK', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'DiskBytesSec', 'AvgQLength', 'PercentDiskTime', 'PercentFreeSpace',
'LogicalDiskFreeSpace','LogicalDiskTotalSize' );

insert into session.AMY_MsmtRul
select 'AMY_PROCESS', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'HandleCount', 'PercentUserTime', 'PercentPrivilegedTime', 'PercentProcessorTime',
'WorkingSet', 'PrivateBytes', 'VirtualBytes' );

insert into session.AMY_MsmtRul
select 'AMY_MEMORY', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'TotalAvail', 'TotalCache', 'CommittedBytes', 'PagesSec', 'PageFaultsSec', 
'CommitLimit', 'PercentCommittedBytesInUse','TotalPageFileSize','PercentMemoryUsage' );

insert into session.AMY_MsmtRul
select 'AMY_REDIR', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'BytesTotalSec', 'CurrentCommands' );

insert into session.AMY_MsmtRul
select 'AMY_NETSEG', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'PercentNetworkUtil', 'PercentBroadcastFrames' );

insert into session.AMY_MsmtRul
select 'AMY_SERVER', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'BytesTotalSec', 'ServerTotalSessions', 'SessionsErroredOut', 'SessionsForcedOff',
'SessionsLoggedOff', 'WorkItemShortages' );

insert into session.AMY_MsmtRul
select 'AMY_NETWORK', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'BytesTotalSec', 'CurrentBandwidth', 'OutputQueueLength' );

--insert into session.AMY_MsmtRul
--select 'AMY_SERVICE', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
--'');

--insert into session.AMY_MsmtRul
--select 'AMY_PORT', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
--'');

insert into session.AMY_MsmtRul
select 'AMY_PRNQUEUE', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'JobErrors', 'NotReadyErrors', 'OutOfPaperErrors' );

insert into session.AMY_MsmtRul
select 'AMY_CPU', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'HighestPercentUsage', 'LowestPercentUsage', 'InterruptsSec', 'PercentInterruptTime' ,
'PercentProcessorTime', 'PercentPrivilegedTime', 'PercentUserTime','ProcessorQueueLength');

insert into session.AMY_MsmtRul
select 'AMY_SYSTEM', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'SystemUpTime'
);

insert into session.AMY_MsmtRul
select 'AMY_TCPIP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'SegmentsRetrasmitted', 'SegmentSentSec', 'SegmentsSec', 'SegmentRcvdSec' );

insert into session.AMY_MsmtRul
select 'AMY_IP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'DGSentSec', 'DGSec', 'DGReceivedSec', 'FragmentsReceivedSec' );

-- ////////////////////////////////////////////
-- //////// UNIX_Linux Resource Models ////////
-- ////////////////////////////////////////////

insert into session.AMY_MsmtRul
select 'AMY_CPU', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'prcIdleTime', 'prcSysTime', 'prcUserTime', 'loadAvg1', 'loadAvg5', 'loadAvg15',
'SystemUpTime');

insert into session.AMY_MsmtRul
select 'AMY_FILE', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'size', 'modificationTime', 'changeTime', 'checksum' );

insert into session.AMY_MsmtRul
select 'AMY_FS', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'percUsed', 'percInodesUsed','percAvail',
'fileSystemFreeSpace',
'fileSystemTotalSpace');

insert into session.AMY_MsmtRul
select 'AMY_NETWORK', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'InPacks', 'InPacksErr', 'OutPacks', 'OutPackErr', 'OutPackColl' );

insert into session.AMY_MsmtRul
select 'AMY_NFS', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'NFScalls', 'NFSbadcalls', 'NFSgetattr', 'NFSread', 'NFSwrite', 'NFSlookup', 'NFSreadlink' );

insert into session.AMY_MsmtRul
select 'AMY_RPC', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'RPCcalls', 'RPCbadcalls', 'RPCretrans', 'RPCbadxids', 'RPCtimeouts', 'RPCDuprequests', 'RPCDupchecks' );

insert into session.AMY_MsmtRul
select 'AMY_USER', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'numLogged' );

insert into session.AMY_MsmtRul
select 'AMY_MEMORY', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'PageInsRate', 'PageOutsRate', 'PrcAvailSwap', 'PrcAvailStorage' );

insert into session.AMY_MsmtRul
select 'AMY_PROCESS', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'PercentProcessUsage' );

-- ////////////////////////////////////////////
-- ////////// OS400 Resource Models ///////////
-- ////////////////////////////////////////////

insert into session.AMY_MsmtRul
select 'AMY_OS400ASP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'overflowStorageMBytes', 'totalAvailableMBytesPercentage' );

insert into session.AMY_MsmtRul
select 'AMY_OS400BCPU', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'basicAverageCPUPct', 'numOfProcessors' );

insert into session.AMY_MsmtRul
select 'AMY_OS400ICPU', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'numOfProcessors', 'basicInteractiveCPUPct' );

insert into session.AMY_MsmtRul
select 'AMY_OS400DBCPU', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'databaseCapabilityCPUPct', 'databaseThresholdPct' );

insert into session.AMY_MsmtRul
select 'AMY_OS400IFCPU', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'interactiveThresholdPct', 'basicInteractiveCPUPct' );

insert into session.AMY_MsmtRul
select 'AMY_OS400DISK', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'systemASPUsedPct', 'totalAuxiliaryStorageAvailablePercentage' );

insert into session.AMY_MsmtRul
select 'AMY_OS400SPOOL', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='AMY' and MsmtTyp_Nm in (
'databaseFaults', 'nonDatabaseFaults', 'databasePages', 'nonDatabasePages',
'activeToWaitTransitions', 'activeToIneligibleTransitions', 'waitToIneligibleTransitions',
'activityLevel', 'totalSizeMBytes' );

insert into TWG.MsmtRul (
  CompTyp_Cd, MsmtTyp_ID )
select * from session.AMY_MsmtRul s
where not exists (
  select 1 from
  TWG.MsmtRul t
  where
  t.MsmtTyp_ID = s.MsmtTyp_ID and
  t.CompTyp_Cd = s.CompTyp_Cd
);

--------------
-- TWG.AttrTyp
--------------
--
-- Attribute Types:
-- Defines the type of caractheristics or properties that may be captured about a component.
--
--
declare global temporary table AMY_AttrTyp (
  AttrTyp_Cd    CHAR(17) NOT NULL,
  AttrTyp_Nm    VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

-- NOTE: The endpoints table contains 2 information that do not exist in the
-- CDW by default, which are the endpoint id (EID) and the GMT offset (GMT_OFFSET).
-- This requires two new attributes AMX_EID and AMX_GMT_OFFSET under the <AVA>_HOST
-- that are inserted by the prereq Generic ETL1 pack (AMX)...

-- ////////////////////////////////////////////////////
-- //////// Windows NT/2000/XP Resource Models ////////
-- ////////////////////////////////////////////////////

-- Attributes of Process Resource
insert into session.AMY_AttrTyp values ('AMY_PROCNM',        'Process name');
insert into session.AMY_AttrTyp values ('AMY_PROCID',        'Process ID');

-- Attributes of Service Resource
insert into session.AMY_AttrTyp values ('AMY_SERVICESTATE',  'Service state');
insert into session.AMY_AttrTyp values ('AMY_SERVICESTATUS', 'Service status');

-- Attributes of Port Resource
insert into session.AMY_AttrTyp values ('AMY_PORTSTATE',     'Port state');

-- Attributes of Memory Resource
insert into session.AMY_AttrTyp values ('AMY_VISPHYSMEMORY',     'Total amount of visible physical memory available to the operating system');

-- ////////////////////////////////////////////
-- //////// UNIX_Linux Resource Models ////////
-- ////////////////////////////////////////////

-- Attributes of File Resource
insert into session.AMY_AttrTyp values ('AMY_FPATHNM',    'Full path to the file');
insert into session.AMY_AttrTyp values ('AMY_FGROUP',     'File group');
insert into session.AMY_AttrTyp values ('AMY_FOWNER',     'Owner of the file');
insert into session.AMY_AttrTyp values ('AMY_FMODE',      'Type of access permission to the file');

-- Attributes of User Resource
insert into session.AMY_AttrTyp values ('AMY_USRID',      'ID of the suspicious user');

insert into TWG.AttrTyp (
  AttrTyp_Cd, AttrTyp_Nm )
select * from session.AMY_AttrTyp s
where not exists (
  select 1 from
  TWG.AttrTyp t
  where
  t.AttrTyp_Cd = s.AttrTyp_Cd )
;

--------------
-- TWG.MGrpTyp
--------------
--
-- Measurement Group Type:
-- A high-level classification for a measurement group; it is used to
-- distinguish between Measurement Groups set up for different reason,
-- e.g. categorization v.s. monitoring collections.
--
declare global temporary table AMY_MGrpTyp (
  MGrpTyp_Cd           CHAR(6) NOT NULL,
  MGrpTyp_Nm           VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.AMY_MGrpTyp values ('ITM', 'ITM Monitoring Collection for Operating Systems');

insert into TWG.MGrpTyp (
  MGrpTyp_Cd, MGrpTyp_Nm )
select * from session.AMY_MGrpTyp s
where not exists (
  select 1 from
  TWG.MGrpTyp t
  where
  t.MGrpTyp_Cd = s.MGrpTyp_Cd )
;

-----------
-- TWG.MGrp
-----------
--
-- Measurement Group:
-- Measurements may be grouped in various ways; for example they may be grouped
-- into categories such as Capacity, Availability, Performance, Utilization, Errors
-- or into monitoring collections, i.e. measurements that are grouped togheter
-- as part of a particular monitoring activity.
--
declare global temporary table AMY_MGrp (
  MGrp_Cd           char(6) not null,
  MGrpTyp_Cd        char(6) not null,
  MGrp_Parent_Cd    char(6),
  MGrp_Nm           varchar(120) not null
)
with replace on commit preserve rows not logged
;

-- NOTE: STORAG, AVG_E, MIN_E, MAX_E and TOT_E are common to every other PAC enablement
-- and are inserted by the prereq Generic ETL1 pack (AMX)...

-- specific to ITM Monitoring Collection for Operating Systems...
insert into session.AMY_MGrp values ('CPU_E', 'ITM', NULL, 'CPU');
insert into session.AMY_MGrp values ('MEM_E', 'ITM', NULL, 'Memory');
insert into session.AMY_MGrp values ('NIC_E', 'ITM', NULL, 'Network interface');
insert into session.AMY_MGrp values ('HD_E',  'ITM', NULL, 'I/O');
insert into session.AMY_MGrp values ('FS_E',  'ITM', NULL, 'File system');
insert into session.AMY_MGrp values ('SEC_E', 'ITM', NULL, 'Security');
insert into session.AMY_MGrp values ('PRN_E', 'ITM', NULL, 'Printer');

insert into TWG.MGrp (
  MGrp_Cd, MGrpTyp_Cd,
  MGrp_Parent_Cd, MGrp_Nm )
select * from session.AMY_MGrp s
where not exists (
  select 1 from
  TWG.MGrp t
  where
  t.MGrpTyp_Cd = s.MGrpTyp_Cd and
  t.MGrp_Cd = s.MGrp_Cd )
;

--------------
-- TWG.MGrpMbr
--------------
--
-- Measurement Group Member:
-- Defines a type of measurement within a particular grouping (Measurement Group);
-- a Measurement Type may be a member of several Measurement Groups.
--
declare global temporary table AMY_MGrpMbr (
  MGrp_Cd      char(6) not null,
  MGrpTyp_Cd   char(6) not null,
  MsmtTyp_ID   integer not null
)
with replace on commit preserve rows not logged
;

-- ////////////////////////////////////////////////////////////////////////////////////
-- MIN_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ///// Windows NT/2000/XP Resource Models
insert into session.AMY_MGrpMbr
select 'MIN_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in (
'DiskBytesSec', 'AvgQLength', 'PercentFreeSpace', 'PercentDiskTime', 'WorkingSet',
'PrivateBytes', 'VirtualBytes', 'TotalAvail', 'TotalCache', 'CommittedBytes',
'PagesSec', 'PageFaultsSec', 'BytesTotalSec', 'CurrentCommands', 'PercentNetworkUtil',
'PercentBroadcastFrames', 'ServerTotalSessions', 'SessionsErroredOut', 'SessionsForcedOff',
'SessionsLoggedOff', 'WorkItemShortages', 'CurrentBandwidth', 'OutputQueueLength',
'JobErrors', 'NotReadyErrors', 'OutOfPaperErrors', 'HandleCount', 'PercentUserTime',
'PercentPrivilegedTime', 'PercentProcessorTime', 'HighestPercentUsage', 'LowestPercentUsage',
'Delta', 'InterruptsSec', 'PercentInterruptTime', 'ProcessorQueueLength', 'SegmentsRetrasmitted',
'SegmentSentSec', 'SegmentsSec', 'SegmentRcvdSec', 'DGSentSec', 'DGSec', 'DGReceivedSec',
'FragmentsReceivedSec',
'CommitLimit', 'PercentCommittedBytesInUse', 'TotalPageFileSize', 'PercentMemoryUsage','SystemUpTime','LogicalDiskFreeSpace','LogicalDiskTotalSize',
-- ////// UNIX_Linux Resource Models
'prcIdleTime', 'prcSysTime', 'prcUserTime', 'loadAvg1', 'loadAvg5', 'loadAvg15',
'size', 'percUsed', 'percInodesUsed','percAvail', 'PageInsRate',
'PageOutsRate', 'PrcAvailSwap', 'PrcAvailStorage', 'InPacks', 'InPacksErr', 'OutPacks',
'OutPackErr', 'OutPackColl', 'NFScalls', 'NFSbadcalls', 'NFSgetattr', 'NFSread',
'NFSwrite', 'NFSlookup', 'NFSreadlink', 'RPCcalls', 'RPCbadcalls', 'RPCretrans',
'RPCbadxids', 'RPCtimeouts', 'RPCCalls', 'RPCBadcalls', 'RPCDuprequests',
'RPCDupchecks', 'PercentProcessUsage', 'numLogged',
'fileSystemFreeSpace', 'fileSystemTotalSpace',
-- ////// OS400 Resource Models
'overflowStorageMBytes', 'totalAvailableMBytesPercentage', 'basicAverageCPUPct',
'numOfProcessors', 'basicInteractiveCPUPct', 'databaseCapabilityCPUPct',
'databaseThresholdPct', 'interactiveThresholdPct', 'systemASPUsedPct',
'totalAuxiliaryStorageAvailablePercentage', 'databaseFaults', 'nonDatabaseFaults',
'databasePages', 'nonDatabasePages', 'activeToWaitTransitions',
'activeToIneligibleTransitions', 'waitToIneligibleTransitions', 'activityLevel',
'totalSizeMBytes'
);

-- ////////////////////////////////////////////////////////////////////////////////////
-- MAX_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ///// Windows NT/2000/XP Resource Models
insert into session.AMY_MGrpMbr
select 'MAX_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in (
'DiskBytesSec', 'AvgQLength', 'PercentFreeSpace', 'PercentDiskTime', 'WorkingSet',
'PrivateBytes', 'VirtualBytes', 'TotalAvail', 'TotalCache', 'CommittedBytes',
'PagesSec', 'PageFaultsSec', 'BytesTotalSec', 'CurrentCommands', 'PercentNetworkUtil',
'PercentBroadcastFrames', 'ServerTotalSessions', 'SessionsErroredOut', 'SessionsForcedOff',
'SessionsLoggedOff', 'WorkItemShortages', 'CurrentBandwidth', 'OutputQueueLength',
'JobErrors', 'NotReadyErrors', 'OutOfPaperErrors', 'HandleCount', 'PercentUserTime',
'PercentPrivilegedTime', 'PercentProcessorTime', 'HighestPercentUsage', 'LowestPercentUsage',
'Delta', 'InterruptsSec', 'PercentInterruptTime', 'ProcessorQueueLength', 'SegmentsRetrasmitted',
'SegmentSentSec', 'SegmentsSec', 'SegmentRcvdSec', 'DGSentSec', 'DGSec', 'DGReceivedSec',
'FragmentsReceivedSec',
'CommitLimit', 'PercentCommittedBytesInUse', 'TotalPageFileSize', 'PercentMemoryUsage','SystemUpTime','LogicalDiskFreeSpace','LogicalDiskTotalSize',
-- //////// UNIX_Linux Resource Models ////////
'prcIdleTime', 'prcSysTime', 'prcUserTime', 'loadAvg1', 'loadAvg5', 'loadAvg15',
'size', 'percUsed', 'percInodesUsed','percAvail', 'PageInsRate',
'PageOutsRate', 'PrcAvailSwap', 'PrcAvailStorage', 'InPacks', 'InPacksErr', 'OutPacks',
'OutPackErr', 'OutPackColl', 'NFScalls', 'NFSbadcalls', 'NFSgetattr', 'NFSread',
'NFSwrite', 'NFSlookup', 'NFSreadlink', 'RPCcalls', 'RPCbadcalls', 'RPCretrans',
'RPCbadxids', 'RPCtimeouts', 'RPCCalls', 'RPCBadcalls', 'RPCDuprequests',
'RPCDupchecks', 'PercentProcessUsage', 'numLogged',
'fileSystemFreeSpace', 'fileSystemTotalSpace',
-- ////// OS400 Resource Models
'overflowStorageMBytes', 'totalAvailableMBytesPercentage', 'basicAverageCPUPct',
'numOfProcessors', 'basicInteractiveCPUPct', 'databaseCapabilityCPUPct',
'databaseThresholdPct', 'interactiveThresholdPct', 'systemASPUsedPct',
'totalAuxiliaryStorageAvailablePercentage', 'databaseFaults', 'nonDatabaseFaults',
'databasePages', 'nonDatabasePages', 'activeToWaitTransitions',
'activeToIneligibleTransitions', 'waitToIneligibleTransitions', 'activityLevel',
'totalSizeMBytes'
);

-- ////////////////////////////////////////////////////////////////////////////////////
-- AVG_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ///// Windows NT/2000/XP Resource Models
insert into session.AMY_MGrpMbr
select 'AVG_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in (
'DiskBytesSec', 'AvgQLength', 'PercentFreeSpace', 'PercentDiskTime', 'WorkingSet',
'PrivateBytes', 'VirtualBytes', 'TotalAvail', 'TotalCache', 'CommittedBytes',
'PagesSec', 'PageFaultsSec', 'BytesTotalSec', 'CurrentCommands', 'PercentNetworkUtil',
'PercentBroadcastFrames', 'ServerTotalSessions', 'SessionsErroredOut', 'SessionsForcedOff',
'SessionsLoggedOff', 'WorkItemShortages', 'CurrentBandwidth', 'OutputQueueLength',
'JobErrors', 'NotReadyErrors', 'OutOfPaperErrors', 'HandleCount', 'PercentUserTime',
'PercentPrivilegedTime', 'PercentProcessorTime', 'HighestPercentUsage', 'LowestPercentUsage',
'Delta', 'InterruptsSec', 'PercentInterruptTime', 'ProcessorQueueLength', 'SegmentsRetrasmitted',
'SegmentSentSec', 'SegmentsSec', 'SegmentRcvdSec', 'DGSentSec', 'DGSec', 'DGReceivedSec',
'FragmentsReceivedSec',
'CommitLimit', 'PercentCommittedBytesInUse', 'TotalPageFileSize', 'PercentMemoryUsage','SystemUpTime','LogicalDiskFreeSpace','LogicalDiskTotalSize',
-- ////// UNIX_Linux Resource Models
'prcIdleTime', 'prcSysTime', 'prcUserTime', 'loadAvg1', 'loadAvg5', 'loadAvg15',
'size', 'percUsed', 'percInodesUsed','percAvail', 'PageInsRate',
'PageOutsRate', 'PrcAvailSwap', 'PrcAvailStorage', 'InPacks', 'InPacksErr', 'OutPacks',
'OutPackErr', 'OutPackColl', 'NFScalls', 'NFSbadcalls', 'NFSgetattr', 'NFSread',
'NFSwrite', 'NFSlookup', 'NFSreadlink', 'RPCcalls', 'RPCbadcalls', 'RPCretrans',
'RPCbadxids', 'RPCtimeouts', 'RPCCalls', 'RPCBadcalls', 'RPCDuprequests',
'RPCDupchecks', 'PercentProcessUsage', 'numLogged',
'fileSystemFreeSpace', 'fileSystemTotalSpace',
-- ////// OS400 Resource Models
'overflowStorageMBytes', 'totalAvailableMBytesPercentage', 'basicAverageCPUPct',
'numOfProcessors', 'basicInteractiveCPUPct', 'databaseCapabilityCPUPct',
'databaseThresholdPct', 'interactiveThresholdPct', 'systemASPUsedPct',
'totalAuxiliaryStorageAvailablePercentage', 'databaseFaults', 'nonDatabaseFaults',
'databasePages', 'nonDatabasePages', 'activeToWaitTransitions',
'activeToIneligibleTransitions', 'waitToIneligibleTransitions', 'activityLevel',
'totalSizeMBytes'
);

-- ////////////////////////////////////////////////////////////////////////////////////
-- TOT_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ///// Windows NT/2000/XP Resource Models
-- ///// UNIX_Linux Resource Models
-- ///// OS400 Resource Models

-- ////////////////////////////////////////////////////////////////////////////////////
-- STORAG /////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ///// Windows NT/2000/XP Resource Models
insert into session.AMY_MGrpMbr
select 'STORAG','CATEG', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in (
'DiskBytesSec', 'AvgQLength', 'PercentDiskTime', 'PercentFreeSpace', 'PercentDiskTime',
-- ////// UNIX_Linux Resource Models
'size', 'percUsed', 'percInodesUsed','percAvail',
-- ////// OS400 Resource Models
'overflowStorageMBytes', 'totalAvailableMBytesPercentage', 'systemASPUsedPct',
'totalAuxiliaryStorageAvailablePercentage'
);

----------------------------------------------------------------------
-- specific to ITM Monitoring Collection for Operating System (ITM)...
----------------------------------------------------------------------

-- ////////////////////////////////////////////////////////////////////////////////////
-- CPU_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ///// Windows NT/2000/XP Resource Models
insert into session.AMY_MGrpMbr
select 'CPU_E','ITM', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in (
'HandleCount', 'PercentUserTime', 'PercentPrivilegedTime', 'PercentProcessorTime',
'WorkingSet', 'PrivateBytes', 'VirtualBytes', 'HighestPercentUsage', 'LowestPercentUsage',
'InterruptsSec', 'PercentInterruptTime', 'ProcessorQueueLength', 'Delta',
-- ////// UNIX_Linux Resource Models
'prcIdleTime', 'prcSysTime', 'prcUserTime', 'loadAvg1', 'loadAvg5', 'loadAvg15',
'PercentProcessUsage' ,
-- ////// OS400 Resource Models
'basicAverageCPUPct', 'numOfProcessors', 'basicInteractiveCPUPct',
'databaseCapabilityCPUPct', 'databaseThresholdPct', 'interactiveThresholdPct'
);

-- ////////////////////////////////////////////////////////////////////////////////////
-- MEM_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ///// Windows NT/2000/XP Resource Models
insert into session.AMY_MGrpMbr
select 'MEM_E','ITM', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in (
'TotalAvail', 'TotalCache', 'CommittedBytes', 'PagesSec', 'PageFaultsSec',
'PrcAvailStorage',
'CommitLimit', 'PercentCommittedBytesInUse', 'TotalPageFileSize','PercentMemoryUsage',
-- ////// UNIX_Linux Resource Models
'PrcAvailSwap', 'PageOutsRate', 'PageInsRate',
-- ////// OS400 Resource Models
'databaseFaults', 'nonDatabaseFaults', 'databasePages', 'nonDatabasePages',
'activeToWaitTransitions', 'activeToIneligibleTransitions',
'waitToIneligibleTransitions', 'activityLevel', 'totalSizeMBytes'
);

-- ////////////////////////////////////////////////////////////////////////////////////
-- NIC_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ///// Windows NT/2000/XP Resource Models
insert into session.AMY_MGrpMbr
select 'NIC_E','ITM', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in (
'BytesTotalSec', 'CurrentCommands', 'PercentNetworkUtil', 'PercentBroadcastFrames',
'WorkItemShortages', 'BytesTotalSec', 'CurrentBandwidth',
'OutputQueueLength', 'SegmentsRetrasmitted', 'SegmentSentSec', 'SegmentsSec',
'SegmentRcvdSec', 'DGSentSec', 'DGSec', 'DGReceivedSec', 'FragmentsReceivedSec' ,
-- ////// UNIX_Linux Resource Models
'InPacks', 'InPacksErr', 'OutPacks', 'OutPackErr', 'OutPackColl', 'NFScalls',
'NFSbadcalls', 'NFSgetattr', 'NFSread', 'NFSwrite', 'NFSlookup', 'NFSreadlink',
'RPCcalls', 'RPCbadcalls', 'RPCretrans', 'RPCbadxids', 'RPCtimeouts', 'RPCDuprequests',
'RPCDupchecks'
-- ////// OS400 Resource Models
);

-- ////////////////////////////////////////////////////////////////////////////////////
-- HD_E ///////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ///// Windows NT/2000/XP Resource Models
insert into session.AMY_MGrpMbr
select 'HD_E','ITM', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in (
'DiskBytesSec', 'AvgQLength', 'PercentDiskTime', 'PercentFreeSpace',
'LogicalDiskFreeSpace','LogicalDiskTotalSize',
-- ////// UNIX_Linux Resource Models

-- ////// OS400 Resource Models
'systemASPUsedPct', 'totalAuxiliaryStorageAvailablePercentage'
);

-- ////////////////////////////////////////////////////////////////////////////////////
-- FS_E ///////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ///// Windows NT/2000/XP Resource Models
insert into session.AMY_MGrpMbr
select 'FS_E','ITM', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in (
-- ////// UNIX_Linux Resource Models
'size', 'modificationTime', 'changeTime', 'checksum', 'percUsed', 'percInodesUsed','percAvail',
'fileSystemFreeSpace','fileSystemTotalSpace',
-- ////// OS400 Resource Models
'overflowStorageMBytes', 'totalAvailableMBytesPercentage'
);

-- ////////////////////////////////////////////////////////////////////////////////////
-- SEC_E ///////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ///// Windows NT/2000/XP Resource Models
insert into session.AMY_MGrpMbr
select 'SEC_E','ITM', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in (
'ServerTotalSessions', 'SessionsErroredOut', 'SessionsForcedOff', 'SessionsLoggedOff',
-- ////// UNIX_Linux Resource Models
'numLogged'
-- ////// OS400 Resource Models
);

-- ////////////////////////////////////////////////////////////////////////////////////
-- PRN_E ///////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ///// Windows NT/2000/XP Resource Models
insert into session.AMY_MGrpMbr
select 'PRN_E','ITM', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in (
'JobErrors', 'NotReadyErrors', 'OutOfPaperErrors'
-- ////// UNIX_Linux Resource Models
-- ////// OS400 Resource Models
);

insert into TWG.MGrpMbr (
  MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID )
select * from session.AMY_MGrpMbr s
where not exists (
  select 1 from
  TWG.MGrpMbr t
  where
  t.MGrpTyp_Cd = s.MGrpTyp_Cd and
  t.MGrp_Cd = s.MGrp_Cd and
  t.MsmtTyp_ID = s.MsmtTyp_ID )
;

--------------
-- TWG.RelnRul
--------------
--
-- Relationship Rule:
-- Defines which types of components may participate in which type of relationships.
--
declare global temporary table AMY_RelnRul (
  CompTyp_Source_Cd    CHAR(17) NOT NULL,
  CompTyp_Target_Cd    CHAR(17) NOT NULL,
  RelnTyp_Cd           CHAR(6) NOT NULL,
  RelnRul_Strt_DtTm    TIMESTAMP NOT NULL,
  RelnRul_End_DtTm     TIMESTAMP NOT NULL
)
with replace on commit preserve rows not logged
;

-- ////////////////////////////////////////////////////
-- //////// Windows NT/2000/XP Resource Models ////////
-- ////////////////////////////////////////////////////

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_PDISK','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_PDISK','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_LDISK','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_LDISK','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_PROCESS','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_PROCESS','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_MEMORY','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_MEMORY','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_REDIR','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_REDIR','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_NETSEG','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_NETSEG','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_SERVER','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_SERVER','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_SERVICE','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_SERVICE','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_PORT','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_PORT','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_PRNQUEUE','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_PRNQUEUE','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_TCPIP','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_TCPIP','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_IP','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_IP','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

-- ////////////////////////////////////////////
-- //////// UNIX_Linux Resource Models ////////
-- ////////////////////////////////////////////

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_CPU','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_CPU','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_FILE','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_FILE','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_FS','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_FS','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_NETWORK','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_NETWORK','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_NFS','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_NFS','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_RPC','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_RPC','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_USER','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_USER','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

-- ////////////////////////////////////////////
-- ////////// OS400 Resource Models ///////////
-- ////////////////////////////////////////////

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_OS400DISK','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_OS400DISK','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_OS400IFCPU','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_OS400IFCPU','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_OS400DBCPU','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_OS400DBCPU','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_OS400ICPU','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_OS400ICPU','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_OS400BCPU','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_OS400BCPU','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_OS400ASP','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_OS400ASP','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('AMY_HOST','AMY_OS400SPOOL','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_OS400SPOOL','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into TWG.RelnRul (
  CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd,
  RelnRul_Strt_DtTm, RelnRul_End_DtTm )
select * from session.AMY_RelnRul s
where not exists (
  select 1 from
  TWG.RelnRul t
  where
  t.CompTyp_Source_Cd = s.CompTyp_Source_Cd and
  t.CompTyp_Target_Cd = s.CompTyp_Target_Cd and
  t.RelnTyp_Cd = s.RelnTyp_Cd )
;

--------------
-- TWG.AttrRul
--------------
--
-- Attribute Rule:
-- Defines which type of attributes may be tracked for which types of components.
-- NOTE: the fields (CompTyp_Cd, AttrTyp_Cd) constitute the primary key of the table
--
declare global temporary table AMY_AttrRul (
  CompTyp_Cd           CHAR(17) NOT NULL,
  AttrTyp_Cd           CHAR(17) NOT NULL,
  AttrRul_Strt_DtTm    TIMESTAMP NOT NULL,
  AttrRul_End_DtTm     TIMESTAMP NOT NULL,
  AttrRul_Dom_Ind      CHAR NOT NULL
)
with replace on commit preserve rows not logged
;
--
-- The endpoints table contains 2 information that do not exist in the CDW by default,
-- which are the endpoint id (EID) and the GMT offset (GMT_OFFSET).
-- This requires two new attributes AMX_EID and AMX_GMT_OFFSET under the <AVA>_HOST.
-- that are inserted by the prereq Generic ETL1 pack (AMX)...
--
insert into session.AMY_AttrRul values ('AMY_HOST','AMX_GMT_OFFSET',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AMY_AttrRul values ('AMY_HOST','AMX_EID',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');

-- ////////////////////////////////////////////////////
-- //////// Windows NT/2000/XP Resource Models ////////
-- ////////////////////////////////////////////////////

insert into session.AMY_AttrRul values ('AMY_PROCESS','AMY_PROCNM',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AMY_AttrRul values ('AMY_PROCESS','AMY_PROCID',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AMY_AttrRul values ('AMY_SERVICE','AMY_SERVICESTATE',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AMY_AttrRul values ('AMY_SERVICE','AMY_SERVICESTATUS',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AMY_AttrRul values ('AMY_PORT','AMY_PORTSTATE',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AMY_AttrRul values ('AMY_MEMORY','AMY_VISPHYSMEMORY',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');

-- ////////////////////////////////////////////
-- //////// UNIX_Linux Resource Models ////////
-- ////////////////////////////////////////////

insert into session.AMY_AttrRul values ('AMY_FILE','AMY_FPATHNM',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AMY_AttrRul values ('AMY_FILE','AMY_FGROUP',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AMY_AttrRul values ('AMY_FILE','AMY_FOWNER',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.AMY_AttrRul values ('AMY_FILE','AMY_FMODE',current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');

insert into session.AMY_AttrRul values ('AMY_USER','AMY_USRID', current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');

insert into TWG.AttrRul (
  CompTyp_Cd, AttrTyp_Cd, AttrRul_Strt_DtTm,
  AttrRul_End_DtTm, AttrRul_Dom_Ind )
select * from session.AMY_AttrRul s
where not exists (
  select 1 from
  TWG.AttrRul t
  where
  t.CompTyp_Cd = s.CompTyp_Cd and
  t.AttrTyp_Cd = s.AttrTyp_Cd )
;

---------------------------------------------
---------------------------------------------
-- /////////// Translation tables ///////////
---------------------------------------------
---------------------------------------------

----------------------
-- AMX.Resource_Transl
----------------------

--
-- //////// Resource (Resources) ---> Component Type (CompTyp)
-- //////// NOTE: there is a unique index on CompTyp_Cd
--
declare global temporary table AMX_Resource_Transl (
  Resource       varchar(50) not null,
  CompTyp_Cd     varchar(17) not null
)
with replace on commit preserve rows not logged
;

-- NOTE: it is not possible to define a n:1 relationship, because
-- the AMX.Resource_Transl defines CompTyp_Cd as PRIMARY KEY; we
-- need a different CompTyp_Cd for each distinct ITM Resource...

-- ////////////////////////////////////////////////////
-- //////// Windows NT/2000/XP Resource Models ////////
-- ////////////////////////////////////////////////////

insert into session.AMX_Resource_Transl values ('PhysicalDisk','AMY_PDISK');
insert into session.AMX_Resource_Transl values ('LogicalDisk','AMY_LDISK');
insert into session.AMX_Resource_Transl values ('Process','AMY_PROCESS');
insert into session.AMX_Resource_Transl values ('Memory','AMY_MEMORY');
insert into session.AMX_Resource_Transl values ('Redirector','AMY_REDIR');
insert into session.AMX_Resource_Transl values ('NetworkSegment','AMY_NETSEG');
insert into session.AMX_Resource_Transl values ('Server','AMY_SERVER');
insert into session.AMX_Resource_Transl values ('Service','AMY_SERVICE');
insert into session.AMX_Resource_Transl values ('Port','AMY_PORT');
insert into session.AMX_Resource_Transl values ('PrintQueue','AMY_PRNQUEUE');
insert into session.AMX_Resource_Transl values ('TCPIP','AMY_TCPIP');
insert into session.AMX_Resource_Transl values ('IP','AMY_IP');
insert into session.AMX_Resource_Transl values ('RealSystem','AMY_SYSTEM');

-- ////////////////////////////////////////////
-- //////// UNIX_Linux Resource Models ////////
-- ////////////////////////////////////////////

insert into session.AMX_Resource_Transl values ('CPU','AMY_CPU');
insert into session.AMX_Resource_Transl values ('File','AMY_FILE');
insert into session.AMX_Resource_Transl values ('FileSystem','AMY_FS');
insert into session.AMX_Resource_Transl values ('Network','AMY_NETWORK');
insert into session.AMX_Resource_Transl values ('NFS','AMY_NFS');
insert into session.AMX_Resource_Transl values ('RPC','AMY_RPC');
insert into session.AMX_Resource_Transl values ('User','AMY_USER');

-- NOTE: Memory and Process are common to both Windows and UNIX_Linux RMs

-- ///////////////////////////////////////
-- //////// OS400 Resource Models ////////
-- ///////////////////////////////////////

insert into session.AMX_Resource_Transl values ('Disk','AMY_OS400DISK');
insert into session.AMX_Resource_Transl values ('InteractiveFeatureCPU','AMY_OS400IFCPU');
insert into session.AMX_Resource_Transl values ('DatabaseCPU','AMY_OS400DBCPU');
insert into session.AMX_Resource_Transl values ('InteractiveCPU','AMY_OS400ICPU');
insert into session.AMX_Resource_Transl values ('BasicCPU','AMY_OS400BCPU');
insert into session.AMX_Resource_Transl values ('ASP','AMY_OS400ASP');
insert into session.AMX_Resource_Transl values ('StoragePool','AMY_OS400SPOOL');

insert into AMX.Resource_Transl
select * from session.AMX_Resource_Transl s
where not exists (
  select 1 from
  AMX.Resource_Transl t
  where
  t.CompTyp_Cd = s.CompTyp_Cd )
;

-------------------------
-- AMX.Categories_Convert
-------------------------

--
-- NOTE: this table is used by the Generic ETL1 parsing process in order
-- to convert the multiple categories used for Operating System Resource
-- Models into a generic OperatingSystem category, because the ETL1 doesn't
-- support an n:1 mapping for the category
--
declare global temporary table AMX_Categories_Convert (
  Category_Convert  varchar(64) not null,
  Category          varchar(64) not null,
  Description       varchar(128)
)
with replace on commit preserve rows not logged
;

insert into session.AMX_Categories_Convert values ('OperatingSystem','Windows','Windows NT/2000/XP');
insert into session.AMX_Categories_Convert values ('OperatingSystem','UNIX_Linux','Unix/Linux');
insert into session.AMX_Categories_Convert values ('OperatingSystem','Solaris','Solaris');
insert into session.AMX_Categories_Convert values ('OperatingSystem','OS400','OS400');
insert into session.AMX_Categories_Convert values ('OperatingSystem','OS2','OS2');

insert into AMX.Categories_Convert
select * from session.AMX_Categories_Convert s
where not exists (
  select 1 from
  AMX.Categories_Convert t
  where
  t.Category_Convert = s.Category_Convert and
  t.Category = s.Category )
;

----------------------
-- AMX.Category_Transl
----------------------

--
-- //////// Resource Model Category ---> Measurement Source (MSrc)
-- //////// NOTE: there is a unique index on (MSrc_Cd)
--
declare global temporary table AMX_Category_Transl (
  Category      varchar(120) not null,
  MSrc_Cd           char(3) not null
)
with replace on commit preserve rows not logged
;

-- NOTE: it is not possible to define a n:1 relationship between ITM Categories and TEDW
-- MSrc_Cd, i.e. we cannot do the following map:
--
--   Windows    |
--              |--> AMY
--   Unix_Linux |
--
-- because there is a unique index on the MSrc_Cd field of the AMY.Category_Transl table.
-- Without changing the Category value for the sample Resource models, we need to map
-- Windows to a TMW MSrc_Cd and Unix_Linux to a DMX MSrc_Cd, but this could not be
-- allowed by the Generic ETL1...; another approach is to change the Category of the
-- RMs to a common value (e.g. for Spp we can set Category='Spp')...

insert into session.AMX_Category_Transl values ('OperatingSystem','AMY');

insert into AMX.Category_Transl
select * from session.AMX_Category_Transl s
where not exists (
  select 1 from
  AMX.Category_Transl t
  where
  t.MSrc_Cd = s.MSrc_Cd )
;

-----------------------
-- AMX.Inst_key_Convert
-----------------------

-- This table is used to support any product that
-- may have created multiples ITM keys for the same component type
-- such as ITM Operating System Resource models
-- we convert all the Key_Typ to a unique Key_Typ_Convert

declare global temporary table AMX_Inst_Key_Convert (
  Key_Typ_Convert  varchar(255) not null,
  Key_Typ          varchar(255) not null,
  Description      varchar(128)
)
with replace on commit preserve rows not logged
;

--Windows RM uses Processor.Processor as key property for the Processor resource, it should use the same property used by Unix RM for the CPU resource, i.e. CPU.name
insert into session.AMX_Inst_Key_Convert values ('CPU.name','Processor.Processor','System Processor');
--Windows RM uses System.Processor as key property for the System resource, it should use the same property used by Unix RM for the CPU resource, i.e. CPU.name
insert into session.AMX_Inst_Key_Convert values ('CPU.name','System.Processor','System Processor');
--Windows RM uses Memory.Memory as key property for the Memory resource, it should use the same property used by Unix RM, i.e. Memory.name
insert into session.AMX_Inst_Key_Convert values ('Memory.name','Memory.Memory','System Memory');
--Windows RM uses NetworkInterfaceCard.NetworkInterfaceCard as key property for the NetworkInterfaceCard resource, it should use the same property used by Unix RM, i.e. Network.InterfaceName
insert into session.AMX_Inst_Key_Convert values ('Network.InterfaceName','NetworkInterfaceCard.NetworkInterfaceCard','Network Interface Card');

--the File.fileName key is mapped to the File.pathname key using the AMX.Inst_key_Convert conversion table
insert into session.AMX_Inst_Key_Convert values ('File.pathname','File.fileName','File Name');

--the "Process.PID" key is mapped to the "Process.ID" key using the AMX.Inst_key_Convert conversion table because
--the unique index on the (MSrc_Cd, CompTyp_Cd) fields disallow a further mapping of the "Process.PID" key to the AMY_PROCESS CompTyp_Cd
insert into session.AMX_Inst_Key_Convert values ('Process.ID','Process.PID','Process ID');

insert into AMX.Inst_Key_Convert
select * from session.AMX_Inst_Key_Convert s
where not exists (
  select 1 from
  AMX.Inst_Key_Convert t
  where
  t.Key_Typ_Convert = s.Key_Typ_Convert and
  t.Key_Typ = s.Key_Typ )
;

------------------------
-- AMX.Resources_Convert
------------------------

-- This table is used to support any product that
-- needs to convert multiple resource names to one
-- unique name, which is used to map a TEDW CompTyp
-- by the AMX.Resource_Transl table...

declare global temporary table AMX_Resources_Convert (
  Resource_Convert varchar(128) not null,
  Resource         varchar(128) not null,
  Description      varchar(128)
)
with replace on commit preserve rows not logged
;

insert into session.AMX_Resources_Convert values ('CPU','Processor','Processor to CPU conversion');
insert into session.AMX_Resources_Convert values ('CPU','System','System to CPU conversion');
insert into session.AMX_Resources_Convert values ('Network','NetworkInterfaceCard','NetworkInterfaceCard to Network conversion');

insert into AMX.Resources_Convert
select * from session.AMX_Resources_Convert s
where not exists (
  select 1 from
  AMX.Resources_Convert t
  where
  t.Resource_Convert = s.Resource_Convert and
  t.Resource = s.Resource )
;

---------------------
-- AMX.CompTyp_Transl
---------------------

--
-- //////// Logged Key Property (Instances.Instance_Key) ---> Component Type (CompTyp)
--
-- //////// NOTE: there is a unique index on (MSrc_Cd, CompTyp_Cd)
-- //////// RULE: Here we define a lookup table for conversion between ITM
-- ////////       key properties and TEDW Components keys.
-- ////////       - MSrc_Cd is the AVA code for the producs;
-- ////////       - ITM_Key_Property is the list of the properties in the "key" parameter
-- ////////         of in DefineLogInst, where the properties are primary keys; if there
-- ////////         are multiple properties they are separated by a semicolon; this value
-- ////////         is always in the form Resource.Property and defines the ITM side of
-- ////////         the mapping;
-- ////////       - CompTyp_Cd is the component type code, i.e. the code of the TEDW CompTyp
-- ////////         which maps the ITM Resources;
-- ////////       - Comp_Format_Nm contains the ITM properties that constitute the display
-- ////////         name.
--
declare global temporary table AMX_CompTyp_Transl (
  MSrc_Cd           char(3) not null,
  ITM_Key_Property  varchar(600) not null,
  CompTyp_Cd        varchar(17) not null,
  Comp_Format_Nm    varchar(120) not null
)
with replace on commit preserve rows not logged
;

-- ////////////////////////////////////////////////////
-- //////// Windows NT/2000/XP Resource Models ////////
-- ////////////////////////////////////////////////////

insert into session.AMX_CompTyp_Transl values ('AMY','PhysicalDisk.PhysicalDisk','AMY_PDISK','PhysicalDisk.PhysicalDisk');
insert into session.AMX_CompTyp_Transl values ('AMY','LogicalDisk.LogicalDisk','AMY_LDISK','LogicalDisk.LogicalDisk');
insert into session.AMX_CompTyp_Transl values ('AMY','Process.Process;Process.ID','AMY_PROCESS','Process.Process');
insert into session.AMX_CompTyp_Transl values ('AMY','Redirector.Redirector','AMY_REDIR','Redirector.Redirector');
insert into session.AMX_CompTyp_Transl values ('AMY','NetworkSegment.Segment','AMY_NETSEG','NetworkSegment.Segment');
insert into session.AMX_CompTyp_Transl values ('AMY','Server.Server','AMY_SERVER','Server.Server');
insert into session.AMX_CompTyp_Transl values ('AMY','Service.Service','AMY_SERVICE','Service.Service');
insert into session.AMX_CompTyp_Transl values ('AMY','Port.Port','AMY_PORT','Port.Port');
insert into session.AMX_CompTyp_Transl values ('AMY','PrintQueue.PrintQueue','AMY_PRNQUEUE','PrintQueue.PrintQueue');
insert into session.AMX_CompTyp_Transl values ('AMY','TCPIP.TCP','AMY_TCPIP','TCPIP.TCP');
insert into session.AMX_CompTyp_Transl values ('AMY','IP.IP','AMY_IP','IP.IP');
insert into session.AMX_CompTyp_Transl values ('AMY','RealSystem.Name','AMY_SYSTEM','RealSystem.Name');

-- ////////////////////////////////////////////
-- //////// UNIX_Linux Resource Models ////////
-- ////////////////////////////////////////////

insert into session.AMX_CompTyp_Transl values ('AMY','CPU.name','AMY_CPU','CPU.name');
insert into session.AMX_CompTyp_Transl values ('AMY','Memory.name','AMY_MEMORY','Memory.name');
insert into session.AMX_CompTyp_Transl values ('AMY','File.pathname','AMY_FILE','File.pathname');
insert into session.AMX_CompTyp_Transl values ('AMY','FileSystem.mountpoint','AMY_FS','FileSystem.mountpoint');
insert into session.AMX_CompTyp_Transl values ('AMY','Network.InterfaceName','AMY_NETWORK','Network.InterfaceName');
insert into session.AMX_CompTyp_Transl values ('AMY','NFS.name','AMY_NFS','NFS.name');
insert into session.AMX_CompTyp_Transl values ('AMY','RPC.name','AMY_RPC','RPC.name');
insert into session.AMX_CompTyp_Transl values ('AMY','User.userName','AMY_USER','User.userName');

-- ///////////////////////////////////////
-- //////// OS400 Resource Models ////////
-- ///////////////////////////////////////

insert into session.AMX_CompTyp_Transl values ('AMY','Disk.spare','AMY_OS400DISK','Disk.spare');
insert into session.AMX_CompTyp_Transl values ('AMY','InteractiveFeatureCPU.spare','AMY_OS400IFCPU','InteractiveFeatureCPU.spare');
insert into session.AMX_CompTyp_Transl values ('AMY','DatabaseCPU.spare','AMY_OS400DBCPU','DatabaseCPU.spare');
insert into session.AMX_CompTyp_Transl values ('AMY','InteractiveCPU.spare','AMY_OS400ICPU','InteractiveCPU.spare');
insert into session.AMX_CompTyp_Transl values ('AMY','BasicCPU.spare','AMY_OS400BCPU','BasicCPU.spare');
insert into session.AMX_CompTyp_Transl values ('AMY','ASP.ASPInstance','AMY_OS400ASP','ASP.ASPInstance');
insert into session.AMX_CompTyp_Transl values ('AMY','StoragePool.storagePoolName','AMY_OS400SPOOL','StoragePool.storagePoolName');

insert into AMX.Comptyp_Transl
select * from session.AMX_Comptyp_Transl s
where not exists (
  select 1 from
  AMX.CompTyp_Transl t
  where
  t.MSrc_Cd = s.MSrc_Cd and
  t.CompTyp_Cd  = s.CompTyp_Cd )
;

---------------------
-- AMX.AttrTyp_Transl
---------------------

--
-- /////// Logged Non-Key Property (Instances.instance_key) --> Attribute Type (AttrType)
--
--
declare global temporary table AMX_AttrTyp_Transl (
  MSrc_Cd           char(3) not null,
  AMY_Attr_Property varchar(120) not null,
  AttrTyp_Cd        varchar(17) not null
)
with replace on commit preserve rows not logged
;

insert into session.AMX_AttrTyp_Transl values ('AMY','Process.Process','AMY_PROCNM');
insert into session.AMX_AttrTyp_Transl values ('AMY','Process.ID','AMY_PROCID');
insert into session.AMX_AttrTyp_Transl values ('AMY','Service.State','AMY_SERVICESTATE');
insert into session.AMX_AttrTyp_Transl values ('AMY','Service.Status','AMY_SERVICESTATUS');
insert into session.AMX_AttrTyp_Transl values ('AMY','Port.State','AMY_PORTSTATE');

insert into session.AMX_AttrTyp_Transl values ('AMY','File.group','AMY_FGROUP');
insert into session.AMX_AttrTyp_Transl values ('AMY','File.owner','AMY_FOWNER');
insert into session.AMX_AttrTyp_Transl values ('AMY','File.mode','AMY_FMODE');

insert into session.AMX_AttrTyp_Transl values ('AMY','User.id','AMY_USRID');
insert into session.AMX_AttrTyp_Transl values ('AMY','Memory.TotalVisiblePhysicalMemory','AMY_VISPHYSMEMORY');

insert into AMX.Attrtyp_Transl
select * from session.AMX_Attrtyp_Transl s
where not exists (
  select 1 from
  AMX.Attrtyp_Transl t
  where
  t.MSrc_Cd = s.MSrc_Cd and
  t.AttrTyp_Cd  = s.AttrTyp_Cd )
;

---------------------------------------------
---------------------------------------------
-- ////// Fixes for the AMY metadatas ///////
---------------------------------------------
---------------------------------------------

--
-- 39864: fix the name of the metric 'PagesFaultsSec' collected by the TMW_MemoryModel RM
--
UPDATE TWG.MsmtTyp
SET MsmtTyp_Nm = 'PagesFaultsSec'
WHERE MsmtTyp_Nm = 'PageFaultsSec' and
not exists ( select 1 from TWG.MsmtTyp where MsmtTyp_Nm = 'PagesFaultsSec')
;

--
-- IY38862: fix the data format of the metric 'TotalAvail' collected by the DMXMemory RM
--
UPDATE TWG.MsmtTyp
SET MUNIT_CD = 'B'
WHERE MSMTTYP_NM = 'TotalAvail'
AND MSRC_CD = 'AMY'
;

--
-- 48964: fix the name of the metric 'ServerErroredOut' collected by the TMW_NetworkIntCard RM
--
UPDATE TWG.MsmtTyp
SET MsmtTyp_Nm = 'ServerErroredOut'
WHERE MSMTTYP_NM = 'SessionsErroredOut'
AND MSRC_CD = 'AMY'
;

-- The File resource is mapped to the AMY_FILE component using the AMX.Resource_Transl
-- translation table, but the logging key used by the DMXFile resource model is not
-- unique between the different logging contexts: it is "fileName" for the "File Checksum"
-- context and "pathname" for the "File Times" context.
--
-- For this reason the key attribute "fileName" is absorbed by "pathname" key attribute
-- using the AMX_Inst_Key_Convert conversion table and thus, the only attributes of the
-- File resource that are mapped to TEDW component attributes are:
--
-- MSRC_CD ITM_ATTR_PROPERTY   ATTRTYP_CD
-- ------- ------------------- -----------------
-- AMY     File.group          AMY_FGROUP
-- AMY     File.owner          AMY_FOWNER
-- AMY     File.mode           AMY_FMODE

DELETE FROM TWG.AttrRul
WHERE ATTRTYP_CD = 'AMY_FPATHNM';

DELETE FROM TWG.AttrTyp
WHERE ATTRTYP_CD = 'AMY_FPATHNM';

--------------
-- TWG.MGrpMbr
--------------

declare global temporary table AMY_MGrpMbr (
  MGrp_Cd      char(6) not null,
  MGrpTyp_Cd   char(6) not null,
  MsmtTyp_ID   integer not null
)
with replace on commit preserve rows not logged
;

-- ////////////////////////////////////////////////////////////////////////////////////
-- MIN_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ////// UNIX_Linux Resource Models
insert into session.AMY_MGrpMbr
select 'MIN_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in (
'modificationTime', 'changeTime', 'checksum');

-- ////////////////////////////////////////////////////////////////////////////////////
-- MAX_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ////// UNIX_Linux Resource Models
insert into session.AMY_MGrpMbr
select 'MAX_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in (
'modificationTime', 'changeTime', 'checksum');

-- ////////////////////////////////////////////////////////////////////////////////////
-- AVG_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ////// UNIX_Linux Resource Models
insert into session.AMY_MGrpMbr
select 'AVG_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in (
'modificationTime', 'changeTime', 'checksum');

-- ////////////////////////////////////////////////////////////////////////////////////
-- TOT_E //////////////////////////////////////////////////////////////////////////////
-- ////////////////////////////////////////////////////////////////////////////////////

-- ///// UNIX_Linux/Solaris Resource Models
--insert into session.AMY_MGrpMbr
--select 'TOT_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd = 'AMY' and MsmtTyp_Nm in (
--'' );

insert into TWG.MGrpMbr (
  MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID )
select * from session.AMY_MGrpMbr s
where not exists (
  select 1 from
  TWG.MGrpMbr t
  where
  t.MGrpTyp_Cd = s.MGrpTyp_Cd and
  t.MGrp_Cd = s.MGrp_Cd and
  t.MsmtTyp_ID = s.MsmtTyp_ID )
;

--------------
-- TWG.RelnRul
--------------

declare global temporary table AMY_RelnRul (
  CompTyp_Source_Cd    CHAR(17)  NOT NULL,
  CompTyp_Target_Cd    CHAR(17)  NOT NULL,
  RelnTyp_Cd           CHAR(6)   NOT NULL,
  RelnRul_Strt_DtTm    TIMESTAMP NOT NULL,
  RelnRul_End_DtTm     TIMESTAMP NOT NULL
)
with replace on commit preserve rows not logged
;

-- ////////////////////////////////////////////////////
-- //////// Windows NT/2000/XP Resource Models ////////
-- ////////////////////////////////////////////////////

insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_PDISK',    'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_LDISK',    'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_PROCESS',  'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_MEMORY',   'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_REDIR',    'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_NETSEG',   'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_SERVER',   'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
--the windows specific AMY_NIC component is mapped to the generic AMY_NETWORK component
--insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_NIC',      'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_SERVICE',  'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_PORT',     'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_PRNQUEUE', 'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
--the windows specific AMY_PROCESSOR component is mapped to the generic AMY_CPU component
--insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_PROCESSOR','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
--the windows specific AMY_SYSTEM component is mapped to the generic AMY_CPU component
--insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_SYSTEM',   'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_TCPIP',    'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_IP',       'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_CPU',    'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_FILE',   'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_NETWORK','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_NFS',    'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_RPC',    'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_USER',   'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');


insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_OS400DISK', 'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_OS400IFCPU','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_OS400DBCPU','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_OS400ICPU', 'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_OS400BCPU', 'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_OS400ASP',  'PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_OS400SPOOL','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into session.AMY_RelnRul values ('IP_INTERFACE','AMY_SYSTEM','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('IP_HOST','AMY_SYSTEM','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.AMY_RelnRul values ('AMY_HOST','AMY_SYSTEM','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into TWG.RelnRul (
  CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd,
  RelnRul_Strt_DtTm, RelnRul_End_DtTm )
select * from session.AMY_RelnRul s
where not exists (
  select 1 from
  TWG.RelnRul t
  where
  t.CompTyp_Source_Cd = s.CompTyp_Source_Cd and
  t.CompTyp_Target_Cd = s.CompTyp_Target_Cd and
  t.RelnTyp_Cd = s.RelnTyp_Cd )
;

-------------------------------------------------
-- temporary tables indicating which measurement
-- is in the group MIN_E, MAX_E, AVG_E, TOT_E
-- for the AMY DataMart
-------------------------------------------------

declare global temporary table temp_min_exists (
 msmttyp_id integer,
 min_exists     char(1)
)
with replace on commit preserve rows not logged
;

insert into session.temp_min_exists
select
 mb.msmttyp_id,
 'Y' as min_exists
from
 twg.mgrpmbr mb
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MIN_E'
;

-- select * from session.temp_min_exists;

declare global temporary table temp_max_exists (
 msmttyp_id integer,
 max_exists     char(1)
)
with replace on commit preserve rows not logged
;

insert into session.temp_max_exists
select
 mb.msmttyp_id,
 'Y' as max_exists
from
 twg.mgrpmbr mb
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MAX_E'
;

declare global temporary table temp_avg_exists (
 msmttyp_id integer,
 avg_exists     char(1)
)
with replace on commit preserve rows not logged
;

insert into session.temp_avg_exists
select
 mb.msmttyp_id,
 'Y' as avg_exists
from
 twg.mgrpmbr mb
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='AVG_E'
;

-- select * from session.temp_avg_exists;

declare global temporary table temp_tot_exists (
 msmttyp_id integer,
 tot_exists     char(1)
)
with replace on commit preserve rows not logged
;

insert into session.temp_tot_exists
select
 mb.msmttyp_id,
 'Y' as tot_exists
from
 twg.mgrpmbr mb
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='TOT_E'
;

---------------------------------------
-- temporary table for Extract Control
---------------------------------------
declare global temporary table Extract_Control (
    ExtCtl_Source       varchar(120) not null,
    ExtCtl_Target       varchar(120) not null,
    ExtCtl_From_RawSeq  char(10) for bit data,
    ExtCtl_To_RawSeq    char(10) for bit data,
    ExtCtl_From_IntSeq  bigint,
    ExtCtl_To_IntSeq    bigint,
    ExtCtl_From_DtTm    timestamp not null,
    ExtCtl_To_DtTm      timestamp not null
    )
with replace on commit preserve rows not logged
;

-----------------------------------------------
-- From Staging to the T tables
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'AMY.T_HOST_IP' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- Component  CPU
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'AMY.T_CPU' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'AMY.STG_CPU_MET' ,
    'AMY.T_CPU_METRIC' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'AMY.STG_CPU_HR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- Component  FILE
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'AMY.T_FILE' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'AMY.STG_FILE_HR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- Component  FS
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'AMY.T_FS' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'AMY.STG_FS_MET' ,
    'AMY.T_FS_METRIC' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'AMY.STG_FS_HR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- Component  IP
-----------------------------------------------

-----------------------------------------------
-- Component  LDISK
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'AMY.T_LDISK' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'AMY.STG_IO_MET' ,
    'AMY.T_IO_METRIC' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'AMY.STG_LDISK_HR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- Component  MEMORY
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'AMY.T_MEMORY' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'AMY.STG_MEM_MET' ,
    'AMY.T_MEM_METRIC' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'AMY.STG_MEMORY_HR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- Component  NETSEG
-----------------------------------------------

-----------------------------------------------
-- Component  NETWORK
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'AMY.T_NETWORK' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'AMY.STG_NET_MET' ,
    'AMY.T_NET_METRIC' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'AMY.STG_NETWORK_HR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- Component  NFS
-----------------------------------------------

-----------------------------------------------
-- Component  OS400ASP
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'AMY.T_OS400ASP' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);


insert into session.extract_control values (
    'TWG.MSMT' ,
    'AMY.STG_OS400ASP_HR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- Component  OS4KBCPU
-----------------------------------------------

-----------------------------------------------
-- Component  OS4KDBCPU
-----------------------------------------------

-----------------------------------------------
-- Component  OS4KDISK
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'AMY.T_OS4KDISK' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'AMY.STG_OS4KDISK_HR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- Component  OS4KICPU
-----------------------------------------------

-----------------------------------------------
-- Component  OS4KIFCPU
-----------------------------------------------

-----------------------------------------------
-- Component  OS4KSPOOL
-----------------------------------------------

-----------------------------------------------
-- Component  PDISK
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'AMY.T_PDISK' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);


insert into session.extract_control values (
    'TWG.MSMT' ,
    'AMY.STG_PDISK_HR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- Component  PORT
-----------------------------------------------

-----------------------------------------------
-- Component  PRNQUEUE
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'AMY.T_PRINTER' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'AMY.STG_PRN_MET' ,
    'AMY.T_PRN_METRIC' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'AMY.STG_PRN_HR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- Component  PROCESS
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'AMY.T_PROCESS' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);


insert into session.extract_control values (
    'TWG.MSMT' ,
    'AMY.STG_PROCESS_HR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- Component  REDIR
-----------------------------------------------

-----------------------------------------------
-- Component  RPC
-----------------------------------------------

-----------------------------------------------
-- Component  SERVER
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'AMY.T_SERVER' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'AMY.STG_SERVER_MET' ,
    'AMY.T_SERVER_METRIC' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'AMY.STG_SERVER_HR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- Component  SERVICE
-----------------------------------------------

-----------------------------------------------
-- Component  TCPIP
-----------------------------------------------

-----------------------------------------------
-- Component  USER
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'AMY.T_USER' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'AMY.STG_USER_MET' ,
    'AMY.T_USER_METRIC' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'AMY.STG_USER_HR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- Component  SYSTEM
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'AMY.T_SYSTEM' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'AMY.STG_SYSTEM_MET' ,
    'AMY.T_SYSTEM_METRIC' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'AMY.STG_SYSTEM_HR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-- insert the static data for the extract table
-- if not exist already

insert into TWG.Extract_control
select
 m.ExtCtl_Source as ExtCtl_Source,
 m.ExtCtl_Target as ExtCtl_Target,
 m.ExtCtl_From_RawSeq as ExtCtl_From_RawSeq,
 m.ExtCtl_To_RawSeq as ExtCtl_To_RawSeq,
 m.ExtCtl_From_IntSeq as ExtCtl_From_IntSeq,
 m.ExtCtl_To_IntSeq as ExtCtl_To_IntSeq,
 m.ExtCtl_From_DtTm as ExtCtl_From_DtTm,
 m.ExtCtl_To_DtTm as ExtCtl_To_DtTm
from
 session.Extract_Control m
where not exists
( select 1 from
  TWG.Extract_Control t
  where
  t.ExtCtl_Source=m.ExtCtl_Source  and
  t.ExtCtl_Target=m.ExtCtl_Target
);

--------------------------------------
-- insert the  measurement types in
-- the metrics dimensions for
-- the measurement group CPU_E
--------------------------------------

insert into AMY.STG_CPU_MET(
 insert_dttm,
 metric_id,
 met_category,
 met_name,
 met_desc,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'CPU' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.mgrpmbr b,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and
 mt.msrc_cd='AMY' and
 s.msrc_cd=mt.msrc_cd and
 b.msmttyp_id=mt.msmttyp_id and
 b.mgrp_cd='CPU_E' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from AMY.STG_CPU_MET m
    where
    m.metric_id = mt.msmttyp_id and
    m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;

--------------------------------------
-- insert the  measurement types in
-- the metrics dimensions for
-- the measurement group FS_E
--------------------------------------

insert into AMY.STG_FS_MET (
 insert_dttm,
 metric_id,
 met_category,
 met_name,
 met_desc,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'File system' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.mgrpmbr b,
 twg.msmtrul mr,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and
 mt.msrc_cd='AMY' and
 s.msrc_cd=mt.msrc_cd and
 b.msmttyp_id=mt.msmttyp_id and
 b.mgrp_cd='FS_E' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from AMY.STG_FS_MET m
    where
    m.metric_id = mt.msmttyp_id and
    m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;

--------------------------------------
-- insert the  measurement types in
-- the metrics dimensions for
-- the measurement group NET_E
--------------------------------------

insert into AMY.STG_NET_MET(
 insert_dttm,
 metric_id,
 met_category,
 met_name,
 met_desc,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'Network interface' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.mgrpmbr b,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and
 mt.msrc_cd='AMY' and
 s.msrc_cd=mt.msrc_cd and
 b.msmttyp_id=mt.msmttyp_id and
 b.mgrp_cd='NIC_E' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from AMY.STG_NET_MET m
    where
    m.metric_id = mt.msmttyp_id and
    m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;

--------------------------------------
-- insert the  measurement types in
-- the metrics dimensions for
-- the measurement group HD_E
--------------------------------------

insert into AMY.STG_IO_MET(
 insert_dttm,
 metric_id,
 met_category,
 met_name,
 met_desc,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'I/O' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.mgrpmbr b,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and
 mt.msrc_cd='AMY' and
 s.msrc_cd=mt.msrc_cd and
 b.msmttyp_id=mt.msmttyp_id and
 b.mgrp_cd='HD_E' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from AMY.STG_IO_MET m
    where
    m.metric_id = mt.msmttyp_id and
    m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;

--------------------------------------
-- insert the  measurement types in
-- the metrics dimensions for
-- the measurement group MEM_E
--------------------------------------

insert into AMY.STG_MEM_MET(
 insert_dttm,
 metric_id,
 met_category,
 met_name,
 met_desc,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'Memory' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.mgrpmbr b,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and
 mt.msrc_cd='AMY' and
 s.msrc_cd=mt.msrc_cd and
 b.msmttyp_id=mt.msmttyp_id and
 b.mgrp_cd='MEM_E' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from AMY.STG_MEM_MET m
    where
    m.metric_id = mt.msmttyp_id and
    m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;

--------------------------------------
-- insert the  measurement types in
-- the metrics dimensions for
-- the measurement group PRN_E
--------------------------------------

insert into AMY.STG_PRN_MET(
 insert_dttm,
 metric_id,
 met_category,
 met_name,
 met_desc,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'Printer' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.mgrpmbr b,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and
 mt.msrc_cd='AMY' and
 s.msrc_cd=mt.msrc_cd and
 b.msmttyp_id=mt.msmttyp_id and
 b.mgrp_cd='PRN_E' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from AMY.STG_PRN_MET m
    where
    m.metric_id = mt.msmttyp_id and
    m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;

--------------------------------------
-- insert the  measurement types in
-- the metrics dimensions for
-- the component type AMY_USER
--------------------------------------

insert into AMY.STG_USER_MET(
 insert_dttm,
 metric_id,
 met_category,
 met_name,
 met_desc,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'Not Used' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and
 mt.msrc_cd='AMY' and
 s.msrc_cd=mt.msrc_cd and
 mr.comptyp_cd='AMY_USER' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from AMY.STG_USER_MET m
    where
    m.metric_id = mt.msmttyp_id and
    m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;

--------------------------------------
-- insert the  measurement types in
-- the metrics dimensions for
-- the component type AMY_SERVER
--------------------------------------

insert into AMY.STG_SERVER_MET(
 insert_dttm,
 metric_id,
 met_category,
 met_name,
 met_desc,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'Not Used' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and
 mt.msrc_cd='AMY' and
 s.msrc_cd=mt.msrc_cd and
 mr.comptyp_cd='AMY_SERVER' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from AMY.STG_SERVER_MET m
    where
    m.metric_id = mt.msmttyp_id and
    m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;

--------------------------------------
-- insert the  measurement types in
-- the metrics dimensions for
-- the component type AMY_SYSTEM
--------------------------------------

insert into AMY.STG_SYSTEM_MET(
 insert_dttm,
 metric_id,
 met_category,
 met_name,
 met_desc,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'Not Used' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and
 mt.msrc_cd='AMY' and
 s.msrc_cd=mt.msrc_cd and
 mr.comptyp_cd='AMY_SYSTEM' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from AMY.STG_SYSTEM_MET m
    where
    m.metric_id = mt.msmttyp_id and
    m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;

--#endtag fixpack_600

--#iftag fixpack_660
-- do nothing...
--#endtag fixpack_660