------------------------------------------------------------------------
--
-- Tivoli Enterprise Data Warehouse, v 1.1.0
-- (C) Copyright IBM Corp. 2002.  All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
--
------------------------------------------------------------------------
--
-- File Information: cdw/dml/twh_cdw_data.sql, cdw_data, enable_tools
--
-- Revision: 1.40
--
-- Date: 8/22/03 17:21:41
--
-- Description: This is a common file for inserting static data
-- into the CDW. All application installs should place this file in their
-- /tedw/ava_code/v110/cdw/dml directory.
--
------------------------------------------------------------------------

-- All data is initially inserted into a temporary table that has
-- the same columns as the target table in the CDW.
-- That table is then inserted into the CDW table with a "where not exists"
-- clause. This insures that duplicate data is not inserted and an
-- error is not generated for trying to insert duplicate data.

declare global temporary table comptyp (
       CompTyp_Cd           CHAR(17) NOT NULL,
       CompTyp_Parent_Cd    CHAR(17),
       CompTyp_Nm           VARCHAR(120) NOT NULL,
       CompTyp_Strt_DtTm    TIMESTAMP NOT NULL,
       CompTyp_End_DtTm     TIMESTAMP NOT NULL
)
with replace on commit preserve rows not logged
;

--Insert all time values in UTC

--IP Types
insert into session.comptyp values ('IP_HOST', NULL, 'IP Host', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('IP_INTERFACE', NULL, 'IP Interface', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('IPX_INTERFACE', NULL, 'IPX Interface', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('IP_NODE', NULL, 'IP Node', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

--Tivoli Framework Types

insert into session.comptyp values ('TME_ENDPOINT', NULL, 'Tivoli Endpoint', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

--Web Types

insert into session.comptyp values ('WEBSITE', NULL, 'Website', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('WEBSITE_QUERY', NULL, 'Website Query', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('WEBSITE_PATH', NULL, 'Website Path', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

--z/OS Types

insert into session.comptyp values ('SYSPLEX', NULL, 'Sysplex', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('MVS_SYSTEM', NULL, 'MVS System', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('MVS_SUBSYSTEM', NULL, 'MVS Subsystem', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('MVS_SYSAPPL', NULL, 'MVS System Application', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('CEC', NULL, 'Central Electronic Complex', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('LOGICAL_PARTITION', NULL, 'Logical Partition', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('COUPLING_FACILITY', NULL, 'Coupling Facility', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

--MQ Types

insert into session.comptyp values ('MQ_QUEUE_MANAGER', NULL, 'MQ Queue Manager', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('MQ_QUEUE', NULL, 'MQ Queue', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('MQ_CHANNEL', NULL, 'MQ Channel', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('MQ_ADAPTER', NULL, 'MQ Adapter', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

--Workload Scheduler Types

insert into session.comptyp values ('SCHED_ENGINE', NULL, 'Workload Scheduler Master', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('SCHED_WORKSTATION', NULL, 'Workload Scheduler Workstation', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('SCHED_JOB', NULL, 'Workload Scheduler Job', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('SCHED_JOBSTREAM', NULL, 'Workload Scheduler Jobstream', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

--SNA Types

insert into session.comptyp values ('NETWORK_APPL', NULL, 'Network Application', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('SNA_NETWORK', NULL, 'SNA Network', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('SNA_CCU', NULL, 'SNA Communication Control Unit', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('SNA_LINE', NULL, 'SNA Line', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('SNA_PU', NULL, 'SNA Physical Unit', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

--SNMP Types

insert into session.comptyp values ('SNMP_AGENT', NULL, 'SNMP Agent', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

--Software License
insert into session.comptyp values ('SW_INVENTORY', NULL, 'Software Inventory', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('PRODUCT_INV', NULL, 'Software Product Inventory', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('SW_USAGE', NULL, 'Software Usage', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('PRODUCT_GRP_USAGE', NULL, 'Software Usage for a Group', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('PRODUCT_ORG_USAGE', NULL, 'PRODUCT Usage for an Organization', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('USERS_LIC_USAGE', NULL, 'Usage of Software License with Users Capacity Type', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('MEMORY_LIC_USAGE', NULL, 'Usage of Software License with Memory Capacity Type', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('PROCS_LIC_USAGE', NULL, 'Usage of Software License with Processors Capacity Type', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('DISKS_LIC_USAGE', NULL, 'Usage of Software License with Disks Capacity Type', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

--Services
insert into session.comptyp values ('SERVICE', NULL, 'Service', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

--Business Systems
insert into session.comptyp values ('BUSINESS_SYSTEM', NULL, 'Business System', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

--Web Application Server Types

insert into session.comptyp values ('J2EE_SERVER', NULL, 'J2EE Server', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('J2EE_NODE', NULL, 'J2EE Node', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('J2EE_DOMAIN', NULL, 'J2EE Domain', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('WEBSPHERE_CELL', NULL, 'WebSphere Cell', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

--Service Desk Types

insert into session.comptyp values ('INCIDENT', NULL, 'Incident', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('SERVICE_DESK', NULL, 'Service Desk', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('SD_USER', NULL, 'Service Desk User', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('CHANGE_REQUEST', NULL, 'Change Request', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.comptyp values ('CR_TASK', NULL, 'Change Request Task', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into twg.comptyp
(CompTyp_Cd, CompTyp_Parent_Cd, CompTyp_Nm, CompTyp_Strt_DtTm, CompTyp_End_DtTm)
select * from session.comptyp s
where not exists (
  select 1 from
  twg.comptyp t where
  t.comptyp_cd = s.comptyp_cd
);

--
-- Insert component relation type codes
--
declare global temporary table RelnTyp (
       RelnTyp_Cd           CHAR(6) NOT NULL,
       RelnTyp_Nm           VARCHAR(120) NOT NULL)
with replace on commit preserve rows not logged
;

insert into session.RelnTyp values (
  'PCHILD', 'Parent Child Relation'
);
insert into session.RelnTyp values (
  'MEMBER', 'Member Relation'
);
insert into session.RelnTyp values (
  'OWNS', 'Owns Relation'
);
insert into session.RelnTyp values (
  'CNTRLS', 'Controls Relation'
);
insert into session.RelnTyp values (
  'NETWRK', 'Network Relation'
);
insert into session.RelnTyp values (
  'RUNSON', 'Runs on Relation'
);
insert into session.RelnTyp values (
  'INVOKE', 'Invoke Relation'
);
insert into session.RelnTyp values (
  'DEPEND', 'Depend Relation'
);
insert into session.RelnTyp values (
  'PCONT', 'Physical Containment Relation'
);
insert into session.RelnTyp values (
  'MONITR', 'Monitoring Relation'
);
insert into session.RelnTyp values (
  'INSTON', 'Installed On Relation'
);
insert into session.RelnTyp values (
  'LCONT', 'Logical Containment Relation'
);
insert into session.RelnTyp values (
  'MANAGE', 'Manage Relation'
);
insert into session.RelnTyp values (
  'USES', 'Uses Relation'
);
insert into session.RelnTyp values (
  'PROVID', 'Provides Relation'
);
insert into session.RelnTyp values (
  'PROXY', 'Proxy Relation'
);
insert into session.RelnTyp values (
  'SAME', 'Same Relation'
);
insert into session.RelnTyp values (
  'INSTOF', 'Instance Of Relation'
);
insert into session.RelnTyp values (
  'SUPPRT', 'Supports Relation'
);
insert into session.RelnTyp values (
  'CAUSES', 'Causes Relation'
);

insert into twg.RelnTyp
(RelnTyp_Cd, RelnTyp_Nm)
select * from session.RelnTyp s
where not exists (
  select 1 from
  twg.RelnTyp t where
  t.RelnTyp_Cd = s.RelnTyp_Cd
);


--
-- Insert component relation rules
--
declare global temporary table RelnRul (
       CompTyp_Source_Cd    CHAR(17) NOT NULL,
       CompTyp_Target_Cd    CHAR(17) NOT NULL,
       RelnTyp_Cd           CHAR(6) NOT NULL,
       RelnRul_Strt_DtTm    TIMESTAMP NOT NULL,
       RelnRul_End_DtTm     TIMESTAMP NOT NULL)
with replace on commit preserve rows not logged
;
--Web Relationships
insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'WEBSITE', 'WEBSITE_PATH', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'WEBSITE_PATH', 'WEBSITE_QUERY', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

--Workload Relationships

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'SCHED_ENGINE', 'SCHED_WORKSTATION', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'SCHED_ENGINE', 'SCHED_JOBSTREAM', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'SCHED_ENGINE', 'SCHED_JOB', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'SCHED_JOB', 'SCHED_JOBSTREAM', 'LCONT',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'SCHED_JOB', 'SCHED_WORKSTATION', 'RUNSON',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'MVS_SYSTEM', 'SCHED_ENGINE', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

--z/OS Relationships

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'MVS_SYSTEM', 'SYSPLEX', 'LCONT',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'MVS_SYSTEM', 'MVS_SUBSYSTEM', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);


insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'MVS_SYSTEM', 'MVS_SYSAPPL', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'CEC', 'LOGICAL_PARTITION', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'MVS_SYSTEM', 'LOGICAL_PARTITION', 'RUNSON',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'COUPLING_FACILITY', 'SYSPLEX', 'LCONT',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);


--MQ Relationships

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'MVS_SYSTEM', 'MQ_QUEUE_MANAGER', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'MQ_QUEUE_MANAGER', 'MQ_QUEUE', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'MQ_QUEUE_MANAGER', 'MQ_CHANNEL', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'MQ_QUEUE_MANAGER', 'MQ_QUEUE', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

--SNA Relationships

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'SNA_NETWORK', 'SNA_CCU', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'SNA_NETWORK', 'SNA_LINE', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'SNA_NETWORK', 'SNA_PU', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'SNA_CCU', 'SNA_LINE', 'NETWRK',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'SNA_LINE', 'SNA_PU', 'NETWRK',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'SNA_CCU', 'SNA_PU', 'NETWRK',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

--Service Desk Rules

insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'INCIDENT', 'SD_USER', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);
insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'CHANGE_REQUEST', 'INCIDENT', 'CAUSES',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);
insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'CHANGE_REQUEST', 'SD_USER', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);
insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'CHANGE_REQUEST', 'CR_TASK', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);
insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'SERVICE_DESK', 'INCIDENT', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);
insert into session.RelnRul (
  CompTyp_Source_CD, CompTyp_Target_CD, RelnTyp_CD, RelnRul_Strt_DtTm,
  RelnRul_End_DtTm) values (
  'SERVICE_DESK', 'CHANGE_REQUEST', 'PCHILD',
  current timestamp - current timezone, '9999-01-01-00.00.00.00'
);

insert into TWG.RelnRul
(CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd, RelnRul_Strt_DtTm, RelnRul_End_DtTm)
select * from session.RelnRul s
where not exists (
  select 1 from
  TWG.RelnRul t where
  t.CompTyp_Source_Cd = s.CompTyp_Source_Cd and
  t.CompTyp_Target_Cd = s.CompTyp_Target_Cd and
  t.RelnTyp_Cd = s.RelnTyp_Cd
);


--
-- Insert time summary codes
--
declare global temporary table tmsum (
  TmSum_Cd             CHAR NOT NULL,
  TmSum_Nm             VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.tmsum values ('H', 'Hourly');
insert into session.tmsum values ('D', 'Daily');
insert into session.tmsum values ('W', 'Weekly');
insert into session.tmsum values ('M', 'Monthly');
insert into session.TmSum values ('Q', 'Quarterly');
insert into session.TmSum values ('Y', 'Yearly');
insert into session.TmSum values ('5', 'Five Minutes');
insert into session.TmSum values ('T', 'Thirty Minutes');
insert into session.TmSum values ('F', 'Fifteen Minutes');
insert into session.TmSum values ('P', 'Point');

insert into twg.tmsum
(TmSum_Cd, TmSum_Nm)
select * from session.tmsum s
where not exists (
  select 1 from
  twg.tmsum t where
  t.TmSum_Cd = s.TmSum_Cd
);


--
-- Insert measurement unit codes
--
declare global temporary table munitcat (
  MUnitCat_Cd          CHAR(6) NOT NULL,
  MUnitCat_Nm          VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.munitcat values ('TM','Time Duration');
insert into session.munitcat values ('QTY','Quantity');
insert into session.munitcat values ('PRC','Percentage');
insert into session.munitcat values ('RT','Rate');

insert into twg.munitcat
(MUnitCat_Cd, MUnitCat_Nm)
select * from session.munitcat s
where not exists (
  select 1 from
  twg.munitcat t where
  t.munitcat_Cd = s.munitcat_Cd
);


--
-- Insert measurement units
--
declare global temporary table munit (
  MUnit_Cd             CHAR(6) NOT NULL,
  MUnitCat_Cd          CHAR(6),
  MUnit_Nm             VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MUnit values ('PRC', 'PRC', 'Percentage');
insert into session.MUnit values ('Bps', 'RT', 'Bytes per Second');
insert into session.MUnit values ('MBps', 'RT', 'Megabytes per Second');
insert into session.MUnit values ('KBps', 'RT', 'Kilobytes per Second');
insert into session.MUnit values ('Rps', 'RT', 'Requests per Second');
insert into session.MUnit values ('Qps', 'RT', 'Quantity per Second');
insert into session.MUnit values ('Qpm', 'RT', 'Quantity per Minute');
insert into session.MUnit values ('QTY', 'QTY', 'Quantity');
insert into session.MUnit values ('GB', 'QTY', 'Gigabytes');
insert into session.MUnit values ('KB', 'QTY', 'Kilobytes');
insert into session.MUnit values ('MB', 'QTY', 'Megabytes');
insert into session.MUnit values ('B', 'QTY', 'Bytes');
insert into session.MUnit values ('4KPgs', 'QTY', '4K Pages');
insert into session.MUnit values ('SU','QTY','Service Units');
insert into session.MUnit values ('MSec', 'TM', 'Milliseconds');
insert into session.MUnit values ('Sec', 'TM', 'Seconds');
insert into session.MUnit values ('Min', 'TM', 'Minutes');
insert into session.MUnit values ('Hr', 'TM', 'Hours');
insert into session.MUnit values ('Day', 'TM', 'Days');
insert into session.MUnit values ('HSc', 'TM', 'Hundredths of a Second');
insert into session.MUnit values ('HSEC', 'TM', 'Tenths of a Second');

insert into twg.munit
(MUnit_Cd, MUnitCat_Cd, MUnit_Nm)
select * from session.munit s
where not exists (
  select 1 from
  twg.munit t where
  t.munit_Cd = s.munit_Cd
);


--
-- Insert measurement group type codes
--
declare global temporary table mgrptyp (
  MGrpTyp_Cd           CHAR(6) NOT NULL,
  MGrpTyp_Nm           VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MgrpTyp values ('STATE','State');
insert into session.MgrpTyp values ('CATEG','Category');
insert into session.mgrptyp values ('GROUP', 'Aggregate Types or Group Functions');
insert into session.MgrpTyp values ('TRANS','State Transition Groups');
insert into session.MgrpTyp values ('COLL','Data Collection Groups');

insert into twg.mgrptyp
(MGrpTyp_Cd, MGrpTyp_Nm)
select * from session.mgrptyp s
where not exists (
  select 1 from
  twg.mgrptyp t where
  t.mgrptyp_Cd = s.mgrptyp_Cd
);


--
-- Insert measurement groups
--
declare global temporary table mgrp (
  MGrp_Cd              CHAR(6) NOT NULL,
  MGrpTyp_Cd           CHAR(6) NOT NULL,
  MGrp_Parent_Cd       CHAR(6),
  MGrp_Nm              VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MGrp values ('PERF','CATEG', NULL, 'Performance');
insert into session.MGrp values ('UTIL','CATEG', NULL, 'Utilization');
insert into session.MGrp values ('AVL','CATEG', NULL, 'Availability');
insert into session.MGrp values ('STATE','CATEG', NULL, 'Percentage State Measurements');
insert into session.MGrp values ('STORAG','CATEG', NULL, 'Storage');
insert into session.MGrp values ('AVG_E', 'GROUP', NULL, 'Average Value Exists');
insert into session.MGrp values ('MIN_E', 'GROUP', NULL, 'Minimum Value Exists');
insert into session.MGrp values ('MAX_E', 'GROUP', NULL, 'Maximum Value Exists');
insert into session.MGrp values ('TOT_E', 'GROUP', NULL, 'Total Value Exists');
insert into session.MGrp values ('DISABL', 'COLL', NULL, 'Measurements that are Not Currently Available for Data Collection');

insert into twg.mgrp
(MGrp_Cd, MGrpTyp_Cd, MGrp_Parent_Cd, MGrp_Nm)
select * from session.mgrp s
where not exists (
  select 1 from
  twg.mgrp t where
  t.mgrp_Cd = s.mgrp_Cd
);


--
-- Insert measurement source codes
--
declare global temporary table msrc (
  MSrc_Cd              CHAR(6) NOT NULL,
  MSrc_Parent_Cd       CHAR(6),
  MSrc_Nm              VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.msrc values ('Tivoli', NULL, 'Tivoli Application');
insert into session.msrc values ('MODEL1', NULL, 'Tivoli Common Data Model V1');
insert into session.msrc values ('SNMP', NULL, 'Simple Network Management Protocol');
insert into session.msrc values ('SHARED', NULL, 'Shared');
insert into session.msrc values ('SDESK1', NULL, 'Service Desk');

insert into twg.msrc
(MSrc_Cd, MSrc_Parent_Cd, MSrc_Nm)
select * from session.msrc s
where not exists (
  select 1 from
  twg.msrc t where
  t.msrc_Cd = s.msrc_Cd
);


--
-- Insert measurement type codes
--
declare global temporary table MsmtTyp (
  MsmtTyp_ID           INTEGER NOT NULL,
  MUnit_Cd             CHAR(6) NOT NULL,
  MSrc_Cd              CHAR(6) NOT NULL,
  MsmtTyp_Nm           VARCHAR(120) NOT NULL,
  MsmtTyp_Ds           VARCHAR(254)
)
with replace on commit preserve rows not logged
;
--MODEL1 Measurements
insert into session.MsmtTyp values (0, 'Min','MODEL1','Available', 'The amount of time that the resource is available');
insert into session.MsmtTyp values (0, 'Min','MODEL1','Degrading', 'The amount of time that the resource is degrading');
insert into session.MsmtTyp values (0, 'Min','MODEL1','Unavailable', 'The amount of time that the resource is unavailable');
insert into session.MsmtTyp values (0, 'Min','MODEL1','Unreachable', 'The amount of time that the resource is unreachable');
insert into session.MsmtTyp values (0, 'Min','MODEL1','Responding', 'The amount of time that it took to detect, isolate, and respond to a problem with the resource');
insert into session.MsmtTyp values (0, 'Min','MODEL1','Repairing', 'The amount of time that it took to fix the problem associated with the resource');
insert into session.MsmtTyp values (0, 'Min','MODEL1','Closing', 'The amount of time that it took to close the problem with the resource');
insert into session.MsmtTyp values (0, 'Min','MODEL1','Unknown', 'The amount of time that the state of the resource is unknown');
insert into session.MsmtTyp values (0, 'Min','MODEL1','Unmanaged', 'The amount of time that the resource is unmanaged');
insert into session.MsmtTyp values (0, 'Min','MODEL1','Number of Transactions', 'The number of times that the resource has changed state');
insert into session.MsmtTyp values (0, 'QTY','MODEL1','Number of Bytes Sent', 'The number of bytes sent');
insert into session.MsmtTyp values (0, 'QTY','MODEL1','Number of Bytes Received', 'The number of bytes received');
insert into session.MsmtTyp values (0, 'KB','MODEL1','Largest Outstanding Message', 'The largest message outstanding');
insert into session.MsmtTyp values (0, 'QTY','MODEL1','Number of Runs', 'The number of runs');
insert into session.MsmtTyp values (0, 'QTY','MODEL1','Number of Unsuccessful Runs', 'The number of runs that failed');
insert into session.MsmtTyp values (0, 'Hr','MODEL1','Duration', 'The amount of time needed to complete the process');
insert into session.MsmtTyp values (0, 'QTY','MODEL1','Hits', 'Number of hits processed by the Web Server');
insert into session.MsmtTyp values (0, 'KB','MODEL1','Kilobytes Sent', 'Number of kilobytes sent from the server');
insert into session.MsmtTyp values (0, 'QTY','MODEL1','Number of Web Server Errors', 'The number of Web Server 500s status codes');
insert into session.MsmtTyp values (0, 'MSec','MODEL1','Response Time', 'The amount of time it took a process to respond');
insert into session.MsmtTyp values (0, 'MB','MODEL1','Capacity', 'Capacity');
insert into session.MsmtTyp values (0, 'MB','MODEL1','Free Space', 'Free space');
insert into session.MsmtTyp values (0, 'MB','MODEL1','Used Space', 'Used space');
insert into session.MsmtTyp values (0, 'PRC','MODEL1','Online', 'Device online');
insert into session.MsmtTyp values (0, 'PRC','MODEL1','Offline', 'Device offline');
insert into session.MsmtTyp values (0, 'PRC','MODEL1','Powered Off', 'Device is powered off');
insert into session.MsmtTyp values (0, 'PRC','MODEL1','Busy', 'Device is busy');
insert into session.MsmtTyp values (0, 'PRC','MODEL1','User Error', 'Device is in the user error state');
insert into session.MsmtTyp values (0, 'PRC','MODEL1','Hardware Error', 'Device is in the hardware error state');
insert into session.MsmtTyp values (0, 'PRC','MODEL1','No Device', 'Device is not present');
insert into session.MsmtTyp values (0, 'PRC','MODEL1','Device Unknown', 'Device status is unknown');
insert into session.MsmtTyp values (0, 'Qps','MODEL1','Number of Bytes Transmitted Rate', 'Number of bytes transmitted rate');
insert into session.MsmtTyp values (0, 'Qps','MODEL1','Number of Bytes Received Rate', 'Number of bytes received rate');
insert into session.MsmtTyp values (0, 'PRC','MODEL1','Processor Utilization', 'Processor utilization');
insert into session.MsmtTyp values (0, 'Qps','MODEL1','Transmit Packet Rate', 'Transmit packet rate');
insert into session.MsmtTyp values (0, 'Qps','MODEL1','Receive Packet Rate', 'Receive packet rate');
insert into session.MsmtTyp values (0, 'PRC','MODEL1','Transmit Utilization', 'Transmit utilization');
insert into session.MsmtTyp values (0, 'PRC','MODEL1','Receive Utilization', 'Receive utilization');
insert into session.MsmtTyp values (0, 'PRC','MODEL1','Bandwidth Utilization', 'Bandwidth utilization');
insert into session.MsmtTyp values (0, 'Qps','MODEL1','Inbound Discard Rate', 'Inbound discard rate');
insert into session.MsmtTyp values (0, 'PRC','MODEL1','Outbound Discard Rate', 'Outbound discard rate');


--SNMP Measurements
insert into session.MsmtTyp values (0, 'PRC','SNMP','avgBusy5', '5 minutes exponentially-decayed moving average of the CPU busy percentage.  1.3.6.1.4.1.9.2.1.58');
insert into session.MsmtTyp values (0, 'PRC','SNMP','cpmCPUTotal5min', 'The overall CPU busy percentage in the 5 minute period.    1.3.6.1.4.1.9.9.109.1.1.1.1.5');
insert into session.MsmtTyp values (0, 'B','SNMP','ciscomemoryPoolFree', 'Number of bytes from memory pool that are currently unused on the managed device.  Sum of ciscoMemoryPoolUsed and ciscoMemoryPoolFree is total amount of memory in the pool.  1.3.6.1.4.1.9.9.48.1.1.1.6');
insert into session.MsmtTyp values (0, 'PRC','SNMP','Medium Buffer Ratio', '(BufferMdMiss/bufferMdHit)*100  bufferMdMiss (1.3.6.1.4.1.9.2.1.27) contains the number of medium buffer misses.  BufferMdHit contains the number of medium buffer hits.  1.3.6.1.4.1.9.2.1.26');
insert into session.MsmtTyp values (0, 'PRC','SNMP','sysTraffic', 'Traffic meter value, i.e. the percentage of bandwidth utilization for the previous polling interval.  1.3.6.1.4.1.9.1.5.1.1.8');
insert into session.MsmtTyp values (0, 'PRC','SNMP','sysTrafficMeter', 'Traffic meter value, i.e. the percentage of bandwidth utilization for the previous polling interval.  1.3.6.1.4.1.9.5.1.1.32.1.2');
insert into session.MsmtTyp values (0, 'QTY','SNMP','bufferNoMem', 'Count of the number of buffer create failures due to no free memory.  1.3.6.1.4.1.9.2.1.47');
insert into session.MsmtTyp values (0, 'QTY','SNMP','ifInOctets', 'The total number of octets received on the interface, including farming characters.  1.3.6.1.2.1.2.2.1.10');
insert into session.MsmtTyp values (0, 'QTY','SNMP','ifOutOctets', 'The total number of octets transmitted out of the interface, including framing characters.  1.3.6.1.2.1.2.2.1.16');
insert into session.MsmtTyp values (0, 'PRC','SNMP','Bandwidth Utilization for Number of Octets', '(IfInOctets+IfOutOctets)*8*100/time*IfSpeed  IfSpeed is an estimate of the interface''s current bandwidth in bits per second.  IfSpeed = 1.3.6.1.2.1.2.2.1.5');
insert into session.MsmtTyp values (0, 'QTY','SNMP','ifInUcastPkts', 'Number of packets, delivered by this sub-layer to a higher (sub-)layer, which were not addressed to a multicast or broadcast address at this sub-layer.  1.3.6.1.2.1.2.2.1.17');
insert into session.MsmtTyp values (0, 'QTY','SNMP','ifOutUcastPkts', 'Total number of packets that higher-level protocols requested to be transmitted, and which were not addressed to a multicast or broadcast address at this sub-layer, including those that were discarded or not sent.  1.3.6.1.2.1.2.2.1.17');
insert into session.MsmtTyp values (0, 'QTY','SNMP','ifInNUcastPkts', 'Number of packets, delivered by this sub-layer to a higher (sub-)layer, which were addressed to a multicast or broadcast address at this sub-layer.  1.3.6.1.2.1.31.1.1.1.3');
insert into session.MsmtTyp values (0, 'QTY','SNMP','ifInBroadcastPkts', 'Number of packets, delivered by this sub-layer to a higher (sub-)layer, which were addressed to a broadcast address at this sub-layer.  1.3.6.1.2.1.31.1.1.1.3');
insert into session.MsmtTyp values (0, 'QTY','SNMP','ifOutBroadcastPkts', 'Number of packets that higher-level protocols requested be transmitted, and which were addressed to a broadcast address at this sub-layer, including those that were discarded or not sent.   1.3.6.1.2.1.31.1.1.1.5');
insert into session.MsmtTyp values (0, 'QTY','SNMP','ifInMulticastPkts', 'Number of packets, delivered by this sub-layer to a higher (sub-)layer, which were addressed to a multicast address at this sub-layer.  1.3.6.1.2.1.31.1.1.2');
insert into session.MsmtTyp values (0, 'QTY','SNMP','ifOutMulticastPkts', 'Number of packets that higher-level protocols requested be transmitted, and which were addressed to a multicast address at this sub-layer, including those that were discarded or not sent.  1.3.6.1.2.1.31.1.1.1.4');
insert into session.MsmtTyp values (0, 'QTY','SNMP','ifInErrors', 'For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being delivered to a higher-layer protocol.  1.3.6.1.2.1.2.2.1.14');
insert into session.MsmtTyp values (0, 'QTY','SNMP','ifOutErrors', 'For packet-oriented interfaces, the number of outbound packets that could not be transmitted because of errors.  1.3.6.1.2.1.2.2.1.20');
insert into session.MsmtTyp values (0, 'PRC','SNMP','Interface Input Error Rate', 'IfInErrors*100/(IfInUcastPkts+IfInNUcastPkts)');
insert into session.MsmtTyp values (0, 'PRC','SNMP','Interface Output Error Rate', 'IfOutErrors*100/(IfInOutUcastPkts+IfOutNUcastPkts');
insert into session.MsmtTyp values (0, 'QTY','SNMP','ifInDiscards', 'Number of inbound packets which were chosen to be discarded even though no errors had been detected to prevent their being delivered to a higher-layer protocol.  1.3.6.1.2.1.2.2.1.13');
insert into session.MsmtTyp values (0, 'QTY','SNMP','ifOutDiscards', 'The number of outbound packets which were chosen to be discarded even though no errors had been detected to prevent their being transmitted.  1.3.6.1.2.1.2.2.1.19');
insert into session.MsmtTyp values (0, 'QTY','SNMP','etherStatsOctets', 'Total Number of octets (including those in bad packets) received on the network.  This excludes framing bits, but includes Frame Check Sum (FCS) octets.  1.3.6.1.2.1.16.1.1.1.4');
insert into session.MsmtTyp values (0, 'QTY','SNMP','etherStatsMulticastPkts', 'Total number of good packets that are received directed to a multicast address (excluding broadcast addresses).  1.3.6.1.2.1.16.1.1.1.7');
insert into session.MsmtTyp values (0, 'QTY','SNMP','etherStatsBroadcastPkts', 'Total number of good packets received directed to the broadcast address.  This does not include multicast packets.  1.3.6.1.2.1.16.1.1.1.6');
insert into session.MsmtTyp values (0, 'QTY','SNMP','etherStatsCRCAlignErrors', 'Total number of packets received with valid size with checksum or alignment errors.  1.3.6.1.2.1.16.1.1.1.11');
insert into session.MsmtTyp values (0, 'QTY','SNMP','etherStatsFragments', 'Total number of packets received with fewer than 64 octets, with checksum or alignment errors.   1.3.6.1.2.1.16.1.1.1.11');
insert into session.MsmtTyp values (0, 'QTY','SNMP','etherStatsJabbers', 'Total number of packets received longer than 1518 with checksum or alignment errors.  1.3.6.1.2.1.16.1.1.1.12');

--Service Desk Measurements

insert into session.MsmtTyp values (0,'QTY', 'SDESK1', 'Number of Opened Incidents', 'The number of incidents that have been opened');
insert into session.MsmtTyp values (0,'QTY', 'SDESK1', 'Number of Closed Incidents', 'The number of incidents that have been closed');
insert into session.MsmtTyp values (0,'QTY', 'SDESK1', 'Number of Opened Change Requests', 'The number of change requests that have been opened');
insert into session.MsmtTyp values (0,'QTY', 'SDESK1', 'Number of Closed Change Requests', 'The number of change requests that have been closed');
insert into session.MsmtTyp values (0,'QTY', 'SDESK1', 'Number of Successful Change Requests', 'The number of change requests that have been implemented successfully');
insert into session.MsmtTyp values (0,'QTY', 'SDESK1', 'Number of Successful Change Requests With Problems', 'The number of change requests that were implemented successfully with some problems');
insert into session.MsmtTyp values (0,'QTY', 'SDESK1', 'Number of Withdrawn Change Requests', 'The number of change requests that were withdrawn');
insert into session.MsmtTyp values (0,'QTY', 'SDESK1', 'Number of Cancelled Change Requests', 'The number of change requests that were cancelled');
insert into session.MsmtTyp values (0,'QTY', 'SDESK1', 'Number of Unsuccessful Change Requests', 'The number of change requests that were unsuccessful');
insert into session.MsmtTyp values (0,'PRC', 'SDESK1', 'Percent of Successful Change Requests', 'The percent of change requests that were implemented successfully');
insert into session.MsmtTyp values (0,'PRC', 'SDESK1', 'Percent of Successful Change Requests With Problems', 'The percent of change requests that were implemented successfully with problems');
insert into session.MsmtTyp values (0,'PRC', 'SDESK1', 'Percent of Withdrawn Change Requests', 'The percent of change requests that were withdrawn');
insert into session.MsmtTyp values (0,'PRC', 'SDESK1', 'Percent of Cancelled Change Requests', 'The percent of change requests that were cancelled');
insert into session.MsmtTyp values (0,'PRC', 'SDESK1', 'Percent of Unsuccessful Change Requests', 'The percent of change requests that were unsuccessful');
insert into session.MsmtTyp values (0,'QTY', 'SDESK1', 'Number of Emergency Change Requests', 'The number of emergency change requests');
insert into session.MsmtTyp values (0,'PRC', 'SDESK1', 'Percent of Emergency Change Requests', 'The percent of change requests that were emergency requests');

insert into twg.MsmtTyp
(MsmtTyp_ID, MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds)
select * from session.MsmtTyp s
where not exists (
  select 1 from
  twg.MsmtTyp t where
  t.MsmtTyp_Nm = s.MsmtTyp_Nm
);


--
-- Insert measurement rules
--
declare global temporary table MsmtRul (
  CompTyp_Cd           CHAR(17) NOT NULL,
  MsmtTyp_ID           INTEGER NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MsmtRul
  select 'IP_HOST', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;

insert into session.MsmtRul
  select 'IP_INTERFACE', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;

insert into session.MsmtRul
  select 'IPX_INTERFACE', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;

insert into session.MsmtRul
  select 'TME_ENDPOINT', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;

insert into session.MsmtRul
  select 'WEBSITE', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;
insert into session.MsmtRul
  select 'WEBSITE_PATH', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;
insert into session.MsmtRul
  select 'WEBSITE_QUERY', MsmtTyp_ID from twg.MsmtTyp where MsmtTyp_Nm in (
    'Available',
    'Degrading',
    'Unavailable',
    'Unreachable',
    'Responding',
    'Repairing',
    'Closing',
    'Unknown',
    'Unmanaged'
  )
;

insert into twg.MsmtRul
(CompTyp_Cd, MsmtTyp_ID)
select * from session.MsmtRul s
where not exists (
  select 1 from
  twg.MsmtRul t where
  t.CompTyp_Cd = s.CompTyp_Cd and
  t.MsmtTyp_ID = s.MsmtTyp_ID
);


--
-- Insert Attribute Types
--
declare global temporary table AttrTyp (
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Nm           VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;
--IP Types
insert into session.AttrTyp values('LAST_IP_ADDRESS','Last IP Address');
insert into session.AttrTyp values('IP_DOMAIN', 'IP Domain');
insert into session.AttrTyp values('IP_HOSTNAME', 'IP Hostname');
insert into session.AttrTyp values('IP_NET_ADDRESS', 'IP Network Address');
insert into session.AttrTyp values('LOCAL_PORT', 'Local Port');
insert into session.AttrTyp values('REMOTE_PORT', 'Remote Port');
insert into session.AttrTyp values('LOCAL_IP_ADDR', 'Local IP Address');
insert into session.AttrTyp values('INTERFACE_NAME', 'Interface Name');
insert into session.AttrTyp values('REMOTE_IP_ADDR', 'Remote IP Address');
--Tivoli Framework Types
insert into session.AttrTyp values('TME_OBJECT_ID','Tivoli Object ID');
insert into session.AttrTyp values('TME_LABEL','Tivoli Endpoint Label');
insert into session.AttrTyp values('TME_POLICY_REGION', 'Tivoli Endpoint Policy Region');
--Base Types
insert into session.AttrTyp values('CPU_MODEL_TYPE', 'CPU Model Type');
insert into session.AttrTyp values('CPU_MODEL_VERSION', 'CPU Model Version');
insert into session.AttrTyp values('OS_NAME', 'Operating System Name');
insert into session.AttrTyp values('OS_TYPE', 'Operating System Type');
insert into session.AttrTyp values('MAJOR_VERSION', 'Major Version Number');
insert into session.AttrTyp values('MINOR_VERSION', 'Minor Version Number');
insert into session.AttrTyp values('SUB_VERSION', 'Sub Version Number');
insert into session.AttrTyp values('VERSION', 'Version Number');
insert into session.AttrTyp values('CONTACT', 'Contact Name');
insert into session.AttrTyp values('MANUFACTURER', 'Manufacturer');
insert into session.AttrTyp values('MACHINE_TYPE', 'Machine Type');
insert into session.AttrTyp values('MODEL', 'Model Specification for this Hardware Device');
insert into session.AttrTyp values('SERIAL_NUMBER', 'Serial Number');
insert into session.AttrTyp values('OWNER', 'Owner');
insert into session.AttrTyp values('ORGANIZATION', 'Organization');
insert into session.AttrTyp values('GROUP', 'Group');
insert into session.AttrTyp values('NAME', 'Name');
insert into session.AttrTyp values('TYPE', 'Type');
insert into session.AttrTyp values('DESCRIPTION', 'Description');
insert into session.AttrTyp values('MANAGED_BY', 'Managed by');
insert into session.AttrTyp values('INVOKING_USER', 'Invoking User');
insert into session.AttrTyp values('ULB_BUCKET_1', 'Bucket 1 Upper Limit Boundary');
insert into session.AttrTyp values('LLB_BUCKET_1', 'Bucket 1 Lower Limit Boundary');
insert into session.AttrTyp values('ULB_BUCKET_2', 'Bucket 2 Upper Limit Boundary');
insert into session.AttrTyp values('LLB_BUCKET_2', 'Bucket 2 Lower Limit Boundary');
insert into session.AttrTyp values('ULB_BUCKET_3', 'Bucket 3 Upper Limit Boundary');
insert into session.AttrTyp values('LLB_BUCKET_3', 'Bucket 3 Lower Limit Boundary');
insert into session.AttrTyp values('ULB_BUCKET_4', 'Bucket 4 Upper Limit Boundary');
insert into session.AttrTyp values('LLB_BUCKET_4', 'Bucket 4 Lower Limit Boundary');
insert into session.AttrTyp values('ULB_BUCKET_5', 'Bucket 5 Upper Limit Boundary');
insert into session.AttrTyp values('LLB_BUCKET_5', 'Bucket 5 Lower Limit Boundary');
insert into session.AttrTyp values('GUID', 'Global Unique Identifier');
insert into session.AttrTyp values('NAME_GUID', 'Name Global Unique Identifier');
insert into session.attrtyp values ('PRIORITY', 'Priority');
insert into session.attrtyp values ('SEVERITY', 'Severity');
insert into session.attrtyp values ('FIRST_CALL_RES', 'First Call Resolution');
insert into session.attrtyp values ('COMPANY', 'Company');
insert into session.attrtyp values ('E_MAIL_ADDRESS', 'E-Mail');
insert into session.attrtyp values ('PHONE_NUMBER', 'Phone Number');
insert into session.attrtyp values ('CELL_PHONE_NUMBER', 'Cell Phone Number');
insert into session.attrtyp values ('SITE', 'Site');
insert into session.attrtyp values ('DIVISION', 'Division');
insert into session.attrtyp values ('DEPARTMENT', 'Department');
insert into session.attrtyp values ('ABSTRACT', 'Abstract');
insert into session.attrtyp values ('APPROVAL_TIMESTAP', 'Approval Timestamp');
insert into session.attrtyp values ('APPROVER_NAME', 'Approver Name');
insert into session.attrtyp values ('OPEN_TIMESTAMP', 'Open Timestamp');
insert into session.attrtyp values ('FIX_TIME', 'Incident Fix Time');
insert into session.attrtyp values ('CLOSE_TIMESTAMP', 'Close Timestamp');
insert into session.attrtyp values ('FIRST_NAME', 'First Name');
insert into session.attrtyp values ('LAST_NAME', 'Last Name');
insert into session.attrtyp values ('EMPLOYEE_NUMBER', 'Employee Number');
insert into session.attrtyp values ('ASSIGNEE_NAME', 'Assignee Name');
insert into session.attrtyp values ('IMPACT', 'Impact');
insert into session.attrtyp values ('DUE_DATE', 'Due Date');
insert into session.attrtyp values ('CLOSED_BY', 'Closed By');

insert into session.AttrTyp values('USER_LABEL', 'Label for a Component');
--valid values for URL are: - acap,afs,cid,data,dav,fax,file,ftp,gopher
--    http,https,imap,ldap,mailserver,mailto,mid,modem,news,nfs,nntp
--    opaquelocktoken,pop,prospero,rtsp,service,sip,soap.beep,soap.beeps
--    tel,telnet,tip,tn3270,urn,vemmi,wais,z39.50r,z39.50s

--Software License
insert into session.AttrTyp values('SOFTWARE_PRODUCT', 'Software Product');
insert into session.AttrTyp values('LIC_REF_CODE', 'License Reference Code');

--Web Types
insert into session.AttrTyp values('URL_PROTOCOL', 'Protocol Portion of a URL');

--Web Application Server Types
insert into session.AttrTyp values('J2EE_NODE', 'J2EE Node');
insert into session.AttrTyp values('J2EE_DOMAIN', 'J2EE Domain');
insert into session.AttrTyp values('J2EE_SERVER', 'J2EE Server');

--Services
insert into session.AttrTyp values('SERVICE', 'Service');
--Business Systems
insert into session.AttrTyp values('BUSINESS_SYSTEM', 'Business System');
--z/OS Types
insert into session.AttrTyp values('CF_MODEL_TYPE', 'Coupling Facility Model Type');
insert into session.AttrTyp values('CF_MODEL_VERSION', 'Coupling Facility Model Version');
insert into session.AttrTyp values('MVS_SUBSYS_TYPE', 'MVS Subsystem Type');
insert into session.AttrTyp values('MVS_SYSAPPL_TYPE', 'MVS System Application Type');
--MQ Types
insert into session.AttrTyp values('MQ_ADAPTER_TYPE', 'MQ Adapter Type');
--SNA Types
insert into session.AttrTyp values('SNA_CCU_TYPE', 'SNA Communication Control Unit Type');
insert into session.AttrTyp values('SNA_LINE_TYPE', 'SNA Line Type');
insert into session.AttrTyp values('SNA_PU_TYPE', 'SNA Physical Unit Type');

--Service Desk Types

insert into session.attrtyp values ('INCIDENT','Incident');
insert into session.attrtyp values ('CHANGE_REQUEST','Change Requests');
insert into session.attrtyp values ('SD_ASSETS_AFFECTD','Assets Affected');
insert into session.attrtyp values ('SD_RISK_LEVEL','Risk Level');
insert into session.attrtyp values ('SD_ASSIGN_GROUP', 'Assignment Group');
insert into session.attrtyp values ('SD_CAUSE_CODE', 'Incident Cause Code');
insert into session.attrtyp values ('SD_PROBLEM_TYPE', 'Problem Type');
insert into session.attrtyp values ('SD_PRODUCT_TYPE', 'Product Type');
insert into session.attrtyp values ('SD_STATUS_CODE', 'Service Desk Status Code');
insert into session.attrtyp values ('SD_REPORTD_BY_NM', 'Reported By');
insert into session.attrtyp values ('SD_SITE_CATEGORY','Site Category');
insert into session.attrtyp values ('SD_RELATED_CHNGS', 'Related Changes');
insert into session.attrtyp values ('SD_RELATED_INCS', 'Related Incidents');
insert into session.attrtyp values ('SD_COMPONENT', 'Service Desk Component');
insert into session.attrtyp values ('SD_ITEM', 'Service Desk Item');
insert into session.attrtyp values ('SD_MODULE', 'Service Desk Module');
insert into session.attrtyp values ('SD_SYSTEM', 'Service Desk System');

--- begin Service Desk User Data
--- SD_USER_TYPE is one of Requestor, Contact
insert into session.attrtyp values ('SD_USER_TYPE', 'User Type');
insert into session.attrtyp values ('SD_USERID', 'User Identification (User ID)');

--- begin Change Data
insert into session.attrtyp values ('CHANGE','Change Request');
insert into session.attrtyp values ('CR_APP_STATUS', 'Change Request Approval Status');
insert into session.attrtyp values ('CR_COMPLETE_DATE', 'Change Request Complete Date');
insert into session.attrtyp values ('CR_REQUEST_DATE', 'Requested Date for the Change Request ');
insert into session.attrtyp values ('CR_STATUS_CODE', 'Change Request Status Code');
insert into session.attrtyp values ('CR_BACKOUT_PLAN', 'Change Request Backout Plan');
insert into session.attrtyp values ('CR_COMPLETION_CD', 'Completion Code');
insert into session.attrtyp values ('CR_PRIORITY', 'Change Request Priority');
insert into session.attrtyp values ('CR_ACT_START', 'Change Request Actual Start Date and Time');
insert into session.attrtyp values ('CR_ACT_END', 'Change Request Actual End Date and Time');
insert into session.attrtyp values ('CR_ACT_OUTAGE_ED', 'Change Request Actual Outage End Date and Time');
insert into session.attrtyp values ('CR_ACT_OUTAGE_ST', 'Change Request Actual Outage Start Date and Time');
insert into session.attrtyp values ('CR_PLAN_START', 'Change Request Planned Start Date and Time');
insert into session.attrtyp values ('CR_PLAN_END', 'Change Request Planned End Date and Time');
insert into session.attrtyp values ('CR_PLAN_OUTAGE_ST', 'Change Request Planned Outage Start Date and Time');
insert into session.attrtyp values ('CR_PLAN_OUTAGE_ED', 'Change Request Planned Outage End Date and Time');
insert into session.attrtyp values ('CR_START_DELAY', 'Change Request Start Delay (in minutes)');
insert into session.attrtyp values ('CR_END_DELAY', 'Change Request End Delay (in minutes)');
insert into session.attrtyp values ('CR_APP_ACTION', 'Change Request Approval Actions');
insert into session.attrtyp values ('SD_COORDINATOR_NM', 'Change Request Coordinator Name');

--- begin Task Data
insert into session.attrtyp values ('CR_TASK','Task');
insert into session.attrtyp values ('CR_TASK_PHASE', 'Task Phase');
insert into session.attrtyp values ('CR_TASK_STATUS', 'Task Status');
INSERT INTO session.attrtyp VALUES ('CR_TASK_DESC', 'Task Description');


insert into TWG.AttrTyp
(AttrTyp_Cd, AttrTyp_Nm)
select * from
 session.AttrTyp s
where not exists
( select 1 from
  TWG.AttrTyp t
  where
  t.AttrTyp_Cd=s.AttrTyp_Cd )
;

--
-- Insert Attribute Rules
--
declare global temporary table AttrRul (
       CompTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrRul_Strt_DtTm    TIMESTAMP NOT NULL,
       AttrRul_End_DtTm     TIMESTAMP NOT NULL,
       AttrRul_Dom_Ind      CHAR NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.AttrRul values('IP_HOST','LAST_IP_ADDRESS',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','TME_OBJECT_ID',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','TME_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','OS_NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','OS_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','MAJOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','MINOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','SUB_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','CONTACT',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','MANUFACTURER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','MACHINE_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','MODEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','SERIAL_NUMBER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','IP_DOMAIN',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','IP_HOSTNAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','IP_NET_ADDRESS',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','DESCRIPTION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','USER_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_HOST','URL_PROTOCOL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');

insert into session.AttrRul values('IP_INTERFACE','TME_OBJECT_ID',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','TME_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','OS_NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','OS_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','MAJOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','MINOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','SUB_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','CONTACT',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','MANUFACTURER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','MACHINE_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','MODEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','SERIAL_NUMBER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','IP_DOMAIN',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','IP_NET_ADDRESS',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','DESCRIPTION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','USER_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IP_INTERFACE','URL_PROTOCOL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');

insert into session.AttrRul values('IPX_INTERFACE','TME_OBJECT_ID',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','TME_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','OS_NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','OS_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','MAJOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','MINOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','SUB_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','CONTACT',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','MANUFACTURER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','MACHINE_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','MODEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','SERIAL_NUMBER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','IP_DOMAIN',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','IP_NET_ADDRESS',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','DESCRIPTION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','USER_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('IPX_INTERFACE','URL_PROTOCOL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');

insert into session.AttrRul values('TME_ENDPOINT','TME_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','OS_NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','OS_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','MAJOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','MINOR_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','SUB_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','CONTACT',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','MANUFACTURER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','MACHINE_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','MODEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','SERIAL_NUMBER',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','IP_DOMAIN',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','IP_HOSTNAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','IP_NET_ADDRESS',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','NAME',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','DESCRIPTION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','USER_LABEL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('TME_ENDPOINT','URL_PROTOCOL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');

insert into session.AttrRul values('WEBSITE','URL_PROTOCOL',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');

insert into session.AttrRul values('MVS_SUBSYSTEM','MVS_SUBSYS_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('MVS_SUBSYSTEM','MVS_SYSAPPL_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('CEC','CPU_MODEL_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('CEC','CPU_MODEL_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('COUPLING_FACILITY','CF_MODEL_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('COUPLING_FACILITY','CF_MODEL_VERSION',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('MQ_ADAPTER','MQ_ADAPTER_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('SNA_CCU','SNA_CCU_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('SNA_LINE','SNA_LINE_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('SNA_PU','SNA_PU_TYPE',
  current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');

insert into TWG.AttrRul
(CompTyp_Cd, AttrTyp_Cd, AttrRul_Strt_DtTm, AttrRul_End_DtTm, AttrRul_Dom_Ind)
select * from
 session.AttrRul s
where not exists
( select 1 from
  TWG.AttrRul t,
  TWG.CompTyp c
  where
  t.AttrTyp_Cd=s.AttrTyp_Cd and c.CompTyp_Cd=s.CompTyp_Cd)
;
