-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: Common/src/tedw_app/amy/fixpack5/etl/sql/amy_m05_s005_mart_prepare_stage.db2, tmnt_etl, tmnt_5.1.1_FP06, 512ITMFP01_0616
-- #   Revision: 1.3
-- #   Date: 1/30/04 09:33:55
-- ############################################################################

--
-- the vf_* views are replaced by the AMY.STG_HOST_TP_* tables for performance reasons;
-- tose tables are created by the new step amy_m05_s005_mart_prepare_stage, which has
-- the TWH_MART as source and target DB.
--

---------------------
-- PROCESS
---------------------

--#IGNORE_ERROR
drop table AMY.STG_HOST_TO_PROCESS;

create table AMY.STG_HOST_TO_PROCESS(
 orig_PROCESS_id integer not null, 
 PROCESS_Nm	varchar(254) not null,
 orig_host_id integer not null, 
 host_ip_ad varchar(254),
primary key(orig_PROCESS_id)
);

insert into AMY.STG_HOST_TO_PROCESS
select
 c1.comp_id as orig_PROCESS_id,
 c1.comp_nm as PROCESS_Nm,
 c1.comp_corr_id as orig_host_id,
 value (ca1.compattr_val, 'UNKNOWN')  as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2 left outer join twg.cur_compattr ca1 on c2.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'LAST_IP_ADDRESS'
WHERE
 c1.comptyp_cd = 'AMY_PROCESS' and
 c2.comptyp_cd in ('AMY_HOST', 'IP_HOST') and
 c2.comp_id = c1.comp_corr_id
; 

insert into AMY.STG_HOST_TO_PROCESS
select
 c1.comp_id as orig_PROCESS_id,
 c1.comp_nm as PROCESS_Nm,
 c1.comp_corr_id as orig_host_id,
 c2.comp_nm as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2
WHERE
 c1.comptyp_cd = 'AMY_PROCESS' and
 c2.comptyp_cd = 'IP_INTERFACE' and
 c2.comp_id = c1.comp_corr_id
; 

---------------------
-- FILE
---------------------

--#IGNORE_ERROR
drop table AMY.STG_HOST_TO_FILE;

create table AMY.STG_HOST_TO_FILE(
 orig_FILE_id integer not null,
 FMode	      varchar(254),
 FOwner	      varchar(254),
 FGroup       varchar(254),
 orig_host_id integer not null, 
 host_ip_ad varchar(254),
primary key(orig_FILE_id)
);

insert into AMY.STG_HOST_TO_FILE
select
 c1.comp_id as orig_FILE_id,
 value (ca1.compattr_val, 'UNKNOWN') as FMode,
 value (ca2.compattr_val, 'UNKNOWN') as FOwner,
 value (ca3.compattr_val, 'UNKNOWN') as FGroup,
 c1.comp_corr_id as orig_host_id,
 value (ca4.compattr_val, 'UNKNOWN')  as Host_ip_ad
from
 twg.cur_comp c1 left outer join twg.cur_compattr ca1 on c1.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'AMY_FMODE',
 twg.cur_comp c2 left outer join twg.cur_compattr ca2 on c2.comp_id = ca2.comp_id and ca2.attrtyp_cd = 'AMY_FOWNER',
 twg.cur_comp c3 left outer join twg.cur_compattr ca3 on c3.comp_id = ca3.comp_id and ca3.attrtyp_cd = 'AMY_FGROUP',
 twg.cur_comp c4 left outer join twg.cur_compattr ca4 on c4.comp_id = ca4.comp_id and ca4.attrtyp_cd = 'LAST_IP_ADDRESS'
WHERE
 c1.comptyp_cd = 'AMY_FILE' and
 c1.comp_id = c2.comp_id and
 c1.comp_id = c3.comp_id and 
 c4.comptyp_cd in ('AMY_HOST', 'IP_HOST') and
 c4.comp_id = c1.comp_corr_id
; 

insert into AMY.STG_HOST_TO_FILE
select
c1.comp_id as orig_FILE_id,
 value (ca1.compattr_val, 'UNKNOWN') as FMode,
 value (ca2.compattr_val, 'UNKNOWN') as FOwner,
 value (ca3.compattr_val, 'UNKNOWN') as FGroup,
 c1.comp_corr_id as orig_host_id,
 c4.comp_nm as Host_ip_ad
from
 twg.cur_comp c1 left outer join twg.cur_compattr ca1 on c1.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'AMY_FMODE',
 twg.cur_comp c2 left outer join twg.cur_compattr ca2 on c2.comp_id = ca2.comp_id and ca2.attrtyp_cd = 'AMY_FOWNER',
 twg.cur_comp c3 left outer join twg.cur_compattr ca3 on c3.comp_id = ca3.comp_id and ca3.attrtyp_cd = 'AMY_FGROUP',
 twg.cur_comp c4
WHERE
 c1.comptyp_cd = 'AMY_FILE' and
 c1.comp_id = c2.comp_id and
 c1.comp_id = c3.comp_id and 
 c4.comptyp_cd = 'IP_INTERFACE' and
 c4.comp_id = c1.comp_corr_id
; 

---------------------
-- FS
---------------------

--#IGNORE_ERROR
drop table AMY.STG_HOST_TO_FS;

create table AMY.STG_HOST_TO_FS(
 orig_FS_id integer not null, 
 orig_host_id integer not null, 
 host_ip_ad varchar(254),
primary key(orig_FS_id)
);

insert into AMY.STG_HOST_TO_FS
select
 c1.comp_id as orig_FS_id,
 c1.comp_corr_id as orig_host_id,
 value (ca1.compattr_val, 'UNKNOWN')  as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2 left outer join twg.cur_compattr ca1 on c2.comp_id = ca1.comp_id and  ca1.attrtyp_cd = 'LAST_IP_ADDRESS'
WHERE
 c1.comptyp_cd = 'AMY_FS' and
 c2.comptyp_cd in ('AMY_HOST', 'IP_HOST') and
 c2.comp_id = c1.comp_corr_id
; 

insert into AMY.STG_HOST_TO_FS
select
 c1.comp_id as orig_FS_id,
 c1.comp_corr_id as orig_host_id,
 c2.comp_nm as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2
WHERE
 c1.comptyp_cd = 'AMY_FS' and
 c2.comptyp_cd = 'IP_INTERFACE' and
 c2.comp_id = c1.comp_corr_id
; 

---------------------
-- CPU
---------------------

--#IGNORE_ERROR
drop table AMY.STG_HOST_TO_CPU;

create table AMY.STG_HOST_TO_CPU(
 orig_CPU_id integer not null, 
 orig_host_id integer not null, 
 host_ip_ad varchar(254),
primary key(orig_CPU_id)
);

insert into AMY.STG_HOST_TO_CPU
select
 c1.comp_id as orig_CPU_id,
 c1.comp_corr_id as orig_host_id,
 value (ca1.compattr_val, 'UNKNOWN')  as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2 left outer join twg.cur_compattr ca1 on c2.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'LAST_IP_ADDRESS'
WHERE
 c1.comptyp_cd in ('AMY_OS400BCPU', 'AMY_OS400DBCPU','AMY_OS400ICPU','AMY_OS400IFCPU','AMY_CPU') and
 c2.comptyp_cd in ('AMY_HOST', 'IP_HOST') and
 c2.comp_id = c1.comp_corr_id
; 

insert into AMY.STG_HOST_TO_CPU
select
 c1.comp_id as orig_CPU_id,
 c1.comp_corr_id as orig_host_id,
 c2.comp_nm as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2
WHERE
 c1.comptyp_cd in ('AMY_OS400BCPU', 'AMY_OS400DBCPU','AMY_OS400ICPU','AMY_OS400IFCPU','AMY_CPU') and
 c2.comptyp_cd = 'IP_INTERFACE' and
 c2.comp_id = c1.comp_corr_id
; 

---------------------
-- NETWORK
---------------------

--#IGNORE_ERROR
drop table AMY.STG_HOST_TO_NETWORK;

create table AMY.STG_HOST_TO_NETWORK(
 orig_NET_id integer not null, 
 orig_host_id integer not null, 
 host_ip_ad varchar(254),
primary key(orig_NET_id)
);

insert into AMY.STG_HOST_TO_NETWORK
select
 c1.comp_id as orig_NET_id,
 c1.comp_corr_id as orig_host_id,
 value (ca1.compattr_val, 'UNKNOWN')  as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2 left outer join twg.cur_compattr ca1 on c2.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'LAST_IP_ADDRESS'
WHERE
 c1.comptyp_cd IN ('AMY_NETWORK','AMY_IP','AMY_TCPIP','AMY_NFS','AMY_RPC','AMY_NETSEG','AMY_REDIR') and
 c2.comptyp_cd in ('AMY_HOST', 'IP_HOST') and
 c2.comp_id = c1.comp_corr_id
; 

insert into AMY.STG_HOST_TO_NETWORK
select
 c1.comp_id as orig_NET_id,
 c1.comp_corr_id as orig_host_id,
 c2.comp_nm as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2
WHERE
 c1.comptyp_cd IN ('AMY_NETWORK','AMY_IP','AMY_TCPIP','AMY_NFS','AMY_RPC','AMY_NETSEG','AMY_REDIR')and
 c2.comptyp_cd = 'IP_INTERFACE' and
 c2.comp_id = c1.comp_corr_id
; 

---------------------
-- LDISK
---------------------

--#IGNORE_ERROR
drop table AMY.STG_HOST_TO_LDISK;

create table AMY.STG_HOST_TO_LDISK(
 orig_LDISK_id integer not null, 
 orig_host_id integer not null, 
 host_ip_ad varchar(254),
primary key(orig_LDISK_id)
);

insert into AMY.STG_HOST_TO_LDISK
select
 c1.comp_id as orig_LDISK_id,
 c1.comp_corr_id as orig_host_id,
 value (ca1.compattr_val, 'UNKNOWN')  as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2 left outer join twg.cur_compattr ca1 on c2.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'LAST_IP_ADDRESS'
WHERE
 c1.comptyp_cd = 'AMY_LDISK' and
 c2.comptyp_cd in ('AMY_HOST', 'IP_HOST') and
 c2.comp_id = c1.comp_corr_id
; 

insert into AMY.STG_HOST_TO_LDISK
select
 c1.comp_id as orig_LDISK_id,
 c1.comp_corr_id as orig_host_id,
 c2.comp_nm as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2
WHERE
 c1.comptyp_cd = 'AMY_LDISK' and
 c2.comptyp_cd = 'IP_INTERFACE' and
 c2.comp_id = c1.comp_corr_id
; 

---------------------
-- MEMORY
---------------------

--#IGNORE_ERROR
drop table AMY.STG_HOST_TO_MEMORY;

create table AMY.STG_HOST_TO_MEMORY(
 orig_MEMORY_id integer not null, 
 orig_host_id integer not null, 
 host_ip_ad varchar(254),
primary key(orig_MEMORY_id)
);

insert into AMY.STG_HOST_TO_MEMORY
select
 c1.comp_id as orig_MEMORY_id,
 c1.comp_corr_id as orig_host_id,
 value (ca1.compattr_val, 'UNKNOWN')  as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2 left outer join twg.cur_compattr ca1 on c2.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'LAST_IP_ADDRESS'
WHERE
 c1.comptyp_cd in ('AMY_MEMORY','AMY_OS400SPOOL') and
 c2.comptyp_cd in ('AMY_HOST', 'IP_HOST') and
 c2.comp_id = c1.comp_corr_id
; 

insert into AMY.STG_HOST_TO_MEMORY
select
 c1.comp_id as orig_MEMORY_id,
 c1.comp_corr_id as orig_host_id,
 c2.comp_nm as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2
WHERE
 c1.comptyp_cd in ('AMY_MEMORY','AMY_OS400SPOOL') and
 c2.comptyp_cd = 'IP_INTERFACE' and
 c2.comp_id = c1.comp_corr_id
; 

---------------------
-- OS400ASP
---------------------

--#IGNORE_ERROR
drop table AMY.STG_HOST_TO_OS400ASP;

create table AMY.STG_HOST_TO_OS400ASP(
 orig_OS400ASP_id integer not null, 
 orig_host_id integer not null, 
 host_ip_ad varchar(254),
primary key(orig_OS400ASP_id)
);

insert into AMY.STG_HOST_TO_OS400ASP
select
 c1.comp_id as orig_OS400ASP_id,
 c1.comp_corr_id as orig_host_id,
 value (ca1.compattr_val, 'UNKNOWN')  as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2 left outer join twg.cur_compattr ca1 on c2.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'LAST_IP_ADDRESS'
WHERE
 c1.comptyp_cd = 'AMY_OS400ASP' and
 c2.comptyp_cd in ('AMY_HOST', 'IP_HOST') and
 c2.comp_id = c1.comp_corr_id
; 

insert into AMY.STG_HOST_TO_OS400ASP
select
 c1.comp_id as orig_OS400ASP_id,
 c1.comp_corr_id as orig_host_id,
 c2.comp_nm as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2
WHERE
 c1.comptyp_cd = 'AMY_OS400ASP' and
 c2.comptyp_cd = 'IP_INTERFACE' and
 c2.comp_id = c1.comp_corr_id
; 

---------------------
-- OS4KDISK
---------------------

--#IGNORE_ERROR
drop table AMY.STG_HOST_TO_OS4KDISK;

create table AMY.STG_HOST_TO_OS4KDISK(
 orig_OS4KDISK_id integer not null, 
 orig_host_id integer not null, 
 host_ip_ad varchar(254),
primary key(orig_OS4KDISK_id)
);

insert into AMY.STG_HOST_TO_OS4KDISK
select
 c1.comp_id as orig_OS4KDISK_id,
 c1.comp_corr_id as orig_host_id,
 value (ca1.compattr_val, 'UNKNOWN')  as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2 left outer join twg.cur_compattr ca1 on c2.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'LAST_IP_ADDRESS'
WHERE
 c1.comptyp_cd = 'AMY_OS4KDISK' and
 c2.comptyp_cd in ('AMY_HOST', 'IP_HOST') and
 c2.comp_id = c1.comp_corr_id
; 

insert into AMY.STG_HOST_TO_OS4KDISK
select
 c1.comp_id as orig_OS4KDISK_id,
 c1.comp_corr_id as orig_host_id,
 c2.comp_nm as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2
WHERE
 c1.comptyp_cd = 'AMY_OS4KDISK' and
 c2.comptyp_cd = 'IP_INTERFACE' and
 c2.comp_id = c1.comp_corr_id
; 

---------------------
-- PDISK
---------------------

--#IGNORE_ERROR
drop table AMY.STG_HOST_TO_PDISK;

create table AMY.STG_HOST_TO_PDISK(
 orig_PDISK_id integer not null, 
 orig_host_id integer not null, 
 host_ip_ad varchar(254),
primary key(orig_PDISK_id)
);

insert into AMY.STG_HOST_TO_PDISK
select
 c1.comp_id as orig_PDISK_id,
 c1.comp_corr_id as orig_host_id,
 value (ca1.compattr_val, 'UNKNOWN')  as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2 left outer join twg.cur_compattr ca1 on c2.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'LAST_IP_ADDRESS'
WHERE
 c1.comptyp_cd = 'AMY_PDISK' and
 c2.comptyp_cd in ('AMY_HOST', 'IP_HOST') and
 c2.comp_id = c1.comp_corr_id
; 

insert into AMY.STG_HOST_TO_PDISK
select
 c1.comp_id as orig_PDISK_id,
 c1.comp_corr_id as orig_host_id,
 c2.comp_nm as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2
WHERE
 c1.comptyp_cd = 'AMY_PDISK' and
 c2.comptyp_cd = 'IP_INTERFACE' and
 c2.comp_id = c1.comp_corr_id
; 

---------------------
-- PRN
---------------------

--#IGNORE_ERROR
drop table AMY.STG_HOST_TO_PRN;

create table AMY.STG_HOST_TO_PRN (
 orig_PRN_id integer not null, 
 orig_host_id integer not null, 
 host_ip_ad varchar(254),
primary key(orig_PRN_id)
);

insert into AMY.STG_HOST_TO_PRN
select
 c1.comp_id as orig_PRN_id,
 c1.comp_corr_id as orig_host_id,
 value (ca1.compattr_val, 'UNKNOWN')  as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2 left outer join twg.cur_compattr ca1 on c2.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'LAST_IP_ADDRESS'
WHERE
 c1.comptyp_cd = 'AMY_PRNQUEUE' and
 c2.comptyp_cd in ('AMY_HOST', 'IP_HOST') and
 c2.comp_id = c1.comp_corr_id
; 

insert into AMY.STG_HOST_TO_PRN
select
 c1.comp_id as orig_PRN_id,
 c1.comp_corr_id as orig_host_id,
 c2.comp_nm as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2
WHERE
 c1.comptyp_cd = 'AMY_PRNQUEUE' and
 c2.comptyp_cd = 'IP_INTERFACE' and
 c2.comp_id = c1.comp_corr_id
; 

---------------------
-- SERVER
---------------------

--#IGNORE_ERROR
drop table AMY.STG_HOST_TO_SERVER;

create table AMY.STG_HOST_TO_SERVER(
 orig_SERVER_id integer not null, 
 orig_host_id integer not null, 
 host_ip_ad varchar(254),
primary key(orig_SERVER_id)
);

insert into AMY.STG_HOST_TO_SERVER
select
 c1.comp_id as orig_SERVER_id,
 c1.comp_corr_id as orig_host_id,
 value (ca1.compattr_val, 'UNKNOWN')  as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2 left outer join twg.cur_compattr ca1 on c2.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'LAST_IP_ADDRESS'
WHERE
 c1.comptyp_cd = 'AMY_SERVER' and
 c2.comptyp_cd in ('AMY_HOST', 'IP_HOST') and
 c2.comp_id = c1.comp_corr_id
; 

insert into AMY.STG_HOST_TO_SERVER
select
 c1.comp_id as orig_SERVER_id,
 c1.comp_corr_id as orig_host_id,
 c2.comp_nm as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2
WHERE
 c1.comptyp_cd = 'AMY_SERVER' and
 c2.comptyp_cd = 'IP_INTERFACE' and
 c2.comp_id = c1.comp_corr_id
; 

---------------------
-- USER
---------------------

--#IGNORE_ERROR
drop table AMY.STG_HOST_TO_USER;

create table AMY.STG_HOST_TO_USER(
 orig_USER_id integer not null,
 UserId       varchar(254),
 orig_host_id integer not null, 
 host_ip_ad varchar(254),
primary key(orig_USER_id)
);

insert into AMY.STG_HOST_TO_USER
select
 c1.comp_id as orig_USER_id,
 value (ca1.compattr_val, 'UNKNOWN') as UserId,
 c1.comp_corr_id as orig_host_id,
 value (ca2.compattr_val, 'UNKNOWN')  as Host_ip_ad
from
 twg.cur_comp c1 left outer join twg.cur_compattr ca1 on c1.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'AMY_USRID', 
 twg.cur_comp c2 left outer join twg.cur_compattr ca2 on c2.comp_id = ca2.comp_id and ca2.attrtyp_cd = 'LAST_IP_ADDRESS'
WHERE
 c1.comptyp_cd = 'AMY_USER' and
 c2.comptyp_cd in ('AMY_HOST', 'IP_HOST') and
 c2.comp_id = c1.comp_corr_id
; 

insert into AMY.STG_HOST_TO_USER
select
 c1.comp_id as orig_USER_id,
 value (ca1.compattr_val, 'UNKNOWN') as UserId,
 c1.comp_corr_id as orig_host_id,
 c2.comp_nm as Host_ip_ad
from
 twg.cur_comp c1 left outer join twg.cur_compattr ca1 on c1.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'AMY_USRID', 
 twg.cur_comp c2
WHERE
 c1.comptyp_cd='AMY_USER' and
 c2.comptyp_cd = 'IP_INTERFACE' and
 c2.comp_id = c1.comp_corr_id
; 

---------------------
-- SYSTEM
---------------------

--#IGNORE_ERROR
drop table AMY.STG_HOST_TO_SYSTEM;

create table AMY.STG_HOST_TO_SYSTEM(
 orig_SYSTEM_id integer not null, 
 orig_host_id   integer not null, 
 host_ip_ad     varchar(254),
  primary key(orig_SYSTEM_id)
);

insert into AMY.STG_HOST_TO_SYSTEM
select
 c1.comp_id as orig_SYSTEM_id,
 c1.comp_corr_id as orig_host_id,
 value (ca1.compattr_val, 'UNKNOWN') as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2 left outer join twg.cur_compattr ca1 on c2.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'LAST_IP_ADDRESS'
WHERE
 c1.comptyp_cd = 'AMY_SYSTEM' and
 c2.comptyp_cd in ('AMY_HOST', 'IP_HOST') and
 c2.comp_id = c1.comp_corr_id
; 

insert into AMY.STG_HOST_TO_SYSTEM
select
 c1.comp_id as orig_SYSTEM_id,
 c1.comp_corr_id as orig_host_id,
 c2.comp_nm as Host_ip_ad
from
 twg.cur_comp c1,
 twg.cur_comp c2 
WHERE
 c1.comptyp_cd = 'AMY_SYSTEM' and
 c2.comptyp_cd = 'IP_INTERFACE' and
 c2.comp_id = c1.comp_corr_id
; 
