-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: Common/src/tedw_app/amy/fixpack5/etl/sql/amy_m05_s020_mart_extract.db2, tmnt_etl, tmnt_5.1.1_FP06
-- #   Revision: 1.6
-- #   Date: 2/5/04 16:49:51
-- ############################################################################

-- etl2

-- extract step - populate "translation" dimension tables
-- and stage fact table
-- translation dimension tables are used to track ids from the
-- original cdw into the star schema so you can tell where the data
-- actually came from when looking at a star schema.  star schemas
-- re-assign ids so that data from various cdws use the same ids for
-- the same thing.  remember that the translatoin dimension tables
-- are "permanent" and the stage fact table is dropped and recreated
-- each time (in the pre-extract step in fact).

-- this script is "re-written" multiple times by the java program that
-- runs execsql - once for each cdw where data is extracted.

-- get the high value for the window

--#VERSION 1.1.0.1.0

--#IGNORE_ERROR
drop table AMY.Prune_Mart_Control;
 
create table amy.Prune_Mart_Control (
  table_name  varchar(120) not null,
  pmartc_duration decimal(8,0) not null
);
 
--#INSERT_INTO_SOURCE
insert into AMY.Prune_Mart_Control
select
 table_name,
 pmartc_duration
from
 AMY.Prune_Mart_Control
;

------------------------
-- HOST
------------------------

update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_host
)
where
 extctl_source = 'TWG.COMP' and
 extctl_target = 'AMY.T_HOST_IP' and
 exists
(
   select max_value
     from AMY.ve_host
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_HOST_IP
(cdw_id,
 host_id,
 orig_host_id,
 hostname,
 NETWORK_DOMAIN,
 NETWORK_SUBDOMAIN,
 NETWORK_SUBDOMAIN2,
 SHORT_HOSTNAME,
 CUSTOMER_NAME,
 CENTER_NAME)
select
 1,
 0,
 a.orig_host_id,
 a.hostname,
 a.NETWORK_DOMAIN,
 a.NETWORK_SUBDOMAIN,
 a.NETWORK_SUBDOMAIN2,
 a.SHORT_HOSTNAME,
 a.CUSTOMER_NAME,
 a.CENTER_NAME
from
 AMY.vd_host  a,
 twg.extract_control ec
where
 ec.extctl_source='TWG.COMP'  and
 ec.extctl_target='AMY.T_HOST_IP'  and
 a.orig_host_id > ec.extctl_from_intseq and
 a.orig_host_id <= ec.extctl_to_intseq
;


-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.COMP'  and
 ec.extctl_target='AMY.T_HOST_IP'
;

---------------------------
-- AMY_CPU
---------------------------

update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_CPU_met
)
where
 extctl_source= 'AMY.STG_CPU_MET'  and
 extctl_target= 'AMY.T_CPU_METRIC'  and
exists
(
  select max_value
    from AMY.ve_CPU_met
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_CPU_METRIC
(cdw_id,
metric_id,
orig_metric_id,
met_category,
met_desc,
met_name,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
1,
0,
a.orig_metric_id,
a.met_category,
a.met_desc,
a.met_name,
a.met_units,
a.min_exists,
a.max_exists,
a.avg_exists,
a.total_exists,
a.msrc_nm
from
AMY.vd_CPU_met  a,
twg.extract_control ec
where
ec.extctl_source='AMY.STG_CPU_MET'  and
ec.extctl_target='AMY.T_CPU_METRIC'  and
a.orig_metric_id > ec.extctl_from_intseq and
a.orig_metric_id <= ec.extctl_to_intseq
;

-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='AMY.STG_CPU_MET'  and
ec.extctl_target='AMY.T_CPU_METRIC';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_CPU
)
where
extctl_source= 'TWG.COMP'  and
extctl_target= 'AMY.T_CPU'  and
exists
(
  select max_value
    from AMY.ve_CPU
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_CPU
(cdw_id,
CPU_id,
orig_CPU_id,
CPU_Nm,
CPU_Type)
select
1,
0,
a.orig_CPU_id,
a.CPU_Nm,
a.CPU_Type
from
AMY.vd_CPU  a,
twg.extract_control ec
where
ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_CPU'  and
a.orig_CPU_id > ec.extctl_from_intseq and
a.orig_CPU_id <= ec.extctl_to_intseq
;

-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_CPU';

update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_STG_CPU_HR
)
where
extctl_source= 'TWG.MSMT'  and
extctl_target= 'AMY.STG_CPU_HR'  and
exists
(
  select max_value
    from AMY.ve_STG_CPU_HR
);

-- insert from the view for the stage fact
-- table (located in the cdw)
-- into the staging fact table for the fact table
-- located in the data mart

--#INSERT_INTO_TARGET
insert into
AMY.STG_CPU_HR
(
 cdw_id, msmt_id, orig_CPU_id, CPU_id, orig_host_id, host_id, host_ip_ad, host_ip_ad_id, orig_metric_id, metric_id, meas_hour, row_exists, min_value, max_value, avg_value, total_value, sample_count)
select
 1,
 min(m.msmt_id),
 a.orig_CPU_id,
 -1,
 a.orig_host_id,
 -1,
 a.host_ip_ad,
 -1,
 m.msmttyp_id,
 -1,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm),
 'N',
 min(m.msmt_min_val),
 max(m.msmt_max_val),
 avg(m.msmt_avg_val),
 avg(m.msmt_tot_val),
 avg(m.msmt_smpl_cnt)
from
 AMY.STG_HOST_TO_CPU a,
 TWG.msmt m,
 twg.extract_control ec
where
 m.comp_id = a.orig_CPU_id and
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_CPU_HR' and
 (date(current timestamp - current timezone) - date(m.msmt_strt_dt)) <
      (select PMartC_Duration
         from AMY.Prune_Mart_Control p
        where p.Table_Name = 'AMY.F_CPU_HOUR') and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq
group by
 a.orig_CPU_id,
 a.orig_host_id,
 a.host_ip_ad,
 m.msmttyp_id,
 m.msmt_strt_dt,
 m.msmt_strt_tm
;


-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_CPU_HR';

---------------------------
-- AMY_FILE
---------------------------

update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_FILE
)
where
extctl_source= 'TWG.COMP'  and
extctl_target= 'AMY.T_FILE'  and
exists
(
  select max_value from
       AMY.ve_FILE
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_FILE
(cdw_id,
FILE_id,
orig_FILE_id,
FILE_Nm )
select
1,
0,
a.orig_FILE_id,
a.FILE_Nm
from
AMY.vd_FILE  a,
twg.extract_control ec
where
ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_FILE'  and
a.orig_FILE_id > ec.extctl_from_intseq and
a.orig_FILE_id <= ec.extctl_to_intseq
;

-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_FILE';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1) 
    from AMY.ve_STG_FILE_HR
)
where
extctl_source= 'TWG.MSMT'  and
extctl_target= 'AMY.STG_FILE_HR'  and
exists
(
  select max_value from
       AMY.ve_STG_FILE_HR
);


-- insert from the view for the stage fact
-- table (located in the cdw)
-- into the staging fact table for the fact table
-- located in the data mart

--#INSERT_INTO_TARGET
insert into
AMY.STG_FILE_HR
( cdw_id, msmt_id, orig_FILE_id, FILE_id, FMode, FOwner, FGroup, FAttribute_id, orig_host_id, host_id, host_ip_ad, host_ip_ad_id, orig_metric_id, metric_id, meas_hour, row_exists, min_value, max_value, avg_value, total_value, sample_count)
select
 1,
 min(m.msmt_id),
 a.orig_FILE_id,
 -1,
 a.FMode,
 a.FOwner,
 a.FGroup,
 -1,
 a.orig_host_id,
 -1,
 a.host_ip_ad,
 -1,
 m.msmttyp_id,
 -1,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm),
 'N',
 min(m.msmt_min_val),
 max(m.msmt_max_val),
 avg(m.msmt_avg_val),
 avg(m.msmt_tot_val),
 avg(m.msmt_smpl_cnt)
from
 AMY.STG_HOST_TO_FILE  a,
 TWG.msmt m,
 twg.extract_control ec
where
 m.comp_id = a.orig_FILE_id and
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_FILE_HR'  and
 (date(current timestamp - current timezone) - date(m.msmt_strt_dt))<
      (select PMartC_Duration
         from AMY.Prune_Mart_Control p
        where p.Table_Name= 'AMY.F_FILE_HOUR') and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq
group by
 a.orig_FILE_id,
 a.FMode,
 a.FOwner,
 a.FGroup,
 a.orig_host_id,
 a.host_ip_ad,
 m.msmttyp_id,
 m.msmt_strt_dt,
 m.msmt_strt_tm
;


-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_FILE_HR'
;

---------------------------
-- AMY_FS
---------------------------

update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1) 
    from AMY.ve_FS_met
)
where
extctl_source= 'AMY.STG_FS_MET'  and
extctl_target= 'AMY.T_FS_METRIC'  and
exists
(
  select max_value from
       AMY.ve_FS_met
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_FS_METRIC
(cdw_id,
metric_id,
orig_metric_id,
met_category,
met_desc,
met_name,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
1,
0,
a.orig_metric_id,
a.met_category,
a.met_desc,
a.met_name,
a.met_units,
a.min_exists,
a.max_exists,
a.avg_exists,
a.total_exists,
a.msrc_nm
from
AMY.vd_FS_met  a,
twg.extract_control ec
where
ec.extctl_source='AMY.STG_FS_MET'  and
ec.extctl_target='AMY.T_FS_METRIC'  and
a.orig_metric_id > ec.extctl_from_intseq and
a.orig_metric_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='AMY.STG_FS_MET'  and
ec.extctl_target='AMY.T_FS_METRIC';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1) 
    from AMY.ve_FS
)
where
extctl_source= 'TWG.COMP'  and
extctl_target= 'AMY.T_FS'  and
exists
(
  select max_value from
       AMY.ve_FS
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_FS
(cdw_id,
FS_id,
orig_FS_id,
FS_Nm )
select
1,
0,
a.orig_FS_id,
a.FS_Nm
from
AMY.vd_FS  a,
twg.extract_control ec
where
ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_FS'  and
a.orig_FS_id > ec.extctl_from_intseq and
a.orig_FS_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_FS';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1) 
    from AMY.ve_STG_FS_HR
)
where
extctl_source= 'TWG.MSMT'  and
extctl_target= 'AMY.STG_FS_HR'  and
exists
(
  select max_value from
       AMY.ve_STG_FS_HR
);


-- insert from the view for the stage fact
-- table (located in the cdw)
-- into the staging fact table for the fact table
-- located in the data mart

--#INSERT_INTO_TARGET
insert into
AMY.STG_FS_HR
( cdw_id, msmt_id, orig_FS_id, FS_id, orig_host_id, host_id, host_ip_ad, host_ip_ad_id, orig_metric_id, metric_id, meas_hour, row_exists, min_value, max_value, avg_value, total_value, sample_count)
select
 1,
 min(m.msmt_id),
 a.orig_FS_id,
 -1,
 a.orig_host_id,
 -1,
 a.host_ip_ad,
 -1,
 m.msmttyp_id,
 -1,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm),
 'N',
 min(m.msmt_min_val),
 max(m.msmt_max_val),
 avg(m.msmt_avg_val),
 avg(m.msmt_tot_val),
 avg(m.msmt_smpl_cnt)
from
 AMY.STG_HOST_TO_FS  a,
 TWG.msmt m,
 twg.extract_control ec
where
 m.comp_id = a.orig_FS_id and
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_FS_HR'  and
 (date(current timestamp - current timezone) - date(m.msmt_strt_dt))<
      (select PMartC_Duration
         from AMY.Prune_Mart_Control p
        where p.Table_Name= 'AMY.F_FS_HOUR') and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq
group by
 a.orig_FS_id,
 a.orig_host_id,
 a.host_ip_ad,
 m.msmttyp_id,
 m.msmt_strt_dt,
 m.msmt_strt_tm
;


-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_FS_HR';


---------------------------
-- AMY_IP
---------------------------

---------------------------
-- AMY_LDISK
---------------------------

update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_IO_met
)
where
extctl_source= 'AMY.STG_IO_MET'  and
extctl_target= 'AMY.T_IO_METRIC'  and
exists
(
  select max_value from
       AMY.ve_IO_met
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_IO_METRIC
(cdw_id,
metric_id,
orig_metric_id,
met_category,
met_desc,
met_name,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
1,
0,
a.orig_metric_id,
a.met_category,
a.met_desc,
a.met_name,
a.met_units,
a.min_exists,
a.max_exists,
a.avg_exists,
a.total_exists,
a.msrc_nm
from
AMY.vd_IO_met  a,
twg.extract_control ec
where
ec.extctl_source='AMY.STG_IO_MET'  and
ec.extctl_target='AMY.T_IO_METRIC'  and
a.orig_metric_id > ec.extctl_from_intseq and
a.orig_metric_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='AMY.STG_IO_MET'  and
ec.extctl_target='AMY.T_IO_METRIC';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1) 
    from AMY.ve_LDISK
)
where
extctl_source= 'TWG.COMP'  and
extctl_target= 'AMY.T_LDISK'  and
exists
(
  select max_value from
       AMY.ve_LDISK
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_LDISK
(cdw_id,
LDISK_id,
orig_LDISK_id,
LDISK_Nm )
select
1,
0,
a.orig_LDISK_id,
a.LDISK_Nm
from
AMY.vd_LDISK  a,
twg.extract_control ec
where
ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_LDISK'  and
a.orig_LDISK_id > ec.extctl_from_intseq and
a.orig_LDISK_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_LDISK';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1) 
    from AMY.ve_STG_LDISK_HR
)
where
extctl_source= 'TWG.MSMT'  and
extctl_target= 'AMY.STG_LDISK_HR'  and
exists
(
  select max_value from
       AMY.ve_STG_LDISK_HR
);


-- insert from the view for the stage fact
-- table (located in the cdw)
-- into the staging fact table for the fact table
-- located in the data mart

--#INSERT_INTO_TARGET
insert into
AMY.STG_LDISK_HR
( cdw_id, msmt_id, orig_LDISK_id, LDISK_id, orig_host_id, host_id, host_ip_ad, host_ip_ad_id, orig_metric_id, metric_id, meas_hour, row_exists, min_value, max_value, avg_value, total_value, sample_count)
select
 1,
 min(m.msmt_id),
 a.orig_LDISK_id,
 -1,
 a.orig_host_id,
 -1,
 a.host_ip_ad,
 -1,
 m.msmttyp_id,
 -1,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm),
 'N',
 min(m.msmt_min_val),
 max(m.msmt_max_val),
 avg(m.msmt_avg_val),
 avg(m.msmt_tot_val),
 avg(m.msmt_smpl_cnt)
from
 AMY.STG_HOST_TO_LDISK  a,
 TWG.msmt m,
 twg.extract_control ec
where
 m.comp_id = a.orig_LDISK_id and
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_LDISK_HR'  and
 (date(current timestamp - current timezone) - date(m.msmt_strt_dt))<
      (select PMartC_Duration
         from AMY.Prune_Mart_Control p
        where p.Table_Name= 'AMY.F_LDISK_HOUR') and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq
group by
 a.orig_LDISK_id,
 a.orig_host_id,
 a.host_ip_ad,
 m.msmttyp_id,
 m.msmt_strt_dt,
 m.msmt_strt_tm
;


-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_LDISK_HR';

---------------------------
-- AMY_MEMORY
---------------------------

update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1) 
    from AMY.ve_MEM_met
)
where
extctl_source= 'AMY.STG_MEM_MET'  and
extctl_target= 'AMY.T_MEM_METRIC'  and
exists
(
  select max_value from
       AMY.ve_MEM_met
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_MEM_METRIC
(cdw_id,
metric_id,
orig_metric_id,
met_category,
met_desc,
met_name,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
1,
0,
a.orig_metric_id,
a.met_category,
a.met_desc,
a.met_name,
a.met_units,
a.min_exists,
a.max_exists,
a.avg_exists,
a.total_exists,
a.msrc_nm
from
AMY.vd_MEM_met  a,
twg.extract_control ec
where
ec.extctl_source='AMY.STG_MEM_MET'  and
ec.extctl_target='AMY.T_MEM_METRIC'  and
a.orig_metric_id > ec.extctl_from_intseq and
a.orig_metric_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='AMY.STG_MEM_MET'  and
ec.extctl_target='AMY.T_MEM_METRIC';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1) 
    from AMY.ve_MEMORY
)
where
extctl_source= 'TWG.COMP'  and
extctl_target= 'AMY.T_MEMORY'  and
exists
(
  select max_value from
       AMY.ve_MEMORY
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_MEMORY
(cdw_id,
MEMORY_id,
orig_MEMORY_id,
MEMORY_Nm,
MEMORY_Type)
select
1,
0,
a.orig_MEMORY_id,
a.MEMORY_Nm,
a.MEMORY_Type
from
AMY.vd_MEMORY  a,
twg.extract_control ec
where
ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_MEMORY'  and
a.orig_MEMORY_id > ec.extctl_from_intseq and
a.orig_MEMORY_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_MEMORY';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_STG_MEMORY_HR
)
where
extctl_source= 'TWG.MSMT'  and
extctl_target= 'AMY.STG_MEMORY_HR'  and
exists
(
  select max_value from
       AMY.ve_STG_MEMORY_HR
);




-- insert from the view for the stage fact
-- table (located in the cdw)
-- into the staging fact table for the fact table
-- located in the data mart

--#INSERT_INTO_TARGET
insert into
AMY.STG_MEMORY_HR
( cdw_id, msmt_id, orig_MEMORY_id, MEMORY_id, orig_host_id, host_id, host_ip_ad, host_ip_ad_id, orig_metric_id, metric_id, meas_hour, row_exists, min_value, max_value, avg_value, total_value, sample_count)
select
 1,
 min(m.msmt_id),
 a.orig_MEMORY_id,
 -1,
 a.orig_host_id,
 -1,
 a.host_ip_ad,
 -1,
 m.msmttyp_id,
 -1,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm),
 'N',
 min(m.msmt_min_val),
 max(m.msmt_max_val),
 avg(m.msmt_avg_val),
 avg(m.msmt_tot_val),
 avg(m.msmt_smpl_cnt)
from
 AMY.STG_HOST_TO_MEMORY  a,
 TWG.msmt m,
 twg.extract_control ec
where
 m.comp_id = a.orig_MEMORY_id and
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_MEMORY_HR'  and
 (date(current timestamp - current timezone) - date(m.msmt_strt_dt))<
      (select PMartC_Duration
         from AMY.Prune_Mart_Control p
        where p.Table_Name= 'AMY.F_MEMORY_HOUR') and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq
group by
 a.orig_MEMORY_id,
 a.orig_host_id,
 a.host_ip_ad,
 m.msmttyp_id,
 m.msmt_strt_dt,
 m.msmt_strt_tm
;


-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_MEMORY_HR';

---------------------------
-- AMY_NETSEG
---------------------------

---------------------------
-- AMY_NETWORK
---------------------------

update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1) 
    from AMY.ve_NET_met
)
where
extctl_source= 'AMY.STG_NET_MET'  and
extctl_target= 'AMY.T_NET_METRIC'  and
exists
(
  select max_value from
       AMY.ve_NET_met
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_NET_METRIC
(cdw_id,
metric_id,
orig_metric_id,
met_category,
met_desc,
met_name,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
1,
0,
a.orig_metric_id,
a.met_category,
a.met_desc,
a.met_name,
a.met_units,
a.min_exists,
a.max_exists,
a.avg_exists,
a.total_exists,
a.msrc_nm
from
AMY.vd_NET_met  a,
twg.extract_control ec
where
ec.extctl_source='AMY.STG_NET_MET'  and
ec.extctl_target='AMY.T_NET_METRIC'  and
a.orig_metric_id > ec.extctl_from_intseq and
a.orig_metric_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='AMY.STG_NET_MET'  and
ec.extctl_target='AMY.T_NET_METRIC';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_NETWORK
)
where
extctl_source= 'TWG.COMP'  and
extctl_target= 'AMY.T_NETWORK'  and
exists
(
  select max_value from
       AMY.ve_NETWORK
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_NETWORK
(cdw_id,
NET_id,
orig_NET_id,
NET_Nm,
NET_Type)
select
1,
0,
a.orig_NET_id,
a.NET_Nm,
a.NET_Type
from
AMY.vd_NETWORK  a,
twg.extract_control ec
where
ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_NETWORK'  and
a.orig_NET_id > ec.extctl_from_intseq and
a.orig_NET_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_NETWORK';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_STG_NETWORK_HR
)
where
extctl_source= 'TWG.MSMT'  and
extctl_target= 'AMY.STG_NETWORK_HR'  and
exists
(
  select max_value from
       AMY.ve_STG_NETWORK_hr
);




-- insert from the view for the stage fact
-- table (located in the cdw)
-- into the staging fact table for the fact table
-- located in the data mart

--#INSERT_INTO_TARGET
insert into
AMY.STG_NETWORK_HR
( cdw_id, msmt_id, orig_NET_id, NET_id, orig_host_id, host_id, host_ip_ad, host_ip_ad_id, orig_metric_id, metric_id, meas_hour, row_exists, min_value, max_value, avg_value, total_value, sample_count)
select
 1,
 min(m.msmt_id),
 a.orig_NET_id,
 -1,
 a.orig_host_id,
 -1,
 a.host_ip_ad,
 -1,
 m.msmttyp_id,
 -1,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm),
 'N',
 min(m.msmt_min_val),
 max(m.msmt_max_val),
 avg(m.msmt_avg_val),
 avg(m.msmt_tot_val),
 avg(m.msmt_smpl_cnt)
from
 AMY.STG_HOST_TO_NETWORK  a,
 TWG.msmt m,
 twg.extract_control ec
where
 m.comp_id = a.orig_NET_id and
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_NETWORK_HR'  and
 (date(current timestamp - current timezone) - date(m.msmt_strt_dt))<
      (select PMartC_Duration
         from AMY.Prune_Mart_Control p
        where p.Table_Name= 'AMY.F_NETWORK_HOUR') and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq
group by
 a.orig_NET_id,
 a.orig_host_id,
 a.host_ip_ad,
 m.msmttyp_id,
 m.msmt_strt_dt,
 m.msmt_strt_tm;


-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_NETWORK_HR';

---------------------------
-- AMY_NFS
---------------------------

---------------------------
-- AMY_OS400ASP
---------------------------

update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_OS400ASP
)
where
extctl_source= 'TWG.COMP'  and
extctl_target= 'AMY.T_OS400ASP'  and
exists
(
  select max_value from
       AMY.ve_OS400ASP
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_OS400ASP
(cdw_id,
OS400ASP_id,
orig_OS400ASP_id,
OS4KASP_Nm )
select
1,
0,
a.orig_OS400ASP_id,
a.OS4KASP_Nm
from
AMY.vd_OS400ASP  a,
twg.extract_control ec
where
ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_OS400ASP'  and
a.orig_OS400ASP_id > ec.extctl_from_intseq and
a.orig_OS400ASP_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_OS400ASP';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_STG_OS400ASP_HR
)
where
extctl_source= 'TWG.MSMT'  and
extctl_target= 'AMY.STG_OS400ASP_HR'  and
exists
(
  select max_value from
       AMY.ve_STG_OS400ASP_HR
);




-- insert from the view for the stage fact
-- table (located in the cdw)
-- into the staging fact table for the fact table
-- located in the data mart

--#INSERT_INTO_TARGET
insert into
AMY.STG_OS400ASP_HR
( cdw_id, msmt_id, orig_OS400ASP_id, OS400ASP_id, orig_host_id, host_id, host_ip_ad, host_ip_ad_id, orig_metric_id, metric_id, meas_hour, row_exists, min_value, max_value, avg_value, total_value, sample_count)
select
 1,
 min(m.msmt_id),
 a.orig_OS400ASP_id,
 -1,
 a.orig_host_id,
 -1,
 a.host_ip_ad,
 -1,
 m.msmttyp_id,
 -1,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm),
 'N',
 min(m.msmt_min_val),
 max(m.msmt_max_val),
 avg(m.msmt_avg_val),
 avg(m.msmt_tot_val),
 avg(m.msmt_smpl_cnt)
from
 AMY.STG_HOST_TO_OS400ASP a,
 TWG.msmt m,
 twg.extract_control ec
where
 m.comp_id = a.orig_OS400ASP_id and
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_OS400ASP_HR'  and
 (date(current timestamp - current timezone) - date(m.msmt_strt_dt))<
      (select PMartC_Duration
         from AMY.Prune_Mart_Control p
        where p.Table_Name= 'AMY.F_OS400ASP_HOUR') and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq
group by
 a.orig_OS400ASP_id,
 a.orig_host_id,
 a.host_ip_ad,
 m.msmttyp_id,
 m.msmt_strt_dt,
 m.msmt_strt_tm
;


-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_OS400ASP_HR';

---------------------------
-- AMY_OS400BCPU
---------------------------

---------------------------
-- AMY_OS400DBCPU
---------------------------

---------------------------
-- AMY_OS400DISK
---------------------------

update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_OS4KDISK
)
where
extctl_source= 'TWG.COMP'  and
extctl_target= 'AMY.T_OS4KDISK'  and
exists
(
  select max_value from
       AMY.ve_OS4KDISK
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_OS4KDISK
(cdw_id,
OS4KDISK_id,
orig_OS4KDISK_id,
OS4KDISK_Nm )
select
1,
0,
a.orig_OS4KDISK_id,
a.OS4KDISK_Nm
from
AMY.vd_OS4KDISK  a,
twg.extract_control ec
where
ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_OS4KDISK'  and
a.orig_OS4KDISK_id > ec.extctl_from_intseq and
a.orig_OS4KDISK_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_OS4KDISK';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_STG_OS4KDISK_HR
)
where
extctl_source= 'TWG.MSMT'  and
extctl_target= 'AMY.STG_OS4KDISK_HR'  and
exists
(
  select max_value from
       AMY.ve_STG_OS4KDISK_HR
);


-- insert from the view for the stage fact
-- table (located in the cdw)
-- into the staging fact table for the fact table
-- located in the data mart

--#INSERT_INTO_TARGET
insert into
AMY.STG_OS4KDISK_HR
( cdw_id, msmt_id, orig_OS4KDISK_id, OS4KDISK_id, orig_host_id, host_id, host_ip_ad, host_ip_ad_id, orig_metric_id, metric_id, meas_hour, row_exists, min_value, max_value, avg_value, total_value, sample_count)
select
 1,
 min(m.msmt_id),
 a.orig_OS4KDISK_id,
 -1,
 a.orig_host_id,
 -1,
 a.host_ip_ad,
 -1,
 m.msmttyp_id,
 -1,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm),
 'N',
 min(m.msmt_min_val),
 max(m.msmt_max_val),
 avg(m.msmt_avg_val),
 avg(m.msmt_tot_val),
 avg(m.msmt_smpl_cnt)
from
 AMY.STG_HOST_TO_OS4KDISK  a,
 TWG.msmt m,
 twg.extract_control ec
where
 m.comp_id = a.orig_OS4KDISK_id and
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_OS4KDISK_HR'  and
 (date(current timestamp - current timezone) - date(m.msmt_strt_dt))<
      (select PMartC_Duration
         from AMY.Prune_Mart_Control p
        where p.Table_Name= 'AMY.F_OS4KDISK_HOUR') and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq
group by
 a.orig_OS4KDISK_id,
 a.orig_host_id,
 a.host_ip_ad,
 m.msmttyp_id,
 m.msmt_strt_dt,
 m.msmt_strt_tm ;


-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_OS4KDISK_HR';



---------------------------
-- AMY_OS400ICPU
---------------------------

---------------------------
-- AMY_OS400IFCPU
---------------------------

---------------------------
-- AMY_OS400SPOOL
---------------------------

---------------------------
-- AMY_PDISK
---------------------------

update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_PDISK
)
where
extctl_source= 'TWG.COMP'  and
extctl_target= 'AMY.T_PDISK'  and
exists
(
  select max_value from
       AMY.ve_PDISK
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_PDISK
(cdw_id,
PDISK_id,
orig_PDISK_id,
PDISK_Nm )
select
1,
0,
a.orig_PDISK_id,
a.PDISK_Nm
from
AMY.vd_PDISK  a,
twg.extract_control ec
where
ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_PDISK'  and
a.orig_PDISK_id > ec.extctl_from_intseq and
a.orig_PDISK_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_PDISK';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_STG_PDISK_HR
)
where
extctl_source= 'TWG.MSMT'  and
extctl_target= 'AMY.STG_PDISK_HR'  and
exists
(
  select max_value from
       AMY.ve_STG_PDISK_HR
);




-- insert from the view for the stage fact
-- table (located in the cdw)
-- into the staging fact table for the fact table
-- located in the data mart

--#INSERT_INTO_TARGET
insert into
AMY.STG_PDISK_HR
( cdw_id, msmt_id, orig_PDISK_id, PDISK_id, orig_host_id, host_id, host_ip_ad, host_ip_ad_id, orig_metric_id, metric_id, meas_hour, row_exists, min_value, max_value, avg_value, total_value, sample_count)
select
 1,
 min(m.msmt_id),
 a.orig_PDISK_id,
 -1,
 a.orig_host_id,
 -1,
 a.host_ip_ad,
 -1,
 m.msmttyp_id,
 -1,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm),
 'N',
 min(m.msmt_min_val),
 max(m.msmt_max_val),
 avg(m.msmt_avg_val),
 avg(m.msmt_tot_val),
 avg(m.msmt_smpl_cnt)
from
 AMY.STG_HOST_TO_PDISK  a,
 TWG.msmt m,
 twg.extract_control ec
where
 m.comp_id = a.orig_PDISK_id and
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_PDISK_HR'  and
 (date(current timestamp - current timezone) - date(m.msmt_strt_dt))<
      (select PMartC_Duration
         from AMY.Prune_Mart_Control p
        where p.Table_Name= 'AMY.F_PDISK_HOUR') and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq
group by
 a.orig_PDISK_id,
 a.orig_host_id,
 a.host_ip_ad,
 m.msmttyp_id,
 m.msmt_strt_dt,
 m.msmt_strt_tm
;


-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_PDISK_HR';


---------------------------
-- AMY_PORT
---------------------------

---------------------------
-- AMY_PRNQUEUE
---------------------------

update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_PRN_met
)
where
extctl_source= 'AMY.STG_PRN_MET'  and
extctl_target= 'AMY.T_PRN_METRIC'  and
exists
(
  select max_value from
       AMY.ve_PRN_met
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_PRN_METRIC
(cdw_id,
metric_id,
orig_metric_id,
met_category,
met_desc,
met_name,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
1,
0,
a.orig_metric_id,
a.met_category,
a.met_desc,
a.met_name,
a.met_units,
a.min_exists,
a.max_exists,
a.avg_exists,
a.total_exists,
a.msrc_nm
from
AMY.vd_PRN_met  a,
twg.extract_control ec
where
ec.extctl_source='AMY.STG_PRN_MET'  and
ec.extctl_target='AMY.T_PRN_METRIC'  and
a.orig_metric_id > ec.extctl_from_intseq and
a.orig_metric_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='AMY.STG_PRN_MET'  and
ec.extctl_target='AMY.T_PRN_METRIC';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_PRINTER
)
where
extctl_source= 'TWG.COMP'  and
extctl_target= 'AMY.T_PRINTER'  and
exists
(
  select max_value from
       AMY.ve_PRINTER
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_PRINTER
(cdw_id,
PRN_id,
orig_PRN_id,
PRN_Nm )
select
1,
0,
a.orig_PRN_id,
a.PRN_Nm
from
AMY.vd_PRINTER  a,
twg.extract_control ec
where
ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_PRINTER'  and
a.orig_PRN_id > ec.extctl_from_intseq and
a.orig_PRN_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_PRINTER';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_STG_PRN_HR
)
where
extctl_source= 'TWG.MSMT'  and
extctl_target= 'AMY.STG_PRN_HR'  and
exists
(
  select max_value from
       AMY.ve_STG_PRN_HR
);




-- insert from the view for the stage fact
-- table (located in the cdw)
-- into the staging fact table for the fact table
-- located in the data mart

--#INSERT_INTO_TARGET
insert into
AMY.STG_PRN_HR
( cdw_id, msmt_id, orig_PRN_id, PRN_id, orig_host_id, host_id, host_ip_ad, host_ip_ad_id, orig_metric_id, metric_id, meas_hour, row_exists, min_value, max_value, avg_value, total_value, sample_count)
select
 1,
 min(m.msmt_id),
 a.orig_PRN_id,
 -1,
 a.orig_host_id,
 -1,
 a.host_ip_ad,
 -1,
 m.msmttyp_id,
 -1,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm),
 'N',
 min(m.msmt_min_val),
 max(m.msmt_max_val),
 avg(m.msmt_avg_val),
 avg(m.msmt_tot_val),
 avg(m.msmt_smpl_cnt)
from
 AMY.STG_HOST_TO_PRN  a,
 TWG.msmt m,
 twg.extract_control ec
where
 m.comp_id = a.orig_PRN_id and
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_PRN_HR'  and
 (date(current timestamp - current timezone) - date(m.msmt_strt_dt))<
      (select PMartC_Duration
         from AMY.Prune_Mart_Control p
        where p.Table_Name= 'AMY.F_PRN_HOUR') and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq
group by
 a.orig_PRN_id,
 a.orig_host_id,
 a.host_ip_ad,
 m.msmttyp_id,
 m.msmt_strt_dt,
 m.msmt_strt_tm  ;


-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_PRN_HR';


---------------------------
-- AMY_PROCESS
---------------------------

update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_PROCESS
)
where
extctl_source= 'TWG.COMP'  and
extctl_target= 'AMY.T_PROCESS'  and
exists
(
  select max_value from
       AMY.ve_PROCESS
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_PROCESS
(cdw_id,
PROCESS_id,
orig_PROCESS_id,
PROC_Nm,
PROC_Ds
 )
select
1,
0,
a.orig_PROCESS_id,
a.PROC_Nm,
a.PROC_Ds
from
AMY.vd_PROCESS  a,
twg.extract_control ec
where
ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_PROCESS'  and
a.orig_PROCESS_id > ec.extctl_from_intseq and
a.orig_PROCESS_id <= ec.extctl_to_intseq
;


-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_PROCESS';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_STG_PROCESS_HR
)
where
extctl_source= 'TWG.MSMT'  and
extctl_target= 'AMY.STG_PROCESS_HR'  and
exists
(
  select max_value from
       AMY.ve_STG_PROCESS_HR
);




-- insert from the view for the stage fact
-- table (located in the cdw)
-- into the staging fact table for the fact table
-- located in the data mart

--#INSERT_INTO_TARGET
insert into
AMY.STG_PROCESS_HR
( cdw_id, msmt_id, orig_PROCESS_id, PROCESS_id, orig_host_id, host_id, host_ip_ad, host_ip_ad_id, orig_metric_id, metric_id, meas_hour, row_exists, min_value, max_value, avg_value, total_value, sample_count)
select
 1,
 min(m.msmt_id),
 a.orig_PROCESS_id,
 -1,
 a.orig_host_id,
 -1,
 a.host_ip_ad,
 -1,
 m.msmttyp_id,
 -1,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm),
 'N',
 min(m.msmt_min_val),
 max(m.msmt_max_val),
 avg(m.msmt_avg_val),
 avg(m.msmt_tot_val),
 avg(m.msmt_smpl_cnt)
from
 AMY.STG_HOST_TO_PROCESS a,
 TWG.msmt m,
 twg.extract_control ec
where
 m.comp_id = a.orig_PROCESS_id and
 ec.extctl_source='TWG.MSMT' and
 ec.extctl_target='AMY.STG_PROCESS_HR'  and
 (date(current timestamp - current timezone) - date(m.msmt_strt_dt))<
      (select PMartC_Duration
         from AMY.Prune_Mart_Control p
        where p.Table_Name= 'AMY.F_PROCESS_HOUR') and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq
group by
 a.orig_PROCESS_id,
 a.orig_host_id,
 a.host_ip_ad,
 m.msmttyp_id,
 m.msmt_strt_dt,
 m.msmt_strt_tm
;


-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_PROCESS_HR';

---------------------------
-- AMY_REDIR
---------------------------

---------------------------
-- AMY_RPC
---------------------------

---------------------------
-- AMY_SERVER
---------------------------

update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_SERVER_met
)
where
extctl_source= 'AMY.STG_SERVER_MET'  and
extctl_target= 'AMY.T_SERVER_METRIC'  and
exists
(
  select max_value from
       AMY.ve_SERVER_met
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_SVR_METRIC
(cdw_id,
metric_id,
orig_metric_id,
met_category,
met_desc,
met_name,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
1,
0,
a.orig_metric_id,
a.met_category,
a.met_desc,
a.met_name,
a.met_units,
a.min_exists,
a.max_exists,
a.avg_exists,
a.total_exists,
a.msrc_nm
from
AMY.vd_SERVER_met  a,
twg.extract_control ec
where
ec.extctl_source='AMY.STG_SERVER_MET'  and
ec.extctl_target='AMY.T_SERVER_METRIC'  and
a.orig_metric_id > ec.extctl_from_intseq and
a.orig_metric_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='AMY.STG_SERVER_MET'  and
ec.extctl_target='AMY.T_SERVER_METRIC';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_SERVER
)
where
extctl_source= 'TWG.COMP'  and
extctl_target= 'AMY.T_SERVER'  and
exists
(
  select max_value from
       AMY.ve_SERVER
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_SERVER
(cdw_id,
SERVER_id,
orig_SERVER_id,
SERVER_Nm )
select
1,
0,
a.orig_SERVER_id,
a.SERVER_Nm
from
AMY.vd_SERVER  a,
twg.extract_control ec
where
ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_SERVER'  and
a.orig_SERVER_id > ec.extctl_from_intseq and
a.orig_SERVER_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_SERVER';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_STG_SERVER_HR
)
where
extctl_source= 'TWG.MSMT'  and
extctl_target= 'AMY.STG_SERVER_HR'  and
exists
(
  select max_value from
       AMY.ve_STG_SERVER_HR
);

-- insert from the view for the stage fact
-- table (located in the cdw)
-- into the staging fact table for the fact table
-- located in the data mart

--#INSERT_INTO_TARGET
insert into
AMY.STG_SERVER_HR
( cdw_id, msmt_id, orig_SERVER_id, SERVER_id, orig_host_id, host_id, host_ip_ad, host_ip_ad_id, orig_metric_id, metric_id, meas_hour, row_exists, min_value, max_value, avg_value, total_value, sample_count)
select
 1,
 min(m.msmt_id),
 a.orig_SERVER_id,
 -1,
 a.orig_host_id,
 -1,
 a.host_ip_ad,
 -1,
 m.msmttyp_id,
 -1,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm),
 'N',
 min(m.msmt_min_val),
 max(m.msmt_max_val),
 avg(m.msmt_avg_val),
 avg(m.msmt_tot_val),
 avg(m.msmt_smpl_cnt)
from
 AMY.STG_HOST_TO_SERVER  a,
 TWG.msmt m,
 twg.extract_control ec
where
 m.comp_id = a.orig_SERVER_id and
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_SERVER_HR'  and
 (date(current timestamp - current timezone) - date(m.msmt_strt_dt))<
      (select PMartC_Duration
         from AMY.Prune_Mart_Control p
        where p.Table_Name= 'AMY.F_SERVER_HOUR') and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq
group by
 a.orig_SERVER_id,
 a.orig_host_id,
 a.host_ip_ad,
 m.msmttyp_id,
 m.msmt_strt_dt,
 m.msmt_strt_tm  ;


-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_SERVER_HR';

---------------------------
-- AMY_SERVICE
---------------------------
---------------------------
-- AMY_TCPIP
---------------------------
---------------------------
-- AMY_USER
---------------------------

update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_USER_met
)
where
extctl_source= 'AMY.STG_USER_MET'  and
extctl_target= 'AMY.T_USER_METRIC'  and
exists
(
  select max_value from
       AMY.ve_USER_met
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_USER_METRIC
(cdw_id,
metric_id,
orig_metric_id,
met_category,
met_desc,
met_name,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
1,
0,
a.orig_metric_id,
a.met_category,
a.met_desc,
a.met_name,
a.met_units,
a.min_exists,
a.max_exists,
a.avg_exists,
a.total_exists,
a.msrc_nm
from
AMY.vd_USER_met  a,
twg.extract_control ec
where
ec.extctl_source='AMY.STG_USER_MET'  and
ec.extctl_target='AMY.T_USER_METRIC'  and
a.orig_metric_id > ec.extctl_from_intseq and
a.orig_metric_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='AMY.STG_USER_MET'  and
ec.extctl_target='AMY.T_USER_METRIC';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_USER
)
where
extctl_source= 'TWG.COMP'  and
extctl_target= 'AMY.T_USER'  and
exists
(
  select max_value from
       AMY.ve_USER
);


--#INSERT_INTO_TARGET
insert into AMY.STG_T_USER
(cdw_id,
USER_id,
orig_USER_id,
USER_Nm )
select
1,
0,
a.orig_USER_id,
a.USER_Nm
from
AMY.vd_USER  a,
twg.extract_control ec
where
ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_USER'  and
a.orig_USER_id > ec.extctl_from_intseq and
a.orig_USER_id <= ec.extctl_to_intseq;



-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_USER';


update twg.extract_control set
extctl_to_intseq =
(
  select VALUE(max_value,-1)
    from AMY.ve_STG_USER_HR
)
where
extctl_source= 'TWG.MSMT'  and
extctl_target= 'AMY.STG_USER_HR'  and
exists
(
  select max_value from
       AMY.ve_STG_USER_HR
);


-- insert from the view for the stage fact
-- table (located in the cdw)
-- into the staging fact table for the fact table
-- located in the data mart

--#INSERT_INTO_TARGET
insert into
AMY.STG_USER_HR
( cdw_id, msmt_id, orig_USER_id, USER_id, UserId, UserId_id, orig_host_id, host_id, host_ip_ad, host_ip_ad_id, orig_metric_id, metric_id, meas_hour, row_exists, min_value, max_value, avg_value, total_value, sample_count)
select
 1,
 min(m.msmt_id),
 a.orig_USER_id,
 -1,
 a.UserId,
 -1,
 a.orig_host_id,
 -1,
 a.host_ip_ad,
 -1,
 m.msmttyp_id,
 -1,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm),
 'N',
 min(m.msmt_min_val),
 max(m.msmt_max_val),
 avg(m.msmt_avg_val),
 avg(m.msmt_tot_val),
 avg(m.msmt_smpl_cnt)
from
 AMY.STG_HOST_TO_USER  a,
 TWG.msmt m,
 twg.extract_control ec
where
 m.comp_id = a.orig_USER_id and
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_USER_HR'  and
 (date(current timestamp - current timezone) - date(m.msmt_strt_dt))<
      (select PMartC_Duration
         from AMY.Prune_Mart_Control p
        where p.Table_Name= 'AMY.F_USER_HOUR') and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq
group by
 a.orig_USER_id,
 a.UserId,
 a.orig_host_id,
 a.host_ip_ad,
 m.msmttyp_id,
 m.msmt_strt_dt,
 m.msmt_strt_tm ;


-- sql statement to update the extract control log
insert into twg.extract_log
select
 ec.extctl_source as extlog_source,
 ec.extctl_target as extlog_target,
 current timestamp as extlog_done_dttm,
 ec.extctl_from_rawseq as extlog_from_rawseq,
 ec.extctl_to_rawseq as extlog_to_rawseq,
 ec.extctl_from_intseq as extlog_from_intseq,
 ec.extctl_to_intseq as extlog_to_intseq,
 ec.extctl_from_dttm as extlog_from_dttm,
 ec.extctl_to_dttm as extlog_to_dttm
from
 twg.extract_control ec
where
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_USER_HR'
;

---------------------------
-- AMY_SYSTEM
---------------------------

update twg.extract_control set  
extctl_to_intseq = 
( 
  select VALUE(max_value,-1)
    from AMY.ve_SYSTEM_met 
) 
where  
extctl_source= 'AMY.STG_SYSTEM_MET'  and 
extctl_target= 'AMY.T_SYSTEM_METRIC'  and 
exists 
( 
  select max_value from 
       AMY.ve_SYSTEM_met 
); 
 

--#INSERT_INTO_TARGET 
insert into AMY.STG_T_SYSTEM_METRIC 
(cdw_id,
metric_id,
orig_metric_id,
met_category,
met_desc,
met_name,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm) 
select 
1,
0,
a.orig_metric_id,
a.met_category,
a.met_desc,
a.met_name,
a.met_units,
a.min_exists,
a.max_exists,
a.avg_exists,
a.total_exists,
a.msrc_nm 
from 
AMY.vd_SYSTEM_met  a, 
twg.extract_control ec 
where 
ec.extctl_source='AMY.STG_SYSTEM_MET'  and
ec.extctl_target='AMY.T_SYSTEM_METRIC'  and
a.orig_metric_id > ec.extctl_from_intseq and
a.orig_metric_id <= ec.extctl_to_intseq  ; 
 
 

-- sql statement to update the extract control log 
insert into twg.extract_log 
select 
 ec.extctl_source as extlog_source, 
 ec.extctl_target as extlog_target, 
 current timestamp as extlog_done_dttm, 
 ec.extctl_from_rawseq as extlog_from_rawseq, 
 ec.extctl_to_rawseq as extlog_to_rawseq, 
 ec.extctl_from_intseq as extlog_from_intseq, 
 ec.extctl_to_intseq as extlog_to_intseq, 
 ec.extctl_from_dttm as extlog_from_dttm, 
 ec.extctl_to_dttm as extlog_to_dttm 
from 
 twg.extract_control ec 
where 
 ec.extctl_source='AMY.STG_SYSTEM_MET'  and
ec.extctl_target='AMY.T_SYSTEM_METRIC'; 
 

update twg.extract_control set  
extctl_to_intseq = 
( 
  select VALUE(max_value,-1)
    from AMY.ve_SYSTEM
) 
where  
extctl_source= 'TWG.COMP'  and 
extctl_target= 'AMY.T_SYSTEM'  and 
exists 
( 
  select max_value from 
       AMY.ve_SYSTEM 
); 
 

--#INSERT_INTO_TARGET 
insert into AMY.STG_T_SYSTEM 
(cdw_id,
SYSTEM_id,
orig_SYSTEM_id, 
SYSTEM_Nm,
SYSTEM_Type) 
select 
1,
0,
a.orig_SYSTEM_id,
a.SYSTEM_Nm,
a.SYSTEM_Type
from 
AMY.vd_SYSTEM  a, 
twg.extract_control ec 
where 
ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_SYSTEM'  and
a.orig_SYSTEM_id > ec.extctl_from_intseq and
a.orig_SYSTEM_id <= ec.extctl_to_intseq  ; 
 
 

-- sql statement to update the extract control log 
insert into twg.extract_log 
select 
 ec.extctl_source as extlog_source, 
 ec.extctl_target as extlog_target, 
 current timestamp as extlog_done_dttm, 
 ec.extctl_from_rawseq as extlog_from_rawseq, 
 ec.extctl_to_rawseq as extlog_to_rawseq, 
 ec.extctl_from_intseq as extlog_from_intseq, 
 ec.extctl_to_intseq as extlog_to_intseq, 
 ec.extctl_from_dttm as extlog_from_dttm, 
 ec.extctl_to_dttm as extlog_to_dttm 
from 
 twg.extract_control ec 
where 
 ec.extctl_source='TWG.COMP'  and
ec.extctl_target='AMY.T_SYSTEM'; 
 

update twg.extract_control set  
extctl_to_intseq = 
( 
  select VALUE(max_value,-1)
    from AMY.ve_STG_SYSTEM_HR 
) 
where  
extctl_source= 'TWG.MSMT'  and 
extctl_target= 'AMY.STG_SYSTEM_HR'  and 
exists 
( 
  select max_value from 
       AMY.ve_STG_SYSTEM_HR 
); 
 
-- insert from the view for the stage fact 
-- table (located in the cdw) 
-- into the staging fact table for the fact table 
-- located in the data mart 

--#INSERT_INTO_TARGET 
insert into  
AMY.STG_SYSTEM_HR
( cdw_id, msmt_id, orig_SYSTEM_id, SYSTEM_id, orig_host_id, host_id, host_ip_ad,  host_ip_ad_id, orig_metric_id, metric_id, meas_hour, row_exists, min_value, max_value, avg_value, total_value, sample_count) 
select 
 1,
 min(m.msmt_id),
 a.orig_SYSTEM_id, 
 -1,
 a.orig_host_id,
 -1,
 a.host_ip_ad,
 -1,
 m.msmttyp_id,
 -1,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm),
 'N',
 min(m.msmt_min_val),
 max(m.msmt_max_val),
 avg(m.msmt_avg_val),
 avg(m.msmt_tot_val),
 avg(m.msmt_smpl_cnt)
from 
 AMY.STG_HOST_TO_SYSTEM a,
 TWG.msmt m, 
 twg.extract_control ec
where 
 m.comp_id = a.orig_SYSTEM_id and
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_SYSTEM_HR' and
 (date(current timestamp - current timezone) - date(m.msmt_strt_dt))<
      (select PMartC_Duration from AMY.Prune_Mart_Control p
        where p.Table_Name= 'AMY.F_SYSTEM_HOUR') and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq
group by
 a.orig_SYSTEM_id,
 a.orig_host_id,
 a.host_ip_ad,
 m.msmttyp_id,
 m.msmt_strt_dt,
 m.msmt_strt_tm
; 
 
-- sql statement to update the extract control log 
insert into twg.extract_log 
select 
 ec.extctl_source as extlog_source, 
 ec.extctl_target as extlog_target, 
 current timestamp as extlog_done_dttm, 
 ec.extctl_from_rawseq as extlog_from_rawseq, 
 ec.extctl_to_rawseq as extlog_to_rawseq, 
 ec.extctl_from_intseq as extlog_from_intseq, 
 ec.extctl_to_intseq as extlog_to_intseq, 
 ec.extctl_from_dttm as extlog_from_dttm, 
 ec.extctl_to_dttm as extlog_to_dttm 
from 
 twg.extract_control ec 
where 
 ec.extctl_source='TWG.MSMT'  and
 ec.extctl_target='AMY.STG_SYSTEM_HR'
; 

--===================== new update step =================================

-- AMY_MEMORY
--#EXECUTE_AT_TARGET
update AMY.STG_T_MEMORY
set MEMORY_Nm='Memory' where MEMORY_Nm='';

--AMY_SERVER
--#EXECUTE_AT_TARGET
update AMY.STG_T_SERVER
set SERVER_Nm='Server' where SERVER_Nm='';

--AMY_REDIR, AMY_IP, AMY_TCPIP
--#EXECUTE_AT_TARGET
update AMY.STG_T_NETWORK
set NET_Nm =
 case NET_type
   when 'IP' then 'IP'
   when 'TCPIP' then 'TCP'
   when 'REDIR' then 'Redirector'
   else 'N/A'
 end
where NET_Nm = ''
;

--AMY_CPU
--#EXECUTE_AT_TARGET
update AMY.STG_T_CPU
set CPU_Nm='Delta_CPU' where CPU_Nm='';

--AMY_PROCESS
--#EXECUTE_AT_TARGET
update AMY.STG_T_PROCESS
set PROC_Nm =
replace(PROC_Nm,
  substr(
    substr(ltrim(rtrim(PROC_Ds)),1,locate('@',ltrim(rtrim(PROC_Ds)))-1),
    1,
    locate('.',replace(substr(ltrim(rtrim(PROC_Ds)),1,locate('@',ltrim(rtrim(PROC_Ds)))-1),',','.'))-1
  ),
'');

