-- ##########################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: Common/src/tedw_app/amy/fixpack5/mart/ddl/amy_mart_schema.sql, tmnt_etl, tmnt_5.1.1_FP06, 512ITMFP01_0503
-- #   Revision: 1.7
-- #   Date: 1/30/04 09:34:07
-- ############################################################################

--#iftag fixpack_21
-- do nothing...
--#endtag fixpack_21

--#iftag fixpack_400
-- do nothing...
--#endtag fixpack_400

--#iftag fixpack_500

----------------------------
-- Prune tables
----------------------------

create table AMY.prune_mart_control (
table_name  varchar(120) not null,
pmartc_duration decimal(8,0) not null
);


create table AMY.prune_mart_log (
pmart_run_dttm  timestamp not null,
table_name  varchar(30),
pmartc_duration decimal(8,0) not null,
number_pruned   decimal(8,0) not null
);

----------------------------
--- Dimension Table:  Host
----------------------------

create table AMY.d_host_ip (
 host_id             integer        not null,
 hostname            varchar(254)   not null,
 network_domain      varchar(120),
 network_subdomain   varchar(120),
 network_subdomain2  varchar(120),
 short_hostname      varchar(64)    not null,
 customer_name       varchar(120),
 center_name         varchar(120),
      primary key (host_id)
);

-- Translation table
create table AMY.t_host_ip (
 orig_host_id        integer        not null,
 host_id             integer,
 cdw_id              integer        not null,
 hostname            varchar(254)   not null,
 network_domain      varchar(120),
 network_subdomain   varchar(120),
 network_subdomain2  varchar(120),
 short_hostname      varchar(64)    not null,
 customer_name       varchar(120),
 center_name         varchar(120),
      primary key (orig_host_id, cdw_id)
);

-- SEQUENCE
create sequence AMY.host_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER
create trigger AMY.host_i1
no cascade before insert on AMY.d_host_ip
referencing new as n for each row mode db2sql
set n.host_id = nextval for AMY.host_id_seq;

-----------------------------
-- dimension table:  host_ip_address
-----------------------------

create table AMY.D_Host_ip_ad (
 Host_ip_ad_id               integer        not null,
 Host_ip_ad                  varchar(254)   not null,
      primary key (Host_ip_ad_id));


-- SEQUENCE
create sequence AMY.Host_ip_ad_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER
create trigger AMY.Host_ip_ad_i0
no cascade before insert on AMY.d_Host_ip_ad
referencing new as n for each row mode db2sql
set n.Host_ip_ad_id = nextval for AMY.Host_ip_ad_id_seq;

--------------------
---  CPU
--------------------

---------------------------------
-- dimension table: CPU metric
---------------------------------

create table AMY.d_CPU_metric (
 metric_id         integer        not null,
 met_category      varchar(254),
 met_desc          varchar(254),
 met_name          varchar(254)   not null,
 met_units         varchar(254),
 min_exists        char(1)        not null,
 max_exists        char(1)        not null,
 avg_exists        char(1)        not null,
 total_exists      char(1)        not null,
 msrc_nm           varchar(254),
      primary key (metric_id)
);

-- translation table
create table AMY.t_CPU_metric (
  orig_metric_id    integer       not null,
  metric_id         integer       not null,
  cdw_id            integer       not null,
  met_category      varchar(254),
  met_desc          varchar(254),
  met_name          varchar(254)  not null,
  met_units         varchar(254),
  min_exists        char(1)       not null,
  max_exists        char(1)       not null,
  avg_exists        char(1)       not null,
  total_exists      char(1)       not null,
  msrc_nm           varchar(254),
    primary key (orig_metric_id, cdw_id)
);

-- SEQUENCE
create sequence AMY.CPUmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER
create trigger AMY.CPUmt_i1
no cascade before insert on AMY.d_CPU_metric
referencing new as n for each row mode db2sql
set n.metric_id = nextval for AMY.CPUmt_id_seq;

-----------------------------
-- dimension table: CPU
-----------------------------

create table AMY.D_CPU (
 CPU_Nm varchar(254),
 CPU_Type   varchar(254),
 CPU_id     integer  not null,
      primary key (CPU_id)
);

-- translation table
create table AMY.T_CPU (
 CPU_Nm varchar(254),
 CPU_Type     varchar(254),
 orig_CPU_id  integer   not null,
 cdw_id       integer   not null,
 CPU_id       integer   not null,
      primary key (orig_CPU_id,cdw_id)
);

-- SEQUENCE
create sequence AMY.CPU_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER
create trigger AMY.CPU_i1
no cascade before insert on AMY.d_CPU
referencing new as n for each row mode db2sql
set n.CPU_id = nextval for AMY.CPU_id_seq;

-----------------------------
-- staging hour fact table
------------------------------

create table AMY.STG_CPU_HR (
    msmt_id         integer   not null,
    orig_CPU_id     integer   not null,
    orig_host_id    integer   not null,
    orig_metric_id  integer   not null,
    cdw_id          integer   not null,
    meas_hour       timestamp not null,
    min_value       float,
    max_value       float,
    avg_value       float,
    total_value     float,
    sample_count    float,
       primary key (msmt_id,cdw_id)
);

----------------------------
-- hourly fact table: CPU
-----------------------------

create table AMY.F_CPU_HOUR (
 CPU_id          integer   not null,
 host_id         integer   not null,
 host_ip_ad_id   integer   not null,
 metric_id       integer   not null,
 meas_hour       timestamp not null,
 min_value       float,
 max_value       float,
 avg_value       float,
 total_value     float,
 sample_count    float,
       primary key (CPU_id,
       host_id, host_ip_ad_id, metric_id,
       meas_hour)
);

create index AMY.f_CPU_hr1 on AMY.F_CPU_HOUR (CPU_id);
create index AMY.f_CPU_hr2 on AMY.F_CPU_HOUR (host_id);
create index AMY.f_CPU_hr3 on AMY.F_CPU_HOUR (metric_id);
create index AMY.f_CPU_hr4 on AMY.F_CPU_HOUR (meas_hour);
create index AMY.f_CPU_hr5 on AMY.F_CPU_HOUR (host_ip_ad_id);

alter table AMY.F_CPU_HOUR
add constraint K1
foreign key (CPU_id)
references AMY.D_CPU (CPU_id);

alter table AMY.F_CPU_HOUR
add constraint K2
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_CPU_HOUR
add constraint K3
foreign key (metric_id)
references AMY.D_CPU_METRIC (metric_id);

alter table AMY.F_CPU_HOUR
add constraint K303
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- daily fact table: CPU
-----------------------------

create table AMY.F_CPU_DAY (
 CPU_id          integer not null,
 host_id         integer not null,
 host_ip_ad_id   integer not null,
 metric_id       integer not null,
 meas_date       timestamp not null,
 min_value       float,
 max_value       float,
 avg_value       float,
 total_value     float,
 sample_count    float,
       primary key (CPU_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
);

create index AMY.f_CPU_day1 on AMY.F_CPU_DAY (CPU_id);
create index AMY.f_CPU_day2 on AMY.F_CPU_DAY (host_id);
create index AMY.f_CPU_day3 on AMY.F_CPU_DAY (metric_id);
create index AMY.f_CPU_day4 on AMY.F_CPU_DAY (meas_date);
create index AMY.f_CPU_day5 on AMY.F_CPU_DAY (host_ip_ad_id);

alter table AMY.F_CPU_DAY
add constraint K4
foreign key (CPU_id)
references AMY.D_CPU (CPU_id);

alter table AMY.F_CPU_DAY
add constraint K5
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_CPU_DAY
add constraint K6
foreign key (metric_id)
references AMY.D_CPU_METRIC (metric_id);

alter table AMY.F_CPU_DAY
add constraint K304
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- weekly fact table: CPU
-----------------------------

create table AMY.F_CPU_WEEK (
 CPU_id         integer not null,
 host_id        integer not null,
 host_ip_ad_id  integer not null,
 metric_id      integer not null,
 meas_date      timestamp not null,
 min_value      float,
 max_value      float,
 avg_value      float,
 total_value    float,
 sample_count   float,
       primary key (CPU_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
);

create index AMY.f_CPU_wk1 on AMY.F_CPU_WEEK (CPU_id);
create index AMY.f_CPU_wk2 on AMY.F_CPU_WEEK (host_id);
create index AMY.f_CPU_wk3 on AMY.F_CPU_WEEK (metric_id);
create index AMY.f_CPU_wk4 on AMY.F_CPU_WEEK (meas_date);
create index AMY.f_CPU_wk5 on AMY.F_CPU_WEEK (host_ip_ad_id);

alter table AMY.F_CPU_WEEK
add constraint K7
foreign key (CPU_id)
references AMY.D_CPU (CPU_id);

alter table AMY.F_CPU_WEEK
add constraint K8
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_CPU_WEEK
add constraint K9
foreign key (metric_id)
references AMY.D_CPU_METRIC (metric_id);

alter table AMY.F_CPU_WEEK
add constraint K305
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- monthly fact table: CPU
-----------------------------

create table AMY.F_CPU_MONTH (
 CPU_id            integer not null,
 host_id           integer not null,
 host_ip_ad_id     integer not null,
 metric_id         integer not null,
 meas_date         timestamp not null,
 min_value         float,
 max_value         float,
 avg_value         float,
 total_value       float,
 sample_count      float,
       primary key (CPU_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
);

create index AMY.f_CPU_mo1 on AMY.F_CPU_MONTH (CPU_id);
create index AMY.f_CPU_mo2 on AMY.F_CPU_MONTH (host_id);
create index AMY.f_CPU_mo3 on AMY.F_CPU_MONTH (metric_id);
create index AMY.f_CPU_mo4 on AMY.F_CPU_MONTH (meas_date);
create index AMY.f_CPU_mo5 on AMY.F_CPU_MONTH (host_ip_ad_id);

alter table AMY.F_CPU_MONTH
add constraint K9
foreign key (CPU_id)
references AMY.D_CPU (CPU_id);

alter table AMY.F_CPU_MONTH
add constraint K10
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_CPU_MONTH
add constraint K11
foreign key (metric_id)
references AMY.D_CPU_METRIC (metric_id);

alter table AMY.F_CPU_MONTH
add constraint K306
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

--------------------
---  FS
--------------------

---------------------------------
-- dimension table: FS metric
---------------------------------

create table AMY.d_FS_metric (
 metric_id         integer        not null,
 met_category      varchar(254),
 met_desc          varchar(254),
 met_name          varchar(254)   not null,
 met_units         varchar(254),
 min_exists        char(1)        not null,
 max_exists        char(1)        not null,
 avg_exists        char(1)        not null,
 total_exists      char(1)        not null,
 msrc_nm           varchar(254),
      primary key (metric_id)
);


-- translation table

create table AMY.t_FS_metric (
  orig_metric_id    integer not null,
  metric_id         integer not null,
  cdw_id            integer not null,
  met_category      varchar(254),
  met_desc          varchar(254),
  met_name          varchar(254)   not null,
  met_units         varchar(254),
  min_exists        char(1)        not null,
  max_exists        char(1)        not null,
  avg_exists        char(1)        not null,
  total_exists      char(1)        not null,
  msrc_nm           varchar(254),
    primary key (orig_metric_id, cdw_id)
);

-- SEQUENCE
create sequence AMY.FSmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER
create trigger AMY.FSmt_i1
no cascade before insert on AMY.d_FS_metric
referencing new as n for each row mode db2sql
set n.metric_id = nextval for AMY.FSmt_id_seq;

-----------------------------
-- dimension table: FS
-----------------------------

create table AMY.D_FS (
 FS_Nm  varchar(254),
 FS_id  integer        not null,
      primary key (FS_id)
);

-- translation table

create table AMY.T_FS (
 FS_Nm  varchar(254),
 orig_FS_id      integer   not null,
 cdw_id          integer   not null,
 FS_id           integer   not null,
      primary key (orig_FS_id,cdw_id)
);

-- SEQUENCE

create sequence AMY.FS_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.FS_i1
no cascade before insert on AMY.d_FS
referencing new as n for each row mode db2sql
set n.FS_id = nextval for AMY.FS_id_seq;


-----------------------------
-- staging hour fact table
------------------------------

create table AMY.STG_FS_HR (
    msmt_id        integer not null,
    orig_FS_id     integer not null,
    orig_host_id   integer not null,
    orig_metric_id integer not null,
    cdw_id         integer not null,
    meas_hour      timestamp not null,
    min_value      float,
    max_value      float,
    avg_value      float,
    total_value    float,
    sample_count   float,
       primary key (msmt_id,cdw_id)
);

----------------------------
-- hourly fact table: FS
-----------------------------

create table AMY.F_FS_HOUR (
 FS_id            integer not null,
 host_id          integer not null,
 host_ip_ad_id    integer not null,
 metric_id        integer not null,
 meas_hour        timestamp not null,
 min_value        float,
 max_value        float,
 avg_value        float,
 total_value      float,
 sample_count     float,
       primary key (FS_id,
       host_id, host_ip_ad_id, metric_id,
       meas_hour)
);

create index AMY.f_FS_hr1 on AMY.F_FS_HOUR (FS_id);
create index AMY.f_FS_hr2 on AMY.F_FS_HOUR (host_id);
create index AMY.f_FS_hr3 on AMY.F_FS_HOUR (metric_id);
create index AMY.f_FS_hr4 on AMY.F_FS_HOUR (meas_hour);
create index AMY.f_FS_hr5 on AMY.F_FS_HOUR (host_ip_ad_id);


alter table AMY.F_FS_HOUR
add constraint K27
foreign key (FS_id)
references AMY.D_FS (FS_id);

alter table AMY.F_FS_HOUR
add constraint K28
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_FS_HOUR
add constraint K29
foreign key (metric_id)
references AMY.D_FS_METRIC (metric_id);

alter table AMY.F_FS_HOUR
add constraint K307
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- daily fact table: FS
-----------------------------

create table AMY.F_FS_DAY (
 FS_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (FS_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_FS_day1 on AMY.F_FS_DAY (FS_id);
create index AMY.f_FS_day2 on AMY.F_FS_DAY (host_id);
create index AMY.f_FS_day3 on AMY.F_FS_DAY (metric_id);
create index AMY.f_FS_day4 on AMY.F_FS_DAY (meas_date);
create index AMY.f_FS_day5 on AMY.F_FS_DAY (host_ip_ad_id);

alter table AMY.F_FS_DAY
add constraint K30
foreign key (FS_id)
references AMY.D_FS (FS_id);

alter table AMY.F_FS_DAY
add constraint K31
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_FS_DAY
add constraint K32
foreign key (metric_id)
references AMY.D_FS_METRIC (metric_id);

alter table AMY.F_FS_DAY
add constraint K308
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- weekly fact table: FS
-----------------------------

create table AMY.F_FS_WEEK (
 FS_id         integer not null,
 host_id        integer not null,
 host_ip_ad_id         integer not null,
 metric_id      integer not null,
 meas_date      timestamp not null,
 min_value      float,
 max_value      float,
 avg_value      float,
 total_value        float,
 sample_count       float,
       primary key (FS_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_FS_wk1 on AMY.F_FS_WEEK (FS_id);
create index AMY.f_FS_wk2 on AMY.F_FS_WEEK (host_id);
create index AMY.f_FS_wk3 on AMY.F_FS_WEEK (metric_id);
create index AMY.f_FS_wk4 on AMY.F_FS_WEEK (meas_date);
create index AMY.f_FS_wk5 on AMY.F_FS_WEEK (host_ip_ad_id);

alter table AMY.F_FS_WEEK
add constraint K33
foreign key (FS_id)
references AMY.D_FS (FS_id);

alter table AMY.F_FS_WEEK
add constraint K34
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_FS_WEEK
add constraint K35
foreign key (metric_id)
references AMY.D_FS_METRIC (metric_id);

alter table AMY.F_FS_WEEK
add constraint K309
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- monthly fact table: FS
-----------------------------

create table AMY.F_FS_MONTH (
 FS_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (FS_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_FS_mo1 on AMY.F_FS_MONTH (FS_id);
create index AMY.f_FS_mo2 on AMY.F_FS_MONTH (host_id);
create index AMY.f_FS_mo3 on AMY.F_FS_MONTH (metric_id);
create index AMY.f_FS_mo4 on AMY.F_FS_MONTH (meas_date);
create index AMY.f_FS_mo5 on AMY.F_FS_MONTH (host_ip_ad_id);

alter table AMY.F_FS_MONTH
add constraint K35
foreign key (FS_id)
references AMY.D_FS (FS_id);

alter table AMY.F_FS_MONTH
add constraint K36
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_FS_MONTH
add constraint K37
foreign key (metric_id)
references AMY.D_FS_METRIC (metric_id);

alter table AMY.F_FS_MONTH
add constraint K310
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

--------------------
---  FILE
--------------------

-----------------------------
-- dimension table: FILE
-----------------------------

create table AMY.D_FILE (
 FILE_Nm    varchar(254),
 FILE_id        integer        not null,
      primary key (FILE_id));

-- translation table

create table AMY.T_FILE (
 FILE_Nm    varchar(254),
 orig_FILE_id         integer        not null,
 cdw_id          integer        not null,
 FILE_id              integer not null,
      primary key (orig_FILE_id,cdw_id)
      );

-- SEQUENCE

create sequence AMY.FILE_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.FILE_i1
no cascade before insert on AMY.d_FILE
referencing new as n for each row mode db2sql
set n.FILE_id = nextval for AMY.FILE_id_seq;


-----------------------------
-- dimension table:FAttribute
-----------------------------

create table AMY.D_FAttribute (
 FAttribute_id                 integer        not null,
 FMode                    varchar(254)   not null,
 FOwner                   varchar(254)   not null,
 FGroup                   varchar(254)   not null,
      primary key (FAttribute_ID));


-- SEQUENCE

create sequence AMY.FAttr_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.FAttr_i1
no cascade before insert on AMY.d_FAttribute
referencing new as n for each row mode db2sql
set n.FAttribute_id = nextval for AMY.FAttr_id_seq;


-----------------------------
-- staging hour fact table
------------------------------

create table AMY.STG_FILE_HR (
    msmt_id       integer not null,
    orig_FILE_id   integer not null,
    FMode   varchar(254) not null,
    Fowner  varchar(254) not null,
    FGroup  varchar(254) not null,
    orig_host_id          integer not null,
    orig_metric_id        integer not null,
    cdw_id        integer not null,
    meas_hour             timestamp not null,
    min_value         float,
    max_value             float,
    avg_value             float,
    total_value       float,
    sample_count      float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: FILE
-----------------------------

create table AMY.F_FILE_HOUR (
 FILE_id            integer not null,
 FAttribute_id  integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_hour                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (FILE_id,
       FAttribute_id,
       host_id, host_ip_ad_id, metric_id,
       meas_hour)
       );

create index AMY.f_FILE_hr1 on AMY.F_FILE_HOUR (FILE_id);
create index AMY.f_FILE_hr2 on AMY.F_FILE_HOUR (host_id);
create index AMY.f_FILE_hr3 on AMY.F_FILE_HOUR (metric_id);
create index AMY.f_FILE_hr4 on AMY.F_FILE_HOUR (meas_hour);
create index AMY.f_FILE_hr5 on AMY.F_FILE_HOUR (FAttribute_id);
create index AMY.f_FILE_hr6 on AMY.F_FILE_HOUR (host_ip_ad_id);

alter table AMY.F_FILE_HOUR
add constraint K12
foreign key (FILE_id)
references AMY.D_FILE (FILE_id);

alter table AMY.F_FILE_HOUR
add constraint K13
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_FILE_HOUR
add constraint K14
foreign key (metric_id)
references AMY.D_FS_METRIC (metric_id);

alter table AMY.F_FILE_HOUR
add constraint K23
foreign key (FAttribute_id)
references AMY.D_FAttribute (FAttribute_id);

alter table AMY.F_FILE_HOUR
add constraint K311
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- daily fact table: FILE
-----------------------------

create table AMY.F_FILE_DAY (
 FILE_id            integer not null,
 FAttribute_id  integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (FILE_id,
       FAttribute_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_FILE_day1 on AMY.F_FILE_DAY (FILE_id);
create index AMY.f_FILE_day2 on AMY.F_FILE_DAY (host_id);
create index AMY.f_FILE_day3 on AMY.F_FILE_DAY (metric_id);
create index AMY.f_FILE_day4 on AMY.F_FILE_DAY (meas_date);
create index AMY.f_FILE_day5 on AMY.F_FILE_DAY (FAttribute_id);
create index AMY.f_FILE_day6 on AMY.F_FILE_DAY (host_ip_ad_id);

alter table AMY.F_FILE_DAY
add constraint K15
foreign key (FILE_id)
references AMY.D_FILE (FILE_id);

alter table AMY.F_FILE_DAY
add constraint K16
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_FILE_DAY
add constraint K17
foreign key (metric_id)
references AMY.D_FS_METRIC (metric_id);

alter table AMY.F_FILE_DAY
add constraint K24
foreign key (FAttribute_id)
references AMY.D_FAttribute (FAttribute_id);

alter table AMY.F_FILE_DAY
add constraint K312
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- weekly fact table: FILE
-----------------------------

create table AMY.F_FILE_WEEK (
 FILE_id         integer not null,
 FAttribute_id  integer not null,
 host_id        integer not null,
 host_ip_ad_id         integer not null,
 metric_id      integer not null,
 meas_date      timestamp not null,
 min_value      float,
 max_value      float,
 avg_value      float,
 total_value        float,
 sample_count       float,
       primary key (FILE_id,
       FAttribute_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_FILE_wk1 on AMY.F_FILE_WEEK (FILE_id);
create index AMY.f_FILE_wk2 on AMY.F_FILE_WEEK (host_id);
create index AMY.f_FILE_wk3 on AMY.F_FILE_WEEK (metric_id);
create index AMY.f_FILE_wk4 on AMY.F_FILE_WEEK (meas_date);
create index AMY.f_FILE_wk5 on AMY.F_FILE_WEEK (FAttribute_id);
create index AMY.f_FILE_wk6 on AMY.F_FILE_WEEK (host_ip_ad_id);

alter table AMY.F_FILE_WEEK
add constraint K18
foreign key (FILE_id)
references AMY.D_FILE (FILE_id);

alter table AMY.F_FILE_WEEK
add constraint K19
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_FILE_WEEK
add constraint K20
foreign key (metric_id)
references AMY.D_FS_METRIC (metric_id);

alter table AMY.F_FILE_WEEK
add constraint K25
foreign key (FAttribute_id)
references AMY.D_FAttribute (FAttribute_id);

alter table AMY.F_FILE_WEEK
add constraint K313
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- monthly fact table: FILE
-----------------------------

create table AMY.F_FILE_MONTH (
 FILE_id            integer not null,
 FAttribute_id  integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (FILE_id,
       FAttribute_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_FILE_mo1 on AMY.F_FILE_MONTH (FILE_id);
create index AMY.f_FILE_mo2 on AMY.F_FILE_MONTH (host_id);
create index AMY.f_FILE_mo3 on AMY.F_FILE_MONTH (metric_id);
create index AMY.f_FILE_mo4 on AMY.F_FILE_MONTH (meas_date);
create index AMY.f_FILE_mo5 on AMY.F_FILE_MONTH (FAttribute_id);
create index AMY.f_FILE_mo6 on AMY.F_FILE_MONTH (host_ip_ad_id);

alter table AMY.F_FILE_MONTH
add constraint K20
foreign key (FILE_id)
references AMY.D_FILE (FILE_id);

alter table AMY.F_FILE_MONTH
add constraint K21
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_FILE_MONTH
add constraint K22
foreign key (metric_id)
references AMY.D_FS_METRIC (metric_id);

alter table AMY.F_FILE_MONTH
add constraint K26
foreign key (FAttribute_id)
references AMY.D_FAttribute (FAttribute_id);

alter table AMY.F_FILE_MONTH
add constraint K314
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

--------------------
---  IP
--------------------

--------------------
---  LDISK
--------------------

---------------------------------
-- dimension table: IO metric
---------------------------------

create table AMY.d_IO_metric (
 metric_id                 integer        not null,
 met_category              varchar(254),
 met_desc              varchar(254),
 met_name              varchar(254)   not null,
 met_units             varchar(254),
 min_exists        char(1)        not null,
 max_exists        char(1)        not null,
 avg_exists        char(1)        not null,
 total_exists              char(1)        not null,
 msrc_nm           varchar(254),
      primary key (metric_id));


-- translation table

create table AMY.t_IO_metric (
  orig_metric_id        integer not null,
  metric_id             integer not null,
  cdw_id            integer not null,
  met_category                  varchar(254),
  met_desc                  varchar(254),
  met_name          varchar(254) not null,
  met_units             varchar(254),
  min_exists            char(1)        not null,
  max_exists            char(1)        not null,
  avg_exists            char(1)        not null,
  total_exists              char(1)        not null,
  msrc_nm           varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

-- SEQUENCE

create sequence AMY.IOmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.IOmt_i1
no cascade before insert on AMY.d_IO_metric
referencing new as n for each row mode db2sql
set n.metric_id = nextval for AMY.IOmt_id_seq;

-----------------------------
-- dimension table: LDISK
-----------------------------

create table AMY.D_LDISK (
 LDISK_Nm   varchar(254),
 LDISK_id       integer        not null,
      primary key (LDISK_id));

-- translation table

create table AMY.T_LDISK (
 LDISK_Nm   varchar(254),
 orig_LDISK_id         integer        not null,
 cdw_id          integer        not null,
 LDISK_id              integer not null,
      primary key (orig_LDISK_id,cdw_id)
      );

-- SEQUENCE

create sequence AMY.LDSK_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.LDSK_i1
no cascade before insert on AMY.d_LDISK
referencing new as n for each row mode db2sql
set n.LDISK_id = nextval for AMY.LDSK_id_seq;


-----------------------------
-- staging hour fact table
------------------------------

create table AMY.STG_LDISK_HR (
    msmt_id       integer not null,
    orig_LDISK_id   integer not null,
    orig_host_id          integer not null,
    orig_metric_id        integer not null,
    cdw_id        integer not null,
    meas_hour             timestamp not null,
    min_value         float,
    max_value             float,
    avg_value             float,
    total_value       float,
    sample_count      float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: LDISK
-----------------------------

create table AMY.F_LDISK_HOUR (
 LDISK_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_hour                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (LDISK_id,
       host_id, host_ip_ad_id, metric_id,
       meas_hour)
       );

create index AMY.f_LDSK_hr1 on AMY.F_LDISK_HOUR (LDISK_id);
create index AMY.f_LDSK_hr2 on AMY.F_LDISK_HOUR (host_id);
create index AMY.f_LDSK_hr3 on AMY.F_LDISK_HOUR (metric_id);
create index AMY.f_LDSK_hr4 on AMY.F_LDISK_HOUR (meas_hour);
create index AMY.f_LDSK_hr5 on AMY.F_LDISK_HOUR (host_ip_ad_id);

alter table AMY.F_LDISK_HOUR
add constraint K49
foreign key (LDISK_id)
references AMY.D_LDISK (LDISK_id);

alter table AMY.F_LDISK_HOUR
add constraint K50
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_LDISK_HOUR
add constraint K51
foreign key (metric_id)
references AMY.D_IO_METRIC (metric_id);

alter table AMY.F_LDISK_HOUR
add constraint K315
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- daily fact table: LDISK
-----------------------------

create table AMY.F_LDISK_DAY (
 LDISK_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (LDISK_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_LDSK_day1 on AMY.F_LDISK_DAY (LDISK_id);
create index AMY.f_LDSK_day2 on AMY.F_LDISK_DAY (host_id);
create index AMY.f_LDSK_day3 on AMY.F_LDISK_DAY (metric_id);
create index AMY.f_LDSK_day4 on AMY.F_LDISK_DAY (meas_date);
create index AMY.f_LDSK_day5 on AMY.F_LDISK_DAY (host_ip_ad_id);

alter table AMY.F_LDISK_DAY
add constraint K52
foreign key (LDISK_id)
references AMY.D_LDISK (LDISK_id);

alter table AMY.F_LDISK_DAY
add constraint K53
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_LDISK_DAY
add constraint K54
foreign key (metric_id)
references AMY.D_IO_METRIC (metric_id);

alter table AMY.F_LDISK_DAY
add constraint K316
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);


-----------------------------
-- weekly fact table: LDISK
-----------------------------

create table AMY.F_LDISK_WEEK (
 LDISK_id         integer not null,
 host_id        integer not null,
 host_ip_ad_id         integer not null,
 metric_id      integer not null,
 meas_date      timestamp not null,
 min_value      float,
 max_value      float,
 avg_value      float,
 total_value        float,
 sample_count       float,
       primary key (LDISK_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_LDSK_wk1 on AMY.F_LDISK_WEEK (LDISK_id);
create index AMY.f_LDSK_wk2 on AMY.F_LDISK_WEEK (host_id);
create index AMY.f_LDSK_wk3 on AMY.F_LDISK_WEEK (metric_id);
create index AMY.f_LDSK_wk4 on AMY.F_LDISK_WEEK (meas_date);
create index AMY.f_LDSK_wk5 on AMY.F_LDISK_WEEK (host_ip_ad_id);

alter table AMY.F_LDISK_WEEK
add constraint K55
foreign key (LDISK_id)
references AMY.D_LDISK (LDISK_id);

alter table AMY.F_LDISK_WEEK
add constraint K56
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_LDISK_WEEK
add constraint K57
foreign key (metric_id)
references AMY.D_IO_METRIC (metric_id);

alter table AMY.F_LDISK_WEEK
add constraint K317
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- monthly fact table: LDISK
-----------------------------

create table AMY.F_LDISK_MONTH (
 LDISK_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (LDISK_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_LDSK_mo1 on AMY.F_LDISK_MONTH (LDISK_id);
create index AMY.f_LDSK_mo2 on AMY.F_LDISK_MONTH (host_id);
create index AMY.f_LDSK_mo3 on AMY.F_LDISK_MONTH (metric_id);
create index AMY.f_LDSK_mo4 on AMY.F_LDISK_MONTH (meas_date);
create index AMY.f_LDSK_mo5 on AMY.F_LDISK_MONTH (host_ip_ad_id);

alter table AMY.F_LDISK_MONTH
add constraint K57
foreign key (LDISK_id)
references AMY.D_LDISK (LDISK_id);

alter table AMY.F_LDISK_MONTH
add constraint K58
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_LDISK_MONTH
add constraint K59
foreign key (metric_id)
references AMY.D_IO_METRIC (metric_id);

alter table AMY.F_LDISK_MONTH
add constraint K318
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
--------------------
---  MEMORY
--------------------

---------------------------------
-- dimension table: MEMORY metric
---------------------------------

create table AMY.d_MEM_metric (
 metric_id                 integer        not null,
 met_category              varchar(254),
 met_desc              varchar(254),
 met_name              varchar(254)   not null,
 met_units             varchar(254),
 min_exists        char(1)        not null,
 max_exists        char(1)        not null,
 avg_exists        char(1)        not null,
 total_exists              char(1)        not null,
 msrc_nm           varchar(254),
      primary key (metric_id));


-- translation table

create table AMY.t_MEM_metric (
  orig_metric_id        integer not null,
  metric_id             integer not null,
  cdw_id            integer not null,
  met_category                  varchar(254),
  met_desc                  varchar(254),
  met_name          varchar(254) not null,
  met_units             varchar(254),
  min_exists            char(1)        not null,
  max_exists            char(1)        not null,
  avg_exists            char(1)        not null,
  total_exists              char(1)        not null,
  msrc_nm           varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

-- SEQUENCE

create sequence AMY.MEMmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.MEMmt_i1
no cascade before insert on AMY.d_MEM_metric
referencing new as n for each row mode db2sql
set n.metric_id = nextval for AMY.MEMmt_id_seq;

-----------------------------
-- dimension table: MEMORY
-----------------------------

create table AMY.D_MEMORY (
 MEMORY_Nm  varchar(254),
 MEMORY_Type    varchar(254),
 MEMORY_id      integer        not null,
      primary key (MEMORY_id));

-- translation table

create table AMY.T_MEMORY (
 MEMORY_Nm  varchar(254),
 MEMORY_Type    varchar(254),
 orig_MEMORY_id         integer        not null,
 cdw_id          integer        not null,
 MEMORY_id              integer not null,
      primary key (orig_MEMORY_id,cdw_id)
      );

-- SEQUENCE

create sequence AMY.MEM_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.MEM_i1
no cascade before insert on AMY.d_MEMORY
referencing new as n for each row mode db2sql
set n.MEMORY_id = nextval for AMY.MEM_id_seq;


-----------------------------
-- staging hour fact table
------------------------------

create table AMY.STG_MEMORY_HR (
    msmt_id       integer not null,
    orig_MEMORY_id   integer not null,
    orig_host_id          integer not null,
    orig_metric_id        integer not null,
    cdw_id        integer not null,
    meas_hour             timestamp not null,
    min_value         float,
    max_value             float,
    avg_value             float,
    total_value       float,
    sample_count      float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: MEMORY
-----------------------------

create table AMY.F_MEMORY_HOUR (
 MEMORY_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_hour                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (MEMORY_id,
       host_id, host_ip_ad_id, metric_id,
       meas_hour)
       );

create index AMY.f_MEM_hr1 on AMY.F_MEMORY_HOUR (MEMORY_id);
create index AMY.f_MEM_hr2 on AMY.F_MEMORY_HOUR (host_id);
create index AMY.f_MEM_hr3 on AMY.F_MEMORY_HOUR (metric_id);
create index AMY.f_MEM_hr4 on AMY.F_MEMORY_HOUR (meas_hour);
create index AMY.f_MEM_hr5 on AMY.F_MEMORY_HOUR (host_ip_ad_id);

alter table AMY.F_MEMORY_HOUR
add constraint K60
foreign key (MEMORY_id)
references AMY.D_MEMORY (MEMORY_id);

alter table AMY.F_MEMORY_HOUR
add constraint K61
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_MEMORY_HOUR
add constraint K62
foreign key (metric_id)
references AMY.D_MEM_METRIC (metric_id);

alter table AMY.F_MEMORY_HOUR
add constraint K319
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- daily fact table: MEMORY
-----------------------------

create table AMY.F_MEMORY_DAY (
 MEMORY_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (MEMORY_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_MEM_day1 on AMY.F_MEMORY_DAY (MEMORY_id);
create index AMY.f_MEM_day2 on AMY.F_MEMORY_DAY (host_id);
create index AMY.f_MEM_day3 on AMY.F_MEMORY_DAY (metric_id);
create index AMY.f_MEM_day4 on AMY.F_MEMORY_DAY (meas_date);
create index AMY.f_MEM_day5 on AMY.F_MEMORY_DAY (host_ip_ad_id);

alter table AMY.F_MEMORY_DAY
add constraint K63
foreign key (MEMORY_id)
references AMY.D_MEMORY (MEMORY_id);

alter table AMY.F_MEMORY_DAY
add constraint K64
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_MEMORY_DAY
add constraint K65
foreign key (metric_id)
references AMY.D_MEM_METRIC (metric_id);

alter table AMY.F_MEMORY_DAY
add constraint K320
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- weekly fact table: MEMORY
-----------------------------

create table AMY.F_MEMORY_WEEK (
 MEMORY_id         integer not null,
 host_id        integer not null,
 host_ip_ad_id         integer not null,
 metric_id      integer not null,
 meas_date      timestamp not null,
 min_value      float,
 max_value      float,
 avg_value      float,
 total_value        float,
 sample_count       float,
       primary key (MEMORY_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_MEM_wk1 on AMY.F_MEMORY_WEEK (MEMORY_id);
create index AMY.f_MEM_wk2 on AMY.F_MEMORY_WEEK (host_id);
create index AMY.f_MEM_wk3 on AMY.F_MEMORY_WEEK (metric_id);
create index AMY.f_MEM_wk4 on AMY.F_MEMORY_WEEK (meas_date);
create index AMY.f_MEM_wk5 on AMY.F_MEMORY_WEEK (host_ip_ad_id);

alter table AMY.F_MEMORY_WEEK
add constraint K66
foreign key (MEMORY_id)
references AMY.D_MEMORY (MEMORY_id);

alter table AMY.F_MEMORY_WEEK
add constraint K67
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_MEMORY_WEEK
add constraint K68
foreign key (metric_id)
references AMY.D_MEM_METRIC (metric_id);

alter table AMY.F_MEMORY_WEEK
add constraint K321
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- monthly fact table: MEMORY
-----------------------------

create table AMY.F_MEMORY_MONTH (
 MEMORY_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (MEMORY_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_MEM_mo1 on AMY.F_MEMORY_MONTH (MEMORY_id);
create index AMY.f_MEM_mo2 on AMY.F_MEMORY_MONTH (host_id);
create index AMY.f_MEM_mo3 on AMY.F_MEMORY_MONTH (metric_id);
create index AMY.f_MEM_mo4 on AMY.F_MEMORY_MONTH (meas_date);
create index AMY.f_MEM_mo5 on AMY.F_MEMORY_MONTH (host_ip_ad_id);

alter table AMY.F_MEMORY_MONTH
add constraint K68
foreign key (MEMORY_id)
references AMY.D_MEMORY (MEMORY_id);

alter table AMY.F_MEMORY_MONTH
add constraint K69
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_MEMORY_MONTH
add constraint K70
foreign key (metric_id)
references AMY.D_MEM_METRIC (metric_id);

alter table AMY.F_MEMORY_MONTH
add constraint K322
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
--------------------
---  NETSEG
--------------------

--------------------
---  NETWORK
--------------------

---------------------------------
-- dimension table: NET metric
---------------------------------

create table AMY.d_NET_metric (
 metric_id                 integer        not null,
 met_category              varchar(254),
 met_desc              varchar(254),
 met_name              varchar(254)   not null,
 met_units             varchar(254),
 min_exists        char(1)        not null,
 max_exists        char(1)        not null,
 avg_exists        char(1)        not null,
 total_exists              char(1)        not null,
 msrc_nm           varchar(254),
      primary key (metric_id));


-- translation table

create table AMY.t_NET_metric (
  orig_metric_id        integer not null,
  metric_id             integer not null,
  cdw_id            integer not null,
  met_category                  varchar(254),
  met_desc                  varchar(254),
  met_name          varchar(254) not null,
  met_units             varchar(254),
  min_exists            char(1)        not null,
  max_exists            char(1)        not null,
  avg_exists            char(1)        not null,
  total_exists              char(1)        not null,
  msrc_nm           varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

-- SEQUENCE

create sequence AMY.NETmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.NETmt_i1
no cascade before insert on AMY.d_NET_metric
referencing new as n for each row mode db2sql
set n.metric_id = nextval for AMY.NETmt_id_seq;

-----------------------------
-- dimension table: NETWORK
-----------------------------

create table AMY.D_NETWORK (
 NET_Nm varchar(254),
 NET_Type varchar(254),
 NET_id         integer        not null,
      primary key (NET_id));

-- translation table

create table AMY.T_NETWORK (
 NET_Nm varchar(254),
 NET_Type varchar(254),
 orig_NET_id         integer        not null,
 cdw_id          integer        not null,
 NET_id              integer not null,
      primary key (orig_NET_id,cdw_id)
      );

-- SEQUENCE

create sequence AMY.NET_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.NET_i1
no cascade before insert on AMY.d_NETWORK
referencing new as n for each row mode db2sql
set n.NET_id = nextval for AMY.NET_id_seq;


-----------------------------
-- staging hour fact table
------------------------------

create table AMY.STG_NETWORK_HR (
    msmt_id       integer not null,
    orig_NET_id   integer not null,
    orig_host_id          integer not null,
    orig_metric_id        integer not null,
    cdw_id        integer not null,
    meas_hour             timestamp not null,
    min_value         float,
    max_value             float,
    avg_value             float,
    total_value       float,
    sample_count      float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: NETWORK
-----------------------------

create table AMY.F_NETWORK_HOUR (
 NET_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_hour                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (NET_id,
       host_id, host_ip_ad_id, metric_id,
       meas_hour)
       );

create index AMY.f_NET_hr1 on AMY.F_NETWORK_HOUR (NET_id);
create index AMY.f_NET_hr2 on AMY.F_NETWORK_HOUR (host_id);
create index AMY.f_NET_hr3 on AMY.F_NETWORK_HOUR (metric_id);
create index AMY.f_NET_hr4 on AMY.F_NETWORK_HOUR (meas_hour);
create index AMY.f_NET_hr5 on AMY.F_NETWORK_HOUR (host_ip_ad_id);

alter table AMY.F_NETWORK_HOUR
add constraint K82
foreign key (NET_id)
references AMY.D_NETWORK (NET_id);

alter table AMY.F_NETWORK_HOUR
add constraint K83
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_NETWORK_HOUR
add constraint K84
foreign key (metric_id)
references AMY.D_NET_METRIC (metric_id);

alter table AMY.F_NETWORK_HOUR
add constraint K323
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- daily fact table: NETWORK
-----------------------------

create table AMY.F_NETWORK_DAY (
 NET_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (NET_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_NET_day1 on AMY.F_NETWORK_DAY (NET_id);
create index AMY.f_NET_day2 on AMY.F_NETWORK_DAY (host_id);
create index AMY.f_NET_day3 on AMY.F_NETWORK_DAY (metric_id);
create index AMY.f_NET_day4 on AMY.F_NETWORK_DAY (meas_date);
create index AMY.f_NET_day5 on AMY.F_NETWORK_DAY (host_ip_ad_id);

alter table AMY.F_NETWORK_DAY
add constraint K85
foreign key (NET_id)
references AMY.D_NETWORK (NET_id);

alter table AMY.F_NETWORK_DAY
add constraint K86
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_NETWORK_DAY
add constraint K87
foreign key (metric_id)
references AMY.D_NET_METRIC (metric_id);

alter table AMY.F_NETWORK_DAY
add constraint K324
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- weekly fact table: NETWORK
-----------------------------

create table AMY.F_NETWORK_WEEK (
 NET_id         integer not null,
 host_id        integer not null,
 host_ip_ad_id         integer not null,
 metric_id      integer not null,
 meas_date      timestamp not null,
 min_value      float,
 max_value      float,
 avg_value      float,
 total_value        float,
 sample_count       float,
       primary key (NET_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_NET_wk1 on AMY.F_NETWORK_WEEK (NET_id);
create index AMY.f_NET_wk2 on AMY.F_NETWORK_WEEK (host_id);
create index AMY.f_NET_wk3 on AMY.F_NETWORK_WEEK (metric_id);
create index AMY.f_NET_wk4 on AMY.F_NETWORK_WEEK (meas_date);
create index AMY.f_NET_wk5 on AMY.F_NETWORK_WEEK (host_ip_ad_id);

alter table AMY.F_NETWORK_WEEK
add constraint K88
foreign key (NET_id)
references AMY.D_NETWORK (NET_id);

alter table AMY.F_NETWORK_WEEK
add constraint K89
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_NETWORK_WEEK
add constraint K90
foreign key (metric_id)
references AMY.D_NET_METRIC (metric_id);

alter table AMY.F_NETWORK_WEEK
add constraint K325
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- monthly fact table: NETWORK
-----------------------------

create table AMY.F_NETWORK_MONTH (
 NET_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (NET_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_NET_mo1 on AMY.F_NETWORK_MONTH (NET_id);
create index AMY.f_NET_mo2 on AMY.F_NETWORK_MONTH (host_id);
create index AMY.f_NET_mo3 on AMY.F_NETWORK_MONTH (metric_id);
create index AMY.f_NET_mo4 on AMY.F_NETWORK_MONTH (meas_date);
create index AMY.f_NET_mo5 on AMY.F_NETWORK_MONTH (host_ip_ad_id);

alter table AMY.F_NETWORK_MONTH
add constraint K90
foreign key (NET_id)
references AMY.D_NETWORK (NET_id);

alter table AMY.F_NETWORK_MONTH
add constraint K91
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_NETWORK_MONTH
add constraint K92
foreign key (metric_id)
references AMY.D_NET_METRIC (metric_id);

alter table AMY.F_NETWORK_MONTH
add constraint K326
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
--------------------
---  NFS
--------------------

--------------------
---  OS400ASP
--------------------

-----------------------------
-- dimension table: OS400ASP
-----------------------------

create table AMY.D_OS400ASP (
 OS4KASP_Nm varchar(254),
 OS400ASP_id        integer        not null,
      primary key (OS400ASP_id));

-- translation table

create table AMY.T_OS400ASP (
 OS4KASP_Nm varchar(254),
 orig_OS400ASP_id         integer        not null,
 cdw_id          integer        not null,
 OS400ASP_id              integer not null,
      primary key (orig_OS400ASP_id,cdw_id)
      );

-- SEQUENCE

create sequence AMY.OASP_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.OASP_i1
no cascade before insert on AMY.d_OS400ASP
referencing new as n for each row mode db2sql
set n.OS400ASP_id = nextval for AMY.OASP_id_seq;


-----------------------------
-- staging hour fact table
------------------------------

create table AMY.STG_OS400ASP_HR (
    msmt_id       integer not null,
    orig_OS400ASP_id   integer not null,
    orig_host_id          integer not null,
    orig_metric_id        integer not null,
    cdw_id        integer not null,
    meas_hour             timestamp not null,
    min_value         float,
    max_value             float,
    avg_value             float,
    total_value       float,
    sample_count      float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: OS400ASP
-----------------------------

create table AMY.F_OS400ASP_HOUR (
 OS400ASP_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_hour                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (OS400ASP_id,
       host_id, host_ip_ad_id, metric_id,
       meas_hour)
       );

create index AMY.f_OASP_hr1 on AMY.F_OS400ASP_HOUR (OS400ASP_id);
create index AMY.f_OASP_hr2 on AMY.F_OS400ASP_HOUR (host_id);
create index AMY.f_OASP_hr3 on AMY.F_OS400ASP_HOUR (metric_id);
create index AMY.f_OASP_hr4 on AMY.F_OS400ASP_HOUR (meas_hour);
create index AMY.f_OASP_hr5 on AMY.F_OS400ASP_HOUR (host_ip_ad_id);

alter table AMY.F_OS400ASP_HOUR
add constraint K104
foreign key (OS400ASP_id)
references AMY.D_OS400ASP (OS400ASP_id);

alter table AMY.F_OS400ASP_HOUR
add constraint K105
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_OS400ASP_HOUR
add constraint K106
foreign key (metric_id)
references AMY.D_FS_METRIC (metric_id);

alter table AMY.F_OS400ASP_HOUR
add constraint K327
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- daily fact table: OS400ASP
-----------------------------

create table AMY.F_OS400ASP_DAY (
 OS400ASP_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (OS400ASP_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_OASP_day1 on AMY.F_OS400ASP_DAY (OS400ASP_id);
create index AMY.f_OASP_day2 on AMY.F_OS400ASP_DAY (host_id);
create index AMY.f_OASP_day3 on AMY.F_OS400ASP_DAY (metric_id);
create index AMY.f_OASP_day4 on AMY.F_OS400ASP_DAY (meas_date);
create index AMY.f_OASP_day5 on AMY.F_OS400ASP_DAY (host_ip_ad_id);

alter table AMY.F_OS400ASP_DAY
add constraint K107
foreign key (OS400ASP_id)
references AMY.D_OS400ASP (OS400ASP_id);

alter table AMY.F_OS400ASP_DAY
add constraint K108
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_OS400ASP_DAY
add constraint K109
foreign key (metric_id)
references AMY.D_FS_METRIC (metric_id);

alter table AMY.F_OS400ASP_DAY
add constraint K328
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- weekly fact table: OS400ASP
-----------------------------

create table AMY.F_OS400ASP_WEEK (
 OS400ASP_id         integer not null,
 host_id        integer not null,
 host_ip_ad_id         integer not null,
 metric_id      integer not null,
 meas_date      timestamp not null,
 min_value      float,
 max_value      float,
 avg_value      float,
 total_value        float,
 sample_count       float,
       primary key (OS400ASP_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_OASP_wk1 on AMY.F_OS400ASP_WEEK (OS400ASP_id);
create index AMY.f_OASP_wk2 on AMY.F_OS400ASP_WEEK (host_id);
create index AMY.f_OASP_wk3 on AMY.F_OS400ASP_WEEK (metric_id);
create index AMY.f_OASP_wk4 on AMY.F_OS400ASP_WEEK (meas_date);
create index AMY.f_OASP_wk5 on AMY.F_OS400ASP_WEEK (host_ip_ad_id);

alter table AMY.F_OS400ASP_WEEK
add constraint K110
foreign key (OS400ASP_id)
references AMY.D_OS400ASP (OS400ASP_id);

alter table AMY.F_OS400ASP_WEEK
add constraint K111
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_OS400ASP_WEEK
add constraint K112
foreign key (metric_id)
references AMY.D_FS_METRIC (metric_id);

alter table AMY.F_OS400ASP_WEEK
add constraint K329
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- monthly fact table: OS400ASP
-----------------------------

create table AMY.F_OS400ASP_MONTH (
 OS400ASP_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (OS400ASP_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_OASP_mo1 on AMY.F_OS400ASP_MONTH (OS400ASP_id);
create index AMY.f_OASP_mo2 on AMY.F_OS400ASP_MONTH (host_id);
create index AMY.f_OASP_mo3 on AMY.F_OS400ASP_MONTH (metric_id);
create index AMY.f_OASP_mo4 on AMY.F_OS400ASP_MONTH (meas_date);
create index AMY.f_OASP_mo5 on AMY.F_OS400ASP_MONTH (host_ip_ad_id);

alter table AMY.F_OS400ASP_MONTH
add constraint K112
foreign key (OS400ASP_id)
references AMY.D_OS400ASP (OS400ASP_id);

alter table AMY.F_OS400ASP_MONTH
add constraint K113
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_OS400ASP_MONTH
add constraint K114
foreign key (metric_id)
references AMY.D_FS_METRIC (metric_id);

alter table AMY.F_OS400ASP_MONTH
add constraint K330
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
--------------------
---  OS4KBCPU
--------------------

--------------------
---  OS4KDBCPU
--------------------

--------------------
---  OS4KDISK
--------------------

-----------------------------
-- dimension table: OS4KDISK
-----------------------------

create table AMY.D_OS4KDISK (
 OS4KDISK_Nm    varchar(254),
 OS4KDISK_id        integer        not null,
      primary key (OS4KDISK_id));

-- translation table

create table AMY.T_OS4KDISK (
 OS4KDISK_Nm    varchar(254),
 orig_OS4KDISK_id         integer        not null,
 cdw_id          integer        not null,
 OS4KDISK_id              integer not null,
      primary key (orig_OS4KDISK_id,cdw_id)
      );

-- SEQUENCE

create sequence AMY.ODSK_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.ODSK_i1
no cascade before insert on AMY.d_OS4KDISK
referencing new as n for each row mode db2sql
set n.OS4KDISK_id = nextval for AMY.ODSK_id_seq;


-----------------------------
-- staging hour fact table
------------------------------

create table AMY.STG_OS4KDISK_HR (
    msmt_id       integer not null,
    orig_OS4KDISK_id   integer not null,
    orig_host_id          integer not null,
    orig_metric_id        integer not null,
    cdw_id        integer not null,
    meas_hour             timestamp not null,
    min_value         float,
    max_value             float,
    avg_value             float,
    total_value       float,
    sample_count      float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: OS4KDISK
-----------------------------

create table AMY.F_OS4KDISK_HOUR (
 OS4KDISK_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_hour                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (OS4KDISK_id,
       host_id, host_ip_ad_id, metric_id,
       meas_hour)
       );

create index AMY.f_ODSK_hr1 on AMY.F_OS4KDISK_HOUR (OS4KDISK_id);
create index AMY.f_ODSK_hr2 on AMY.F_OS4KDISK_HOUR (host_id);
create index AMY.f_ODSK_hr3 on AMY.F_OS4KDISK_HOUR (metric_id);
create index AMY.f_ODSK_hr4 on AMY.F_OS4KDISK_HOUR (meas_hour);
create index AMY.f_ODSK_hr5 on AMY.F_OS4KDISK_HOUR (host_ip_ad_id);

alter table AMY.F_OS4KDISK_HOUR
add constraint K137
foreign key (OS4KDISK_id)
references AMY.D_OS4KDISK (OS4KDISK_id);

alter table AMY.F_OS4KDISK_HOUR
add constraint K138
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_OS4KDISK_HOUR
add constraint K139
foreign key (metric_id)
references AMY.D_IO_METRIC (metric_id);

alter table AMY.F_OS4KDISK_HOUR
add constraint K331
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- daily fact table: OS4KDISK
-----------------------------

create table AMY.F_OS4KDISK_DAY (
 OS4KDISK_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (OS4KDISK_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_ODSK_day1 on AMY.F_OS4KDISK_DAY (OS4KDISK_id);
create index AMY.f_ODSK_day2 on AMY.F_OS4KDISK_DAY (host_id);
create index AMY.f_ODSK_day3 on AMY.F_OS4KDISK_DAY (metric_id);
create index AMY.f_ODSK_day4 on AMY.F_OS4KDISK_DAY (meas_date);
create index AMY.f_ODSK_day5 on AMY.F_OS4KDISK_DAY (host_ip_ad_id);

alter table AMY.F_OS4KDISK_DAY
add constraint K140
foreign key (OS4KDISK_id)
references AMY.D_OS4KDISK (OS4KDISK_id);

alter table AMY.F_OS4KDISK_DAY
add constraint K141
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_OS4KDISK_DAY
add constraint K142
foreign key (metric_id)
references AMY.D_IO_METRIC (metric_id);

alter table AMY.F_OS4KDISK_DAY
add constraint K332
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- weekly fact table: OS4KDISK
-----------------------------

create table AMY.F_OS4KDISK_WEEK (
 OS4KDISK_id         integer not null,
 host_id        integer not null,
 host_ip_ad_id         integer not null,
 metric_id      integer not null,
 meas_date      timestamp not null,
 min_value      float,
 max_value      float,
 avg_value      float,
 total_value        float,
 sample_count       float,
       primary key (OS4KDISK_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_ODSK_wk1 on AMY.F_OS4KDISK_WEEK (OS4KDISK_id);
create index AMY.f_ODSK_wk2 on AMY.F_OS4KDISK_WEEK (host_id);
create index AMY.f_ODSK_wk3 on AMY.F_OS4KDISK_WEEK (metric_id);
create index AMY.f_ODSK_wk4 on AMY.F_OS4KDISK_WEEK (meas_date);
create index AMY.f_ODSK_wk5 on AMY.F_OS4KDISK_WEEK (host_ip_ad_id);

alter table AMY.F_OS4KDISK_WEEK
add constraint K143
foreign key (OS4KDISK_id)
references AMY.D_OS4KDISK (OS4KDISK_id);

alter table AMY.F_OS4KDISK_WEEK
add constraint K144
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_OS4KDISK_WEEK
add constraint K145
foreign key (metric_id)
references AMY.D_IO_METRIC (metric_id);

alter table AMY.F_OS4KDISK_WEEK
add constraint K333
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- monthly fact table: OS4KDISK
-----------------------------

create table AMY.F_OS4KDISK_MONTH (
 OS4KDISK_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (OS4KDISK_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_ODSK_mo1 on AMY.F_OS4KDISK_MONTH (OS4KDISK_id);
create index AMY.f_ODSK_mo2 on AMY.F_OS4KDISK_MONTH (host_id);
create index AMY.f_ODSK_mo3 on AMY.F_OS4KDISK_MONTH (metric_id);
create index AMY.f_ODSK_mo4 on AMY.F_OS4KDISK_MONTH (meas_date);
create index AMY.f_ODSK_mo5 on AMY.F_OS4KDISK_MONTH (host_ip_ad_id);

alter table AMY.F_OS4KDISK_MONTH
add constraint K145
foreign key (OS4KDISK_id)
references AMY.D_OS4KDISK (OS4KDISK_id);

alter table AMY.F_OS4KDISK_MONTH
add constraint K146
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_OS4KDISK_MONTH
add constraint K147
foreign key (metric_id)
references AMY.D_IO_METRIC (metric_id);

alter table AMY.F_OS4KDISK_MONTH
add constraint K334
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
--------------------
---  OS4KICPU
--------------------


--------------------
---  OS4KSPOOL
--------------------

--------------------
---  PDISK
--------------------

-----------------------------
-- dimension table: PDISK
-----------------------------

create table AMY.D_PDISK (
 PDISK_Nm   varchar(254),
 PDISK_id       integer        not null,
      primary key (PDISK_id));

-- translation table

create table AMY.T_PDISK (
 PDISK_Nm   varchar(254),
 orig_PDISK_id         integer        not null,
 cdw_id          integer        not null,
 PDISK_id              integer not null,
      primary key (orig_PDISK_id,cdw_id)
      );

-- SEQUENCE

create sequence AMY.PDSK_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.PDSK_i1
no cascade before insert on AMY.d_PDISK
referencing new as n for each row mode db2sql
set n.PDISK_id = nextval for AMY.PDSK_id_seq;


-----------------------------
-- staging hour fact table
------------------------------

create table AMY.STG_PDISK_HR (
    msmt_id       integer not null,
    orig_PDISK_id   integer not null,
    orig_host_id          integer not null,
    orig_metric_id        integer not null,
    cdw_id        integer not null,
    meas_hour             timestamp not null,
    min_value         float,
    max_value             float,
    avg_value             float,
    total_value       float,
    sample_count      float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: PDISK
-----------------------------

create table AMY.F_PDISK_HOUR (
 PDISK_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_hour                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (PDISK_id,
       host_id, host_ip_ad_id, metric_id,
       meas_hour)
       );

create index AMY.f_PDSK_hr1 on AMY.F_PDISK_HOUR (PDISK_id);
create index AMY.f_PDSK_hr2 on AMY.F_PDISK_HOUR (host_id);
create index AMY.f_PDSK_hr3 on AMY.F_PDISK_HOUR (metric_id);
create index AMY.f_PDSK_hr4 on AMY.F_PDISK_HOUR (meas_hour);
create index AMY.f_PDSK_hr5 on AMY.F_PDISK_HOUR (host_ip_ad_id);

alter table AMY.F_PDISK_HOUR
add constraint K181
foreign key (PDISK_id)
references AMY.D_PDISK (PDISK_id);

alter table AMY.F_PDISK_HOUR
add constraint K182
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_PDISK_HOUR
add constraint K183
foreign key (metric_id)
references AMY.D_IO_METRIC (metric_id);

alter table AMY.F_PDISK_HOUR
add constraint K335
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- daily fact table: PDISK
-----------------------------

create table AMY.F_PDISK_DAY (
 PDISK_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (PDISK_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_PDSK_day1 on AMY.F_PDISK_DAY (PDISK_id);
create index AMY.f_PDSK_day2 on AMY.F_PDISK_DAY (host_id);
create index AMY.f_PDSK_day3 on AMY.F_PDISK_DAY (metric_id);
create index AMY.f_PDSK_day4 on AMY.F_PDISK_DAY (meas_date);
create index AMY.f_PDSK_day5 on AMY.F_PDISK_DAY (host_ip_ad_id);

alter table AMY.F_PDISK_DAY
add constraint K184
foreign key (PDISK_id)
references AMY.D_PDISK (PDISK_id);

alter table AMY.F_PDISK_DAY
add constraint K185
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_PDISK_DAY
add constraint K186
foreign key (metric_id)
references AMY.D_IO_METRIC (metric_id);

alter table AMY.F_PDISK_DAY
add constraint K336
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- weekly fact table: PDISK
-----------------------------

create table AMY.F_PDISK_WEEK (
 PDISK_id         integer not null,
 host_id        integer not null,
 host_ip_ad_id         integer not null,
 metric_id      integer not null,
 meas_date      timestamp not null,
 min_value      float,
 max_value      float,
 avg_value      float,
 total_value        float,
 sample_count       float,
       primary key (PDISK_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_PDSK_wk1 on AMY.F_PDISK_WEEK (PDISK_id);
create index AMY.f_PDSK_wk2 on AMY.F_PDISK_WEEK (host_id);
create index AMY.f_PDSK_wk3 on AMY.F_PDISK_WEEK (metric_id);
create index AMY.f_PDSK_wk4 on AMY.F_PDISK_WEEK (meas_date);
create index AMY.f_PDSK_wk5 on AMY.F_PDISK_WEEK (host_ip_ad_id);

alter table AMY.F_PDISK_WEEK
add constraint K187
foreign key (PDISK_id)
references AMY.D_PDISK (PDISK_id);

alter table AMY.F_PDISK_WEEK
add constraint K188
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_PDISK_WEEK
add constraint K189
foreign key (metric_id)
references AMY.D_IO_METRIC (metric_id);

alter table AMY.F_PDISK_WEEK
add constraint K337
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- monthly fact table: PDISK
-----------------------------

create table AMY.F_PDISK_MONTH (
 PDISK_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (PDISK_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_PDSK_mo1 on AMY.F_PDISK_MONTH (PDISK_id);
create index AMY.f_PDSK_mo2 on AMY.F_PDISK_MONTH (host_id);
create index AMY.f_PDSK_mo3 on AMY.F_PDISK_MONTH (metric_id);
create index AMY.f_PDSK_mo4 on AMY.F_PDISK_MONTH (meas_date);
create index AMY.f_PDSK_mo5 on AMY.F_PDISK_MONTH (host_ip_ad_id);

alter table AMY.F_PDISK_MONTH
add constraint K189
foreign key (PDISK_id)
references AMY.D_PDISK (PDISK_id);

alter table AMY.F_PDISK_MONTH
add constraint K190
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_PDISK_MONTH
add constraint K191
foreign key (metric_id)
references AMY.D_IO_METRIC (metric_id);

alter table AMY.F_PDISK_MONTH
add constraint K338
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

--------------------
---  PORT
--------------------

--------------------
---  PRNQUEUE
--------------------

---------------------------------
-- dimension table: PRN metric
---------------------------------

create table AMY.d_PRN_metric (
 metric_id                 integer        not null,
 met_category              varchar(254),
 met_desc              varchar(254),
 met_name              varchar(254)   not null,
 met_units             varchar(254),
 min_exists        char(1)        not null,
 max_exists        char(1)        not null,
 avg_exists        char(1)        not null,
 total_exists              char(1)        not null,
 msrc_nm           varchar(254),
      primary key (metric_id));


-- translation table

create table AMY.t_PRN_metric (
  orig_metric_id        integer not null,
  metric_id             integer not null,
  cdw_id            integer not null,
  met_category                  varchar(254),
  met_desc                  varchar(254),
  met_name          varchar(254) not null,
  met_units             varchar(254),
  min_exists            char(1)        not null,
  max_exists            char(1)        not null,
  avg_exists            char(1)        not null,
  total_exists              char(1)        not null,
  msrc_nm           varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

-- SEQUENCE

create sequence AMY.PRNQmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.PRNQmt_i1
no cascade before insert on AMY.d_PRN_metric
referencing new as n for each row mode db2sql
set n.metric_id = nextval for AMY.PRNQmt_id_seq;

-----------------------------
-- dimension table: PRINTER
-----------------------------

create table AMY.D_PRINTER (
 PRN_Nm varchar(254),
 PRN_id         integer        not null,
      primary key (PRN_id));

-- translation table

create table AMY.T_PRINTER (
 PRN_Nm          varchar(254),
 orig_PRN_id         integer        not null,
 cdw_id          integer        not null,
 PRN_id              integer not null,
      primary key (orig_PRN_id,cdw_id)
      );

-- SEQUENCE

create sequence AMY.PRNQ_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.PRNQ_i1
no cascade before insert on AMY.d_PRINTER
referencing new as n for each row mode db2sql
set n.PRN_id = nextval for AMY.PRNQ_id_seq;


-----------------------------
-- staging hour fact table
------------------------------

create table AMY.STG_PRN_HR (
    msmt_id       integer not null,
    orig_PRN_id   integer not null,
    orig_host_id          integer not null,
    orig_metric_id        integer not null,
    cdw_id        integer not null,
    meas_hour             timestamp not null,
    min_value         float,
    max_value             float,
    avg_value             float,
    total_value       float,
    sample_count      float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: PRN
-----------------------------

create table AMY.F_PRN_HOUR (
 PRN_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_hour                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (PRN_id,
       host_id, host_ip_ad_id, metric_id,
       meas_hour)
       );

create index AMY.f_PRNQ_hr1 on AMY.F_PRN_HOUR (PRN_id);
create index AMY.f_PRNQ_hr2 on AMY.F_PRN_HOUR (host_id);
create index AMY.f_PRNQ_hr3 on AMY.F_PRN_HOUR (metric_id);
create index AMY.f_PRNQ_hr4 on AMY.F_PRN_HOUR (meas_hour);
create index AMY.f_PRNQ_hr5 on AMY.F_PRN_HOUR (host_ip_ad_id);

alter table AMY.F_PRN_HOUR
add constraint K207
foreign key (PRN_id)
references AMY.D_PRINTER (PRN_id);

alter table AMY.F_PRN_HOUR
add constraint K208
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_PRN_HOUR
add constraint K209
foreign key (metric_id)
references AMY.D_PRN_METRIC (metric_id);

alter table AMY.F_PRN_HOUR
add constraint K339
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- daily fact table: PRN
-----------------------------

create table AMY.F_PRN_DAY (
 PRN_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (PRN_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_PRNQ_day1 on AMY.F_PRN_DAY (PRN_id);
create index AMY.f_PRNQ_day2 on AMY.F_PRN_DAY (host_id);
create index AMY.f_PRNQ_day3 on AMY.F_PRN_DAY (metric_id);
create index AMY.f_PRNQ_day4 on AMY.F_PRN_DAY (meas_date);
create index AMY.f_PRNQ_day5 on AMY.F_PRN_DAY (host_ip_ad_id);

alter table AMY.F_PRN_DAY
add constraint K210
foreign key (PRN_id)
references AMY.D_PRINTER (PRN_id);

alter table AMY.F_PRN_DAY
add constraint K211
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_PRN_DAY
add constraint K212
foreign key (metric_id)
references AMY.D_PRN_METRIC (metric_id);

alter table AMY.F_PRN_DAY
add constraint K340
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- weekly fact table: PRN
-----------------------------

create table AMY.F_PRN_WEEK (
 PRN_id         integer not null,
 host_id        integer not null,
 host_ip_ad_id         integer not null,
 metric_id      integer not null,
 meas_date      timestamp not null,
 min_value      float,
 max_value      float,
 avg_value      float,
 total_value        float,
 sample_count       float,
       primary key (PRN_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_PRNQ_wk1 on AMY.F_PRN_WEEK (PRN_id);
create index AMY.f_PRNQ_wk2 on AMY.F_PRN_WEEK (host_id);
create index AMY.f_PRNQ_wk3 on AMY.F_PRN_WEEK (metric_id);
create index AMY.f_PRNQ_wk4 on AMY.F_PRN_WEEK (meas_date);
create index AMY.f_PRNQ_wk5 on AMY.F_PRN_WEEK (host_ip_ad_id);

alter table AMY.F_PRN_WEEK
add constraint K213
foreign key (PRN_id)
references AMY.D_PRINTER (PRN_id);

alter table AMY.F_PRN_WEEK
add constraint K214
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_PRN_WEEK
add constraint K215
foreign key (metric_id)
references AMY.D_PRN_METRIC (metric_id);

alter table AMY.F_PRN_WEEK
add constraint K341
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- monthly fact table: PRN
-----------------------------

create table AMY.F_PRN_MONTH (
 PRN_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (PRN_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_PRNQ_mo1 on AMY.F_PRN_MONTH (PRN_id);
create index AMY.f_PRNQ_mo2 on AMY.F_PRN_MONTH (host_id);
create index AMY.f_PRNQ_mo3 on AMY.F_PRN_MONTH (metric_id);
create index AMY.f_PRNQ_mo4 on AMY.F_PRN_MONTH (meas_date);
create index AMY.f_PRNQ_mo5 on AMY.F_PRN_MONTH (host_ip_ad_id);

alter table AMY.F_PRN_MONTH
add constraint K215
foreign key (PRN_id)
references AMY.D_PRINTER (PRN_id);

alter table AMY.F_PRN_MONTH
add constraint K216
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_PRN_MONTH
add constraint K217
foreign key (metric_id)
references AMY.D_PRN_METRIC (metric_id);

alter table AMY.F_PRN_MONTH
add constraint K342
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
--------------------
---  PROCESS
--------------------

-----------------------------
-- dimension table: PROCESS
-----------------------------

create table AMY.D_PROCESS (
 PROC_Nm    varchar(254),
 PROCESS_id         integer        not null,
      primary key (PROCESS_id));

-- translation table

create table AMY.T_PROCESS (
 PROC_Nm    varchar(254),
 orig_PROCESS_id         integer        not null,
 cdw_id          integer        not null,
 PROCESS_id              integer not null,
      primary key (orig_PROCESS_id,cdw_id)
      );

-- SEQUENCE

create sequence AMY.PROC_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.PROC_i1
no cascade before insert on AMY.d_PROCESS
referencing new as n for each row mode db2sql
set n.PROCESS_id = nextval for AMY.PROC_id_seq;


-----------------------------
-- staging hour fact table
------------------------------

create table AMY.STG_PROCESS_HR (
    msmt_id       integer not null,
    orig_PROCESS_id   integer not null,
    orig_host_id          integer not null,
    orig_metric_id        integer not null,
    cdw_id        integer not null,
    meas_hour             timestamp not null,
    min_value         float,
    max_value             float,
    avg_value             float,
    total_value       float,
    sample_count      float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: PROCESS
-----------------------------

create table AMY.F_PROCESS_HOUR (
 PROCESS_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_hour                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (PROCESS_id,
       host_id, host_ip_ad_id, metric_id,
       meas_hour)
       );

create index AMY.f_PROC_hr1 on AMY.F_PROCESS_HOUR (PROCESS_id);
create index AMY.f_PROC_hr2 on AMY.F_PROCESS_HOUR (host_id);
create index AMY.f_PROC_hr3 on AMY.F_PROCESS_HOUR (metric_id);
create index AMY.f_PROC_hr4 on AMY.F_PROCESS_HOUR (meas_hour);
create index AMY.f_PROC_hr5 on AMY.F_PROCESS_HOUR (host_ip_ad_id);

alter table AMY.F_PROCESS_HOUR
add constraint K218
foreign key (PROCESS_id)
references AMY.D_PROCESS (PROCESS_id);

alter table AMY.F_PROCESS_HOUR
add constraint K219
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_PROCESS_HOUR
add constraint K220
foreign key (metric_id)
references AMY.D_CPU_METRIC (metric_id);

alter table AMY.F_PROCESS_HOUR
add constraint K343
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- daily fact table: PROCESS
-----------------------------

create table AMY.F_PROCESS_DAY (
 PROCESS_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (PROCESS_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_PROC_day1 on AMY.F_PROCESS_DAY (PROCESS_id);
create index AMY.f_PROC_day2 on AMY.F_PROCESS_DAY (host_id);
create index AMY.f_PROC_day3 on AMY.F_PROCESS_DAY (metric_id);
create index AMY.f_PROC_day4 on AMY.F_PROCESS_DAY (meas_date);
create index AMY.f_PROC_day5 on AMY.F_PROCESS_DAY (host_ip_ad_id);

alter table AMY.F_PROCESS_DAY
add constraint K221
foreign key (PROCESS_id)
references AMY.D_PROCESS (PROCESS_id);

alter table AMY.F_PROCESS_DAY
add constraint K222
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_PROCESS_DAY
add constraint K223
foreign key (metric_id)
references AMY.D_CPU_METRIC (metric_id);

alter table AMY.F_PROCESS_DAY
add constraint K344
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- weekly fact table: PROCESS
-----------------------------

create table AMY.F_PROCESS_WEEK (
 PROCESS_id         integer not null,
 host_id        integer not null,
 host_ip_ad_id         integer not null,
 metric_id      integer not null,
 meas_date      timestamp not null,
 min_value      float,
 max_value      float,
 avg_value      float,
 total_value        float,
 sample_count       float,
       primary key (PROCESS_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_PROC_wk1 on AMY.F_PROCESS_WEEK (PROCESS_id);
create index AMY.f_PROC_wk2 on AMY.F_PROCESS_WEEK (host_id);
create index AMY.f_PROC_wk3 on AMY.F_PROCESS_WEEK (metric_id);
create index AMY.f_PROC_wk4 on AMY.F_PROCESS_WEEK (meas_date);
create index AMY.f_PROC_wk5 on AMY.F_PROCESS_WEEK (host_ip_ad_id);

alter table AMY.F_PROCESS_WEEK
add constraint K224
foreign key (PROCESS_id)
references AMY.D_PROCESS (PROCESS_id);

alter table AMY.F_PROCESS_WEEK
add constraint K225
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_PROCESS_WEEK
add constraint K226
foreign key (metric_id)
references AMY.D_CPU_METRIC (metric_id);

alter table AMY.F_PROCESS_WEEK
add constraint K345
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- monthly fact table: PROCESS
-----------------------------

create table AMY.F_PROCESS_MONTH (
 PROCESS_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (PROCESS_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_PROC_mo1 on AMY.F_PROCESS_MONTH (PROCESS_id);
create index AMY.f_PROC_mo2 on AMY.F_PROCESS_MONTH (host_id);
create index AMY.f_PROC_mo3 on AMY.F_PROCESS_MONTH (metric_id);
create index AMY.f_PROC_mo4 on AMY.F_PROCESS_MONTH (meas_date);
create index AMY.f_PROC_mo5 on AMY.F_PROCESS_MONTH (host_ip_ad_id);

alter table AMY.F_PROCESS_MONTH
add constraint K226
foreign key (PROCESS_id)
references AMY.D_PROCESS (PROCESS_id);

alter table AMY.F_PROCESS_MONTH
add constraint K227
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_PROCESS_MONTH
add constraint K228
foreign key (metric_id)
references AMY.D_CPU_METRIC (metric_id);

alter table AMY.F_PROCESS_MONTH
add constraint K346
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
--------------------
---  REDIR
--------------------

--------------------
---  RPC
--------------------

--------------------
---  SERVER
--------------------

---------------------------------
-- dimension table: SERVER metric
---------------------------------

create table AMY.d_SERVER_metric (
 metric_id                 integer        not null,
 met_category              varchar(254),
 met_desc              varchar(254),
 met_name              varchar(254)   not null,
 met_units             varchar(254),
 min_exists        char(1)        not null,
 max_exists        char(1)        not null,
 avg_exists        char(1)        not null,
 total_exists              char(1)        not null,
 msrc_nm           varchar(254),
      primary key (metric_id));


-- translation table

create table AMY.t_SERVER_metric (
  orig_metric_id        integer not null,
  metric_id             integer not null,
  cdw_id            integer not null,
  met_category                  varchar(254),
  met_desc                  varchar(254),
  met_name          varchar(254) not null,
  met_units             varchar(254),
  min_exists            char(1)        not null,
  max_exists            char(1)        not null,
  avg_exists            char(1)        not null,
  total_exists              char(1)        not null,
  msrc_nm           varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

-- SEQUENCE

create sequence AMY.SRVRmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.SRVRmt_i1
no cascade before insert on AMY.d_SERVER_metric
referencing new as n for each row mode db2sql
set n.metric_id = nextval for AMY.SRVRmt_id_seq;

-----------------------------
-- dimension table: SERVER
-----------------------------

create table AMY.D_SERVER (
 SERVER_Nm  varchar(254),
 SERVER_id      integer        not null,
      primary key (SERVER_id));

-- translation table

create table AMY.T_SERVER (
 SERVER_Nm  varchar(254),
 orig_SERVER_id         integer        not null,
 cdw_id          integer        not null,
 SERVER_id              integer not null,
      primary key (orig_SERVER_id,cdw_id)
      );

-- SEQUENCE

create sequence AMY.SRVR_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.SRVR_i1
no cascade before insert on AMY.d_SERVER
referencing new as n for each row mode db2sql
set n.SERVER_id = nextval for AMY.SRVR_id_seq;


-----------------------------
-- staging hour fact table
------------------------------

create table AMY.STG_SERVER_HR (
    msmt_id       integer not null,
    orig_SERVER_id   integer not null,
    orig_host_id          integer not null,
    orig_metric_id        integer not null,
    cdw_id        integer not null,
    meas_hour             timestamp not null,
    min_value         float,
    max_value             float,
    avg_value             float,
    total_value       float,
    sample_count      float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: SERVER
-----------------------------

create table AMY.F_SERVER_HOUR (
 SERVER_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_hour                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (SERVER_id,
       host_id, host_ip_ad_id, metric_id,
       meas_hour)
       );

create index AMY.f_SRVR_hr1 on AMY.F_SERVER_HOUR (SERVER_id);
create index AMY.f_SRVR_hr2 on AMY.F_SERVER_HOUR (host_id);
create index AMY.f_SRVR_hr3 on AMY.F_SERVER_HOUR (metric_id);
create index AMY.f_SRVR_hr4 on AMY.F_SERVER_HOUR (meas_hour);
create index AMY.f_SRVR_hr5 on AMY.F_SERVER_HOUR (host_ip_ad_id);

alter table AMY.F_SERVER_HOUR
add constraint K251
foreign key (SERVER_id)
references AMY.D_SERVER (SERVER_id);

alter table AMY.F_SERVER_HOUR
add constraint K252
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_SERVER_HOUR
add constraint K253
foreign key (metric_id)
references AMY.D_SERVER_METRIC (metric_id);

alter table AMY.F_SERVER_HOUR
add constraint K347
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- daily fact table: SERVER
-----------------------------

create table AMY.F_SERVER_DAY (
 SERVER_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (SERVER_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_SRVR_day1 on AMY.F_SERVER_DAY (SERVER_id);
create index AMY.f_SRVR_day2 on AMY.F_SERVER_DAY (host_id);
create index AMY.f_SRVR_day3 on AMY.F_SERVER_DAY (metric_id);
create index AMY.f_SRVR_day4 on AMY.F_SERVER_DAY (meas_date);
create index AMY.f_SRVR_day5 on AMY.F_SERVER_DAY (host_ip_ad_id);

alter table AMY.F_SERVER_DAY
add constraint K254
foreign key (SERVER_id)
references AMY.D_SERVER (SERVER_id);

alter table AMY.F_SERVER_DAY
add constraint K255
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_SERVER_DAY
add constraint K256
foreign key (metric_id)
references AMY.D_SERVER_METRIC (metric_id);

alter table AMY.F_SERVER_DAY
add constraint K348
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- weekly fact table: SERVER
-----------------------------

create table AMY.F_SERVER_WEEK (
 SERVER_id         integer not null,
 host_id        integer not null,
 host_ip_ad_id         integer not null,
 metric_id      integer not null,
 meas_date      timestamp not null,
 min_value      float,
 max_value      float,
 avg_value      float,
 total_value        float,
 sample_count       float,
       primary key (SERVER_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_SRVR_wk1 on AMY.F_SERVER_WEEK (SERVER_id);
create index AMY.f_SRVR_wk2 on AMY.F_SERVER_WEEK (host_id);
create index AMY.f_SRVR_wk3 on AMY.F_SERVER_WEEK (metric_id);
create index AMY.f_SRVR_wk4 on AMY.F_SERVER_WEEK (meas_date);
create index AMY.f_SRVR_wk5 on AMY.F_SERVER_WEEK (host_ip_ad_id);

alter table AMY.F_SERVER_WEEK
add constraint K257
foreign key (SERVER_id)
references AMY.D_SERVER (SERVER_id);

alter table AMY.F_SERVER_WEEK
add constraint K258
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_SERVER_WEEK
add constraint K259
foreign key (metric_id)
references AMY.D_SERVER_METRIC (metric_id);

alter table AMY.F_SERVER_WEEK
add constraint K349
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- monthly fact table: SERVER
-----------------------------

create table AMY.F_SERVER_MONTH (
 SERVER_id            integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (SERVER_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_SRVR_mo1 on AMY.F_SERVER_MONTH (SERVER_id);
create index AMY.f_SRVR_mo2 on AMY.F_SERVER_MONTH (host_id);
create index AMY.f_SRVR_mo3 on AMY.F_SERVER_MONTH (metric_id);
create index AMY.f_SRVR_mo4 on AMY.F_SERVER_MONTH (meas_date);
create index AMY.f_SRVR_mo5 on AMY.F_SERVER_MONTH (host_ip_ad_id);

alter table AMY.F_SERVER_MONTH
add constraint K259
foreign key (SERVER_id)
references AMY.D_SERVER (SERVER_id);

alter table AMY.F_SERVER_MONTH
add constraint K260
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_SERVER_MONTH
add constraint K261
foreign key (metric_id)
references AMY.D_SERVER_METRIC (metric_id);

alter table AMY.F_SERVER_MONTH
add constraint K350
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
--------------------
---  SERVICE
--------------------

--------------------
---  TCPIP
--------------------

--------------------
---  USER
--------------------

---------------------------------
-- dimension table: USER metric
---------------------------------

create table AMY.d_USER_metric (
 metric_id                 integer        not null,
 met_category              varchar(254),
 met_desc              varchar(254),
 met_name              varchar(254)   not null,
 met_units             varchar(254),
 min_exists        char(1)        not null,
 max_exists        char(1)        not null,
 avg_exists        char(1)        not null,
 total_exists              char(1)        not null,
 msrc_nm           varchar(254),
      primary key (metric_id));


-- translation table

create table AMY.t_USER_metric (
  orig_metric_id        integer not null,
  metric_id             integer not null,
  cdw_id            integer not null,
  met_category                  varchar(254),
  met_desc                  varchar(254),
  met_name          varchar(254) not null,
  met_units             varchar(254),
  min_exists            char(1)        not null,
  max_exists            char(1)        not null,
  avg_exists            char(1)        not null,
  total_exists              char(1)        not null,
  msrc_nm           varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

-- SEQUENCE

create sequence AMY.USERmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.USERmt_i1
no cascade before insert on AMY.d_USER_metric
referencing new as n for each row mode db2sql
set n.metric_id = nextval for AMY.USERmt_id_seq;

-----------------------------
-- dimension table: USER
-----------------------------

create table AMY.D_USER (
 USER_Nm    varchar(254),
 USER_id        integer        not null,
      primary key (USER_id));

-- translation table

create table AMY.T_USER (
 USER_Nm    varchar(254),
 orig_USER_id         integer        not null,
 cdw_id          integer        not null,
 USER_id              integer not null,
      primary key (orig_USER_id,cdw_id)
      );

-- SEQUENCE

create sequence AMY.USER_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.USER_i1
no cascade before insert on AMY.d_USER
referencing new as n for each row mode db2sql
set n.USER_id = nextval for AMY.USER_id_seq;


-----------------------------
-- dimension table:UserId
-----------------------------

create table AMY.D_UserId (
 UserId_id                 integer        not null,
 UserId                   varchar(254)   not null,
      primary key (UserId_ID));


-- SEQUENCE

create sequence AMY.UserId_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER

create trigger AMY.UserId_i1
no cascade before insert on AMY.d_UserId
referencing new as n for each row mode db2sql
set n.UserId_id = nextval for AMY.UserId_id_seq;

-----------------------------
-- staging hour fact table
------------------------------

create table AMY.STG_USER_HR (
    msmt_id       integer not null,
    orig_USER_id   integer not null,
    UserId    varchar(254) not null,
    orig_host_id          integer not null,
    orig_metric_id        integer not null,
    cdw_id        integer not null,
    meas_hour             timestamp not null,
    min_value         float,
    max_value             float,
    avg_value             float,
    total_value       float,
    sample_count      float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: USER
-----------------------------

create table AMY.F_USER_HOUR (
 USER_id            integer not null,
 UserId_id  integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_hour                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (USER_id,
       UserId_id,
       host_id, host_ip_ad_id, metric_id,
       meas_hour)
       );

create index AMY.f_USER_hr1 on AMY.F_USER_HOUR (USER_id);
create index AMY.f_USER_hr2 on AMY.F_USER_HOUR (host_id);
create index AMY.f_USER_hr3 on AMY.F_USER_HOUR (metric_id);
create index AMY.f_USER_hr4 on AMY.F_USER_HOUR (meas_hour);
create index AMY.f_USER_hr5 on AMY.F_USER_HOUR (UserId_id);
create index AMY.f_USER_hr6 on AMY.F_USER_HOUR (host_ip_ad_id);

alter table AMY.F_USER_HOUR
add constraint K288
foreign key (USER_id)
references AMY.D_USER (USER_id);

alter table AMY.F_USER_HOUR
add constraint K289
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_USER_HOUR
add constraint K290
foreign key (metric_id)
references AMY.D_USER_METRIC (metric_id);

alter table AMY.F_USER_HOUR
add constraint K299
foreign key (UserId_id)
references AMY.D_UserId (UserId_id);

alter table AMY.F_USER_HOUR
add constraint K351
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- daily fact table: USER
-----------------------------

create table AMY.F_USER_DAY (
 USER_id            integer not null,
 UserId_id  integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (USER_id,
       UserId_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_USER_day1 on AMY.F_USER_DAY (USER_id);
create index AMY.f_USER_day2 on AMY.F_USER_DAY (host_id);
create index AMY.f_USER_day3 on AMY.F_USER_DAY (metric_id);
create index AMY.f_USER_day4 on AMY.F_USER_DAY (meas_date);
create index AMY.f_USER_day5 on AMY.F_USER_DAY (UserId_id);
create index AMY.f_USER_day6 on AMY.F_USER_DAY (host_ip_ad_id);

alter table AMY.F_USER_DAY
add constraint K291
foreign key (USER_id)
references AMY.D_USER (USER_id);

alter table AMY.F_USER_DAY
add constraint K292
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_USER_DAY
add constraint K293
foreign key (metric_id)
references AMY.D_USER_METRIC (metric_id);

alter table AMY.F_USER_DAY
add constraint K300
foreign key (UserId_id)
references AMY.D_UserId (UserId_id);

alter table AMY.F_USER_DAY
add constraint K352
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- weekly fact table: USER
-----------------------------

create table AMY.F_USER_WEEK (
 USER_id         integer not null,
 UserId_id  integer not null,
 host_id        integer not null,
 host_ip_ad_id         integer not null,
 metric_id      integer not null,
 meas_date      timestamp not null,
 min_value      float,
 max_value      float,
 avg_value      float,
 total_value        float,
 sample_count       float,
       primary key (USER_id,
       UserId_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_USER_wk1 on AMY.F_USER_WEEK (USER_id);
create index AMY.f_USER_wk2 on AMY.F_USER_WEEK (host_id);
create index AMY.f_USER_wk3 on AMY.F_USER_WEEK (metric_id);
create index AMY.f_USER_wk4 on AMY.F_USER_WEEK (meas_date);
create index AMY.f_USER_wk5 on AMY.F_USER_WEEK (UserId_id);
create index AMY.f_USER_wk6 on AMY.F_USER_WEEK (host_ip_ad_id);

alter table AMY.F_USER_WEEK
add constraint K294
foreign key (USER_id)
references AMY.D_USER (USER_id);

alter table AMY.F_USER_WEEK
add constraint K295
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_USER_WEEK
add constraint K296
foreign key (metric_id)
references AMY.D_USER_METRIC (metric_id);

alter table AMY.F_USER_WEEK
add constraint K301
foreign key (UserId_id)
references AMY.D_UserId (UserId_id);

alter table AMY.F_USER_WEEK
add constraint K353
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);
-----------------------------
-- monthly fact table: USER
-----------------------------

create table AMY.F_USER_MONTH (
 USER_id            integer not null,
 UserId_id  integer not null,
 host_id                   integer not null,
 host_ip_ad_id         integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value         float,
 max_value             float,
 avg_value             float,
 total_value           float,
 sample_count              float,
       primary key (USER_id,
       UserId_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
       );

create index AMY.f_USER_mo1 on AMY.F_USER_MONTH (USER_id);
create index AMY.f_USER_mo2 on AMY.F_USER_MONTH (host_id);
create index AMY.f_USER_mo3 on AMY.F_USER_MONTH (metric_id);
create index AMY.f_USER_mo4 on AMY.F_USER_MONTH (meas_date);
create index AMY.f_USER_mo5 on AMY.F_USER_MONTH (UserId_id);
create index AMY.f_USER_mo6 on AMY.F_USER_MONTH (host_ip_ad_id);

alter table AMY.F_USER_MONTH
add constraint K296
foreign key (USER_id)
references AMY.D_USER (USER_id);

alter table AMY.F_USER_MONTH
add constraint K297
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_USER_MONTH
add constraint K298
foreign key (metric_id)
references AMY.D_USER_METRIC (metric_id);

alter table AMY.F_USER_MONTH
add constraint K302
foreign key (UserId_id)
references AMY.D_UserId (UserId_id);

alter table AMY.F_USER_MONTH
add constraint K354
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

--#endtag fixpack_500

--#iftag fixpack_600

--------------------
--- Host
--------------------

create index AMY.host_ip_ad1 on AMY.d_host_ip_ad (host_ip_ad);  

--------------------
---  SYSTEM
--------------------

---------------------------------
-- dimension table: SYSTEM metric
---------------------------------

create table AMY.d_SYSTEM_metric (
 metric_id         integer        not null,
 met_category      varchar(254),
 met_desc          varchar(254),
 met_name          varchar(254)   not null,
 met_units         varchar(254),
 min_exists        char(1)        not null,
 max_exists        char(1)        not null,
 avg_exists        char(1)        not null,
 total_exists      char(1)        not null,
 msrc_nm           varchar(254),
      primary key (metric_id)
);

-- translation table
create table AMY.t_SYSTEM_metric (
  orig_metric_id    integer       not null,
  metric_id         integer       not null,
  cdw_id            integer       not null,
  met_category      varchar(254),
  met_desc          varchar(254),
  met_name          varchar(254)  not null,
  met_units         varchar(254),
  min_exists        char(1)       not null,
  max_exists        char(1)       not null,
  avg_exists        char(1)       not null,
  total_exists      char(1)       not null,
  msrc_nm           varchar(254),
    primary key (orig_metric_id, cdw_id)
);

-- SEQUENCE
create sequence AMY.SYSmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER
create trigger AMY.SYSmt_i1
no cascade before insert on AMY.d_SYSTEM_metric
referencing new as n for each row mode db2sql
set n.metric_id = nextval for AMY.SYSmt_id_seq;

-----------------------------
-- dimension table: SYSTEM
-----------------------------

create table AMY.D_SYSTEM (
 SYSTEM_Nm varchar(254),
 SYSTEM_Type   varchar(254),
 SYSTEM_id     integer  not null,
      primary key (SYSTEM_id)
);

-- translation table
create table AMY.T_SYSTEM (
 SYSTEM_Nm varchar(254),
 SYSTEM_Type     varchar(254),
 orig_SYSTEM_id  integer   not null,
 cdw_id       integer   not null,
 SYSTEM_id       integer   not null,
      primary key (orig_SYSTEM_id,cdw_id)
);

-- SEQUENCE
create sequence AMY.SYSTEM_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

-- TRIGGER
create trigger AMY.SYSTEM_i1
no cascade before insert on AMY.d_SYSTEM
referencing new as n for each row mode db2sql
set n.SYSTEM_id = nextval for AMY.SYSTEM_id_seq;

-----------------------------
-- staging hour fact table
-----------------------------

create table AMY.STG_SYSTEM_HR (
    msmt_id         integer   not null,
    orig_SYSTEM_id     integer   not null,
    orig_host_id    integer   not null,
    orig_metric_id  integer   not null,
    cdw_id          integer   not null,
    meas_hour       timestamp not null,
    min_value       float,
    max_value       float,
    avg_value       float,
    total_value     float,
    sample_count    float,
       primary key (msmt_id,cdw_id)
);

----------------------------
-- hourly fact table: SYSTEM
----------------------------

create table AMY.F_SYSTEM_HOUR (
 SYSTEM_id          integer   not null,
 host_id         integer   not null,
 host_ip_ad_id   integer   not null,
 metric_id       integer   not null,
 meas_hour       timestamp not null,
 min_value       float,
 max_value       float,
 avg_value       float,
 total_value     float,
 sample_count    float,
       primary key (SYSTEM_id,
       host_id, host_ip_ad_id, metric_id,
       meas_hour)
);

create index AMY.f_SYSTEM_hr1 on AMY.F_SYSTEM_HOUR (SYSTEM_id);
create index AMY.f_SYSTEM_hr2 on AMY.F_SYSTEM_HOUR (host_id);
create index AMY.f_SYSTEM_hr3 on AMY.F_SYSTEM_HOUR (metric_id);
create index AMY.f_SYSTEM_hr4 on AMY.F_SYSTEM_HOUR (meas_hour);
create index AMY.f_SYSTEM_hr5 on AMY.F_SYSTEM_HOUR (host_ip_ad_id);

alter table AMY.F_SYSTEM_HOUR
add constraint K355
foreign key (SYSTEM_id)
references AMY.D_SYSTEM (SYSTEM_id);

alter table AMY.F_SYSTEM_HOUR
add constraint K356
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_SYSTEM_HOUR
add constraint K357
foreign key (metric_id)
references AMY.D_SYSTEM_METRIC (metric_id);

alter table AMY.F_SYSTEM_HOUR
add constraint K358
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- daily fact table: SYSTEM
-----------------------------

create table AMY.F_SYSTEM_DAY (
 SYSTEM_id          integer not null,
 host_id         integer not null,
 host_ip_ad_id   integer not null,
 metric_id       integer not null,
 meas_date       timestamp not null,
 min_value       float,
 max_value       float,
 avg_value       float,
 total_value     float,
 sample_count    float,
       primary key (SYSTEM_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
);

create index AMY.f_SYSTEM_day1 on AMY.F_SYSTEM_DAY (SYSTEM_id);
create index AMY.f_SYSTEM_day2 on AMY.F_SYSTEM_DAY (host_id);
create index AMY.f_SYSTEM_day3 on AMY.F_SYSTEM_DAY (metric_id);
create index AMY.f_SYSTEM_day4 on AMY.F_SYSTEM_DAY (meas_date);
create index AMY.f_SYSTEM_day5 on AMY.F_SYSTEM_DAY (host_ip_ad_id);

alter table AMY.F_SYSTEM_DAY
add constraint K359
foreign key (SYSTEM_id)
references AMY.D_SYSTEM (SYSTEM_id);

alter table AMY.F_SYSTEM_DAY
add constraint K360
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_SYSTEM_DAY
add constraint K361
foreign key (metric_id)
references AMY.D_SYSTEM_METRIC (metric_id);

alter table AMY.F_SYSTEM_DAY
add constraint K362
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- weekly fact table: SYSTEM
-----------------------------

create table AMY.F_SYSTEM_WEEK (
 SYSTEM_id         integer not null,
 host_id        integer not null,
 host_ip_ad_id  integer not null,
 metric_id      integer not null,
 meas_date      timestamp not null,
 min_value      float,
 max_value      float,
 avg_value      float,
 total_value    float,
 sample_count   float,
       primary key (SYSTEM_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
);

create index AMY.f_SYSTEM_wk1 on AMY.F_SYSTEM_WEEK (SYSTEM_id);
create index AMY.f_SYSTEM_wk2 on AMY.F_SYSTEM_WEEK (host_id);
create index AMY.f_SYSTEM_wk3 on AMY.F_SYSTEM_WEEK (metric_id);
create index AMY.f_SYSTEM_wk4 on AMY.F_SYSTEM_WEEK (meas_date);
create index AMY.f_SYSTEM_wk5 on AMY.F_SYSTEM_WEEK (host_ip_ad_id);

alter table AMY.F_SYSTEM_WEEK
add constraint K363
foreign key (SYSTEM_id)
references AMY.D_SYSTEM (SYSTEM_id);

alter table AMY.F_SYSTEM_WEEK
add constraint K364
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_SYSTEM_WEEK
add constraint K365
foreign key (metric_id)
references AMY.D_SYSTEM_METRIC (metric_id);

alter table AMY.F_SYSTEM_WEEK
add constraint K366
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

-----------------------------
-- monthly fact table: SYSTEM
-----------------------------

create table AMY.F_SYSTEM_MONTH (
 SYSTEM_id            integer not null,
 host_id           integer not null,
 host_ip_ad_id     integer not null,
 metric_id         integer not null,
 meas_date         timestamp not null,
 min_value         float,
 max_value         float,
 avg_value         float,
 total_value       float,
 sample_count      float,
       primary key (SYSTEM_id,
       host_id, host_ip_ad_id, metric_id,
       meas_date)
);

create index AMY.f_SYSTEM_mo1 on AMY.F_SYSTEM_MONTH (SYSTEM_id);
create index AMY.f_SYSTEM_mo2 on AMY.F_SYSTEM_MONTH (host_id);
create index AMY.f_SYSTEM_mo3 on AMY.F_SYSTEM_MONTH (metric_id);
create index AMY.f_SYSTEM_mo4 on AMY.F_SYSTEM_MONTH (meas_date);
create index AMY.f_SYSTEM_mo5 on AMY.F_SYSTEM_MONTH (host_ip_ad_id);

alter table AMY.F_SYSTEM_MONTH
add constraint K367
foreign key (SYSTEM_id)
references AMY.D_SYSTEM (SYSTEM_id);

alter table AMY.F_SYSTEM_MONTH
add constraint K368
foreign key (host_id)
references AMY.D_HOST_IP (host_id);

alter table AMY.F_SYSTEM_MONTH
add constraint K369
foreign key (metric_id)
references AMY.D_SYSTEM_METRIC (metric_id);

alter table AMY.F_SYSTEM_MONTH
add constraint K370
foreign key (host_ip_ad_id)
references AMY.D_HOST_IP_AD (host_ip_ad_id);

--#endtag fixpack_600

--#iftag fixpack_660
-- do nothing...
--#endtag fixpack_660